(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   2051853,      55233]
NotebookOptionsPosition[   1916217,      53154]
NotebookOutlinePosition[   1916865,      53175]
CellTagsIndexPosition[   1916822,      53172]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.759061079395566*^9, 
  3.75906108022565*^9}},ExpressionUUID->"46e16825-9137-474e-8a90-\
926dc5d4657e"],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["\n",
  FontSize->12],
 "\t\t\n",
 StyleBox["RIEMANNIAN GEOMETRY & TENSOR CALCULUS\n",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox["A set of functions for tensor calculations in Riemannian Geometry \
and General Relativity\n",
  FontSize->16]
}], "Text",
 ShowGroupOpener->True,
 TextAlignment->Center,
 TextJustification->0,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"93712e9f-463d-418a-aa7e-ede3df646b0f"],

Cell["version 3.8.9 - May 2013", "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Times",
 FontSize->14,
 FontSlant->"Italic"],

Cell[TextData[{
 StyleBox["\n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ButtonBox["S. Bonanos",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/SB.html"], None}],
 StyleBox["\n",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontWeight->"Bold"],
 StyleBox[ButtonBox["Institute of Nuclear Physics",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/"], None}],
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[",  ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[ButtonBox["NCSR \"Demokritos\"",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.demokritos.gr/index_muk.asp"], None}],
  FontSlant->"Italic"],
 StyleBox[", \nAghia Paraskevi 15310, Greece. ",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["\n",
  FontWeight->"Bold"],
 "Please send comments, suggestions, bug reports to:  ",
 ButtonBox["sbonano@inp.demokritos.gr",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["mailto:sbonano@inp.demokritos.gr"], None}],
 StyleBox[" \t",
  FontWeight->"Bold"]
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Times",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 "\[CapitalDelta]\[Omega]\[Rho]\[Epsilon]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "`"],
   FontFamily->"Times"]],ExpressionUUID->
  "24ca4384-d95f-4192-9bae-99901c84f207"],
 "\[Nu] \[Epsilon]\[Lambda]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "'"],
   FontFamily->"Times"]],ExpressionUUID->
  "8411ef51-9cf9-48d6-ad67-4f0fad1a60a6"],
 "\[Beta]\[Epsilon]\[Tau]\[Epsilon], \[Delta]\[Omega]\[Rho]\[Epsilon]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["\[Alpha]", "`"],
   FontFamily->"Times"]],ExpressionUUID->
  "fa7157d4-992b-45ef-9b1d-4d71a0939f7c"],
 "\[Nu] \[Delta]",
 Cell[BoxData[
  StyleBox[
   OverscriptBox["o", "'"],
   FontFamily->"Times"]],ExpressionUUID->
  "58e12e2c-1123-42a4-8422-e378d1f59fbb"],
 "\[Tau]\[Epsilon]."
}], "Text",
 TextAlignment->Center,
 TextJustification->0,
 FontFamily->"Helvetica",
 FontSize->24,
 FontColor->GrayLevel[
  1],ExpressionUUID->"873d17d5-d20d-454f-9abb-c61f78b0b6bd"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 1  Instructions",
 FontWeight->"Bold"]], "Section",
 ShowGroupOpener->True,
 FontSize->24,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"173c2924-6d97-4a8d-a555-e9aae66fa09a"],

Cell[CellGroupData[{

Cell["  1.0  Introduction", "Subsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold"],
 "This package allows calculations in Riemannian Geometry by defining all \
basic tensors and tensor operations. Tensors are represented as nested lists \
of their components in a particular frame (default = coordinate frame). \
Functions are defined for Raising/Lowering indices, Contracting (multiple) \
indices on one (or between two) tensors, for Covariant and Lie \
Differentiation and for classifying the Weyl and Ricci tensors. One can also \
use standard ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions like ",
 StyleBox["Dot",
  FontFamily->"Courier"],
 " or ",
 StyleBox["Outer",
  FontFamily->"Courier"],
 " (giving tensor products), and ",
 StyleBox["Transpose",
  FontFamily->"Courier"],
 " (index rearrangement) to create new (lists representing) tensors. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\tGiven a metric and a set of coordinates, the main routine in the package \
computes explicit expressions for all common Riemannian Geometry tensors \
(Riemann, Ricci, Einstein, Weyl) and tests if the space belongs to any of the \
following categories: ",
 StyleBox["Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Conformally Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Ricci Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Einstein Space",
  FontSlant->"Italic"],
 " or ",
 StyleBox["Space of Constant Curvature",
  FontSlant->"Italic"],
 ". Each tensor is stored as a nested list under an appropriate global name. \
One can optionally specify a frame (if different from the coordinate frame) \
with respect to which tensor components are to be computed. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tThe Riemann and Ricci tensor sign conventions used are:  ",
 Cell[BoxData[
  TagBox[
   SubscriptBox["V", 
    RowBox[{"b", ";", "c", ";", "d"}]],
   DisplayForm]]],
 " - ",
 Cell[BoxData[
  TagBox[
   SubscriptBox["V", 
    RowBox[{"b", ";", "d", ";", "c"}]],
   DisplayForm]]],
 " = ",
 Cell[BoxData[
  SubscriptBox["V", "a"]]],
 StyleBox[" ",
  FontSize->12],
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "bcd"],
   DisplayForm]]],
 " and ",
 Cell[BoxData[
  SubscriptBox["R", "ab"]]],
 " = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "s"], "asb"],
   DisplayForm]]],
 ", so that Einstein's equations are ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["R", "ab"], "-", 
    RowBox[{
     FractionBox["1", "2"], "R", " ", 
     SubscriptBox["g", "ab"]}]}], "=", 
   RowBox[{
    RowBox[{"+", "\[Kappa]"}], " ", 
    SubscriptBox["T", "ab"]}]}]]],
 " (",
 Cell[BoxData[
  RowBox[{"\[Kappa]", "=", 
   RowBox[{"8", " ", "\[Pi]", " ", 
    RowBox[{"G", "/", 
     SuperscriptBox["c", "4"]}]}]}]]],
 ")."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.1  Basic Input /Output & Notation", "Subsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 StyleBox["\t",
  FontWeight->"Bold"],
 "To define the geometry, begin by computing all basic Riemannian Geometry \
tensors for a particular metric. To do this:\n",
 StyleBox["\t ",
  FontWeight->"Bold"],
 "(0) In a new notebook, evaluate the initialization code: ",
 StyleBox["<<EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "\n\t (1) Define a list symbols (coordinate names) and give it a name -- say \
",
 StyleBox["xIN",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["=",
  FontFamily->"Courier",
  FontSize->18],
 StyleBox["{t,r,\[Theta],\[Phi]};",
  FontFamily->"Courier"],
 "\n\t (2) Define a symmetric matrix (list of lists) of functions of the \
coordinates (the metric) and give it a name -- say \n",
 StyleBox["gIN",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["={{1-2M/r,0,0,0},{0,-1/(1-2M/r),0,0},{0,0,-r^2,0},{0,0,0,-(r^2 \
Sin[\[Theta]]^2)}};",
  FontFamily->"Courier"],
 "\n\t(3) Assign appropriate simplification rules to the global list ",
 StyleBox["simpRules",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"],
 " as needed (see Examples and Usage Tips). For example: ",
 StyleBox["simpRules={",
  FontFamily->"Courier"],
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "^", "2"}], "+", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}], "->", "1"}],
   FontFamily->"Courier"]]],
 StyleBox["};",
  FontFamily->"Courier"],
 "\n\t(4) Evaluate ",
 StyleBox["RGtensors[gIN,xIN]",
  FontFamily->"Courier",
  FontSize->18,
  FontWeight->"Bold"]
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 "\t",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 "  computes all common Riemannian Geometry tensors, printing messages along \
the way. It also tests if the space is ",
 StyleBox["Flat,",
  FontSlant->"Italic"],
 " ",
 StyleBox["Conformally Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Ricci Flat",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Einstein Space",
  FontSlant->"Italic"],
 " or ",
 StyleBox["Space of Constant Curvature",
  FontSlant->"Italic"],
 " and, if yes, prints corresponding messages. When it is finished, the \
following \"tensors\" -- nested lists -- are stored in memory and can be used \
in further calculations (the letters U, d  in the tensor names serve as \
mnemonic devices for the position -- ",
 StyleBox["Up",
  FontSlant->"Italic"],
 " or ",
 StyleBox["down",
  FontSlant->"Italic"],
 " -- of the relevant indices) :"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["gdd",
  FontFamily->"Courier"],
 " (covariant form of the metric tensor), with components gdd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["g", "ab"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["gUU",
  FontFamily->"Courier"],
 " (contravariant form of the metric tensor), with components gUU[[a,b]] = ",
 Cell[BoxData[
  SuperscriptBox["g", "ab"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["GUdd",
  FontFamily->"Courier"],
 " (Christoffel symbols of the 2nd kind), with components GUdd[[a,b,c]] = ",
 Cell[BoxData[
  TagBox[
   SubsuperscriptBox["\[CapitalGamma]", "bc", "a"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Rdddd",
  FontFamily->"Courier"],
 " (covariant form of the Riemann tensor), with components Rdddd[[a,b,c,d]] = \
",
 Cell[BoxData[
  TagBox[
   SubscriptBox["R", "abcd"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["RUddd",
  FontFamily->"Courier"],
 " (mixed form of the Riemann tensor), with components RUddd[[a,b,c,d]] = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "bcd"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Rdd",
  FontFamily->"Courier"],
 " (covariant form of the Ricci tensor), with components Rdd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["R", "ab"]]],
 " \[Congruent] ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "s"], "asb"],
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["EUd",
  FontFamily->"Courier"],
 " (mixed form of the Einstein tensor), with components EUd[[a,b]] = ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["E", "a"], "b"],
   DisplayForm]]],
 " \[Congruent] ",
 Cell[BoxData[
  TagBox[
   SubscriptBox[
    SuperscriptBox["R", "a"], "b"],
   DisplayForm]]],
 "- ",
 StyleBox["R/2",
  FontFamily->"Courier"],
 " ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["\[Delta]", "a"], "b"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["R",
  FontFamily->"Courier"],
 " is the curvature scalar    (",
 StyleBox["Important: Do not use the symbol R in coordinates or metric!",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ")"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Wdddd",
  FontFamily->"Courier"],
 " (covariant form of the Weyl tensor), with components Wdddd[[a,b,c,d]] = ",
 Cell[BoxData[
  SubscriptBox["W", "abcd"]]]
}], "Text",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tFinally, ",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 " defines the following global variables: (i) ",
 StyleBox["coordList",
  FontFamily->"Courier"],
 " contains the coordinates defined in (1) above, (ii) ",
 StyleBox["detg",
  FontFamily->"Courier"],
 " is the determinant of the metric, (iii) ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " stores the dimension of the space and (iv) ",
 StyleBox["LineElement",
  FontFamily->"Courier"],
 " stores, of course, the line element! Tensor components refer to the \
coordinate frame and are numbered ",
 StyleBox["1,...,Dim",
  FontFamily->"Courier"],
 ", rather than ",
 StyleBox["0,...,Dim-1",
  FontFamily->"Courier"],
 ", so that the {i,j...k} component of a tensor is the [[i,j...k]] part of \
the corresponding nested list. See section 5, \"",
 StyleBox["Calculating Tensor Components in an Arbitrary Frame",
  FontSlant->"Italic"],
 "\", on how to do calculations in an arbitrary frame. "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": One can choose to skip the most time consuming computations: RUddd, Wdddd \
or EUd. This can be achieved by calling ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 "  with an optional extra argument -- a list of three numbers ",
 StyleBox["{i,j,k}",
  FontFamily->"Courier"],
 ". When the first number is 0, RUddd is not computed; when the second number \
is 0, Wdddd is not computed; and when the third number is 0, EUd is not \
computed. Thus ",
 StyleBox["RGtensors[gIN,xIN,{1,0,0}]",
  FontFamily->"Courier"],
 "  will compute RUddd but not Wdddd or EUd (See Examples 7 and 8). ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " prints warning messages when some tensors are not computed. When EUd is \
not computed, the tests for ",
 StyleBox["Einstein Space",
  FontSlant->"Italic"],
 " and ",
 StyleBox["Space of Constant Curvature",
  FontSlant->"Italic"],
 " are not performed. For compatibility with previous versions of RGTC, the \
optional extra argument can consist of only two numbers corresponding to \
RUddd and Wdddd. Thus ",
 StyleBox["RGtensors[gIN,xIN,{1,0}]",
  FontFamily->"Courier"],
 " is equivalent to ",
 StyleBox["RGtensors[gIN,xIN,{1,0,1}]",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell["\t1.1.1  Totally antisymmetric symbol / tensor", "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t Definitions for the totally antisymmetric symbol ",
 Cell[BoxData[
  SubscriptBox["\[CurlyEpsilon]", 
   RowBox[{
    RowBox[{"a1", "..."}], "an"}]]]],
 " and tensor  ",
 Cell[BoxData[
  SubscriptBox["\[Eta]", 
   RowBox[{
    RowBox[{"a1", "..."}], "an"}]]]],
 " are provided, but the tensor is not evaluated unless called by the user. \
As the number of indices on these objects equals the dimension of the \
mannifold, the U/d notation cannot be used. Instead, the following global \
names are used:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t ",
 StyleBox["epsilon",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a ",
 StyleBox["function",
  FontSlant->"Italic"],
 " that takes ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " integers as arguments and returns one of { 0, 1, -1} - the sign of the \
permutation of the arguments. For example, in 5 dimensions,"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["epsilon[1,2,3,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns 1,  ",
 StyleBox["epsilon[1,3,2,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns -1, and  ",
 StyleBox["epsilon[1,2,2,4,5]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "returns 0."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["eta[]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " can take 0 to ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 " arguments and returns the ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "-rank antisymmetric tensor with raised indices at the position(s) indicated \
by the argument(s). Thus ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " is the totally covariant antisymmetric tensor, with components"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["eta[][[a1,a2,...,an]]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  SuperscriptBox[
   RowBox[{"(", 
    RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], ")"}], 
   
   RowBox[{"1", "/", "2"}]]]],
 StyleBox["epsilon[a1,a2,...,an]",
  FontFamily->"Courier"],
 ", "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "while"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["eta[2,3][[a1,a2,...,an]]=",
  FontFamily->"Courier"],
 Cell[BoxData[
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"\[LeftBracketingBar]", "detg", "\[RightBracketingBar]"}], ")"}], 
    RowBox[{"1", "/", "2"}]], 
   SuperscriptBox["g", 
    RowBox[{"a2", " ", "b2"}]]}]]],
 Cell[BoxData[
  SuperscriptBox["g", 
   RowBox[{"a3", " ", "b3"}]]]],
 StyleBox["epsilon[a1,b2,b3,..,an]",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Warning",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 ": The evaluation of ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " tensors (",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "-fold nested lists) is ",
 StyleBox["very",
  FontSlant->"Italic"],
 " time consuming in high dimensions as the number of components grows as ",
 Cell[BoxData[
  SuperscriptBox["Dim", "Dim"]]],
 ". It also requires large amounts of memory. For example, for the simple \
case of a conformally flat metric, the {Time, Storage} requirements for \
computing ",
 StyleBox["each",
  FontSlant->"Italic"],
 " ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " grow as follows: ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "{~1 sec, <1 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=6, {~20 sec, ~7 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=7, and {> 10 min, >120 MB} for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=8! Thus, calculations with ",
 StyleBox["eta[]",
  FontFamily->"Courier"],
 " should not be attempted if ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 ">7. Fortunately, for ",
 StyleBox["Dim",
  FontFamily->"Courier"],
 "=4 the requirements are quite modest, even for complicated metrics."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tOnce the basic tensors have been computed, one can use the functions \
defined in the following sections to perform further calculations."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.2  Manipulation of tensor indices & tensor products", "Subsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\tThe ",
 StyleBox["first",
  FontSlant->"Italic"],
 " or ",
 StyleBox["last",
  FontSlant->"Italic"],
 " index of a tensor can be raised / lowered by inner (",
 StyleBox["Dot",
  FontWeight->"Bold"],
 ") multiplication with gUU / gdd:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t     ",
 StyleBox["Edd=gdd.EUd",
  FontFamily->"Courier"],
 " has components Edd[[a,b]] = ",
 Cell[BoxData[
  SubscriptBox["E", "ab"]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t     ",
 StyleBox["WdddU=Wdddd.gUU",
  FontFamily->"Courier"],
 " has components WdddU[[a,b,c,d]] = ",
 Cell[BoxData[
  TagBox[
   SuperscriptBox[
    SubscriptBox["W", "abc"], "d"],
   DisplayForm]]],
 ".",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tTo manipulate other indices the following functions have been defined:"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["Lower[x_,ni__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ":: lowers the index (indices) at position(s) ",
 StyleBox["ni",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (assumed U) of the nested list ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " using the matrix  gdd."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["Raise[x_,ni__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ":: raises the index (indices) at position(s) ",
 StyleBox["ni",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " (assumed d) of the nested list ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " using the matrix  gUU."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tFor example, the mixed Riemann tensor with  components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox[
    SubscriptBox[
     SuperscriptBox["R", "a"], "b"], "c"], "d"]]],
 "  is  ",
 StyleBox["RUdUd=Raise[RUddd,3]",
  FontFamily->"Courier"],
 ", ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "while  RUUUd",
 StyleBox["=Raise[RUddd,2,3]",
  FontFamily->"Courier"],
 "  has components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "abc"], "d"]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note",
  FontSlant->"Italic"],
 ": The functions ",
 StyleBox["Raise",
  FontWeight->"Bold"],
 " / ",
 StyleBox["Lower",
  FontWeight->"Bold"],
 " apply the rules in ",
 StyleBox["simpRules",
  FontWeight->"Bold"],
 " and factor the expressions obtained. Thus ",
 StyleBox["Raise[RUddd,4]",
  FontFamily->"Courier"],
 " is equivalent but not identical to ",
 StyleBox["RUddd.gUU",
  FontFamily->"Courier"],
 ". "
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tTensor products are obtained by using the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Outer",
  FontWeight->"Bold"],
 ". For example,"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["gg=Outer[Times,gdd,gdd];",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 4th rank (d-type) tensor with components ",
 StyleBox["gg[[a,b,c,d]]=",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["g", "ab"]}]],
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", "cd"]],
  FontWeight->"Bold"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\tUsing the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Transpose",
  FontWeight->"Bold"],
 ",  one can then define the tensor: ",
 StyleBox["gxg",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "=",
 StyleBox["gg-Transpose[gg,{1,3,2,4}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[",",
  FontVariations->{"CompatibilityType"->0}],
 " ",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "which has components  ",
 StyleBox["gxg[[a,b,c,d]]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox[" = ",
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", "ab"]],
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", 
   RowBox[{"cd", " "}]]],
  FontWeight->"Bold"],
 StyleBox["-",
  FontWeight->"Bold"],
 Cell[BoxData[
  RowBox[{" ", 
   SubscriptBox["g", "ac"]}]],
  FontWeight->"Bold"],
 Cell[BoxData[
  SubscriptBox["g", "bd"]],
  FontWeight->"Bold"],
 ".\n"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.3  Contraction of tensor indices", "Subsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\[FilledSmallCircle]\tThe function  ",
 StyleBox["Contract[x_,{i1_,j1_},{i2_,j2_},..]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  takes as arguments an nth rank tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ", and one or more lists of  pairs of numbers, indicating the positions of \
the indices to be contracted. It returns a tensor of rank ",
 StyleBox["n-2k",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is the number of index-pair lists. ",
 StyleBox["It is assumed that the two numbers in each list refer to one U and \
one d type index, in any order",
  FontSlant->"Italic"],
 ".  Examples (the Einstein summation convention holds):"
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(a) ",
 StyleBox["Contract[GUdd,{1,3}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  gives a d-type vector with components ",
 Cell[BoxData[
  TagBox[
   SubsuperscriptBox["\[CapitalGamma]", "ba", "a"],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(b) ",
 StyleBox["Contract[RUddd,{1,3}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  gives Rdd."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(c) ",
 StyleBox["Contract[Outer[Times,RUddd,RUddd],{1,7},{4,5}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  produces a dddd tensor with components ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "s"], "abt"]]],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "t"], "csd"]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Note1",
  FontSlant->"Italic"],
 ": Even though the last result can be obtained by calling ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 " twice, each time with a single pair of indices, it is ",
 StyleBox["much",
  FontSlant->"Italic"],
 " more efficient to perform multiple contractions simultaneously, as \
above.",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Note2",
  FontSlant->"Italic"],
 ": The result of (c) can also be obtained as  ",
 StyleBox["Contract[RUddd.RUddd,{1,5}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", since the ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function ",
 StyleBox["Dot",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " performs the ",
 StyleBox["{4,5}",
  FontFamily->"Courier"],
 " contraction of the outer product (last index of first tensor with first \
index of second tensor) giving a 6th rank tensor.",
 Cell[BoxData[
  TagBox["",
   DisplayForm]]]
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\[FilledSmallCircle]\tThe function ",
 StyleBox["multiDot[x_,y_,{i1_,j1_},{i2_,j2_},..]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is similar to ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 ", and generalizes the built-in function ",
 StyleBox["Dot",
  FontFamily->"Courier"],
 ".  It takes as arguments ",
 StyleBox["two",
  FontSlant->"Italic"],
 " tensors -- ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " -- and one or more lists of  pairs of numbers.  For each pair of numbers \
",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 ", it contracts the ",
 StyleBox["i",
  FontWeight->"Bold"],
 "th index of the ",
 StyleBox["first",
  FontSlant->"Italic"],
 " tensor (",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ") with the ",
 StyleBox["j",
  FontWeight->"Bold"],
 "th index of the ",
 StyleBox["second",
  FontSlant->"Italic"],
 " tensor (",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "),  returning a tensor of rank ",
 StyleBox["m+n-2k",
  FontSlant->"Italic"],
 ", where ",
 StyleBox["m",
  FontSlant->"Italic"],
 ", ",
 StyleBox["n",
  FontSlant->"Italic"],
 " are the ranks of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", ",
 StyleBox["y",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", respectively, and ",
 StyleBox["k",
  FontSlant->"Italic"],
 " is the number of index pairs. Again, it is assumed that the indices at ",
 StyleBox["{i,j}",
  FontFamily->"Courier"],
 " are of opposite (U/d) types. Using ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 ", the result of example (c) above can also be obtained as  ",
 StyleBox["multiDot[RUddd,RUddd,{1,3},{4,1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ".",
 Cell[BoxData[
  FormBox["", TextForm]], ""],
 Cell[BoxData[
  FormBox["", TextForm]], ""]
}], "Text",
 FontSize->16],

Cell[TextData[{
 StyleBox["\tNote1:",
  FontSlant->"Italic"],
 " When contracting a product of two tensors, as in example (c), one should \
always use ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 " to perform the contractions, thus avoiding the outer product calculation, \
which is very time / memory consuming. See also Example 1a in section 3 and \
Example 4b in Section 5.1",
 Cell[BoxData[
  FormBox["", TextForm]], 
  "\.02\[YAcute]\t\[OSlash]\.03\.08\[CapitalCCedilla]`\.03\.08\
\[CapitalCCedilla]`"]
}], "Text",
 FontSize->16],

Cell[TextData[{
 StyleBox["\tNote2:",
  FontSlant->"Italic"],
 " One can use ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 " and ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 " to contract nested lists with unequal index dimensions (provided, of \
course, that the indices to be contracted have the same dimension); thus, if \
A has dimensions {2, 3, 3, 4} and B {3, 2, 4}, ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 "[A, {2, 3}] will return a tensor with dimensions {2, 4} and ",
 StyleBox["multiDot",
  FontFamily->"Courier"],
 "[A, B, {1, 2}, {3, 1}] will return a tensor with dimensions {3, 4, 4}.",
 Cell[BoxData[
  FormBox["", TextForm]], 
  "\.02\[YAcute]\t\[OSlash]\.03\.08\[CapitalCCedilla]`\.03\.08\
\[CapitalCCedilla]`"]
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.4  Covariant differentiation of tensors", "Subsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell["\<\
\tThe following functions, involving differentiations of tensors, are defined \
in RGTC: \
\>", "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 "\t (i) The function  ",
 StyleBox["covD[x_,{i___}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  takes two arguments -- an nth rank tensor, ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", and a list of numbers indicating the positions of the ",
 StyleBox["contravariant",
  FontSlant->"Italic"],
 "  (U) components of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " -- and produces an ",
 StyleBox["n+1",
  FontFamily->"Courier",
  FontSlant->"Italic"],
 " rank tensor: the covariant derivative of ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". ",
 StyleBox["The last index is the differentiation index (d type)",
  FontSlant->"Italic"],
 ". If ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " has only d-type components, the second argument (empty list) can be \
omitted. Examples:"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covD[Rdd]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (ddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox["R", 
     RowBox[{"ab", ";", "c"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covD[RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 5th rank (Udddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["R", "a"], 
     RowBox[{"bcd", ";", "e"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(ii) The function ",
 StyleBox["covDiv[x_,{i___,{s_}}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " acting on an nth rank tensor ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " with contravariant indices at positions {i..., s} returns an ",
 StyleBox["n-1",
  FontFamily->"Courier",
  FontSlant->"Italic"],
 " rank tensor: the covariant ",
 StyleBox["divergence",
  FontSlant->"Italic"],
 " of ",
 StyleBox["x",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " with respect to the contravariant index at position ",
 StyleBox["s",
  FontSlant->"Italic"],
 ". If there is only one contravariant index, the second argument can be \
written simply {s} rather than {{s}}. Examples (the Einstein summation \
convention holds):"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covDiv[RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (ddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["R", "s"], 
     RowBox[{"abc", ";", "s"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["covDiv[RUdUd,{1,{3}}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 3rd rank (Udd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox[
      SubscriptBox[
       SuperscriptBox["R", "a"], "b"], "s"], 
     RowBox[{"c", ";", "s"}]],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note1",
  FontSlant->"Italic"],
 ": It is ",
 StyleBox["much",
  FontSlant->"Italic"],
 " more efficient to use ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 "  than to use ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  followed by ",
 StyleBox["Contract",
  FontFamily->"Courier"],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Note2",
  FontSlant->"Italic"],
 ": The functions ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 "  can be very slow on high-rank tensors in high dimensions. However, they \
remember their values, so calling them again with the same arguments takes no \
time. "
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "\t(iii)  The function  ",
 StyleBox["LieD[h_,x_,{i___}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " computes the Lie derivative of the tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ", having contravariant indices at index positions ",
 StyleBox["i__",
  FontWeight->"Bold"],
 ", with respect to the contravariant (U type) vector ",
 StyleBox["h",
  FontWeight->"Bold"],
 ". The tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 " can be a tensor-valued p-form, for example the curvature 2-form ",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "b"]]],
 "=",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "bcd"]]],
 "d[",
 Cell[BoxData[
  SuperscriptBox["x", "c"]]],
 "]\[Wedge]d[",
 Cell[BoxData[
  SuperscriptBox["x", "d"]]],
 "]. For totally covariant tensors ",
 StyleBox["x ",
  FontWeight->"Bold"],
 "(or scalars), the last argument (empty list) can be omitted. The result of ",
 StyleBox["LieD",
  FontWeight->"Bold"],
 " is a tensor of the same rank (and type) as ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". As with ",
 StyleBox["covD",
  FontFamily->"Courier"],
 "  and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 ",  ",
 StyleBox["LieD",
  FontFamily->"Courier"],
 " remembers its values. Examples:"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["LieD[{h1,h2,..,hn},gdd]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 2nd rank (dd type) tensor with components ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    TagBox["",
     DisplayForm], 
    SuperscriptBox["h", "s"], 
    SubscriptBox["g", 
     RowBox[{"ab", ",", "s"}]]}], "+", 
   RowBox[{
    TagBox[
     TagBox[
      SubscriptBox[
       SuperscriptBox["h", "s"], 
       RowBox[{",", "a"}]],
      DisplayForm],
     DisplayForm], 
    SubscriptBox["g", "sb"]}], "+", 
   RowBox[{
    TagBox[
     TagBox[
      SubscriptBox[
       SuperscriptBox["h", "s"], 
       RowBox[{",", "b"}]],
      DisplayForm],
     DisplayForm], 
    SubscriptBox["g", "as"]}]}]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t     ",
 StyleBox["LieD[{h1,h2,..,hn},RUddd,{1}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a 4th rank (Uddd type) tensor with components ",
 Cell[BoxData[
  TagBox[
   TagBox[
    RowBox[{
     SuperscriptBox["h", "s"], 
     SubscriptBox[
      SuperscriptBox["R", "a"], 
      RowBox[{"bcd", ",", "s"}]]}],
    DisplayForm],
   DisplayForm]]],
 "+",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["h", "s"], 
     RowBox[{",", "b"}]],
    DisplayForm],
   DisplayForm]]],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "scd"]]],
 "+",
 Cell[BoxData[
  RowBox[{
   TagBox[
    TagBox[
     SubscriptBox[
      SuperscriptBox["h", "s"], 
      RowBox[{",", "c"}]],
     DisplayForm],
    DisplayForm], 
   SubscriptBox[
    SuperscriptBox["R", "a"], "bsd"]}]]],
 "+",
 Cell[BoxData[
  TagBox[
   TagBox[
    SubscriptBox[
     SuperscriptBox["h", "s"], 
     RowBox[{",", "d"}]],
    DisplayForm],
   DisplayForm]]],
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox["R", "a"], "bcs"]]],
 StyleBox["- ",
  FontFamily->"Geneva"],
 Cell[BoxData[
  TagBox[
   TagBox[
    RowBox[{
     SubscriptBox[
      SuperscriptBox["h", "a"], 
      RowBox[{",", "s"}]], 
     SubscriptBox[
      SuperscriptBox["R", "s"], "bcd"]}],
    DisplayForm],
   DisplayForm]]],
 "."
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\tThe function  ",
 StyleBox["LieDcartan",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["[",
  FontWeight->"Bold"],
 StyleBox["vector_,form_",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["]",
  FontWeight->"Bold"],
 ", introduced in ",
 ButtonBox["EDC 3.8.5",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}],
 ", computes the Lie derivative of the differential form expression ",
 StyleBox["form",
  FontWeight->"Bold"],
 " w.r.t. the ",
 StyleBox["vector",
  FontWeight->"Bold"],
 " using the Cartan identity.  It differs from ",
 StyleBox["LieD",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " in that it does not treat lists of forms as components of a tensor. See \
the ",
 ButtonBox["EDCmanual.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}],
 " (section 2.5) for details."
}], "Text",
 ShowGroupOpener->True,
 FontSize->16]
}, Open  ]],

Cell[TextData[{
 "\t(iv) The function  ",
 StyleBox["Laplacian[x_,{i___}]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " computes the Laplacian (",
 Cell[BoxData[
  SubscriptBox[
   SuperscriptBox[
    RowBox[{"=", "x"}], 
    RowBox[{";", "s"}]], 
   RowBox[{";", "s"}]]]],
 ") of the tensor ",
 StyleBox["x",
  FontWeight->"Bold"],
 ", having contravariant indices at index positions ",
 StyleBox["i__",
  FontWeight->"Bold"],
 ". Again, for totally covariant tensors ",
 StyleBox["x",
  FontWeight->"Bold"],
 " (or scalars), the last argument (empty list) can be omitted. The result of \
",
 StyleBox["Laplacian",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " is a tensor of the same rank (and type) as ",
 StyleBox["x",
  FontWeight->"Bold"],
 ". "
}], "Text",
 FontSize->16],

Cell[TextData[{
 "\t(v) The function  ",
 StyleBox["Grad2Norm[x__]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 " takes either 1 or 2  ",
 StyleBox["scalar",
  FontSlant->"Italic"],
 " functions as arguments and computes the square norm of the gradient of ",
 StyleBox["x",
  FontFamily->"Courier"],
 " (inner product): ",
 StyleBox["Grad2Norm[x]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "= ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["g", "ab"], 
   SubscriptBox["x", 
    RowBox[{",", "a"}]], 
   SubscriptBox["x", 
    RowBox[{",", "b"}]]}]]],
 StyleBox[" ",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "and  ",
 StyleBox["Grad2Norm[x,y]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "= ",
 Cell[BoxData[
  RowBox[{
   SuperscriptBox["g", "ab"], 
   SubscriptBox["x", 
    RowBox[{",", "a"}]], 
   SubscriptBox["y", 
    RowBox[{",", "b"}]]}]]],
 "."
}], "Text",
 FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(vi) Using ",
 StyleBox["covD",
  FontFamily->"Courier"],
 " and ",
 StyleBox["covDiv",
  FontFamily->"Courier"],
 ",  the function ",
 StyleBox["Bianchi[n_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 ", for n = 0, 1, 2, computes the full, once, twice contracted Bianchi \
identities and returns a list containing any non-vanishing terms. This list \
is normally the empty list, except when the simplification rules used imply \
relations among the 3rd derivatives of the metric functions (see Example 5). \
"
}], "Text",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\tEvaluation of the Bianchi Identities takes long: for the metrics in the \
examples, the time needed to evaluate ",
 StyleBox["Bianchi[1]",
  FontFamily->"Courier"],
 " is ~ 1 - 15 times the time taken by ",
 StyleBox["RGtensors",
  FontFamily->"Courier"],
 " to compute all basic tensors. ",
 StyleBox["Bianchi[0]",
  FontFamily->"Courier"],
 " takes considerably longer. (For the Bondi metric the times are ~ 12 min, 6 \
min, 7 sec). "
}], "Text",
 FontSize->16]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.5  Index of global names / variables", "Subsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["It is essential that, in choosing coordinates and metric \
functions, one avoids using the symbols listed in this subsection, as they \
are defined by (or have special meanings in) RGTC. In particular, the  \
single-letter symbols R, d, e, as well as the greek letters used in the spin \
coefficient formalism, must be avoided-- see subsection 4.0.",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(i) ",
 StyleBox["Riemannian Geometry tensors / scalars",
  FontSlant->"Italic"],
 " "
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["gdd, gUU, GUdd, Rdddd, RUddd, Rdd, EUd, R, Wdddd, detg\t\t",
  FontWeight->"Bold"],
 "(section 1.1)\n\t",
 StyleBox["epsilon, eta\t\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 1.1.1)\n\t",
 StyleBox["\[Omega]Ud \t\t\t\t\t\t\t\t\t",
  FontWeight->"Bold"],
 "(section 5.1)\n\t",
 StyleBox["\[Alpha],\[Beta],",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["...,  ",
  FontWeight->"Bold"],
 StyleBox["\[GothicCapitalD][_],\[CapitalDelta][_]",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 StyleBox["..., \[CapitalPsi][i], \[CapitalPhi][i, j],",
  FontWeight->"Bold"],
 " ",
 StyleBox["\[CapitalLambda]\t\t\t\t",
  FontWeight->"Bold"],
 "(section 5.1.3)"
}], "Text",
 FontSize->16]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(ii) ",
 StyleBox["Tensor operations / functions",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 " \t",
 StyleBox["RGtensors\t\t\t\t\t\t\t     ",
  FontWeight->"Bold"],
 "(section 1.1, 5.1, 5.2)\n\t",
 StyleBox["Raise, Lower, Outer, Transpose",
  FontWeight->"Bold"],
 "\t\t\t\t\t(section 1.2) \n\t",
 StyleBox["Contract, Dot, multiDot",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t(section 1.3) \n\t",
 StyleBox["covD, covDiv, LieD, Laplacian, Grad2Norm, Bianchi",
  FontWeight->"Bold"],
 "\t\t(section 1.4)\n\t",
 StyleBox["HStar",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t\t(section 5.1.2)\n\t",
 StyleBox["Classify, Plebanski",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t(section 7)"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(iii) ",
 StyleBox["Other global variables",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["Dim, coordList, LineElement",
  FontWeight->"Bold"],
 "\t\t\t\t\t(section 1.1)\n\t",
 StyleBox["simpRules, TrigRules, HypTrigRules, varList",
  FontWeight->"Bold"],
 "\t\t\t(section 4.3)\n\t",
 StyleBox["e[], d[]",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t\t(section 5.1)\n\t",
 StyleBox["deList, dxRuleList",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t(section 5.2)"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(iv) ",
 StyleBox["Auxiliary functions",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\t",
 StyleBox["zeroQ, nonZeroN, nonZeroL, indepTerms, indepCoefs, FacSimp",
  FontWeight->"Bold"],
 "\t(section 4.2)\n\t",
 StyleBox["FuncRepRules\t\t\t\t\t\t\t    \t    ",
  FontWeight->"Bold"],
 "(section 4.4)\n\t",
 StyleBox["eTO$dx, Clear$dx",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t(section 5.1.1)\n\t",
 StyleBox["GenCoef, metric",
  FontWeight->"Bold"],
 "\t\t\t\t\t\t\t\t(section 4.2)"
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t(v) ",
 StyleBox["Functions / variables defined in ",
  FontSlant->"Italic"],
 StyleBox["EDC",
  FontWeight->"Bold",
  FontSlant->"Italic"]
}], "Subsubsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "  \te.g., ",
 StyleBox["Wedge",
  FontWeight->"Bold"],
 ", ",
 StyleBox["d[]",
  FontWeight->"Bold"],
 ", ",
 StyleBox["DeclareForms",
  FontWeight->"Bold"],
 ", ",
 StyleBox["Bar[], DirectSum",
  FontWeight->"Bold"],
 " etc.\t\tsee  ",
 ButtonBox["EDCmanual.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}]
}], "Text",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 Cell[BoxData[
  TagBox["",
   DisplayForm]]],
 "\t",
 StyleBox["Important Note:",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontWeight->"Bold"],
 "As the behavior of ",
 StyleBox["RGtensors",
  FontWeight->"Bold"],
 " depends on the values of global variables like ",
 StyleBox["simpRules, deList, dxRuleList,",
  FontWeight->"Bold"],
 " one should normally restart the kernel to do calculations with a new \
metric."
}], "Text",
 FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["  1.6  Input Palettes", "Subsection",
 ShowGroupOpener->True,
 FontSize->16],

Cell[TextData[{
 "\tThe notebooks ",
 StyleBox["OperatorPLT.nb",
  FontWeight->"Bold"],
 " and ",
 StyleBox["NPsymbolPLT.nb",
  FontWeight->"Bold"],
 " are input palettes. The first contains the more common functions/variables \
used in calculations, so they can be entered easily without misspellings, \
while the second contains the symbols for the Newman-Penrose variables nd \
operators (see section 5.1.3). "
}], "Text",
 FontSize->16]
}, Closed]],

Cell[TextData[{
 "\tIt is assumed that the user has a working knowledge of the basic ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " structures used in symbolic calculations -- in particular that he/she \
understands the properties and use of",
 StyleBox[" Lists, Patterns, Functions, Transformation Rules and Definitions",
  
  FontSlant->"Italic"],
 ".  Although not necessary for elementary evaluations, familiarity with \
these structures is needed to make full use of all features of RG&TC."
}], "Text",
 FontSize->16],

Cell[TextData[{
 StyleBox["\t",
  FontSize->14],
 StyleBox["The executable cells in this notebook must be evaluated ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["in the order they appear",
  FontSize->16,
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[", after placing the file",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox[" ",
  FontSize->16,
  FontWeight->"Bold"],
 StyleBox["in an appropriate directory. Also read subsection 4.0 before doing \
calculations with a new metric.",
  FontSize->16,
  FontWeight->"Bold"]
}], "Text",
 FontSize->18,
 FontColor->RGBColor[0, 0, 1]]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"b65d8ee8-2f6d-4af3-8212-5637a54f4474"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[" 2  RG&TC-Code",
 FontWeight->"Bold"]], "Section",
 ShowGroupOpener->True,
 FontSize->24,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"ee6effb8-abac-448e-8d16-d04c591c5a02"],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7282158987663927`*^9, 
  3.728215899770545*^9}},ExpressionUUID->"ae28db5a-38c1-48a5-ab27-\
40648f80d51d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"<<", "EDCRGTCcode.m"}]], "Input",
 InitializationCell->
  True,ExpressionUUID->"a99268d3-baa0-4575-a11a-7af576bbc269"],

Cell[BoxData[
 TemplateBox[{
  "SetDelayed","write",
   "\"Tag \\!\\(\\*RowBox[{\\\"Classify\\\"}]\\) in \
\\!\\(\\*RowBox[{\\\"Classify\\\", \\\"[\\\", \\\"x_\\\", \\\"]\\\"}]\\) is \
Protected.\"",2,0,1,17640428610865874886,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7270906213566275`*^9, 3.7270919625459614`*^9, 3.727100417422482*^9, 
   3.7271050768602343`*^9, 3.727105737846706*^9, 3.7271082990961733`*^9, 
   3.7271113611036377`*^9, 3.7275157583051553`*^9, 3.727517790590516*^9, {
   3.727518439024067*^9, 3.7275184495210047`*^9}, 3.7275186483762217`*^9, 
   3.727606260923489*^9, 3.7276079535524883`*^9, 3.727608024629487*^9, 
   3.727677057424094*^9, 3.7276789540483932`*^9, 3.7276793924424915`*^9, 
   3.7276801907422495`*^9, 3.7276955174114294`*^9, 3.7277788744954767`*^9, 
   3.7277802367734065`*^9, 3.727781859157692*^9, 3.727855013612213*^9, {
   3.728014887143074*^9, 3.7280148946282544`*^9}, 3.7280230944142733`*^9, 
   3.7280371830951147`*^9, 3.7280404834983177`*^9, 3.7281277820290833`*^9, 
   3.7281941768180428`*^9, 3.728200916009761*^9, 3.728206980593647*^9, 
   3.7282083298163853`*^9, 3.728209933276825*^9, 3.7282099797078276`*^9, 
   3.728213987322059*^9, 3.728215139872596*^9, 3.7282158366532373`*^9, 
   3.7282159030155497`*^9, 3.7282261187152357`*^9, 3.728232580999635*^9, 
   3.728240159766901*^9, 3.728280666578498*^9, 3.728296806641108*^9, 
   3.728893318593072*^9, 3.7319071172113824`*^9, 3.7319197292483687`*^9, 
   3.731924999781872*^9, 3.732353765924738*^9, 3.7323538473073316`*^9, 
   3.7325242072467976`*^9, 3.7326104410243826`*^9, 3.7328547897857285`*^9, 
   3.7328586578603344`*^9, 3.7329413691128263`*^9, 3.7330451311615973`*^9, 
   3.733566198374257*^9, 3.735015785011615*^9, 3.7350164324717245`*^9, 
   3.7350180612239265`*^9, 3.735018766189824*^9, 3.73501973103732*^9, 
   3.735019789279045*^9, 3.7350206422503023`*^9, 3.735020773771123*^9, 
   3.735022031720189*^9, 3.735022365054077*^9, 3.735022812101457*^9, 
   3.735023339117511*^9, 3.735035104486573*^9, 3.735546166399829*^9, 
   3.735898393980877*^9, 3.735914792799757*^9, 3.7359189045408964`*^9, 
   3.7359660270741425`*^9, 3.7359746899464083`*^9, 3.7359861785077314`*^9, 
   3.7360745440427914`*^9, 3.737037736483014*^9, 3.7371129681544757`*^9, 
   3.73717901353351*^9, 3.7372769780667906`*^9, 3.737277666510703*^9, 
   3.737278372126767*^9, 3.737279119035304*^9, 3.7372807049862623`*^9, 
   3.7372819309711213`*^9, 3.7372821934108505`*^9, 3.7372833289893785`*^9, 
   3.7373490697869368`*^9, 3.737904881080914*^9, 3.7379607639829884`*^9, 
   3.7379678510132346`*^9, 3.7379687580351057`*^9, 3.7379693771124153`*^9, 
   3.74566561921761*^9, 3.745824537844431*^9, 3.745831658583044*^9, 
   3.745833527977562*^9, 3.745852944685033*^9, 3.7459046643038783`*^9, 
   3.7459049407368727`*^9, 3.7459154925431056`*^9, 3.746184832345435*^9, 
   3.746253143539814*^9, 3.7462627956306825`*^9, 3.746420808615484*^9, 
   3.7464278186588726`*^9, 3.748254936407503*^9, 3.748320385707425*^9, 
   3.7483310891367865`*^9, 3.7484476107753897`*^9, 3.748448289724312*^9, 
   3.7484501929949923`*^9, 3.748504291044793*^9, 3.7492841845956187`*^9, 
   3.749296532855755*^9, 3.7513739636656423`*^9, 3.751374740380705*^9, 
   3.7513900781863337`*^9, 3.751463746195076*^9, 3.7516222773856497`*^9, 
   3.7516247738391542`*^9, 3.7516300428640327`*^9, 3.753006088220707*^9, 
   3.7530259522261467`*^9, 3.7531038509528837`*^9, 3.7531100323308425`*^9, 
   3.7533433977255154`*^9, 3.7540532129858646`*^9, 3.754130407905632*^9, 
   3.7561092775757637`*^9, 3.756109379671726*^9, 3.7561138501566505`*^9, 
   3.7568074511039505`*^9, 3.7579156695706058`*^9, 3.757923804509288*^9, 
   3.7583540570339217`*^9, 3.7583631374714966`*^9, 3.758372231439682*^9, 
   3.7583723772197165`*^9, 3.7584542282765355`*^9, 3.7584606475915127`*^9, 
   3.759038902530571*^9, 3.7590421844077544`*^9, 3.7590453415392857`*^9, 
   3.759058803775837*^9, 3.7590606200257635`*^9, 3.75906097566796*^9, 
   3.7590610898807173`*^9, 3.7590627984754715`*^9, 3.7590650413746867`*^9, 
   3.759583077153904*^9, 3.759648798189332*^9, 3.759662087440201*^9, 
   3.76060014102886*^9, 3.760705816289156*^9, 3.760706278398962*^9, 
   3.760707295545081*^9, 3.7607934241040573`*^9, 3.760860113365587*^9, 
   3.7608616333850603`*^9, 3.7608661089570646`*^9, 3.7608665659470234`*^9, 
   3.7608678862777452`*^9, 3.7608683544975357`*^9, 3.7608688163564796`*^9, 
   3.7608761164817905`*^9, 3.760877324851229*^9, 3.760954473741836*^9, 
   3.7609545407642126`*^9, 3.760964268131878*^9, 3.760965077096245*^9, 
   3.760966634801968*^9, 3.7610283571046925`*^9, 3.7614714347190914`*^9, 
   3.7614755805670977`*^9, 3.7614839475823483`*^9, 3.761496761840815*^9, 
   3.7615610861368775`*^9, 3.761569929989749*^9, 3.7616467927406454`*^9, 
   3.761648516124036*^9, {3.7616550881396103`*^9, 3.761655106394492*^9}, 
   3.7616571752803063`*^9, 3.7616681656627693`*^9, 3.7619035052380176`*^9, 
   3.761913534292717*^9, 3.7619151176022224`*^9, 3.7619268054258103`*^9, 
   3.761927602926715*^9, 3.7619284886568794`*^9, 3.761978734509909*^9, 
   3.7620807784894753`*^9, 3.762082031815566*^9, 3.7620869209119425`*^9, 
   3.7631008701009855`*^9, 3.7631009405101604`*^9, 3.7631135634855785`*^9, 
   3.7631151319778786`*^9, 3.7631204628764763`*^9, 3.763121431137025*^9, 
   3.7631217305218706`*^9, 3.7631218837772264`*^9, 3.763122819407279*^9, 
   3.7631332058626537`*^9, 3.7631339277218757`*^9, 3.7631344630054674`*^9, 
   3.763188747551607*^9, 3.7631891071889043`*^9, 3.7634619052217855`*^9, 
   3.763462449434415*^9, 3.763463084961478*^9, 
   3.7638063334504395`*^9},ExpressionUUID->"ba51d72e-fa7a-4324-8140-\
11465157b4d2"]
}, Open  ]],

Cell[TextData[{
 "\tThe file ",
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  must be placed in one of the directories that ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " looks at when searching for extra packages (e.g., /Applications/",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "/AddOns/AutoLoad). Such directories can be found by evaluating the command ",
 StyleBox["$Path",
  FontWeight->"Bold"],
 ":"
}], "Text",
 FontSize->16,ExpressionUUID->"e883cdef-f3f8-443e-b8e4-2d5f2af27028"],

Cell[BoxData["$Path"], "Input",ExpressionUUID->"cc6976d9-2e40-43ea-81fe-f25eb0f7084b"],

Cell[TextData[{
 "\t",
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  is the ",
 StyleBox["combined",
  FontSlant->"Italic"],
 " EDC and RGTC code, allowing calculations with differential forms, symbolic \
matrices, etc. (See the  ",
 ButtonBox["EDCmanual.nb",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.inp.demokritos.gr/~sbonano/EDC/"], None}],
 ")."
}], "Text",
 FontSize->16,ExpressionUUID->"aa546552-0d1c-48ef-ab6b-1d813fda1443"],

Cell[TextData[{
 "\tEvaluation of ",
 StyleBox["EDCRGTCcode.m",
  FontFamily->"Courier",
  FontWeight->"Bold"],
 "  erases all previous results. Thus it must be evaluated before any  \
calculations are carried out."
}], "Text",
 FontSize->16,ExpressionUUID->"469b5241-371d-4ff1-806b-8b5b94c61778"]
}, Closed]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"b929167e-301b-47e0-bb06-fd8b7e56756f"],

Cell[CellGroupData[{

Cell[TextData[{
 " 3  Examples (~ 1.5 min) \n",
 StyleBox["(All timings refer to an Apple iBook G3/900 computer running ",
  FontSize->14,
  FontWeight->"Plain"],
 StyleBox["Mathematica",
  FontSize->14,
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox[" 3.0 under Mac OS 9.2.2)",
  FontSize->14,
  FontWeight->"Plain"]
}], "Section",
 ShowGroupOpener->True,
 CellChangeTimes->{3.746188220792528*^9},
 FontSize->24,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"d4db6884-e79e-430e-a3bc-05bcdb8f3307"],

Cell[TextData[{
 "\n\t",
 StyleBox["In each case, after ",
  FontSize->16],
 StyleBox["RGtensors",
  FontFamily->"Courier",
  FontSize->16],
 StyleBox[" is finished, examples of further calculations, using the other \
functions defined in the package, are given.",
  FontSize->16]
}], "Text",ExpressionUUID->"1ad3e9d8-fdc9-4e75-affe-25f5ad4606e2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"stTim", "=", 
   RowBox[{"AbsoluteTime", "[", "]"}]}], ";"}]], "Input",ExpressionUUID->\
"be9b65e3-c8b5-4729-8817-5fd99088891e"],

Cell[CellGroupData[{

Cell[" Example 2: Robertson-Walker", "Subsection",
 ShowGroupOpener->True,
 FontSize->16,ExpressionUUID->"960d3d59-44b4-4599-a928-fb011bcb1f83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]}], "/", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"k", " ", 
           RowBox[{"r", "^", "2"}]}]}], ")"}]}], ",", "0", ",", "0"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]}], 
        RowBox[{"r", "^", "2"}]}], ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"r", "^", "2"}]}], 
        RowBox[{
         RowBox[{"a", "[", "t", "]"}], "^", "2"}], 
        RowBox[{
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "^", "2"}]}]}], "}"}]}], 
    "}"}]}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"g", ",", "xCoord"}], "]"}]], "Input"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], 
          RowBox[{"1", "-", 
           RowBox[{"k", " ", 
            SuperscriptBox["r", "2"]}]}]]}], "0", "0"},
       {"0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}], "0"},
       {"0", "0", "0", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["r", "2"]}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, ((-1)/(1 - k r^2)) a[t]^2, 0, 0}, {
     0, 0, (-r^2) a[t]^2, 0}, {0, 0, 0, ((-r^2) a[t]^2) Sin[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"LineElement = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{
     FractionBox[
      RowBox[{
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{"d", "[", "r", "]"}], "2"]}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"k", " ", 
        SuperscriptBox["r", "2"]}]}]], "+", 
     SuperscriptBox[
      RowBox[{"d", "[", "t", "]"}], "2"], "-", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "\[Theta]", "]"}], "2"]}], "-", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "\[CurlyPhi]", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}],
    Short[#, 32]& ]}],
  SequenceForm["LineElement = ", 
   Short[((-1 + k r^2)^(-1) a[t]^2) d[r]^2 + d[t]^2 - (r^2 a[t]^2) 
    d[\[Theta]]^2 - ((r^2 a[t]^2) d[\[CurlyPhi]]^2) Sin[\[Theta]]^2, 32]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", GridBox[{
       {"1", "0", "0", "0"},
       {"0", 
        FractionBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"k", " ", 
           SuperscriptBox["r", "2"]}]}], 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]], "0", "0"},
       {"0", "0", 
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}]]}], "0"},
       {"0", "0", "0", 
        RowBox[{"-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], 
          RowBox[{
           SuperscriptBox["r", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}]]}]}
      }], ")"}],
    MatrixForm[#]& ]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{1, 0, 0, 0}, {0, (-1 + k r^2) a[t]^(-2), 0, 0}, {
     0, 0, ((-1) r^(-2)) a[t]^(-2), 0}, {
     0, 0, 0, (((-1) r^(-2)) a[t]^(-2)) Csc[\[Theta]]^2}}]],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0.03333333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.03333333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0333333333333314385`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.03333333333333144, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666799301`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.01666666666667993, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666515084`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.01666666666665151, " sec"],
  Editable->False]], "Print"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.0500000000000113686`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.05000000000001137, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"Conformally Flat\"\>"], "Output",
 FontSize->20,
 FontWeight->"Bold",
 FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.0166666666666515084`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.01666666666665151, " sec"],
  Editable->False]], "Print"],

Cell[BoxData["\<\"All tasks completed in 0.333333 seconds\"\>"], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Rdd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["a", "\[DoublePrime]",
      MultilineFunction->None], "[", "t", "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EUd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}]], "Input"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"k", "+", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["a", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], ")"}]}], 
  SuperscriptBox[
   RowBox[{"a", "[", "t", "]"}], "2"]]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\t",
 StyleBox["Check the twice-contracted Bianchi identities:",
  FontSize->16]
}], "Text",
 FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"zeroQ", "[", 
  RowBox[{"Bianchi", "[", "2", "]"}], "]"}]], "Input"],

Cell[BoxData["True"], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
 Example 2c: Robertson-Walker \[LongDash] Perturbation Equations for \
Horndeski \
\>", "Subsection",
 ShowGroupOpener->True,
 CellChangeTimes->{
  3.7270913637732935`*^9, {3.727091975190765*^9, 3.727091976981346*^9}, {
   3.7276770370070543`*^9, 3.7276770425115347`*^9}, {3.7276789803184257`*^9, 
   3.7276789807669234`*^9}, {3.7276819055867476`*^9, 3.727681927444519*^9}, {
   3.751373947425765*^9, 3.751373957006051*^9}, 3.759651483711258*^9, 
   3.762082274295591*^9},
 FontSize->16,ExpressionUUID->"50d1e2f6-1f1e-4769-bffa-d78a2b7aadd5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xCoord", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "}"}]}], ";"}]], "Input",Expr\
essionUUID->"ded5aabc-ec98-42ac-99ca-ba75c35a7f45"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "We", " ", "use", " ", "the", " ", "metric", " ", "in", " ", "the", " ", 
   "following", " ", "notation"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7270919836499414`*^9, 3.7270920067741146`*^9}, {
  3.753103732014081*^9, 3.7531037419179974`*^9}, {3.756807454385459*^9, 
  3.7568074566664515`*^9}},ExpressionUUID->"9ea78abd-6108-46b0-b71e-\
89b9d7124a1a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", 
           RowBox[{"\[CapitalPsi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
       ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "[", "t", "]"}], "^", "2"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
       ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "[", "t", "]"}], "^", "2"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
       ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "[", "t", "]"}], "^", "2"}], 
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"2", 
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}]}],
       "}"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7270920164553432`*^9, 3.727092037173853*^9}, {
  3.7271057467640066`*^9, 3.727105769726654*^9}, {3.727105801886936*^9, 
  3.727105806150839*^9}, {3.751373965035949*^9, 3.7513739791159353`*^9}, {
  3.751374720549304*^9, 3.7513747228950844`*^9}, {3.7516247538832135`*^9, 
  3.7516247585690327`*^9}},ExpressionUUID->"eb0b2c78-a54f-49d1-a0f6-\
31b2f7928f00"],

Cell[BoxData[
 RowBox[{
  RowBox[{"simpRules", "=", "TrigRules"}], ";"}]], "Input",ExpressionUUID->\
"e813fbd8-ba0a-4228-b1ba-d61099f9a209"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RGtensors", "[", 
  RowBox[{"g", ",", "xCoord"}], "]"}]], "Input",ExpressionUUID->"71405c6e-\
decf-4357-8f21-213e6f50d774"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gdd = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{
         RowBox[{"-", "1"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], "0", "0", 
        "0"},
       {"0", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[CapitalPhi]", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
        "0", "0"},
       {"0", "0", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[CapitalPhi]", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
        "0"},
       {"0", "0", "0", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[CapitalPhi]", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gdd = ", 
   MatrixForm[{{-1 - 
      2 $CellContext`\[CapitalPsi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z], 0, 0, 0}, {
     0, $CellContext`a[$CellContext`t]^2 (1 + 
       2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]), 0, 0}, {
     0, 0, $CellContext`a[$CellContext`t]^2 (1 + 
       2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]), 0}, {
     0, 0, 0, $CellContext`a[$CellContext`t]^2 (1 + 
       2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z])}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.7638063340076637`*^9},ExpressionUUID->"ee535809-274b-4970-9fe1-\
08c012169bf0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"LineElement = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "x", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "y", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      SuperscriptBox[
       RowBox[{"d", "[", "z", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"2", " ", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
     "+", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"d", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"\[CapitalPsi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}]}],
    Short[#, 32]& ]}],
  SequenceForm["LineElement = ", 
   Short[$CellContext`a[$CellContext`t]^2 $CellContext`d[$CellContext`x]^2 (1 + 
      2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]) + $CellContext`a[$CellContext`t]^2 \
$CellContext`d[$CellContext`y]^2 (1 + 
      2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]) + $CellContext`a[$CellContext`t]^2 \
$CellContext`d[$CellContext`z]^2 (1 + 
      2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]) + $CellContext`d[$CellContext`t]^2 (-1 - 
      2 $CellContext`\[CapitalPsi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]), 32]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.7638063343110657`*^9},ExpressionUUID->"ca0b8047-b369-44b5-892f-\
840d7a49a263"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU = \"\>", "\[InvisibleSpace]", 
   TagBox[
    RowBox[{"(", "\[NoBreak]", GridBox[{
       {
        RowBox[{"-", 
         FractionBox["1", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", 
            RowBox[{"\[CapitalPsi]", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]]}], "0", 
        "0", "0"},
       {"0", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalPhi]", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
           ")"}]}]], "0", "0"},
       {"0", "0", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalPhi]", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
           ")"}]}]], "0"},
       {"0", "0", "0", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", 
             RowBox[{"\[CapitalPhi]", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
    Function[BoxForm`e$, 
     MatrixForm[BoxForm`e$]]]}],
  SequenceForm["gUU = ", 
   MatrixForm[{{(-1)/(1 + 
      2 $CellContext`\[CapitalPsi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]), 0, 0, 0}, {
     0, $CellContext`a[$CellContext`t]^(-2)/(1 + 
      2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]), 0, 0}, {
     0, 0, $CellContext`a[$CellContext`t]^(-2)/(1 + 
      2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]), 0}, {
     0, 0, 0, $CellContext`a[$CellContext`t]^(-2)/(1 + 
      2 $CellContext`\[CapitalPhi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z])}}]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.7638063344324083`*^9},ExpressionUUID->"e9d5c1f1-f0cf-4e9b-b78a-\
c4e58c962c53"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"gUU computed in \"\>", "\[InvisibleSpace]", "0.`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["gUU computed in ", 0., " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.763806334533744*^9},ExpressionUUID->"283fa127-a14a-499f-9cbb-\
b840cbe711d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Gamma computed in \"\>", "\[InvisibleSpace]", 
   "0.016000000000000014`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Gamma computed in ", 0.016000000000000014`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.763806334644844*^9},ExpressionUUID->"26cf1a1a-4f91-4c03-aca6-\
bf1097050242"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(dddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.04700000000000015`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(dddd) computed in ", 0.04700000000000015, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.763806334756033*^9},ExpressionUUID->"a74234c3-9964-45f5-989c-\
779caafdedbb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Riemann(Uddd) computed in \"\>", "\[InvisibleSpace]", 
   "0.09299999999999997`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Riemann(Uddd) computed in ", 0.09299999999999997, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.763806334836897*^9},ExpressionUUID->"8ba31a41-a9cf-4474-b706-\
b81c567ccfd3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Ricci computed in \"\>", "\[InvisibleSpace]", "0.25`", 
   "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Ricci computed in ", 0.25, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.7638063349177427`*^9},ExpressionUUID->"da562ce9-b60a-489c-af2a-\
fe327bf40a6b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Weyl computed in \"\>", "\[InvisibleSpace]", 
   "0.46899999999999986`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Weyl computed in ", 0.46899999999999986`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.7638063349987307`*^9},ExpressionUUID->"472b4257-96bf-4360-850e-\
e7e502567400"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Einstein computed in \"\>", "\[InvisibleSpace]", 
   "0.17200000000000015`", "\[InvisibleSpace]", "\<\" sec\"\>"}],
  SequenceForm["Einstein computed in ", 0.17200000000000015`, " sec"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.763806335110057*^9},ExpressionUUID->"9c06e9d0-3b43-4767-aa5c-\
42f9ed23292c"],

Cell[BoxData["\<\"All tasks completed in 1.0625 seconds\"\>"], "Print",
 CellChangeTimes->{
  3.7270920436463847`*^9, 3.7271004398450265`*^9, 3.727105118790496*^9, 
   3.727105778091097*^9, 3.7271058147813706`*^9, 3.727108314543071*^9, 
   3.7271113743829594`*^9, 3.7275157873262405`*^9, 3.7275186611344914`*^9, 
   3.7276062667925014`*^9, 3.7276079568456173`*^9, 3.727608034201995*^9, 
   3.7276770639231243`*^9, 3.727678960446472*^9, 3.727679396369104*^9, 
   3.727680196975517*^9, 3.7513739829957113`*^9, 3.751374740911068*^9, 
   3.751390082686185*^9, 3.751463753169423*^9, 3.751622279467896*^9, 
   3.7516247744209447`*^9, 3.7516300476442037`*^9, 3.753006090444191*^9, 
   3.75302595245979*^9, 3.753103853235609*^9, 3.7531100340315633`*^9, 
   3.75334339796542*^9, 3.7540532259504404`*^9, 3.754130408256158*^9, 
   3.756109281064756*^9, 3.756109380291587*^9, 3.756113858636839*^9, 
   3.7568074611507936`*^9, 3.7579156711103168`*^9, 3.757923805038436*^9, {
   3.758354057393325*^9, 3.758354065346374*^9}, 3.758363140109646*^9, 
   3.758372232139803*^9, 3.75837237992478*^9, 3.758454232226609*^9, 
   3.758460649694422*^9, 3.7590389042337027`*^9, 3.7590421850204*^9, 
   3.7590453421496105`*^9, 3.7590588043559456`*^9, 3.759060620795777*^9, 
   3.7590609761708612`*^9, 3.7590610917558055`*^9, 3.759062798853409*^9, 
   3.7590650440102105`*^9, 3.7595830788265657`*^9, 3.7596487986241755`*^9, 
   3.7596620878745103`*^9, 3.7606001424407697`*^9, 3.7607058167814727`*^9, 
   3.760706278738931*^9, 3.7607072998350916`*^9, 3.7607934276442556`*^9, 
   3.76086011407523*^9, 3.7608616339253626`*^9, 3.7608661118668194`*^9, 
   3.760866566465107*^9, 3.7608678868175173`*^9, 3.760868354929799*^9, 
   3.7608688168062015`*^9, 3.7608761168669157`*^9, 3.7608773252470965`*^9, 
   3.760954541201826*^9, 3.7609642685539894`*^9, 3.7609650774564915`*^9, 
   3.7609666351769485`*^9, 3.761028361727021*^9, 3.7614714385389376`*^9, 
   3.7614755810119653`*^9, 3.7614839479572277`*^9, 3.7614967620970078`*^9, 
   3.761561086586611*^9, 3.761569930399506*^9, 3.7616467931881247`*^9, 
   3.761648516523662*^9, {3.7616550884895945`*^9, 3.761655106799511*^9}, 
   3.7616571756605253`*^9, 3.7616681658966436`*^9, 3.7619035056479683`*^9, 
   3.7619135346764097`*^9, 3.7619151180325875`*^9, 3.761926805740426*^9, 
   3.761927603739535*^9, 3.761928488839799*^9, 3.761978734862897*^9, 
   3.762080778875015*^9, 3.7620820322303915`*^9, 3.7620869212899117`*^9, 
   3.763100940996784*^9, 3.7631135638711033`*^9, 3.7631151326283293`*^9, 
   3.7631204632569113`*^9, 3.7631214316067114`*^9, 3.7631217308919754`*^9, 
   3.763121884216708*^9, 3.763122819797329*^9, 3.7631332061517344`*^9, 
   3.763133927924752*^9, 3.763134463183434*^9, 3.763188748175954*^9, 
   3.763189107797223*^9, 3.763461905639781*^9, 3.7634624499005547`*^9, 
   3.7634630854661803`*^9, 
   3.7638063351911726`*^9},ExpressionUUID->"a735375b-6601-43ac-b763-\
91b9df21bc40"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Definitions", " ", "and", " ", "equations"}], " ", "*)"}]], "Input",\

 CellChangeTimes->{{3.756807603369266*^9, 3.756807610510172*^9}, {
  3.7568076517272835`*^9, 3.7568076593229*^9}, {3.7590611017255917`*^9, 
  3.7590611046757765`*^9}},ExpressionUUID->"1c0d27dc-645f-44eb-b78f-\
414d374b5b66"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", " ", "Definitions"}]}]}]}], " ", "and", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"Calculations", " ", "--"}], "--"}], "--"}]}], "-"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"approx", ",", "ApproxSimplify", ",", "ApproxFullSimplify"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"a2H", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{"a", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["a", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"a", "[", "t", "]"}], 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"H", "'"}], "[", "t", "]"}], "+", 
           RowBox[{
            RowBox[{"H", "[", "t", "]"}], "^", "2"}]}], ")"}]}]}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zeroorder", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"\[CapitalPsi]_", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"approx", "[", 
     RowBox[{"a_", "  ", 
      RowBox[{
       RowBox[{"X_", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "^", "m_."}], "  ", 
      RowBox[{
       RowBox[{"Y_", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "^", "n_."}]}], 
     "]"}], ":=", "0"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"approx", "[", 
     RowBox[{
      RowBox[{"X_", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
      RowBox[{"Y_", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ":=", 
    "0"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"approx", "[", 
     RowBox[{
      RowBox[{"X_", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "^", "2"}], "]"}], 
    ":=", "0"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"approx", "[", 
     RowBox[{
      RowBox[{"a_", "  ", 
       RowBox[{
        RowBox[{"X_", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "^", "n_"}]}], "/;", 
      RowBox[{"n", ">", "1"}]}], "]"}], ":=", "0"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"approx", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"a_", "+", 
        RowBox[{"b_", " ", 
         RowBox[{"X_", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}], "^", 
      "n_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"a", "^", "n"}], "+", 
     RowBox[{
      SuperscriptBox["a", 
       RowBox[{"n", "-", "1"}]], "n", " ", "b", "  ", 
      RowBox[{"X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"approx", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"b_", " ", 
         RowBox[{"X_", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
        RowBox[{"c_", " ", 
         RowBox[{"X_", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}], "^", 
      "n_."}], "]"}], ":=", 
    RowBox[{"1", "+", 
     RowBox[{"n", " ", "b", "  ", 
      RowBox[{"X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
     RowBox[{"n", " ", "c", "  ", 
      RowBox[{"X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"thetadef", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kx", " ", 
         RowBox[{"ux", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "a_"}], "+", 
        RowBox[{"ky", " ", 
         RowBox[{"uy", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", "a_"}], 
        "+", 
        RowBox[{"kz", " ", 
         RowBox[{"uz", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", "a_"}]}], "->", 
       RowBox[{"a", " ", 
        FractionBox[
         RowBox[{"\[Theta]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "I"]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"thetadef1", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"kx", " ", 
         RowBox[{
          SuperscriptBox["ux", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", "a_"}], 
        "+", 
        RowBox[{"ky", " ", 
         RowBox[{
          SuperscriptBox["uy", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", "a_"}], 
        "+", 
        RowBox[{"kz", " ", 
         RowBox[{
          SuperscriptBox["uz", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", "a_"}]}], "->", 
       RowBox[{"a", " ", 
        FractionBox[
         RowBox[{
          SuperscriptBox["\[Theta]", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "I"]}]}], 
      "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"k2def", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["kx", "2"], " ", "f_"}], "+", 
        RowBox[{
         SuperscriptBox["ky", "2"], " ", "f_"}], "+", 
        RowBox[{
         SuperscriptBox["kz", "2"], "f_"}]}], "->", 
       RowBox[{
        RowBox[{"k", "^", "2"}], " ", "f"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"app1", "=", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"f_", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "2"], "\[Rule]", 
       "0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"horizon", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CapitalPhi]_", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}],
        ",", 
       RowBox[{
        RowBox[{"\[CapitalPhi]_", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}],
        ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"horizon1", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CapitalPhi]_", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}],
        ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "''"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fourierderiv", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Derivative", "[", 
          RowBox[{"n1_", ",", "n2_", ",", "n3_", ",", "n4_"}], "]"}], "[", 
         "\[CapitalPhi]_", "]"}], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"I", " ", "kx"}], ")"}], "^", "n2"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"I", " ", "ky"}], ")"}], "^", "n3"}], " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"I", " ", "kz"}], ")"}], "^", "n4"}], "  ", 
        RowBox[{
         RowBox[{
          RowBox[{"Derivative", "[", 
           RowBox[{"n1", ",", "0", ",", "0", ",", "0"}], "]"}], "[", 
          "\[CapitalPhi]", "]"}], "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], "}"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApproxSimplify", "[", "x_", "]"}], ":=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"x", ",", 
      RowBox[{"TransformationFunctions", "\[Rule]", "approx"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"ApproxFullSimplify", "[", "x_", "]"}], ":=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"x", "//", "ApproxSimplify"}], "//", "Expand"}], "//", 
          "ApproxSimplify"}], ")"}], "/.", "fourierderiv"}], "//.", 
       "thetadef"}], "//.", "k2def"}], "//.", "thetadef1"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7513748189315634`*^9, 3.75137487008078*^9}, {
  3.751376781872209*^9, 3.7513767843020315`*^9}, {3.758372322855113*^9, 
  3.7583723611300917`*^9}, {3.7590605812202024`*^9, 3.7590605814856043`*^9}, {
  3.7596496124296975`*^9, 
  3.7596496186637754`*^9}},ExpressionUUID->"c1ef4baa-5e9a-4f69-bbc7-\
5922e1993efb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Testing", " ", "the", " ", "metric", " ", "and", " ", "Cronecker", " ", 
    "\[Delta]ij"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Raise", "[", 
    RowBox[{"gdd", ",", 
     RowBox[{"{", "1", "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Lower", "[", 
    RowBox[{"gUU", ",", 
     RowBox[{"{", "1", "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"\[Delta]Ud", "=", 
    RowBox[{"IdentityMatrix", "[", "4", "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Delta]ij", "=", 
     RowBox[{"IdentityMatrix", "[", "3", "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7277825039451513`*^9, 3.7277825200839076`*^9}, {
  3.7278550409146614`*^9, 3.7278550683175163`*^9}, {3.728226515349077*^9, 
  3.728226549260151*^9}},ExpressionUUID->"bd1f1de1-b3a0-4c89-ab1b-\
5d18f5a990ff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7590606303604946`*^9, 3.7590609772716427`*^9, 3.759061095450588*^9, 
   3.759062803815152*^9, 3.7590650519755898`*^9, 3.7595831150818405`*^9, 
   3.75964880956919*^9, 3.759662090494628*^9, 3.760600145691403*^9, 
   3.7607058223628216`*^9, 3.760706279918787*^9, 3.760707305542116*^9, 
   3.76079343203928*^9, 3.760860121825788*^9, 3.760861641180434*^9, 
   3.760866150309973*^9, 3.7608665675879726`*^9, 3.7608678878977084`*^9, 
   3.760868356028985*^9, {3.760868798576586*^9, 3.760868821787098*^9}, 
   3.7608761213764668`*^9, 3.7608773327672396`*^9, 3.760954505631632*^9, 
   3.760954545676605*^9, 3.7609642735434504`*^9, 3.760965086251425*^9, 
   3.7609666415754766`*^9, 3.7610283663493366`*^9, 3.7614714418439503`*^9, 
   3.7614755857016993`*^9, 3.761483953477153*^9, 3.761496767479333*^9, 
   3.761561087771804*^9, 3.761569935367033*^9, 3.7616467981384163`*^9, 
   3.761648523053357*^9, 3.761655111234627*^9, 3.7616571788045173`*^9, 
   3.7616681885481067`*^9, 3.761903512473089*^9, 3.761913697271626*^9, 
   3.7619151223569503`*^9, 3.7619268142842555`*^9, 3.7619276098417034`*^9, 
   3.761928492611199*^9, 3.7619787411600523`*^9, 3.762080789904751*^9, 
   3.762082037055439*^9, 3.7620869254951305`*^9, 3.763100870455947*^9, 
   3.7631009422930593`*^9, 3.763113574016038*^9, 3.763115133805951*^9, 
   3.7631204679336853`*^9, 3.763121432711812*^9, 3.763121735008973*^9, 
   3.76312188551721*^9, 3.7631228241525407`*^9, 3.763133210596504*^9, 
   3.7631339358389225`*^9, 3.7631344676177993`*^9, 3.763188752585925*^9, 
   3.763189113473654*^9, 3.7634619096099157`*^9, 3.7634624850807357`*^9, 
   3.7634630868713207`*^9, 
   3.7638063355250225`*^9},ExpressionUUID->"71a8d887-88ad-4912-8108-\
c3375c9a5148"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7590606303604946`*^9, 3.7590609772716427`*^9, 3.759061095450588*^9, 
   3.759062803815152*^9, 3.7590650519755898`*^9, 3.7595831150818405`*^9, 
   3.75964880956919*^9, 3.759662090494628*^9, 3.760600145691403*^9, 
   3.7607058223628216`*^9, 3.760706279918787*^9, 3.760707305542116*^9, 
   3.76079343203928*^9, 3.760860121825788*^9, 3.760861641180434*^9, 
   3.760866150309973*^9, 3.7608665675879726`*^9, 3.7608678878977084`*^9, 
   3.760868356028985*^9, {3.760868798576586*^9, 3.760868821787098*^9}, 
   3.7608761213764668`*^9, 3.7608773327672396`*^9, 3.760954505631632*^9, 
   3.760954545676605*^9, 3.7609642735434504`*^9, 3.760965086251425*^9, 
   3.7609666415754766`*^9, 3.7610283663493366`*^9, 3.7614714418439503`*^9, 
   3.7614755857016993`*^9, 3.761483953477153*^9, 3.761496767479333*^9, 
   3.761561087771804*^9, 3.761569935367033*^9, 3.7616467981384163`*^9, 
   3.761648523053357*^9, 3.761655111234627*^9, 3.7616571788045173`*^9, 
   3.7616681885481067`*^9, 3.761903512473089*^9, 3.761913697271626*^9, 
   3.7619151223569503`*^9, 3.7619268142842555`*^9, 3.7619276098417034`*^9, 
   3.761928492611199*^9, 3.7619787411600523`*^9, 3.762080789904751*^9, 
   3.762082037055439*^9, 3.7620869254951305`*^9, 3.763100870455947*^9, 
   3.7631009422930593`*^9, 3.763113574016038*^9, 3.763115133805951*^9, 
   3.7631204679336853`*^9, 3.763121432711812*^9, 3.763121735008973*^9, 
   3.76312188551721*^9, 3.7631228241525407`*^9, 3.763133210596504*^9, 
   3.7631339358389225`*^9, 3.7631344676177993`*^9, 3.763188752585925*^9, 
   3.763189113473654*^9, 3.7634619096099157`*^9, 3.7634624850807357`*^9, 
   3.7634630868713207`*^9, 
   3.763806335535178*^9},ExpressionUUID->"12fb8686-9d0b-4d60-90c7-\
6661cf9a8647"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7590606303604946`*^9, 3.7590609772716427`*^9, 3.759061095450588*^9, 
   3.759062803815152*^9, 3.7590650519755898`*^9, 3.7595831150818405`*^9, 
   3.75964880956919*^9, 3.759662090494628*^9, 3.760600145691403*^9, 
   3.7607058223628216`*^9, 3.760706279918787*^9, 3.760707305542116*^9, 
   3.76079343203928*^9, 3.760860121825788*^9, 3.760861641180434*^9, 
   3.760866150309973*^9, 3.7608665675879726`*^9, 3.7608678878977084`*^9, 
   3.760868356028985*^9, {3.760868798576586*^9, 3.760868821787098*^9}, 
   3.7608761213764668`*^9, 3.7608773327672396`*^9, 3.760954505631632*^9, 
   3.760954545676605*^9, 3.7609642735434504`*^9, 3.760965086251425*^9, 
   3.7609666415754766`*^9, 3.7610283663493366`*^9, 3.7614714418439503`*^9, 
   3.7614755857016993`*^9, 3.761483953477153*^9, 3.761496767479333*^9, 
   3.761561087771804*^9, 3.761569935367033*^9, 3.7616467981384163`*^9, 
   3.761648523053357*^9, 3.761655111234627*^9, 3.7616571788045173`*^9, 
   3.7616681885481067`*^9, 3.761903512473089*^9, 3.761913697271626*^9, 
   3.7619151223569503`*^9, 3.7619268142842555`*^9, 3.7619276098417034`*^9, 
   3.761928492611199*^9, 3.7619787411600523`*^9, 3.762080789904751*^9, 
   3.762082037055439*^9, 3.7620869254951305`*^9, 3.763100870455947*^9, 
   3.7631009422930593`*^9, 3.763113574016038*^9, 3.763115133805951*^9, 
   3.7631204679336853`*^9, 3.763121432711812*^9, 3.763121735008973*^9, 
   3.76312188551721*^9, 3.7631228241525407`*^9, 3.763133210596504*^9, 
   3.7631339358389225`*^9, 3.7631344676177993`*^9, 3.763188752585925*^9, 
   3.763189113473654*^9, 3.7634619096099157`*^9, 3.7634624850807357`*^9, 
   3.7634630868713207`*^9, 
   3.7638063355453253`*^9},ExpressionUUID->"f9a3b860-90b2-4feb-a463-\
ab5994af19f8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"R0", "=", 
  RowBox[{
   RowBox[{"R", "/.", "zeroorder"}], "//", "Expand"}]}], "\n", 
 RowBox[{"R0order", "=", 
  RowBox[{
   RowBox[{"R0", "/.", "a2H"}], "//", "Simplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"dR", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"R", "-", "R0"}], "/.", "a2H"}], "//", "Simplify"}], "//", 
   "ApproxFullSimplify"}]}]}], "Input",ExpressionUUID->"42d26ee8-2449-4850-\
8f12-f2945ae3924b"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"6", " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["a", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]], "+", 
  FractionBox[
   RowBox[{"6", " ", 
    RowBox[{
     SuperscriptBox["a", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]]}]], "Output",
 CellChangeTimes->{
  3.759060630431581*^9, 3.7590609773356757`*^9, 3.7590610955155935`*^9, 
   3.7590628038802648`*^9, 3.7590650520447483`*^9, 3.759583115142438*^9, 
   3.7596488096344576`*^9, 3.7596620905649223`*^9, 3.7606001457121105`*^9, 
   3.7607058224241076`*^9, 3.760706279979782*^9, 3.7607073056033525`*^9, 
   3.7607934321138945`*^9, 3.7608601219007573`*^9, 3.76086164192819*^9, 
   3.7608661503741474`*^9, 3.760866567651971*^9, 3.7608678879625545`*^9, 
   3.760868356100346*^9, {3.7608687986415386`*^9, 3.760868821847828*^9}, 
   3.7608761214367857`*^9, 3.7608773328319044`*^9, 3.760954505681946*^9, 
   3.760954545736639*^9, 3.7609642736115503`*^9, 3.760965086313573*^9, 
   3.7609666416416273`*^9, 3.7610283664814596`*^9, 3.7614714419043393`*^9, 
   3.7614755857790394`*^9, 3.761483953537105*^9, 3.761496767529524*^9, 
   3.7615610878269625`*^9, 3.761569935439452*^9, 3.7616467982102537`*^9, 
   3.761648523127827*^9, 3.76165511129965*^9, 3.7616571788652716`*^9, 
   3.7616681886725254`*^9, 3.7619035125381713`*^9, 3.761913697333951*^9, 
   3.7619151224221864`*^9, 3.7619268143268785`*^9, 3.7619276098655186`*^9, 
   3.761928492631485*^9, 3.761978741217676*^9, 3.7620807899648666`*^9, 
   3.7620820371253223`*^9, 3.7620869255722866`*^9, 3.7631008705189443`*^9, 
   3.7631009423721695`*^9, 3.763113574088132*^9, 3.7631151339317675`*^9, 
   3.7631204679886055`*^9, 3.7631214327715507`*^9, 3.7631217350666976`*^9, 
   3.7631218855817204`*^9, 3.763122824209553*^9, 3.7631332106372843`*^9, 
   3.7631339358589706`*^9, 3.763134467643613*^9, 3.763188752680815*^9, 
   3.7631891135641656`*^9, 3.763461909679641*^9, 3.763462485160813*^9, 
   3.76346308694637*^9, 
   3.763806335606058*^9},ExpressionUUID->"a5cc3dc2-de20-4a3d-8833-\
1f89dbc131de"],

Cell[BoxData[
 RowBox[{"6", " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.759060630431581*^9, 3.7590609773356757`*^9, 3.7590610955155935`*^9, 
   3.7590628038802648`*^9, 3.7590650520447483`*^9, 3.759583115142438*^9, 
   3.7596488096344576`*^9, 3.7596620905649223`*^9, 3.7606001457121105`*^9, 
   3.7607058224241076`*^9, 3.760706279979782*^9, 3.7607073056033525`*^9, 
   3.7607934321138945`*^9, 3.7608601219007573`*^9, 3.76086164192819*^9, 
   3.7608661503741474`*^9, 3.760866567651971*^9, 3.7608678879625545`*^9, 
   3.760868356100346*^9, {3.7608687986415386`*^9, 3.760868821847828*^9}, 
   3.7608761214367857`*^9, 3.7608773328319044`*^9, 3.760954505681946*^9, 
   3.760954545736639*^9, 3.7609642736115503`*^9, 3.760965086313573*^9, 
   3.7609666416416273`*^9, 3.7610283664814596`*^9, 3.7614714419043393`*^9, 
   3.7614755857790394`*^9, 3.761483953537105*^9, 3.761496767529524*^9, 
   3.7615610878269625`*^9, 3.761569935439452*^9, 3.7616467982102537`*^9, 
   3.761648523127827*^9, 3.76165511129965*^9, 3.7616571788652716`*^9, 
   3.7616681886725254`*^9, 3.7619035125381713`*^9, 3.761913697333951*^9, 
   3.7619151224221864`*^9, 3.7619268143268785`*^9, 3.7619276098655186`*^9, 
   3.761928492631485*^9, 3.761978741217676*^9, 3.7620807899648666`*^9, 
   3.7620820371253223`*^9, 3.7620869255722866`*^9, 3.7631008705189443`*^9, 
   3.7631009423721695`*^9, 3.763113574088132*^9, 3.7631151339317675`*^9, 
   3.7631204679886055`*^9, 3.7631214327715507`*^9, 3.7631217350666976`*^9, 
   3.7631218855817204`*^9, 3.763122824209553*^9, 3.7631332106372843`*^9, 
   3.7631339358589706`*^9, 3.763134467643613*^9, 3.763188752680815*^9, 
   3.7631891135641656`*^9, 3.763461909679641*^9, 3.763462485160813*^9, 
   3.76346308694637*^9, 
   3.763806335614128*^9},ExpressionUUID->"70685291-5a2d-412c-bd34-\
cb9810ca5e39"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"4", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[CapitalPhi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]], "+", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]], "-", 
  RowBox[{"24", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"12", " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"24", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.759060630431581*^9, 3.7590609773356757`*^9, 3.7590610955155935`*^9, 
   3.7590628038802648`*^9, 3.7590650520447483`*^9, 3.759583115142438*^9, 
   3.7596488096344576`*^9, 3.7596620905649223`*^9, 3.7606001457121105`*^9, 
   3.7607058224241076`*^9, 3.760706279979782*^9, 3.7607073056033525`*^9, 
   3.7607934321138945`*^9, 3.7608601219007573`*^9, 3.76086164192819*^9, 
   3.7608661503741474`*^9, 3.760866567651971*^9, 3.7608678879625545`*^9, 
   3.760868356100346*^9, {3.7608687986415386`*^9, 3.760868821847828*^9}, 
   3.7608761214367857`*^9, 3.7608773328319044`*^9, 3.760954505681946*^9, 
   3.760954545736639*^9, 3.7609642736115503`*^9, 3.760965086313573*^9, 
   3.7609666416416273`*^9, 3.7610283664814596`*^9, 3.7614714419043393`*^9, 
   3.7614755857790394`*^9, 3.761483953537105*^9, 3.761496767529524*^9, 
   3.7615610878269625`*^9, 3.761569935439452*^9, 3.7616467982102537`*^9, 
   3.761648523127827*^9, 3.76165511129965*^9, 3.7616571788652716`*^9, 
   3.7616681886725254`*^9, 3.7619035125381713`*^9, 3.761913697333951*^9, 
   3.7619151224221864`*^9, 3.7619268143268785`*^9, 3.7619276098655186`*^9, 
   3.761928492631485*^9, 3.761978741217676*^9, 3.7620807899648666`*^9, 
   3.7620820371253223`*^9, 3.7620869255722866`*^9, 3.7631008705189443`*^9, 
   3.7631009423721695`*^9, 3.763113574088132*^9, 3.7631151339317675`*^9, 
   3.7631204679886055`*^9, 3.7631214327715507`*^9, 3.7631217350666976`*^9, 
   3.7631218855817204`*^9, 3.763122824209553*^9, 3.7631332106372843`*^9, 
   3.7631339358589706`*^9, 3.763134467643613*^9, 3.763188752680815*^9, 
   3.7631891135641656`*^9, 3.763461909679641*^9, 3.763462485160813*^9, 
   3.76346308694637*^9, 
   3.763806335910205*^9},ExpressionUUID->"0ac012ca-86c8-497a-be2a-\
cf488456cbce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\[Delta]R = \>\"", ",", "dR"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{"\"\<\[Delta]R (k^2>>a^2 H^2) = \>\"", ",", 
   RowBox[{
    RowBox[{"dR", "/.", "horizon"}], "//", "Expand"}]}], "]"}]}], "Input",Expr\
essionUUID->"01cb8c31-1d2f-4630-a9aa-6bbf134eb797"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\[Delta]R = \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{"4", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]], "+", 
    FractionBox[
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]], "-", 
    RowBox[{"24", " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"24", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}],
  SequenceForm[
  "\[Delta]R = ", 
   4 $CellContext`k^2 $CellContext`a[$CellContext`t]^(-2) $CellContext`\
\[CapitalPhi][$CellContext`t, $CellContext`x, $CellContext`y, $CellContext`z] + 
   2 $CellContext`k^2 $CellContext`a[$CellContext`t]^(-2) $CellContext`\
\[CapitalPsi][$CellContext`t, $CellContext`x, $CellContext`y, $CellContext`z] - 
   24 $CellContext`H[$CellContext`t]^2 \
$CellContext`\[CapitalPsi][$CellContext`t, $CellContext`x, $CellContext`y, \
$CellContext`z] - 
   12 $CellContext`\[CapitalPsi][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z] Derivative[1][$CellContext`H][$CellContext`t] + 
   24 $CellContext`H[$CellContext`t] 
    Derivative[
     1, 0, 0, 0][$CellContext`\[CapitalPhi]][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z] - 6 $CellContext`H[$CellContext`t] 
   Derivative[
    1, 0, 0, 0][$CellContext`\[CapitalPsi]][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z] + 
   6 Derivative[
     2, 0, 0, 0][$CellContext`\[CapitalPhi]][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z]],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7590606307378044`*^9, 3.7590609776855326`*^9, 3.7590610958556423`*^9, 
   3.759062804220085*^9, 3.7590650523551064`*^9, 3.7595831154516344`*^9, 
   3.759648809929325*^9, 3.7596620908696785`*^9, 3.76060014595553*^9, 
   3.7607058227576437`*^9, 3.760706280314084*^9, 3.760707305929514*^9, 
   3.760793432419361*^9, 3.760860122217688*^9, 3.7608616435949817`*^9, 
   3.7608661506745048`*^9, 3.760866567981799*^9, 3.7608678882675743`*^9, 
   3.760868356417729*^9, {3.760868798731619*^9, 3.7608688222407475`*^9}, 
   3.7608761217419276`*^9, 3.7608773331692343`*^9, 3.76095450574193*^9, 
   3.760954546081467*^9, 3.7609642739116073`*^9, 3.7609650866738386`*^9, 
   3.7609666419620857`*^9, 3.7610283667452545`*^9, 3.7614714422393217`*^9, 
   3.761475586116731*^9, 3.7614839538392954`*^9, 3.7614967678190145`*^9, 
   3.761561088186981*^9, 3.7615699357447343`*^9, 3.7616467985231266`*^9, 
   3.76164852344363*^9, 3.7616551116419134`*^9, 3.761657179190094*^9, 
   3.761668188926268*^9, 3.761903512847846*^9, 3.761913697631603*^9, 
   3.7619151227572355`*^9, 3.7619268145991993`*^9, 3.7619276102106123`*^9, 
   3.7619284929237413`*^9, 3.7619787415327673`*^9, 3.7620807902848935`*^9, 
   3.762082037465766*^9, 3.7620869258848205`*^9, 3.763100870590049*^9, 
   3.763100942718793*^9, 3.7631135743861456`*^9, 3.763115134266389*^9, 
   3.763120468296665*^9, 3.7631214330869184`*^9, 3.7631217353992543`*^9, 
   3.7631218859171457`*^9, 3.7631228245070286`*^9, 3.763133210912633*^9, 
   3.763133936123515*^9, 3.7631344679174185`*^9, 3.763188753065727*^9, 
   3.763189114022584*^9, 3.7634619099914017`*^9, 3.7634624854557867`*^9, 
   3.763463087291398*^9, 
   3.763806335989319*^9},ExpressionUUID->"e507c56e-25ad-46e6-aef4-\
885eac9b3455"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\[Delta]R (k^2>>a^2 H^2) = \"\>", "\[InvisibleSpace]", "0"}],
  SequenceForm["\[Delta]R (k^2>>a^2 H^2) = ", 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7590606307378044`*^9, 3.7590609776855326`*^9, 3.7590610958556423`*^9, 
   3.759062804220085*^9, 3.7590650523551064`*^9, 3.7595831154516344`*^9, 
   3.759648809929325*^9, 3.7596620908696785`*^9, 3.76060014595553*^9, 
   3.7607058227576437`*^9, 3.760706280314084*^9, 3.760707305929514*^9, 
   3.760793432419361*^9, 3.760860122217688*^9, 3.7608616435949817`*^9, 
   3.7608661506745048`*^9, 3.760866567981799*^9, 3.7608678882675743`*^9, 
   3.760868356417729*^9, {3.760868798731619*^9, 3.7608688222407475`*^9}, 
   3.7608761217419276`*^9, 3.7608773331692343`*^9, 3.76095450574193*^9, 
   3.760954546081467*^9, 3.7609642739116073`*^9, 3.7609650866738386`*^9, 
   3.7609666419620857`*^9, 3.7610283667452545`*^9, 3.7614714422393217`*^9, 
   3.761475586116731*^9, 3.7614839538392954`*^9, 3.7614967678190145`*^9, 
   3.761561088186981*^9, 3.7615699357447343`*^9, 3.7616467985231266`*^9, 
   3.76164852344363*^9, 3.7616551116419134`*^9, 3.761657179190094*^9, 
   3.761668188926268*^9, 3.761903512847846*^9, 3.761913697631603*^9, 
   3.7619151227572355`*^9, 3.7619268145991993`*^9, 3.7619276102106123`*^9, 
   3.7619284929237413`*^9, 3.7619787415327673`*^9, 3.7620807902848935`*^9, 
   3.762082037465766*^9, 3.7620869258848205`*^9, 3.763100870590049*^9, 
   3.763100942718793*^9, 3.7631135743861456`*^9, 3.763115134266389*^9, 
   3.763120468296665*^9, 3.7631214330869184`*^9, 3.7631217353992543`*^9, 
   3.7631218859171457`*^9, 3.7631228245070286`*^9, 3.763133210912633*^9, 
   3.763133936123515*^9, 3.7631344679174185`*^9, 3.763188753065727*^9, 
   3.763189114022584*^9, 3.7634619099914017`*^9, 3.7634624854557867`*^9, 
   3.763463087291398*^9, 
   3.7638063359913845`*^9},ExpressionUUID->"bc5fbe84-1c8b-40c8-9951-\
06a33d6590bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"uU", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "-", 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], ",", 
     RowBox[{
      RowBox[{"ux", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
      RowBox[{"a", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"uy", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
      RowBox[{"a", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"uz", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
      RowBox[{"a", "[", "t", "]"}]}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ud", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Lower", "[", 
      RowBox[{"uU", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "//", "ApproxFullSimplify"}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"multiDot", "[", 
   RowBox[{"gdd", ",", "gUU", ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "2"}], "}"}]}], "]"}], "//", 
  "ApproxFullSimplify"}], "\n", 
 RowBox[{
  RowBox[{"multiDot", "[", 
   RowBox[{"ud", ",", 
    RowBox[{"Raise", "[", 
     RowBox[{"ud", ",", "1"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}], "]"}], "//", 
  "ApproxFullSimplify"}]}], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQvWGVkPONo68dvzF89wXRDlclb9wE0rNsIsD0PkXh
+yBaZ14wmPaUvSh4C0h/+d8rBKLV0j5ngehNDTHZIHrW1uztIPr30+QdIDqg
i5n197HXjp9CXomC6BtThCaB6B2SFWD6z83cWX+BdN8Ps7kg2ue5ofJ/IP1T
8LcaiF4idmAm43Ggebqsc0H0NtUuP9YLrx1vLRf2B9HnlnwKAtFBq+cFg+i6
aJejM96+dpRbGgSmeZK8ZGYC6WWtgWA6Qj2XVe/za8dpO8vZQDST4H0+EP3C
LUoQTC96WmQKpNl//ikH0WnJzZeWAell0rsug2mGOVvaGN443nO13QaiAURu
tnQ=
  "],ExpressionUUID->"eab5c015-1e4a-4b02-aba1-1e3a80689083"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.7631009427997093`*^9, 3.763113574470743*^9, 
  3.763115134366584*^9, 3.763120468376342*^9, 3.7631214331768045`*^9, 
  3.763121735501907*^9, 3.763121886017059*^9, 3.763122824589617*^9, 
  3.7631332110891037`*^9, 3.763133936165812*^9, 3.763134467963481*^9, 
  3.7631887531873903`*^9, 3.763189114143776*^9, 3.763461910084491*^9, 
  3.7634624855606766`*^9, 3.763463087391301*^9, 
  3.7638063360723796`*^9},ExpressionUUID->"f8bbbc8f-1a7f-4456-9324-\
6dec9e45bfac"],

Cell[BoxData[
 RowBox[{"-", "1"}]], "Output",
 CellChangeTimes->{3.7631009427997093`*^9, 3.763113574470743*^9, 
  3.763115134366584*^9, 3.763120468376342*^9, 3.7631214331768045`*^9, 
  3.763121735501907*^9, 3.763121886017059*^9, 3.763122824589617*^9, 
  3.7631332110891037`*^9, 3.763133936165812*^9, 3.763134467963481*^9, 
  3.7631887531873903`*^9, 3.763189114143776*^9, 3.763461910084491*^9, 
  3.7634624855606766`*^9, 3.763463087391301*^9, 
  3.763806336082465*^9},ExpressionUUID->"96e98809-a839-456f-af81-\
ebc6ec23ffd5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[CapitalSigma]mij", "=", 
  RowBox[{
   RowBox[{
    FractionBox["3", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "+", 
      RowBox[{"Pm", "[", "t", "]"}]}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"\[Sigma]m", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "2"}], "}"}]}], 
           "]"}], "-", 
          RowBox[{
           FractionBox["1", "3"], "\[Delta]ij", " ", 
           RowBox[{"Laplacian", "[", 
            RowBox[{
             RowBox[{"\[Sigma]m", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]}], ")"}], "//",
         "ApproxFullSimplify"}], "//", "FullSimplify"}], ")"}], "/", 
     RowBox[{"k", "^", "2"}]}]}], "/.", 
   RowBox[{
    SuperscriptBox["kx", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"k", "^", "2"}], "-", 
     SuperscriptBox["ky", "2"], "-", 
     SuperscriptBox["kz", "2"]}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalSigma]mUd", "=", 
   RowBox[{"PadLeft", "[", 
    RowBox[{"\[CapitalSigma]mij", ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "4"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "//", "Tr"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7282265644463835`*^9, 3.7282265927394605`*^9}, {
  3.7282266358858113`*^9, 3.7282266477086425`*^9}, {3.728226694240508*^9, 
  3.728226701809886*^9}, {3.7282276143118486`*^9, 3.7282276289434986`*^9}, {
  3.7282290285520906`*^9, 3.728229031516563*^9}, {3.728229104884276*^9, 
  3.7282291191554737`*^9}, {3.7282292011905327`*^9, 3.7282292474078226`*^9}, {
  3.7282294521716614`*^9, 3.7282294563422194`*^9}, {3.7282295476299024`*^9, 
  3.728229556812442*^9}, {3.728229608753275*^9, 3.728229609280752*^9}, {
  3.728229695971506*^9, 3.728229717849072*^9}, {3.728230388372016*^9, 
  3.72823040431419*^9}, {3.72823143686861*^9, 3.728231438815976*^9}, {
  3.7484477975745754`*^9, 3.748447861564948*^9}, {3.748448256678035*^9, 
  3.7484482710531406`*^9}, {3.748450211280148*^9, 3.7484502327661595`*^9}, {
  3.7513749175412693`*^9, 
  3.7513749217307234`*^9}},ExpressionUUID->"c66f8feb-b80a-4274-bd8d-\
4d357b56e58e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["ky", "2"], "+", 
         SuperscriptBox["kz", "2"], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["k", "2"], "-", 
            SuperscriptBox["ky", "2"], "-", 
            SuperscriptBox["kz", "2"]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Pm", "[", "t", "]"}], "+", 
         RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]m", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "kx", " ", "ky", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pm", "[", "t", "]"}], "+", 
          RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "kx", " ", "kz", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pm", "[", "t", "]"}], "+", 
          RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "kx", " ", "ky", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pm", "[", "t", "]"}], "+", 
          RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["ky", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Pm", "[", "t", "]"}], "+", 
         RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]m", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "ky", " ", "kz", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pm", "[", "t", "]"}], "+", 
          RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "kx", " ", "kz", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pm", "[", "t", "]"}], "+", 
          RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}], ",", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", "ky", " ", "kz", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"Pm", "[", "t", "]"}], "+", 
          RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"]}]]}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["k", "2"], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["kz", "2"]}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Pm", "[", "t", "]"}], "+", 
         RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
       RowBox[{"\[Sigma]m", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.751374933931777*^9, 3.751374990251089*^9, 3.751390327226348*^9, 
   3.751463768062127*^9, 3.7516223048492246`*^9, 3.7516247896032963`*^9, 
   3.751630062190139*^9, 3.753006102461089*^9, 3.753025954135844*^9, 
   3.7531038675050297`*^9, 3.7531100489603024`*^9, 3.7533433997269087`*^9, 
   3.7540532276802635`*^9, 3.7541304100394917`*^9, 3.756109307238*^9, 
   3.7561093882601385`*^9, 3.756113860232616*^9, 3.756807472950308*^9, 
   3.757915711819989*^9, 3.7579238216541505`*^9, 3.7583540850228925`*^9, 
   3.7583631530637655`*^9, 3.758372392935295*^9, 3.7584542489473577`*^9, 
   3.7584606624868855`*^9, 3.7590389281522074`*^9, 3.7590421915924077`*^9, 
   3.759045349454528*^9, 3.759058817950717*^9, 3.7590606309506783`*^9, 
   3.75906097791563*^9, 3.7590610960755067`*^9, 3.759062804425481*^9, 
   3.7590650525548897`*^9, 3.759583115681364*^9, 3.7596488101604385`*^9, 
   3.7596620911089087`*^9, 3.76060014606775*^9, 3.7607058229741707`*^9, 
   3.7607062805839796`*^9, 3.7607073062350717`*^9, 3.760793432659232*^9, 
   3.760860122465685*^9, 3.7608616477451863`*^9, 3.7608661508941274`*^9, 
   3.760866568216975*^9, 3.760867888509745*^9, 3.760868356647871*^9, {
   3.7608687988214426`*^9, 3.760868822456597*^9}, 3.7608761219816756`*^9, 
   3.7608773334322248`*^9, 3.7609545059914913`*^9, 3.7609545463190536`*^9, 
   3.7609642741438518`*^9, 3.7609650869413757`*^9, 3.7609666422218056`*^9, 
   3.761028366958644*^9, 3.7614714424641747`*^9, 3.7614755863920856`*^9, 
   3.761483954087438*^9, 3.7614967680172415`*^9, 3.761561088426938*^9, 
   3.761569935994686*^9, 3.7616467987732677`*^9, 3.7616485236584425`*^9, 
   3.761655111884472*^9, 3.761657179432846*^9, 3.7616681890490403`*^9, 
   3.761903513102708*^9, 3.7619136978375783`*^9, 3.761915123032145*^9, 
   3.761926814807205*^9, 3.7619276103144865`*^9, 3.761928493027172*^9, 
   3.7619787417522964`*^9, 3.762080790495079*^9, 3.76208203770041*^9, 
   3.762086926049755*^9, 3.7631008708951564`*^9, 3.7631009429516573`*^9, 
   3.7631135746006403`*^9, 3.7631151345212183`*^9, 3.763120468506692*^9, 
   3.763121433346856*^9, 3.763121735651561*^9, 3.7631218861621995`*^9, 
   3.7631228247223024`*^9, 3.7631332111449366`*^9, 3.7631339362269106`*^9, 
   3.7631344680271664`*^9, 3.7631887533284187`*^9, 3.7631891143707867`*^9, 
   3.7634619102220244`*^9, 3.763462485698086*^9, 3.7634630875362935`*^9, 
   3.7638063362442017`*^9},ExpressionUUID->"985126c7-bb1a-45ea-b75d-\
30baa1a66675"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.751374933931777*^9, 3.751374990251089*^9, 3.751390327226348*^9, 
   3.751463768062127*^9, 3.7516223048492246`*^9, 3.7516247896032963`*^9, 
   3.751630062190139*^9, 3.753006102461089*^9, 3.753025954135844*^9, 
   3.7531038675050297`*^9, 3.7531100489603024`*^9, 3.7533433997269087`*^9, 
   3.7540532276802635`*^9, 3.7541304100394917`*^9, 3.756109307238*^9, 
   3.7561093882601385`*^9, 3.756113860232616*^9, 3.756807472950308*^9, 
   3.757915711819989*^9, 3.7579238216541505`*^9, 3.7583540850228925`*^9, 
   3.7583631530637655`*^9, 3.758372392935295*^9, 3.7584542489473577`*^9, 
   3.7584606624868855`*^9, 3.7590389281522074`*^9, 3.7590421915924077`*^9, 
   3.759045349454528*^9, 3.759058817950717*^9, 3.7590606309506783`*^9, 
   3.75906097791563*^9, 3.7590610960755067`*^9, 3.759062804425481*^9, 
   3.7590650525548897`*^9, 3.759583115681364*^9, 3.7596488101604385`*^9, 
   3.7596620911089087`*^9, 3.76060014606775*^9, 3.7607058229741707`*^9, 
   3.7607062805839796`*^9, 3.7607073062350717`*^9, 3.760793432659232*^9, 
   3.760860122465685*^9, 3.7608616477451863`*^9, 3.7608661508941274`*^9, 
   3.760866568216975*^9, 3.760867888509745*^9, 3.760868356647871*^9, {
   3.7608687988214426`*^9, 3.760868822456597*^9}, 3.7608761219816756`*^9, 
   3.7608773334322248`*^9, 3.7609545059914913`*^9, 3.7609545463190536`*^9, 
   3.7609642741438518`*^9, 3.7609650869413757`*^9, 3.7609666422218056`*^9, 
   3.761028366958644*^9, 3.7614714424641747`*^9, 3.7614755863920856`*^9, 
   3.761483954087438*^9, 3.7614967680172415`*^9, 3.761561088426938*^9, 
   3.761569935994686*^9, 3.7616467987732677`*^9, 3.7616485236584425`*^9, 
   3.761655111884472*^9, 3.761657179432846*^9, 3.7616681890490403`*^9, 
   3.761903513102708*^9, 3.7619136978375783`*^9, 3.761915123032145*^9, 
   3.761926814807205*^9, 3.7619276103144865`*^9, 3.761928493027172*^9, 
   3.7619787417522964`*^9, 3.762080790495079*^9, 3.76208203770041*^9, 
   3.762086926049755*^9, 3.7631008708951564`*^9, 3.7631009429516573`*^9, 
   3.7631135746006403`*^9, 3.7631151345212183`*^9, 3.763120468506692*^9, 
   3.763121433346856*^9, 3.763121735651561*^9, 3.7631218861621995`*^9, 
   3.7631228247223024`*^9, 3.7631332111449366`*^9, 3.7631339362269106`*^9, 
   3.7631344680271664`*^9, 3.7631887533284187`*^9, 3.7631891143707867`*^9, 
   3.7634619102220244`*^9, 3.763462485698086*^9, 3.7634630875362935`*^9, 
   3.7638063362543907`*^9},ExpressionUUID->"6eb91ec1-9e95-4756-9c7f-\
a29f28365e27"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TmUd", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Rho]m", "[", "t", "]"}], "+", 
            RowBox[{"\[Delta]\[Rho]m", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
            RowBox[{"Pm", "[", "t", "]"}], "+", 
            RowBox[{"\[Delta]Pm", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
          RowBox[{"uU", "[", 
           RowBox[{"[", "m", "]"}], "]"}], 
          RowBox[{"ud", "[", 
           RowBox[{"[", "n", "]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Pm", "[", "t", "]"}], "+", 
            RowBox[{"\[Delta]Pm", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
          RowBox[{"\[Delta]Ud", "[", 
           RowBox[{"[", 
            RowBox[{"m", ",", "n"}], "]"}], "]"}]}], "+", 
         RowBox[{"\[CapitalSigma]mUd", "[", 
          RowBox[{"[", 
           RowBox[{"m", ",", "n"}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"m", ",", "1", ",", "4"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "1", ",", "4"}], "}"}]}], "]"}], "//", 
      "FullSimplify"}], "//", "ApproxFullSimplify"}], "//", 
    "ApproxFullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Tmdd", "=", 
   RowBox[{"Lower", "[", 
    RowBox[{"TmUd", ",", 
     RowBox[{"{", "1", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"kv", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"kx", ",", "ky", ",", "kz"}], "}"}], "/", "k"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7282105220306444`*^9, 3.728210528279722*^9}, {
   3.72821056978397*^9, 3.7282105842135286`*^9}, {3.728215748742786*^9, 
   3.7282157739265547`*^9}, {3.7282277238705873`*^9, 3.7282277344965115`*^9}, 
   3.732941446289823*^9, {3.74844786996275*^9, 3.748447884583949*^9}, 
   3.7484479455572577`*^9, {3.7484480134886007`*^9, 3.748448025993548*^9}, {
   3.751374924371088*^9, 
   3.751374929360957*^9}},ExpressionUUID->"40897f7c-8c9c-4954-bfea-\
e0670da49f77"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"TmUd", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "1"}], "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TmUd", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "2"}], "]"}], "]"}], "//", 
  "Factor"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TmUd", "[", 
   RowBox[{"[", 
    RowBox[{"2", ",", "1"}], "]"}], "]"}], "//", 
  "Factor"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox["1", "3"], 
     RowBox[{"Sum", "[", 
      RowBox[{
       RowBox[{"TmUd", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "i"}], "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", "4"}], "}"}]}], "]"}]}], "/.", 
    RowBox[{
     SuperscriptBox["kx", "2"], "\[Rule]", 
     RowBox[{
      RowBox[{"k", "^", "2"}], "-", 
      SuperscriptBox["ky", "2"], "-", 
      SuperscriptBox["kz", "2"]}]}]}], "//", "ApproxFullSimplify"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"TmUd", "[", 
    RowBox[{"[", 
     RowBox[{"2", ",", "3"}], "]"}], "]"}], "/.", 
   RowBox[{
    SuperscriptBox["kx", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"k", "^", "2"}], "-", 
     SuperscriptBox["ky", "2"], "-", 
     SuperscriptBox["kz", "2"]}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalSigma]mij", "-", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"TmUd", "[", 
       RowBox[{"[", 
        RowBox[{"i", ",", "j"}], "]"}], "]"}], "-", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Delta]Ud", "[", 
         RowBox[{"[", 
          RowBox[{"i", ",", "j"}], "]"}], "]"}], "3"], 
       RowBox[{"Tr", "[", 
        RowBox[{"TmUd", "[", 
         RowBox[{"[", 
          RowBox[{
           RowBox[{"2", ";;", "4"}], ",", 
           RowBox[{"2", ";;", "4"}]}], "]"}], "]"}], "]"}]}]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "2", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"j", ",", "2", ",", "4"}], "}"}]}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sum", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"kv", "[", 
             RowBox[{"[", "i", "]"}], "]"}], 
            RowBox[{"kv", "[", 
             RowBox[{"[", "j", "]"}], "]"}]}], "-", 
           RowBox[{
            FractionBox["1", "3"], 
            RowBox[{"\[Delta]ij", "[", 
             RowBox[{"[", 
              RowBox[{"i", ",", "j"}], "]"}], "]"}]}]}], ")"}], 
         RowBox[{"\[CapitalSigma]mij", "[", 
          RowBox[{"[", 
           RowBox[{"i", ",", "j"}], "]"}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "1", ",", "3"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}]}], "//", 
     "FullSimplify"}], ")"}], "/.", 
   RowBox[{
    SuperscriptBox["kx", "2"], "\[Rule]", 
    RowBox[{
     RowBox[{"k", "^", "2"}], "-", 
     SuperscriptBox["ky", "2"], "-", 
     SuperscriptBox["kz", "2"]}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalSigma]mij", "//", "Tr"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7282157260577545`*^9, 3.7282157348151407`*^9}, {
  3.72821599042015*^9, 3.728216017926318*^9}, {3.7282327180497165`*^9, 
  3.728232786537921*^9}, {3.7282329038982887`*^9, 3.728232920124566*^9}, {
  3.728233042404564*^9, 3.7282331003867397`*^9}, {3.728280722845909*^9, 
  3.7282807283308706`*^9}, {3.7484478896171503`*^9, 
  3.748447912429358*^9}},ExpressionUUID->"11d3145f-840e-4458-ba95-\
aabc41d721e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"\[Delta]\[Rho]m", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.763806337296693*^9},ExpressionUUID->"583dfaf9-3e86-406f-8f10-\
9395fe0c23d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"a", "[", "t", "]"}], " ", 
  RowBox[{"ux", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], "+", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.763806337306895*^9},ExpressionUUID->"6b1e5775-14f2-49c8-8243-\
3dcfc754bcd0"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"ux", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Pm", "[", "t", "]"}], "+", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}]}], 
   RowBox[{"a", "[", "t", "]"}]]}]], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.76380633731705*^9},ExpressionUUID->"0c5a6da5-60a5-40fe-9e98-\
0e951580ccf2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Pm", "[", "t", "]"}], "+", 
  RowBox[{"\[Delta]Pm", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.763806337327199*^9},ExpressionUUID->"e1ea27f7-9f35-41d6-8d9a-\
bc99bef9e8b9"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"3", " ", "kx", " ", "ky", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Pm", "[", "t", "]"}], "+", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
    RowBox[{"\[Sigma]m", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.7638063373372583`*^9},ExpressionUUID->"65ae0f94-b21d-484c-8b77-\
5df7055fbcbd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.763806337347411*^9},ExpressionUUID->"42961622-ff19-4fcb-9d65-\
32a175cc3f49"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], "+", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}], " ", 
  RowBox[{"\[Sigma]m", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.7638063373574953`*^9},ExpressionUUID->"dcff1757-d66f-406b-96ed-\
3923d2a0a002"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.758372401885089*^9, 3.758454469457201*^9, 3.758460663291957*^9, 
   3.759038928902187*^9, 3.7590421925347805`*^9, 3.7590453504119997`*^9, 
   3.7590588187560096`*^9, 3.759060631755909*^9, 3.759060978810378*^9, 
   3.75906109697055*^9, 3.7590628053551455`*^9, 3.7590650533950176`*^9, 
   3.759583116525955*^9, 3.7596488110493546`*^9, 3.759662091959638*^9, 
   3.7606001469047737`*^9, 3.760705823884105*^9, 3.7607062814222283`*^9, 
   3.760707307134988*^9, 3.7607934335339437`*^9, 3.760860123302723*^9, 
   3.760866151726267*^9, 3.7608665690868635`*^9, 3.7608678894164925`*^9, 
   3.760868357589857*^9, {3.7608687989913116`*^9, 3.7608688233890157`*^9}, 
   3.760876122831828*^9, 3.7608773343870134`*^9, 3.7609545080115757`*^9, 
   3.7609545471917095`*^9, 3.760964274971733*^9, 3.7609650879617233`*^9, 
   3.7609666431466722`*^9, 3.7610283677940235`*^9, 3.7614714433090997`*^9, 
   3.7614755872969666`*^9, 3.7614839549071198`*^9, 3.7614967688421316`*^9, 
   3.7615610893670015`*^9, 3.761569936849597*^9, 3.7616467996590605`*^9, 
   3.7616485245937815`*^9, 3.761655112974552*^9, 3.76165718029032*^9, 
   3.761668189881096*^9, 3.761903513957554*^9, 3.7619136986387267`*^9, 
   3.761915123932329*^9, 3.76192681563546*^9, 3.7619276113076906`*^9, 
   3.7619284940101075`*^9, 3.761978742587617*^9, 3.7620807913297243`*^9, 
   3.7620820385779505`*^9, 3.7620869270197353`*^9, 3.7631008730430045`*^9, 
   3.7631009440063972`*^9, 3.7631135754305124`*^9, 3.76311513554617*^9, 
   3.763120469331721*^9, 3.7631214342767735`*^9, 3.7631217365618935`*^9, 
   3.7631218870095296`*^9, 3.763122825562302*^9, 3.7631332120112305`*^9, 
   3.7631339373425674`*^9, 3.7631344689739604`*^9, 3.7631887545110903`*^9, 
   3.76318911567274*^9, 3.7634619110815945`*^9, 3.763462486545665*^9, 
   3.763463088421341*^9, 
   3.7638063373676324`*^9},ExpressionUUID->"cb10c5de-7b75-4673-9eb0-\
634f293b7012"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "="}], ";"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]m", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "=", "0"}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.7513750272012033`*^9, 3.7513750332012186`*^9}, {
   3.7513770202022324`*^9, 3.7513770238764143`*^9}, 3.7514656973106537`*^9, {
   3.7516223194160223`*^9, 3.7516223198161387`*^9}, 3.760965056712118*^9, {
   3.7634599219869585`*^9, 
   3.7634599261969347`*^9}},ExpressionUUID->"0e3b9ecc-3482-4d0a-833d-\
f1e1e642a618"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Delta]G3", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"G3\[Phi]", "[", "t", "]"}], 
    RowBox[{"\[Delta]\[Phi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"G3X", "[", "t", "]"}], " ", 
    RowBox[{"\[Delta]X", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]G4", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"G4\[Phi]", "[", "t", "]"}], 
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]K", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"K\[Phi]", "[", "t", "]"}], 
    RowBox[{"\[Delta]\[Phi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"KX", "[", "t", "]"}], 
    RowBox[{"\[Delta]X", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]KX", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"KX\[Phi]", "[", "t", "]"}], 
    RowBox[{"\[Delta]\[Phi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"KXX", "[", "t", "]"}], 
    RowBox[{"\[Delta]X", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]G3X", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"G3X\[Phi]", "[", "t", "]"}], 
    RowBox[{"\[Delta]\[Phi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"G3XX", "[", "t", "]"}], 
    RowBox[{"\[Delta]X", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]G4\[Phi]", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], 
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]G4\[Phi]\[Phi]", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], 
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]K\[Phi]", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], 
    RowBox[{"\[Delta]\[Phi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"K\[Phi]X", "[", "t", "]"}], 
    RowBox[{"\[Delta]X", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Delta]G3\[Phi]", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], 
    RowBox[{"\[Delta]\[Phi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"G3\[Phi]X", "[", "t", "]"}], 
    RowBox[{"\[Delta]X", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K\[Phi]X", "[", "t_", "]"}], ":=", 
  RowBox[{"KX\[Phi]", "[", "t", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G3X\[Phi]", "[", "t_", "]"}], ":=", 
  RowBox[{"G3\[Phi]X", "[", "t", "]"}]}]}], "Input",
 CellChangeTimes->{{3.7513756680413914`*^9, 3.7513757932159615`*^9}, {
  3.751376089982006*^9, 3.751376097181456*^9}, {3.751376422321667*^9, 
  3.7513764775818787`*^9}, {3.75137665281417*^9, 3.75137666750132*^9}, {
  3.751391445007161*^9, 3.751391477966897*^9}, {3.7514644313514333`*^9, 
  3.7514644544422264`*^9}},ExpressionUUID->"29c2d53f-5f5d-4df6-8864-\
f56e538dc447"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"G2dd", "[", 
    RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]KX", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
     RowBox[{
      RowBox[{"covD", "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "m", "]"}], "]"}], 
     RowBox[{
      RowBox[{"covD", "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
      RowBox[{"[", "n", "]"}], "]"}]}], "-", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"K", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]K", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
     RowBox[{"gdd", "[", 
      RowBox[{"[", 
       RowBox[{"m", ",", "n"}], "]"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G3dd", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]G3X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
    RowBox[{"Laplacian", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
    RowBox[{
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "m", "]"}], "]"}], 
    RowBox[{
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "n", "]"}], "]"}]}], "+", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"G3", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]G3", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", "m", "]"}], "]"}], 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", "n", "]"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"G3", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]G3", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", "n", "]"}], "]"}], 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", "m", "]"}], "]"}]}]}], ")"}]}], "-", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"gdd", "[", 
     RowBox[{"[", 
      RowBox[{"m", ",", "n"}], "]"}], "]"}], 
    RowBox[{"multiDot", "[", 
     RowBox[{
      RowBox[{"covD", "[", 
       RowBox[{
        RowBox[{"G3", "[", "t", "]"}], "+", 
        RowBox[{"\[Delta]G3", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ",", 
      RowBox[{"Raise", "[", 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"G4dd", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]G4", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
    RowBox[{
     RowBox[{"Lower", "[", 
      RowBox[{"EUd", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"m", ",", "n"}], "]"}], "]"}]}], "+", 
   RowBox[{
    RowBox[{"gdd", "[", 
     RowBox[{"[", 
      RowBox[{"m", ",", "n"}], "]"}], "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"G4\[Phi]", "[", "t", "]"}], "+", 
         RowBox[{"\[Delta]G4\[Phi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], " ", 
       RowBox[{"Laplacian", "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
         RowBox[{"\[Delta]\[Phi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], "-", 
      
      RowBox[{"2", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"X", "[", "t", "]"}], "+", 
         RowBox[{"\[Delta]X", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "+", 
         RowBox[{"\[Delta]G4\[Phi]\[Phi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], 
     ")"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]G4\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
    RowBox[{
     RowBox[{"covD", "[", 
      RowBox[{"covD", "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "]"}], 
     "[", 
     RowBox[{"[", 
      RowBox[{"n", ",", "m"}], "]"}], "]"}]}], "-", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]G4\[Phi]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
    RowBox[{
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "m", "]"}], "]"}], 
    RowBox[{
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "n", "]"}], "]"}]}]}]}]}], "Input",
 CellChangeTimes->{{3.751375099651079*^9, 3.7513751667409544`*^9}, {
   3.7513752485150113`*^9, 3.7513752863210588`*^9}, {3.7513753247314715`*^9, 
   3.7513754701115875`*^9}, {3.751375503841916*^9, 3.7513755598207664`*^9}, {
   3.751375591521429*^9, 3.7513755928511724`*^9}, 3.7513757439508743`*^9, {
   3.7513758977814054`*^9, 3.751375898601404*^9}, {3.7513759591558895`*^9, 
   3.7513759621312313`*^9}, {3.7513760005316906`*^9, 
   3.7513760118115416`*^9}, {3.7513760695713687`*^9, 
   3.7513762243713083`*^9}, {3.7513763888319964`*^9, 3.751376447511751*^9}, {
   3.7513764821656513`*^9, 3.7513765106458206`*^9}, 3.7513765697717733`*^9, 
   3.7513770729520874`*^9, {3.7513771931268625`*^9, 
   3.7513772455822277`*^9}},ExpressionUUID->"58191868-87a6-4184-98cf-\
7755c3015750"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"L2", "=", 
   RowBox[{
    RowBox[{"K", "[", "t", "]"}], "+", 
    RowBox[{"\[Delta]K", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L3", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"G3", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]G3", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}], 
    RowBox[{"Laplacian", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"L4", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]G4", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "R"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P2", "=", 
   RowBox[{
    RowBox[{"K\[Phi]", "[", "t", "]"}], "+", 
    RowBox[{"\[Delta]K\[Phi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P3", "=", 
   RowBox[{"multiDot", "[", 
    RowBox[{
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"G3\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]G3\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ",", 
     RowBox[{"Raise", "[", 
      RowBox[{
       RowBox[{"covD", "[", 
        RowBox[{
         RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
         RowBox[{"\[Delta]\[Phi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "1"}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"P4", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]G4\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "R"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"J2", "=", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]KX", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}], 
    RowBox[{"covD", "[", 
     RowBox[{
      RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"J3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]G3X", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
     RowBox[{"Laplacian", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]G3X", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"X", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]X", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], "+", 
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"G3\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]G3\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], 
     RowBox[{"covD", "[", 
      RowBox[{
       RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"J4", "=", "0"}], ";"}]}], "Input",
 CellChangeTimes->{{3.7513911352521706`*^9, 3.7513911517095985`*^9}, {
  3.7513911821351604`*^9, 3.751391192069843*^9}, {3.751391224101254*^9, 
  3.7513912746603603`*^9}, {3.751391335135298*^9, 3.7513914168231983`*^9}, {
  3.7513915634734755`*^9, 3.7513917233424115`*^9}, {3.751392285474001*^9, 
  3.751392292830901*^9}},ExpressionUUID->"a0a86744-b7ae-4ae1-8124-\
f68a66a4e643"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Jtot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"J2", "+", "J3", "+", "J4"}], "/.", "a2H"}], "//", 
    "ApproxFullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Ptot", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"P2", "+", "P3", "+", "P4"}], "/.", "a2H"}], "//", 
    "ApproxFullSimplify"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.751630089960346*^9, 
  3.7516301008409786`*^9}},ExpressionUUID->"08b1fbf1-27b9-487c-9c31-\
32bd4fc1bb06"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqfield", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"covDiv", "[", 
       RowBox[{
        RowBox[{"Raise", "[", 
         RowBox[{"Jtot", ",", 
          RowBox[{"{", "1", "}"}]}], "]"}], ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], "-", "Ptot"}], "/.", "a2H"}], "//", 
    "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7513918006994076`*^9, 3.7513918839569454`*^9}, 
   3.7513923566150537`*^9, {3.7516300948798637`*^9, 
   3.751630105958971*^9}},ExpressionUUID->"bc4a36df-f3dc-4ab4-84a0-\
d0658a9f76b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqs", "[", 
   RowBox[{"m_", ",", "n_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"G2dd", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "+", 
   RowBox[{"G3dd", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "+", 
   RowBox[{"G4dd", "[", 
    RowBox[{"m", ",", "n"}], "]"}], "-", 
   RowBox[{"4", "\[Pi]", " ", "G", " ", 
    RowBox[{"Tmdd", "[", 
     RowBox[{"[", 
      RowBox[{"m", ",", "n"}], "]"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7270920960886416`*^9, 3.727092115063374*^9}, {
   3.7270921534795413`*^9, 3.7270921539424887`*^9}, {3.7271004926634445`*^9, 
   3.7271004929651904`*^9}, {3.7271005419843283`*^9, 3.727100549112282*^9}, 
   3.7276771288839464`*^9, {3.727679168704543*^9, 3.727679203568277*^9}, {
   3.727679242704391*^9, 3.7276792978083973`*^9}, 3.7276793506242247`*^9, {
   3.727680476673273*^9, 3.7276804771207595`*^9}, 3.7513750154910417`*^9, 
   3.7513763854716005`*^9, {3.7513766896039553`*^9, 3.7513767026218786`*^9}, 
   3.7514660608815327`*^9},ExpressionUUID->"b221360c-92d5-4177-bfe3-\
34eb74f0ae79"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"X0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], 
     RowBox[{
      RowBox[{"covD", "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ".", 
      "gUU", ".", 
      RowBox[{"covD", "[", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], "/.",
     "zeroorder"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dX", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ".", 
        "gUU", ".", 
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], 
      "-", "X0"}], "/.", "a2H"}], "//", "ApproxFullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rules", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"X", "[", "t", "]"}], "\[Rule]", "X0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["X", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"X0", ",", "t"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["X", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "->", 
      RowBox[{"D", "[", 
       RowBox[{"X0", ",", "t", ",", "t"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3X", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"G3X\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G3\[Phi]X", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["KX", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "->", 
      RowBox[{
       RowBox[{
        RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"\[Delta]X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "dX"}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Delta]X", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"dX", ",", "t"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Delta]X", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"dX", ",", "t", ",", "t"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["KX\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"KX\[Phi]X", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3\[Phi]X", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G3\[Phi]XX", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["KXX", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"KXXX", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3\[Phi]\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3XX", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "->", 
      RowBox[{
       RowBox[{
        RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G3XXX", "[", "t", "]"}], 
        RowBox[{"D", "[", 
         RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G4", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "->", 
      RowBox[{
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G4\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "->", 
      RowBox[{
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G4", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "->", 
      RowBox[{
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.751466593081308*^9, 3.751466614704674*^9}, {
  3.7516228899564342`*^9, 3.751622908806258*^9}, {3.751630624845647*^9, 
  3.751630688620259*^9}, {3.751631294980787*^9, 3.7516313126698475`*^9}, {
  3.7516330948767977`*^9, 3.751633095346636*^9}, {3.751633164717033*^9, 
  3.751633179776682*^9}, {3.7516341560292773`*^9, 3.751634167921378*^9}, {
  3.7530061436607847`*^9, 3.7530061498089514`*^9}, {3.756109333107901*^9, 
  3.756109342707824*^9}, {3.756109405996835*^9, 3.7561094391070805`*^9}, {
  3.7608678499980555`*^9, 3.760867854937951*^9}, {3.7609550353418703`*^9, 
  3.7609551744140778`*^9}},ExpressionUUID->"3ca70d18-2b39-4a00-ba63-\
dcb10f18c83a"],

Cell[CellGroupData[{

Cell[BoxData["dX"], "Input",ExpressionUUID->"66116201-7b3d-4afc-8d54-3e91bfa85b54"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.757915732106677*^9, 3.7579238254440403`*^9, 3.758354088801685*^9, 
   3.7583724274353437`*^9, 3.75846066637178*^9, 3.759038931964712*^9, 
   3.7590421959727297`*^9, 3.7590453539992547`*^9, 3.7590588218112106`*^9, 
   3.7590606350001354`*^9, 3.7590609822377195`*^9, 3.759061100485592*^9, 
   3.7590628088223085`*^9, 3.7590650565371056`*^9, 3.7595831196219277`*^9, 
   3.7596488144390335`*^9, 3.759662095509716*^9, 3.7606001497451563`*^9, 
   3.7607058274389014`*^9, 3.760706284849327*^9, 3.760707310724988*^9, 
   3.7607934367288923`*^9, 3.760860126360731*^9, 3.7608661547364416`*^9, 
   3.7608665725295115`*^9, 3.7608678927476673`*^9, 3.760868361079499*^9, {
   3.7608687998716197`*^9, 3.760868827171611*^9}, 3.760876125886914*^9, 
   3.760877337687288*^9, 3.7609545094519234`*^9, 3.7609545504647923`*^9, 
   3.7609642780217123`*^9, 3.7609650910464387`*^9, 3.7609666465619955`*^9, 
   3.7610283706261353`*^9, 3.7614714465292206`*^9, 3.7614755908766766`*^9, 
   3.76148395795018*^9, 3.761496771686111*^9, 3.761561092781741*^9, 
   3.761569940111106*^9, 3.7616468029585066`*^9, 3.7616485280957403`*^9, 
   3.7616551163446856`*^9, 3.7616571834300327`*^9, 3.7616681926036797`*^9, 
   3.761903517378001*^9, 3.7619137018988843`*^9, 3.7619151276130624`*^9, 
   3.761926818500166*^9, 3.761927614416256*^9, 3.7619284971915216`*^9, 
   3.761978745667389*^9, 3.7620807943851147`*^9, 3.762082041857686*^9, 
   3.7620869302599287`*^9, 3.763100874528059*^9, 3.7631009475661564`*^9, 
   3.76311357845584*^9, 3.7631151388499618`*^9, 3.763120472376645*^9, 
   3.763121437789259*^9, 3.763121740197112*^9, 3.7631218904492855`*^9, 
   3.763122828637475*^9, 3.7631332150278635`*^9, 3.763133940298296*^9, 
   3.763134472512398*^9, 3.763188758876912*^9, 3.763189120506238*^9, 
   3.7634619142495327`*^9, 3.7634624896104527`*^9, 3.763463091731574*^9, 
   3.7638063413484693`*^9},ExpressionUUID->"bf8b0f61-98f3-47dd-88ba-\
2ab4972b5752"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"dX", "=", 
    RowBox[{"\[Delta]X", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"rules", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"X", "[", "t", "]"}], "\[Rule]", "X0"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["X", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{"X0", ",", "t"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["X", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "->", 
       RowBox[{"D", "[", 
        RowBox[{"X0", ",", "t", ",", "t"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["G3", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"G3X", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["G3X", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"G3X\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"G3XX", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["G3\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"G3\[Phi]X", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["KX", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "->", 
       RowBox[{
        RowBox[{
         RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"KXX", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{"\[Delta]X", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "dX"}],
       ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Delta]X", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{"dX", ",", "t"}], "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["KX\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"KX\[Phi]X", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["G3\[Phi]X", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"G3\[Phi]XX", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["KXX", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"KXXX", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["G3\[Phi]\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["G3XX", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "->", 
       RowBox[{
        RowBox[{
         RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"G3XXX", "[", "t", "]"}], 
         RowBox[{"D", "[", 
          RowBox[{"X0", ",", "t"}], "]"}]}]}]}]}], "}"}]}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.756109446846969*^9, 3.7561094542266045`*^9}, {
  3.7568076202940035`*^9, 
  3.7568076225777435`*^9}},ExpressionUUID->"7792188c-1d30-4ca4-a05e-\
5ae1645766a6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eq00", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"eqs", "[", 
          RowBox[{"1", ",", "1"}], "]"}], "/.", "a2H"}], "//", 
        "ApproxFullSimplify"}], ")"}]}], "/.", "zeroorder"}], "/.", "rules"}],
    "//", "Expand"}]}], "\[IndentingNewLine]", 
 RowBox[{"eq11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{"eqs", "[", 
           RowBox[{"2", ",", "2"}], "]"}], 
          RowBox[{
           RowBox[{"a", "[", "t", "]"}], "^", "2"}]], "/.", "a2H"}], "//", 
        "ApproxFullSimplify"}], ")"}]}], "/.", "zeroorder"}], "/.", "rules"}],
    "//", "Expand"}]}]}], "Input",
 CellChangeTimes->{{3.751376707701953*^9, 3.751376730300601*^9}, 
   3.7513768399721413`*^9, {3.7513908298509245`*^9, 3.751390832775833*^9}, {
   3.7513909530965395`*^9, 3.751391000110719*^9}, {3.751466238456035*^9, 
   3.751466240629837*^9}, {3.7514664336815395`*^9, 3.7514664891124773`*^9}, {
   3.751466596764176*^9, 3.751466610133151*^9}, {3.751622912946325*^9, 
   3.7516229175302362`*^9}},ExpressionUUID->"8f248569-bc88-4c83-99f4-\
7af21d3b9264"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  FractionBox[
   RowBox[{"K", "[", "t", "]"}], "2"], "+", 
  RowBox[{"4", " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}]}]], "Output",
 CellChangeTimes->{{3.751376713070223*^9, 3.751376730956009*^9}, 
   3.7513767981711683`*^9, 3.7513768406862564`*^9, 3.751377119881615*^9, 
   3.7513907366231174`*^9, 3.7513908334970093`*^9, {3.751390960592874*^9, 
   3.751391000734701*^9}, 3.7514651513000174`*^9, 3.751465464218873*^9, 
   3.7514657098876023`*^9, 3.751466071898115*^9, 3.751466241402182*^9, {
   3.7514664714766912`*^9, 3.751466490341572*^9}, {3.751466611575799*^9, 
   3.751466617152934*^9}, 3.7516223350089736`*^9, 3.7516229187862635`*^9, 
   3.7516248786087084`*^9, 3.7516301583937936`*^9, {3.7516306344537954`*^9, 
   3.7516306628245125`*^9}, 3.751630703732272*^9, {3.751631301850486*^9, 
   3.751631315144618*^9}, 3.7530061646847563`*^9, 3.7530259583621187`*^9, 
   3.753103908000991*^9, 3.7531100527225323`*^9, 3.7533434036944904`*^9, 
   3.754053232146161*^9, 3.7541304142902727`*^9, 3.7561093114622617`*^9, 
   3.7561093489819217`*^9, 3.7561094577302823`*^9, 3.756113864427392*^9, 
   3.7568076357408414`*^9, 3.757916193914268*^9, 3.757923825713781*^9, 
   3.7583540890828977`*^9, 3.758363176909272*^9, 3.758372429937717*^9, 
   3.7584544872390423`*^9, 3.758460666656889*^9, 3.75903893223031*^9, 
   3.7590421962623577`*^9, 3.759045354344272*^9, 3.759058822096059*^9, 
   3.7590606353111415`*^9, 3.7590609825207877`*^9, 3.759061100790713*^9, 
   3.7590628092860203`*^9, 3.759065056905059*^9, 3.7595831199085903`*^9, 
   3.7596488147590804`*^9, 3.7596620958845296`*^9, 3.7606001499378147`*^9, 
   3.7607058277290993`*^9, 3.760706285239178*^9, 3.7607073109996667`*^9, 
   3.760793437059223*^9, 3.7608601266527395`*^9, 3.760866155019267*^9, 
   3.760866572876711*^9, 3.7608678930424995`*^9, 3.7608683613834553`*^9, {
   3.760868800041335*^9, 3.760868827481219*^9}, 3.7608761261670475`*^9, 
   3.7608773379671817`*^9, 3.7609545097015686`*^9, 3.760954550781454*^9, 
   3.760964278313612*^9, 3.7609650913413744`*^9, 3.7609666468765516`*^9, 
   3.7610283708191433`*^9, 3.761471446816258*^9, 3.7614755911635575`*^9, 
   3.7614839582292857`*^9, 3.761496771887991*^9, 3.7615610930872865`*^9, 
   3.7615699405196686`*^9, 3.7616468033680897`*^9, 3.7616485284584928`*^9, 
   3.7616551166943254`*^9, 3.761657183720351*^9, 3.761668192786562*^9, 
   3.761903517687793*^9, 3.7619137021889563`*^9, 3.761915128097145*^9, 
   3.7619268186928883`*^9, 3.7619276145992823`*^9, 3.761928497393459*^9, 
   3.7619787459725156`*^9, 3.7620807946749077`*^9, 3.762082042235176*^9, 
   3.762086930569903*^9, 3.7631008748221006`*^9, 3.7631009478981314`*^9, 
   3.763113578735885*^9, 3.763115139151227*^9, 3.7631204726563787`*^9, 
   3.763121438086717*^9, 3.7631217404769125`*^9, 3.7631218907471294`*^9, 
   3.763122828982233*^9, 3.7631332152294803`*^9, 3.7631339404860907`*^9, 
   3.7631344727867064`*^9, 3.7631887592505145`*^9, 3.763189120929308*^9, 
   3.7634619147957516`*^9, 3.763462489930638*^9, 3.7634630920414686`*^9, 
   3.7638063417629623`*^9},ExpressionUUID->"3187eb37-2804-4a03-a3ab-\
6e28663841bf"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
  FractionBox[
   RowBox[{"K", "[", "t", "]"}], "2"], "+", 
  RowBox[{"4", " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"Pm", "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.751376713070223*^9, 3.751376730956009*^9}, 
   3.7513767981711683`*^9, 3.7513768406862564`*^9, 3.751377119881615*^9, 
   3.7513907366231174`*^9, 3.7513908334970093`*^9, {3.751390960592874*^9, 
   3.751391000734701*^9}, 3.7514651513000174`*^9, 3.751465464218873*^9, 
   3.7514657098876023`*^9, 3.751466071898115*^9, 3.751466241402182*^9, {
   3.7514664714766912`*^9, 3.751466490341572*^9}, {3.751466611575799*^9, 
   3.751466617152934*^9}, 3.7516223350089736`*^9, 3.7516229187862635`*^9, 
   3.7516248786087084`*^9, 3.7516301583937936`*^9, {3.7516306344537954`*^9, 
   3.7516306628245125`*^9}, 3.751630703732272*^9, {3.751631301850486*^9, 
   3.751631315144618*^9}, 3.7530061646847563`*^9, 3.7530259583621187`*^9, 
   3.753103908000991*^9, 3.7531100527225323`*^9, 3.7533434036944904`*^9, 
   3.754053232146161*^9, 3.7541304142902727`*^9, 3.7561093114622617`*^9, 
   3.7561093489819217`*^9, 3.7561094577302823`*^9, 3.756113864427392*^9, 
   3.7568076357408414`*^9, 3.757916193914268*^9, 3.757923825713781*^9, 
   3.7583540890828977`*^9, 3.758363176909272*^9, 3.758372429937717*^9, 
   3.7584544872390423`*^9, 3.758460666656889*^9, 3.75903893223031*^9, 
   3.7590421962623577`*^9, 3.759045354344272*^9, 3.759058822096059*^9, 
   3.7590606353111415`*^9, 3.7590609825207877`*^9, 3.759061100790713*^9, 
   3.7590628092860203`*^9, 3.759065056905059*^9, 3.7595831199085903`*^9, 
   3.7596488147590804`*^9, 3.7596620958845296`*^9, 3.7606001499378147`*^9, 
   3.7607058277290993`*^9, 3.760706285239178*^9, 3.7607073109996667`*^9, 
   3.760793437059223*^9, 3.7608601266527395`*^9, 3.760866155019267*^9, 
   3.760866572876711*^9, 3.7608678930424995`*^9, 3.7608683613834553`*^9, {
   3.760868800041335*^9, 3.760868827481219*^9}, 3.7608761261670475`*^9, 
   3.7608773379671817`*^9, 3.7609545097015686`*^9, 3.760954550781454*^9, 
   3.760964278313612*^9, 3.7609650913413744`*^9, 3.7609666468765516`*^9, 
   3.7610283708191433`*^9, 3.761471446816258*^9, 3.7614755911635575`*^9, 
   3.7614839582292857`*^9, 3.761496771887991*^9, 3.7615610930872865`*^9, 
   3.7615699405196686`*^9, 3.7616468033680897`*^9, 3.7616485284584928`*^9, 
   3.7616551166943254`*^9, 3.761657183720351*^9, 3.761668192786562*^9, 
   3.761903517687793*^9, 3.7619137021889563`*^9, 3.761915128097145*^9, 
   3.7619268186928883`*^9, 3.7619276145992823`*^9, 3.761928497393459*^9, 
   3.7619787459725156`*^9, 3.7620807946749077`*^9, 3.762082042235176*^9, 
   3.762086930569903*^9, 3.7631008748221006`*^9, 3.7631009478981314`*^9, 
   3.763113578735885*^9, 3.763115139151227*^9, 3.7631204726563787`*^9, 
   3.763121438086717*^9, 3.7631217404769125`*^9, 3.7631218907471294`*^9, 
   3.763122828982233*^9, 3.7631332152294803`*^9, 3.7631339404860907`*^9, 
   3.7631344727867064`*^9, 3.7631887592505145`*^9, 3.763189120929308*^9, 
   3.7634619147957516`*^9, 3.763462489930638*^9, 3.7634630920414686`*^9, 
   3.7638063418721595`*^9},ExpressionUUID->"3083c499-5790-49d1-b0c2-\
1add072f5f1d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eq00", "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eq11", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{
       RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
      RowBox[{"a", "[", "t", "]"}]}]}]}], "/.", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
       RowBox[{"a", "[", "t", "]"}]}], ",", "t"}], "]"}]}]}], "/.", 
  RowBox[{
   RowBox[{
    RowBox[{"a", "'"}], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"a", "[", "t", "]"}], 
    SqrtBox[
     RowBox[{
      FractionBox[
       RowBox[{"8", " ", "Pi", " ", "G"}], "3"], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}]]}]}]}]}], "Input",
 CellChangeTimes->{{3.7514654713399496`*^9, 3.7514655262995234`*^9}, {
  3.751465649484001*^9, 3.7514656519638386`*^9}, {3.751465729566573*^9, 
  3.751465734192225*^9}, {3.7514660780134525`*^9, 3.751466080468111*^9}, {
  3.7514661134038553`*^9, 3.7514661198939185`*^9}, {3.751466245159999*^9, 
  3.7514662454050875`*^9}, {3.751466407984293*^9, 3.751466414578638*^9}, {
  3.7530062778706365`*^9, 
  3.7530062868006754`*^9}},ExpressionUUID->"f1fb0577-94f8-4228-a64d-\
9a493c82b710"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["3", "2"]}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"4", " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7514654760634675`*^9, 3.751465520278522*^9}, 
   3.7514656525007763`*^9, {3.751465713065056*^9, 3.7514657345223756`*^9}, 
   3.751466082275853*^9, {3.751466114448547*^9, 3.751466120340541*^9}, 
   3.7514662467961783`*^9, 3.7514664153848853`*^9, 3.7516223352089596`*^9, 
   3.7516248867019672`*^9, 3.751630162450206*^9, {3.751630640540604*^9, 
   3.751630664390217*^9}, 3.7516307050135717`*^9, {3.75163130396036*^9, 
   3.7516313167003736`*^9}, 3.75300629600504*^9, 3.753025958402253*^9, 
   3.753103911062791*^9, 3.7531100527696605`*^9, 3.753343403745551*^9, 
   3.7540532323081303`*^9, 3.7541304144559574`*^9, 3.7561093164082384`*^9, 
   3.7561093527477093`*^9, 3.7561094602167616`*^9, 3.7561138645625916`*^9, 
   3.7568076374908423`*^9, 3.7579162061815805`*^9, 3.7579238258831205`*^9, 
   3.7583540892078967`*^9, 3.7583631782193685`*^9, 3.7583724325049353`*^9, 
   3.7584544889372063`*^9, 3.758460666811969*^9, 3.7590389323709936`*^9, 
   3.759042196412393*^9, 3.759045354544445*^9, 3.7590588222503276`*^9, 
   3.759060635470483*^9, 3.7590609826654224`*^9, 3.7590611009603906`*^9, 
   3.7590628093901834`*^9, 3.7590650570547776`*^9, 3.7595831200565157`*^9, 
   3.759648814899024*^9, 3.7596620960544195`*^9, 3.7606001499887776`*^9, 
   3.7607058278692284`*^9, 3.7607062853939548`*^9, 3.7607073111397943`*^9, 
   3.7607934372089977`*^9, 3.760860126795411*^9, 3.7608661551590614`*^9, 
   3.760866573056701*^9, 3.7608678931974807`*^9, 3.760868361526283*^9, {
   3.7608688001685753`*^9, 3.7608688276264033`*^9}, 3.76087612629187*^9, 
   3.760877338107276*^9, 3.760954510181572*^9, 3.7609545509567137`*^9, 
   3.7609642785166583`*^9, 3.760965091491449*^9, 3.7609666470240984`*^9, 
   3.7610283708696823`*^9, 3.7614714469692173`*^9, 3.7614755913270683`*^9, 
   3.7614839583673787`*^9, 3.7614967719490023`*^9, 3.7615610932441864`*^9, 
   3.761569940719694*^9, 3.761646803590511*^9, 3.761648528608303*^9, 
   3.761655116874651*^9, 3.761657183870199*^9, 3.761668192849822*^9, 
   3.761903517837641*^9, 3.7619137023516474`*^9, 3.761915128197298*^9, 
   3.761926818743984*^9, 3.761927614663001*^9, 3.761928497456169*^9, 
   3.76197874611773*^9, 3.762080794812051*^9, 3.76208204242677*^9, 
   3.762086930741974*^9, 3.7631008753105736`*^9, 3.763100948052006*^9, 
   3.763113578865604*^9, 3.763115139306137*^9, 3.76312047278657*^9, 
   3.7631214382368555`*^9, 3.7631217406390405`*^9, 3.763121890902028*^9, 
   3.763122829119494*^9, 3.763133215281457*^9, 3.7631339405418367`*^9, 
   3.7631344728467855`*^9, 3.7631887594313064`*^9, 3.76318912112586*^9, 
   3.763461914949511*^9, 3.7634624900804806`*^9, 3.763463092207136*^9, 
   3.7638063419246736`*^9},ExpressionUUID->"06aab65f-6c71-4e27-b62b-\
dbde50cf7765"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "2"], "+", 
  RowBox[{"4", " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"Pm", "[", "t", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.7514654760634675`*^9, 3.751465520278522*^9}, 
   3.7514656525007763`*^9, {3.751465713065056*^9, 3.7514657345223756`*^9}, 
   3.751466082275853*^9, {3.751466114448547*^9, 3.751466120340541*^9}, 
   3.7514662467961783`*^9, 3.7514664153848853`*^9, 3.7516223352089596`*^9, 
   3.7516248867019672`*^9, 3.751630162450206*^9, {3.751630640540604*^9, 
   3.751630664390217*^9}, 3.7516307050135717`*^9, {3.75163130396036*^9, 
   3.7516313167003736`*^9}, 3.75300629600504*^9, 3.753025958402253*^9, 
   3.753103911062791*^9, 3.7531100527696605`*^9, 3.753343403745551*^9, 
   3.7540532323081303`*^9, 3.7541304144559574`*^9, 3.7561093164082384`*^9, 
   3.7561093527477093`*^9, 3.7561094602167616`*^9, 3.7561138645625916`*^9, 
   3.7568076374908423`*^9, 3.7579162061815805`*^9, 3.7579238258831205`*^9, 
   3.7583540892078967`*^9, 3.7583631782193685`*^9, 3.7583724325049353`*^9, 
   3.7584544889372063`*^9, 3.758460666811969*^9, 3.7590389323709936`*^9, 
   3.759042196412393*^9, 3.759045354544445*^9, 3.7590588222503276`*^9, 
   3.759060635470483*^9, 3.7590609826654224`*^9, 3.7590611009603906`*^9, 
   3.7590628093901834`*^9, 3.7590650570547776`*^9, 3.7595831200565157`*^9, 
   3.759648814899024*^9, 3.7596620960544195`*^9, 3.7606001499887776`*^9, 
   3.7607058278692284`*^9, 3.7607062853939548`*^9, 3.7607073111397943`*^9, 
   3.7607934372089977`*^9, 3.760860126795411*^9, 3.7608661551590614`*^9, 
   3.760866573056701*^9, 3.7608678931974807`*^9, 3.760868361526283*^9, {
   3.7608688001685753`*^9, 3.7608688276264033`*^9}, 3.76087612629187*^9, 
   3.760877338107276*^9, 3.760954510181572*^9, 3.7609545509567137`*^9, 
   3.7609642785166583`*^9, 3.760965091491449*^9, 3.7609666470240984`*^9, 
   3.7610283708696823`*^9, 3.7614714469692173`*^9, 3.7614755913270683`*^9, 
   3.7614839583673787`*^9, 3.7614967719490023`*^9, 3.7615610932441864`*^9, 
   3.761569940719694*^9, 3.761646803590511*^9, 3.761648528608303*^9, 
   3.761655116874651*^9, 3.761657183870199*^9, 3.761668192849822*^9, 
   3.761903517837641*^9, 3.7619137023516474`*^9, 3.761915128197298*^9, 
   3.761926818743984*^9, 3.761927614663001*^9, 3.761928497456169*^9, 
   3.76197874611773*^9, 3.762080794812051*^9, 3.76208204242677*^9, 
   3.762086930741974*^9, 3.7631008753105736`*^9, 3.763100948052006*^9, 
   3.763113578865604*^9, 3.763115139306137*^9, 3.76312047278657*^9, 
   3.7631214382368555`*^9, 3.7631217406390405`*^9, 3.763121890902028*^9, 
   3.763122829119494*^9, 3.763133215281457*^9, 3.7631339405418367`*^9, 
   3.7631344728467855`*^9, 3.7631887594313064`*^9, 3.76318912112586*^9, 
   3.763461914949511*^9, 3.7634624900804806`*^9, 3.763463092207136*^9, 
   3.763806341934826*^9},ExpressionUUID->"faf74ffe-a256-42ef-acbf-\
6453a9e3efe1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"4", " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"Pm", "[", "t", "]"}]}], "+", 
  RowBox[{
   FractionBox["4", "3"], " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["a", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], 
   RowBox[{"a", "[", "t", "]"}]]}]], "Output",
 CellChangeTimes->{{3.7514654760634675`*^9, 3.751465520278522*^9}, 
   3.7514656525007763`*^9, {3.751465713065056*^9, 3.7514657345223756`*^9}, 
   3.751466082275853*^9, {3.751466114448547*^9, 3.751466120340541*^9}, 
   3.7514662467961783`*^9, 3.7514664153848853`*^9, 3.7516223352089596`*^9, 
   3.7516248867019672`*^9, 3.751630162450206*^9, {3.751630640540604*^9, 
   3.751630664390217*^9}, 3.7516307050135717`*^9, {3.75163130396036*^9, 
   3.7516313167003736`*^9}, 3.75300629600504*^9, 3.753025958402253*^9, 
   3.753103911062791*^9, 3.7531100527696605`*^9, 3.753343403745551*^9, 
   3.7540532323081303`*^9, 3.7541304144559574`*^9, 3.7561093164082384`*^9, 
   3.7561093527477093`*^9, 3.7561094602167616`*^9, 3.7561138645625916`*^9, 
   3.7568076374908423`*^9, 3.7579162061815805`*^9, 3.7579238258831205`*^9, 
   3.7583540892078967`*^9, 3.7583631782193685`*^9, 3.7583724325049353`*^9, 
   3.7584544889372063`*^9, 3.758460666811969*^9, 3.7590389323709936`*^9, 
   3.759042196412393*^9, 3.759045354544445*^9, 3.7590588222503276`*^9, 
   3.759060635470483*^9, 3.7590609826654224`*^9, 3.7590611009603906`*^9, 
   3.7590628093901834`*^9, 3.7590650570547776`*^9, 3.7595831200565157`*^9, 
   3.759648814899024*^9, 3.7596620960544195`*^9, 3.7606001499887776`*^9, 
   3.7607058278692284`*^9, 3.7607062853939548`*^9, 3.7607073111397943`*^9, 
   3.7607934372089977`*^9, 3.760860126795411*^9, 3.7608661551590614`*^9, 
   3.760866573056701*^9, 3.7608678931974807`*^9, 3.760868361526283*^9, {
   3.7608688001685753`*^9, 3.7608688276264033`*^9}, 3.76087612629187*^9, 
   3.760877338107276*^9, 3.760954510181572*^9, 3.7609545509567137`*^9, 
   3.7609642785166583`*^9, 3.760965091491449*^9, 3.7609666470240984`*^9, 
   3.7610283708696823`*^9, 3.7614714469692173`*^9, 3.7614755913270683`*^9, 
   3.7614839583673787`*^9, 3.7614967719490023`*^9, 3.7615610932441864`*^9, 
   3.761569940719694*^9, 3.761646803590511*^9, 3.761648528608303*^9, 
   3.761655116874651*^9, 3.761657183870199*^9, 3.761668192849822*^9, 
   3.761903517837641*^9, 3.7619137023516474`*^9, 3.761915128197298*^9, 
   3.761926818743984*^9, 3.761927614663001*^9, 3.761928497456169*^9, 
   3.76197874611773*^9, 3.762080794812051*^9, 3.76208204242677*^9, 
   3.762086930741974*^9, 3.7631008753105736`*^9, 3.763100948052006*^9, 
   3.763113578865604*^9, 3.763115139306137*^9, 3.76312047278657*^9, 
   3.7631214382368555`*^9, 3.7631217406390405`*^9, 3.763121890902028*^9, 
   3.763122829119494*^9, 3.763133215281457*^9, 3.7631339405418367`*^9, 
   3.7631344728467855`*^9, 3.7631887594313064`*^9, 3.76318912112586*^9, 
   3.763461914949511*^9, 3.7634624900804806`*^9, 3.763463092207136*^9, 
   3.7638063419448814`*^9},ExpressionUUID->"8ff67c02-d731-45c2-a36b-\
df3926363080"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"(*", " ", 
    RowBox[{"Scalar", " ", "field", " ", "eqs"}], " ", "*)"}],
   FontSize->16], "\[IndentingNewLine]", 
  RowBox[{"eqscal", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"eqfield", "/.", "zeroorder"}], "/.", "rules"}], "//", 
     "FullSimplify"}], "//", "Expand"}]}]}]], "Input",
 CellChangeTimes->{
  3.7276786808959465`*^9, {3.7276795205761857`*^9, 3.7276795211343575`*^9}, {
   3.727680572319871*^9, 3.727680587231969*^9}, {3.751376987286188*^9, 
   3.751376998862132*^9}, {3.751466552452615*^9, 3.751466579342861*^9}, {
   3.7514666317915473`*^9, 3.751466722173766*^9}, {3.7516223591559687`*^9, 
   3.751622372395875*^9}, 3.751622842816296*^9, 3.7516229240108376`*^9, {
   3.751630650190221*^9, 
   3.751630667310192*^9}},ExpressionUUID->"02811add-c244-4b86-945e-\
1ca407df69d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "12"}], " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"9", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7561094640003204`*^9, 3.7561138650628853`*^9, 3.756807640100209*^9, 
   3.757916209417226*^9, 3.7579238264201946`*^9, 3.758354089696014*^9, 
   3.758363182504444*^9, 3.7583724353397317`*^9, 3.758454496751192*^9, 
   3.7584606673216815`*^9, 3.7590389328553333`*^9, 3.7590421969173727`*^9, 
   3.759045355050947*^9, 3.7590588227733536`*^9, 3.7590606359812145`*^9, 
   3.7590609831971006`*^9, 3.7590611014754887`*^9, 3.7590628099203787`*^9, 
   3.7590650575992603`*^9, 3.759583120596566*^9, 3.7596488154392967`*^9, 
   3.759662096609782*^9, 3.760600150496722*^9, 3.7607058283975*^9, 
   3.760706285959803*^9, 3.7607073116406207`*^9, 3.76079343772913*^9, 
   3.760860127340411*^9, 3.7608661556848783`*^9, 3.76086657366203*^9, 
   3.7608678937878165`*^9, 3.7608683621198378`*^9, {3.7608688002612314`*^9, 
   3.760868828136594*^9}, 3.7608761268320446`*^9, 3.760877338612024*^9, 
   3.760954510461527*^9, 3.760954551611704*^9, 3.760964279051862*^9, 
   3.76096509200161*^9, 3.76096664753187*^9, 3.761028371469221*^9, 
   3.7614714474892807`*^9, 3.7614755918317485`*^9, 3.7614839588974876`*^9, 
   3.7614967725884*^9, 3.761561093831767*^9, 3.761569941294558*^9, 
   3.761646804178214*^9, 3.761648529148496*^9, 3.7616551174994335`*^9, 
   3.7616571844101152`*^9, 3.761668193367916*^9, 3.7619035183980026`*^9, 
   3.761913702881539*^9, 3.7619151287741375`*^9, 3.761926819394227*^9, 
   3.761927615168273*^9, 3.7619284980665984`*^9, 3.7619787468726683`*^9, 
   3.762080795350353*^9, 3.762082042965373*^9, 3.7620869313000484`*^9, 
   3.7631008755556607`*^9, 3.763100948620445*^9, 3.7631135794055104`*^9, 
   3.7631151398663306`*^9, 3.7631204732907333`*^9, 3.7631214387766438`*^9, 
   3.7631217413080606`*^9, 3.763121891462055*^9, 3.7631228297424564`*^9, 
   3.7631332159499407`*^9, 3.7631339410611105`*^9, 3.7631344733728266`*^9, 
   3.7631887601531096`*^9, 3.7631891218105373`*^9, 3.7634619154794383`*^9, 
   3.763462490590856*^9, 3.7634630927389836`*^9, 
   3.7638063426641517`*^9},ExpressionUUID->"88b0a64a-8cc0-4b20-8b5d-\
b979e66f5ff5"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568076413658524`*^9, 
  3.7568076430689554`*^9}},ExpressionUUID->"1bd2e1b9-81d3-44c0-a041-\
6cf69ce0e882"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Perturbations", " ", "equations"}], " ", "*)"}]], "Input",
 CellChangeTimes->{
  3.753007042855545*^9, {3.753009367361864*^9, 3.7530093735622454`*^9}, {
   3.756807517528471*^9, 3.7568075203409376`*^9}, {3.75791631542495*^9, 
   3.7579163168820333`*^9}, {3.7590588532062516`*^9, 
   3.7590588556663914`*^9}},ExpressionUUID->"242e65f5-2958-4477-b53b-\
1af1428be6e0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"solK", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eq11", "\[Equal]", "0"}], ",", 
      RowBox[{"K", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", 
    "0"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"solKf", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"eqscal", "\[Equal]", "0"}], ",", 
     RowBox[{"K\[Phi]", "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7533434173877997`*^9, 3.7533434621639557`*^9}, {
  3.7533438869622183`*^9, 3.7533438871473875`*^9}, {3.7533439198993053`*^9, 
  3.7533439250010424`*^9}, {3.7533439991837597`*^9, 
  3.7533439997925854`*^9}},ExpressionUUID->"a08284af-1301-43d7-ae5d-\
b29a1a1fb80f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7533440002210855`*^9, 3.756109478936617*^9, 3.756113872372669*^9, 
   3.7568093291404943`*^9, 3.757916276097452*^9, 3.7579238277952347`*^9, 
   3.7583541221941824`*^9, 3.758363186082385*^9, 3.75837243775523*^9, 
   3.7584545049617567`*^9, 3.758460667476781*^9, 3.7590421971284266`*^9, 
   3.759045355399319*^9, 3.759060641990959*^9, 3.759060983395623*^9, 
   3.759061111840838*^9, 3.7595831207715373`*^9, 3.759648822709031*^9, 
   3.759662097014552*^9, 3.7606001505677185`*^9, 3.7607058285832148`*^9, 
   3.7607062861391726`*^9, 3.7607073118247347`*^9, 3.7607934379638987`*^9, 
   3.7608601778157444`*^9, 3.760866155834237*^9, 3.7608665738568563`*^9, 
   3.7608678939374485`*^9, 3.7608683622773485`*^9, {3.7608688003665276`*^9, 
   3.7608688283220434`*^9}, 3.760876126992107*^9, 3.7608773387571697`*^9, 
   3.7609545106018786`*^9, 3.7609545517618065`*^9, 3.760964279196615*^9, 
   3.7609650921616955`*^9, 3.7609666476970224`*^9, 3.7610283716270266`*^9, 
   3.7614714476439133`*^9, 3.7614755920269427`*^9, 3.7614839590372725`*^9, 
   3.7614967727004843`*^9, 3.761561093976714*^9, 3.761569941574501*^9, 
   3.7616468044681273`*^9, 3.761648529303579*^9, 3.7616551176538467`*^9, 
   3.7616571845550733`*^9, 3.761668193540102*^9, 3.761903518567639*^9, 
   3.7619137030314226`*^9, 3.7619151289322176`*^9, 3.7619268195666714`*^9, 
   3.7619276151999116`*^9, 3.7619284981164646`*^9, 3.7619787473676543`*^9, 
   3.7620807954949856`*^9, 3.7620820431230907`*^9, 3.762086931504738*^9, 
   3.763100875695914*^9, 3.7631009488235354`*^9, 3.7631135795477886`*^9, 
   3.763115140024703*^9, 3.7631204734315553`*^9, 3.7631214389315987`*^9, 
   3.7631217414567366`*^9, 3.7631218916070843`*^9, 3.7631228298794365`*^9, 
   3.763133216022086*^9, 3.763133941102888*^9, 3.763134473413669*^9, 
   3.763188760404135*^9, 3.763189122056267*^9, 3.763461915669367*^9, 
   3.763462490780553*^9, 3.763463092935195*^9, 
   3.7638063429176364`*^9},ExpressionUUID->"1092175a-7a53-4258-90f0-\
7a06bdcda028"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"9", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7533440002210855`*^9, 3.756109478936617*^9, 3.756113872372669*^9, 
   3.7568093291404943`*^9, 3.757916276097452*^9, 3.7579238277952347`*^9, 
   3.7583541221941824`*^9, 3.758363186082385*^9, 3.75837243775523*^9, 
   3.7584545049617567`*^9, 3.758460667476781*^9, 3.7590421971284266`*^9, 
   3.759045355399319*^9, 3.759060641990959*^9, 3.759060983395623*^9, 
   3.759061111840838*^9, 3.7595831207715373`*^9, 3.759648822709031*^9, 
   3.759662097014552*^9, 3.7606001505677185`*^9, 3.7607058285832148`*^9, 
   3.7607062861391726`*^9, 3.7607073118247347`*^9, 3.7607934379638987`*^9, 
   3.7608601778157444`*^9, 3.760866155834237*^9, 3.7608665738568563`*^9, 
   3.7608678939374485`*^9, 3.7608683622773485`*^9, {3.7608688003665276`*^9, 
   3.7608688283220434`*^9}, 3.760876126992107*^9, 3.7608773387571697`*^9, 
   3.7609545106018786`*^9, 3.7609545517618065`*^9, 3.760964279196615*^9, 
   3.7609650921616955`*^9, 3.7609666476970224`*^9, 3.7610283716270266`*^9, 
   3.7614714476439133`*^9, 3.7614755920269427`*^9, 3.7614839590372725`*^9, 
   3.7614967727004843`*^9, 3.761561093976714*^9, 3.761569941574501*^9, 
   3.7616468044681273`*^9, 3.761648529303579*^9, 3.7616551176538467`*^9, 
   3.7616571845550733`*^9, 3.761668193540102*^9, 3.761903518567639*^9, 
   3.7619137030314226`*^9, 3.7619151289322176`*^9, 3.7619268195666714`*^9, 
   3.7619276151999116`*^9, 3.7619284981164646`*^9, 3.7619787473676543`*^9, 
   3.7620807954949856`*^9, 3.7620820431230907`*^9, 3.762086931504738*^9, 
   3.763100875695914*^9, 3.7631009488235354`*^9, 3.7631135795477886`*^9, 
   3.763115140024703*^9, 3.7631204734315553`*^9, 3.7631214389315987`*^9, 
   3.7631217414567366`*^9, 3.7631218916070843`*^9, 3.7631228298794365`*^9, 
   3.763133216022086*^9, 3.763133941102888*^9, 3.763134473413669*^9, 
   3.763188760404135*^9, 3.763189122056267*^9, 3.763461915669367*^9, 
   3.763462490780553*^9, 3.763463092935195*^9, 
   3.763806342958373*^9},ExpressionUUID->"67d50a59-8e84-415b-922c-\
0b0d33496b51"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"solall", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"eqscal", "\[Equal]", "0"}], ",", 
          RowBox[{"eq11", "\[Equal]", "0"}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], ",", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}]}], "}"}]}], "]"}], "[", 
      
      RowBox[{"[", "1", "]"}], "]"}], "/.", 
     RowBox[{
      RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7533440164152293`*^9, 
  3.75334407063739*^9}},ExpressionUUID->"b08acb51-5750-444b-ae36-\
e6cb1e487561"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pert00", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"eqs", "[", 
       RowBox[{"1", ",", "1"}], "]"}], "/.", "a2H"}], "/.", "rules"}], "//", 
    "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7516225514557905`*^9, 3.7516225724091043`*^9}, {
   3.7516227641361055`*^9, 3.7516227692663093`*^9}, {3.75162280432609*^9, 
   3.7516228046960297`*^9}, 3.7516228824077835`*^9, 3.7516230676103897`*^9, {
   3.7516243353713474`*^9, 3.751624336234041*^9}, {3.751624428611353*^9, 
   3.75162443882599*^9}, {3.7516306794401693`*^9, 
   3.751630680810299*^9}},ExpressionUUID->"be2a4911-e1ea-4f0b-b9d1-\
31a023aac44e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pert00z", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pert00", "/.", "zeroorder"}], ")"}], "\[Equal]", "0"}], ",", 
      
      RowBox[{"K", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", "rules"}]}]], "Input",
 CellChangeTimes->{{3.7516229436703377`*^9, 3.751622996475548*^9}, {
  3.751624347151683*^9, 
  3.751624350091426*^9}},ExpressionUUID->"8e054cb8-4748-4445-a158-\
c1a8c3b3f1da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7516229457062016`*^9, 3.751622997160451*^9}, 
   3.7516230691461887`*^9, 3.751624352051345*^9, 3.7516244420458975`*^9, 
   3.7516248959762807`*^9, 3.751630171630003*^9, {3.7516306951543245`*^9, 
   3.751630709724533*^9}, 3.751631320844836*^9, 3.753343473224225*^9, 
   3.7533440750940485`*^9, 3.7561094838301105`*^9, 3.7561138774521055`*^9, 
   3.756809340120696*^9, 3.757916280157645*^9, 3.7579238317385035`*^9, 
   3.7583541260848155`*^9, 3.758363191059512*^9, 3.7583724607847643`*^9, 
   3.7584545107167897`*^9, 3.758460672951637*^9, 3.7590422011975136`*^9, 
   3.759045359424513*^9, 3.7590606446855097`*^9, 3.759060986475729*^9, 
   3.7590611145457044`*^9, 3.759583123451547*^9, 3.7596488253992844`*^9, 
   3.7596620997499046`*^9, 3.7606001533618326`*^9, 3.760705831259267*^9, 
   3.760706289147175*^9, 3.760707314497327*^9, 3.7607934406543064`*^9, 
   3.7608601804877477`*^9, 3.7608661630344524`*^9, 3.760866576989453*^9, 
   3.76086789706983*^9, 3.760868365725299*^9, {3.760868801146223*^9, 
   3.7608688310262384`*^9}, 3.7608761297219563`*^9, 3.7608773414121246`*^9, 
   3.760954510941886*^9, 3.7609545544314966`*^9, 3.7609642818902316`*^9, 
   3.760965094876548*^9, 3.7609666503718815`*^9, 3.7610283743948865`*^9, 
   3.76147145030902*^9, 3.7614755947869596`*^9, 3.7614839617524137`*^9, 
   3.7614967759918423`*^9, 3.7615610971616583`*^9, 3.761569944429558*^9, 
   3.7616468073630695`*^9, 3.7616485320536766`*^9, 3.7616551203546667`*^9, 
   3.761657187260212*^9, 3.761668196291791*^9, 3.7619035212430553`*^9, 
   3.7619137058312078`*^9, 3.761915131632392*^9, 3.7619268223905687`*^9, 
   3.7619276180329638`*^9, 3.7619285011117764`*^9, 3.7619787501827908`*^9, 
   3.762080798369775*^9, 3.7620820458297086`*^9, 3.76208693431574*^9, 
   3.7631008760634565`*^9, 3.7631009522493715`*^9, 3.763113582231392*^9, 
   3.763115143056163*^9, 3.763120476086399*^9, 3.7631214420665894`*^9, 
   3.7631217441571665`*^9, 3.7631218946015453`*^9, 3.763122832562975*^9, 
   3.7631332188461714`*^9, 3.763133943965748*^9, 3.7631344763245344`*^9, 
   3.7631887641407223`*^9, 3.763189125901229*^9, 3.7634619183699284`*^9, 
   3.7634624935005455`*^9, 3.763463096091295*^9, 
   3.7638063464852657`*^9},ExpressionUUID->"e05570e2-2ab0-4326-8d3d-\
32217e8a3d84"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"pert001", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"2", "pert00"}], "/.", "pert00z"}], "//", 
    "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.751622986646062*^9, 3.751623001450308*^9}, {
   3.7516230640908923`*^9, 3.7516230706764574`*^9}, {3.751624357151512*^9, 
   3.751624360395415*^9}, 
   3.7516317043911304`*^9},ExpressionUUID->"20a5dd20-6083-492b-8b5d-\
8e51ef3817d8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pert22", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{"eqs", "[", 
            RowBox[{"2", ",", "2"}], "]"}], "+", 
           RowBox[{"eqs", "[", 
            RowBox[{"3", ",", "3"}], "]"}], "+", 
           RowBox[{"eqs", "[", 
            RowBox[{"4", ",", "4"}], "]"}]}], "3"], "/.", "a2H"}], "/.", 
        "rules"}], "//", "ApproxFullSimplify"}], ")"}], "/.", "rules"}], "//",
     "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7516225514557905`*^9, 3.7516225724091043`*^9}, {
   3.7516227641361055`*^9, 3.7516227692663093`*^9}, {3.75162280432609*^9, 
   3.7516228046960297`*^9}, 3.7516228824077835`*^9, 3.7516230676103897`*^9, {
   3.7516243353713474`*^9, 3.751624336234041*^9}, {3.751624428611353*^9, 
   3.75162443882599*^9}, {3.7516306794401693`*^9, 3.751630680810299*^9}, {
   3.7516308515804005`*^9, 3.7516308530639553`*^9}, {3.751630917860442*^9, 
   3.751630945380382*^9}, {3.75163120094053*^9, 
   3.751631211500411*^9}},ExpressionUUID->"0e0d18eb-7d6e-462e-ae1d-\
3d3b99c00182"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pert220", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"pert22", "/.", "zeroorder"}], ")"}], "\[Equal]", "0"}], ",", 
      
      RowBox[{"K", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pert221", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], 
      FractionBox["pert22", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]]}], "/.", "pert220"}], "//", 
    "Expand"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7516314039449816`*^9, 3.751631448180908*^9}, {
  3.751631509265126*^9, 
  3.7516315149704657`*^9}},ExpressionUUID->"c349af1c-65f8-4821-b8cb-\
909628591775"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pert12", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"2", "\[ImaginaryI]", " ", 
           RowBox[{
            FractionBox[
             RowBox[{"{", 
              RowBox[{"kx", ",", "ky", ",", "kz"}], "}"}], 
             SuperscriptBox["k", "2"]], ".", 
            RowBox[{"eqs", "[", 
             RowBox[{"1", ",", 
              RowBox[{"2", ";;", "4"}]}], "]"}]}]}], "/.", 
          RowBox[{
           RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", "a2H"}], "/.",
         "rules"}], "//", "ApproxFullSimplify"}], ")"}], "/.", "rules"}], "//",
     "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.756809539340584*^9},ExpressionUUID->"02eb31f1-4233-4e1b-b36a-\
300292cc325d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"perts23", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"eqs", "[", 
            RowBox[{"2", ",", "3"}], "]"}], 
           RowBox[{"kx", " ", "ky"}]], "/.", 
          RowBox[{
           RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", "a2H"}], "/.",
         "rules"}], "//", "ApproxFullSimplify"}], ")"}], "/.", "rules"}], "//",
     "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7516326964512663`*^9, 3.7516327429369965`*^9}, 
   3.7568096420407743`*^9},ExpressionUUID->"4e538a46-c04e-4a91-9bda-\
27425d861be8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"scaleq", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"eqfield", "/.", 
          RowBox[{
           RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", "a2H"}], "/.",
         "rules"}], "//", "ApproxFullSimplify"}], ")"}], "/.", "rules"}], "//",
     "ApproxFullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"scaleq0", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"scaleq", "/.", "zeroorder"}], ")"}], "\[Equal]", "0"}], ",", 
      
      RowBox[{"K\[Phi]", "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"scaleq1", "=", 
   RowBox[{
    RowBox[{"-", "scaleq"}], "/.", "scaleq0"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.751632788586957*^9, 3.751632794836862*^9}, {
  3.751632955706298*^9, 3.7516329584368753`*^9}, {3.751633275005421*^9, 
  3.7516332767613096`*^9}, {3.756809595350969*^9, 
  3.7568095955408354`*^9}},ExpressionUUID->"3bbaf24e-7999-44ce-8701-\
ba6bca517330"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eqs00", "=", "pert001"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqs0i", "=", "pert12"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqsii", "=", "pert221"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqsij", "=", "perts23"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqscal", "=", "scaleq1"}], ";"}]}], "Input",
 CellChangeTimes->{{3.757916366076356*^9, 3.75791636635525*^9}, {
  3.7579165860567684`*^9, 3.757916621252109*^9}, {3.757916821250471*^9, 
  3.7579168260302024`*^9}},ExpressionUUID->"1d4a62c5-bf8b-4f3b-ade4-\
df6b8c572874"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesGR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.757916381634555*^9, 3.757916423887743*^9}, {
  3.757916557500442*^9, 3.757916558410334*^9}, {3.7579168359191437`*^9, 
  3.757916837039179*^9}, {3.7579169687664423`*^9, 
  3.7579170554777555`*^9}},ExpressionUUID->"f3fe56ae-1f36-4341-8120-\
38165c0d1a4a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"-", "Eqs00"}], "/.", "rulesGR"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"-", "Eqsii"}], "/", "6"}], "/.", "rulesGR"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"2", "Eqsij"}], "/.", "rulesGR"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqs0i", "/.", "rulesGR"}], "//", "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqscal", "/.", "rulesGR"}], "//", "Expand"}]}], "Input",
 CellChangeTimes->{{3.757916628530964*^9, 3.757916652767982*^9}, {
  3.7579168299884214`*^9, 3.757916863866147*^9}, {3.7579169094516287`*^9, 
  3.757916955797043*^9}, {3.7579170669399295`*^9, 
  3.757917090683976*^9}},ExpressionUUID->"dd04cbbe-bf61-48e0-a993-\
34f0480b8b82"],

Cell[BoxData[
 RowBox[{
  RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"\[Delta]\[Rho]m", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[CapitalPhi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]], "+", 
  RowBox[{"6", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7579166313253117`*^9, 3.757916655097102*^9}, {
   3.7579168312337685`*^9, 3.7579168643303237`*^9}, {3.7579169143313227`*^9, 
   3.7579169804749184`*^9}, {3.757917019740924*^9, 3.75791709143827*^9}, 
   3.7583541381338735`*^9, 3.7583632168045835`*^9, 3.7583724617600813`*^9, 
   3.758454521822009*^9, 3.7584606846946754`*^9, 3.75904536357652*^9, 
   3.7590606456305504`*^9, 3.759060987475911*^9, 3.7590611155655313`*^9, 
   3.7595831243917174`*^9, 3.759648826423294*^9, 3.7596621007447443`*^9, 
   3.7606001538479037`*^9, 3.760705832209278*^9, 3.760706290181259*^9, 
   3.760707315594792*^9, 3.7607934416541033`*^9, 3.7608601815506525`*^9, 
   3.7608661868146124`*^9, 3.760866577936822*^9, 3.7608678981143045`*^9, 
   3.76086836673753*^9, 3.7608688021412683`*^9, 3.7608688321416073`*^9, 
   3.7608761307222705`*^9, 3.760877342429445*^9, 3.760954513934881*^9, 
   3.7609545554516277`*^9, 3.7609642829816346`*^9, 3.7609650958766603`*^9, 
   3.7609666513468037`*^9, 3.761028375199318*^9, 3.7614714512590437`*^9, 
   3.7614755958866315`*^9, 3.761483962677272*^9, 3.761496776395257*^9, 
   3.761561098117114*^9, 3.761569945579473*^9, 3.761646808463128*^9, 
   3.761648533063673*^9, 3.7616551216694956`*^9, 3.7616571882049856`*^9, 
   3.7616681966571045`*^9, 3.761903522192728*^9, 3.76191370685145*^9, 
   3.761915132597226*^9, 3.7619268227564564`*^9, 3.7619276183990717`*^9, 
   3.7619285014568787`*^9, 3.761978751172299*^9, 3.7620807994499435`*^9, 
   3.7620820469154015`*^9, 3.7620869353569903`*^9, 3.763100879384036*^9, 
   3.7631009533723435`*^9, 3.763113583205462*^9, 3.76311514399199*^9, 
   3.763120477016259*^9, 3.763121443026946*^9, 3.763121745116975*^9, 
   3.763121895637104*^9, 3.7631228335074224`*^9, 3.7631332192109857`*^9, 
   3.7631339443639913`*^9, 3.763134476722481*^9, 3.7631887654930105`*^9, 
   3.7631891273158345`*^9, 3.7634619193594217`*^9, 3.7634624945457163`*^9, 
   3.7634630971471577`*^9, 
   3.7638063476798186`*^9},ExpressionUUID->"6c6618f8-0122-424f-b36a-\
50136ecc6674"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"\[Delta]Pm", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[CapitalPhi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]], "+", 
  RowBox[{"3", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["\[CapitalPhi]", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.7579166313253117`*^9, 3.757916655097102*^9}, {
   3.7579168312337685`*^9, 3.7579168643303237`*^9}, {3.7579169143313227`*^9, 
   3.7579169804749184`*^9}, {3.757917019740924*^9, 3.75791709143827*^9}, 
   3.7583541381338735`*^9, 3.7583632168045835`*^9, 3.7583724617600813`*^9, 
   3.758454521822009*^9, 3.7584606846946754`*^9, 3.75904536357652*^9, 
   3.7590606456305504`*^9, 3.759060987475911*^9, 3.7590611155655313`*^9, 
   3.7595831243917174`*^9, 3.759648826423294*^9, 3.7596621007447443`*^9, 
   3.7606001538479037`*^9, 3.760705832209278*^9, 3.760706290181259*^9, 
   3.760707315594792*^9, 3.7607934416541033`*^9, 3.7608601815506525`*^9, 
   3.7608661868146124`*^9, 3.760866577936822*^9, 3.7608678981143045`*^9, 
   3.76086836673753*^9, 3.7608688021412683`*^9, 3.7608688321416073`*^9, 
   3.7608761307222705`*^9, 3.760877342429445*^9, 3.760954513934881*^9, 
   3.7609545554516277`*^9, 3.7609642829816346`*^9, 3.7609650958766603`*^9, 
   3.7609666513468037`*^9, 3.761028375199318*^9, 3.7614714512590437`*^9, 
   3.7614755958866315`*^9, 3.761483962677272*^9, 3.761496776395257*^9, 
   3.761561098117114*^9, 3.761569945579473*^9, 3.761646808463128*^9, 
   3.761648533063673*^9, 3.7616551216694956`*^9, 3.7616571882049856`*^9, 
   3.7616681966571045`*^9, 3.761903522192728*^9, 3.76191370685145*^9, 
   3.761915132597226*^9, 3.7619268227564564`*^9, 3.7619276183990717`*^9, 
   3.7619285014568787`*^9, 3.761978751172299*^9, 3.7620807994499435`*^9, 
   3.7620820469154015`*^9, 3.7620869353569903`*^9, 3.763100879384036*^9, 
   3.7631009533723435`*^9, 3.763113583205462*^9, 3.76311514399199*^9, 
   3.763120477016259*^9, 3.763121443026946*^9, 3.763121745116975*^9, 
   3.763121895637104*^9, 3.7631228335074224`*^9, 3.7631332192109857`*^9, 
   3.7631339443639913`*^9, 3.763134476722481*^9, 3.7631887654930105`*^9, 
   3.7631891273158345`*^9, 3.7634619193594217`*^9, 3.7634624945457163`*^9, 
   3.7634630971471577`*^9, 
   3.763806347708148*^9},ExpressionUUID->"4c7e63ae-454b-4ad8-a6c4-\
47b21769bc27"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[CapitalPhi]", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
  RowBox[{"\[CapitalPsi]", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]], "Output",
 CellChangeTimes->{{3.7579166313253117`*^9, 3.757916655097102*^9}, {
   3.7579168312337685`*^9, 3.7579168643303237`*^9}, {3.7579169143313227`*^9, 
   3.7579169804749184`*^9}, {3.757917019740924*^9, 3.75791709143827*^9}, 
   3.7583541381338735`*^9, 3.7583632168045835`*^9, 3.7583724617600813`*^9, 
   3.758454521822009*^9, 3.7584606846946754`*^9, 3.75904536357652*^9, 
   3.7590606456305504`*^9, 3.759060987475911*^9, 3.7590611155655313`*^9, 
   3.7595831243917174`*^9, 3.759648826423294*^9, 3.7596621007447443`*^9, 
   3.7606001538479037`*^9, 3.760705832209278*^9, 3.760706290181259*^9, 
   3.760707315594792*^9, 3.7607934416541033`*^9, 3.7608601815506525`*^9, 
   3.7608661868146124`*^9, 3.760866577936822*^9, 3.7608678981143045`*^9, 
   3.76086836673753*^9, 3.7608688021412683`*^9, 3.7608688321416073`*^9, 
   3.7608761307222705`*^9, 3.760877342429445*^9, 3.760954513934881*^9, 
   3.7609545554516277`*^9, 3.7609642829816346`*^9, 3.7609650958766603`*^9, 
   3.7609666513468037`*^9, 3.761028375199318*^9, 3.7614714512590437`*^9, 
   3.7614755958866315`*^9, 3.761483962677272*^9, 3.761496776395257*^9, 
   3.761561098117114*^9, 3.761569945579473*^9, 3.761646808463128*^9, 
   3.761648533063673*^9, 3.7616551216694956`*^9, 3.7616571882049856`*^9, 
   3.7616681966571045`*^9, 3.761903522192728*^9, 3.76191370685145*^9, 
   3.761915132597226*^9, 3.7619268227564564`*^9, 3.7619276183990717`*^9, 
   3.7619285014568787`*^9, 3.761978751172299*^9, 3.7620807994499435`*^9, 
   3.7620820469154015`*^9, 3.7620869353569903`*^9, 3.763100879384036*^9, 
   3.7631009533723435`*^9, 3.763113583205462*^9, 3.76311514399199*^9, 
   3.763120477016259*^9, 3.763121443026946*^9, 3.763121745116975*^9, 
   3.763121895637104*^9, 3.7631228335074224`*^9, 3.7631332192109857`*^9, 
   3.7631339443639913`*^9, 3.763134476722481*^9, 3.7631887654930105`*^9, 
   3.7631891273158345`*^9, 3.7634619193594217`*^9, 3.7634624945457163`*^9, 
   3.7634630971471577`*^9, 
   3.7638063477103386`*^9},ExpressionUUID->"1d8883e1-dbc9-4fe8-afbf-\
45e55c8db680"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
    RowBox[{"a", "[", "t", "]"}], " ", 
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
   SuperscriptBox["k", "2"]], "-", 
  RowBox[{"2", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7579166313253117`*^9, 3.757916655097102*^9}, {
   3.7579168312337685`*^9, 3.7579168643303237`*^9}, {3.7579169143313227`*^9, 
   3.7579169804749184`*^9}, {3.757917019740924*^9, 3.75791709143827*^9}, 
   3.7583541381338735`*^9, 3.7583632168045835`*^9, 3.7583724617600813`*^9, 
   3.758454521822009*^9, 3.7584606846946754`*^9, 3.75904536357652*^9, 
   3.7590606456305504`*^9, 3.759060987475911*^9, 3.7590611155655313`*^9, 
   3.7595831243917174`*^9, 3.759648826423294*^9, 3.7596621007447443`*^9, 
   3.7606001538479037`*^9, 3.760705832209278*^9, 3.760706290181259*^9, 
   3.760707315594792*^9, 3.7607934416541033`*^9, 3.7608601815506525`*^9, 
   3.7608661868146124`*^9, 3.760866577936822*^9, 3.7608678981143045`*^9, 
   3.76086836673753*^9, 3.7608688021412683`*^9, 3.7608688321416073`*^9, 
   3.7608761307222705`*^9, 3.760877342429445*^9, 3.760954513934881*^9, 
   3.7609545554516277`*^9, 3.7609642829816346`*^9, 3.7609650958766603`*^9, 
   3.7609666513468037`*^9, 3.761028375199318*^9, 3.7614714512590437`*^9, 
   3.7614755958866315`*^9, 3.761483962677272*^9, 3.761496776395257*^9, 
   3.761561098117114*^9, 3.761569945579473*^9, 3.761646808463128*^9, 
   3.761648533063673*^9, 3.7616551216694956`*^9, 3.7616571882049856`*^9, 
   3.7616681966571045`*^9, 3.761903522192728*^9, 3.76191370685145*^9, 
   3.761915132597226*^9, 3.7619268227564564`*^9, 3.7619276183990717`*^9, 
   3.7619285014568787`*^9, 3.761978751172299*^9, 3.7620807994499435`*^9, 
   3.7620820469154015`*^9, 3.7620869353569903`*^9, 3.763100879384036*^9, 
   3.7631009533723435`*^9, 3.763113583205462*^9, 3.76311514399199*^9, 
   3.763120477016259*^9, 3.763121443026946*^9, 3.763121745116975*^9, 
   3.763121895637104*^9, 3.7631228335074224`*^9, 3.7631332192109857`*^9, 
   3.7631339443639913`*^9, 3.763134476722481*^9, 3.7631887654930105`*^9, 
   3.7631891273158345`*^9, 3.7634619193594217`*^9, 3.7634624945457163`*^9, 
   3.7634630971471577`*^9, 
   3.7638063477285595`*^9},ExpressionUUID->"cb1fc7d7-e76b-4586-9447-\
94631e31dd93"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7579166313253117`*^9, 3.757916655097102*^9}, {
   3.7579168312337685`*^9, 3.7579168643303237`*^9}, {3.7579169143313227`*^9, 
   3.7579169804749184`*^9}, {3.757917019740924*^9, 3.75791709143827*^9}, 
   3.7583541381338735`*^9, 3.7583632168045835`*^9, 3.7583724617600813`*^9, 
   3.758454521822009*^9, 3.7584606846946754`*^9, 3.75904536357652*^9, 
   3.7590606456305504`*^9, 3.759060987475911*^9, 3.7590611155655313`*^9, 
   3.7595831243917174`*^9, 3.759648826423294*^9, 3.7596621007447443`*^9, 
   3.7606001538479037`*^9, 3.760705832209278*^9, 3.760706290181259*^9, 
   3.760707315594792*^9, 3.7607934416541033`*^9, 3.7608601815506525`*^9, 
   3.7608661868146124`*^9, 3.760866577936822*^9, 3.7608678981143045`*^9, 
   3.76086836673753*^9, 3.7608688021412683`*^9, 3.7608688321416073`*^9, 
   3.7608761307222705`*^9, 3.760877342429445*^9, 3.760954513934881*^9, 
   3.7609545554516277`*^9, 3.7609642829816346`*^9, 3.7609650958766603`*^9, 
   3.7609666513468037`*^9, 3.761028375199318*^9, 3.7614714512590437`*^9, 
   3.7614755958866315`*^9, 3.761483962677272*^9, 3.761496776395257*^9, 
   3.761561098117114*^9, 3.761569945579473*^9, 3.761646808463128*^9, 
   3.761648533063673*^9, 3.7616551216694956`*^9, 3.7616571882049856`*^9, 
   3.7616681966571045`*^9, 3.761903522192728*^9, 3.76191370685145*^9, 
   3.761915132597226*^9, 3.7619268227564564`*^9, 3.7619276183990717`*^9, 
   3.7619285014568787`*^9, 3.761978751172299*^9, 3.7620807994499435`*^9, 
   3.7620820469154015`*^9, 3.7620869353569903`*^9, 3.763100879384036*^9, 
   3.7631009533723435`*^9, 3.763113583205462*^9, 3.76311514399199*^9, 
   3.763120477016259*^9, 3.763121443026946*^9, 3.763121745116975*^9, 
   3.763121895637104*^9, 3.7631228335074224`*^9, 3.7631332192109857`*^9, 
   3.7631339443639913`*^9, 3.763134476722481*^9, 3.7631887654930105`*^9, 
   3.7631891273158345`*^9, 3.7634619193594217`*^9, 3.7634624945457163`*^9, 
   3.7634630971471577`*^9, 
   3.76380634773059*^9},ExpressionUUID->"88940eee-58a7-4a41-8db9-\
148671e45e27"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568075624837775`*^9, 
  3.756807568765033*^9}},ExpressionUUID->"07d3885c-863a-4fd3-937b-\
dcc8b179d940"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"The", " ", "continuity", " ", "equations"}], " ", "*)"}]], "Input",\

 CellChangeTimes->{
  3.728128064348237*^9, 3.7282399499899187`*^9, {3.7484488576593175`*^9, 
   3.748448864323157*^9}, {3.7484511672777033`*^9, 3.748451182923294*^9}, {
   3.762081994780449*^9, 
   3.7620820001355405`*^9}},ExpressionUUID->"4c09478d-8704-4be7-887d-\
ed68ae85d345"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\[Theta]", "]"}]], "Input",
 CellChangeTimes->{{3.7620816365901437`*^9, 
  3.7620816389156327`*^9}},ExpressionUUID->"55bac692-a85d-4424-973f-\
aa26dae6791b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"energcond", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"covDiv", "[", 
      RowBox[{"TmUd", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "//", "Expand"}], "//",
    "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7484486578165584`*^9, {3.7583686109610558`*^9, 3.758368630533529*^9}, 
   3.7620815163752174`*^9},ExpressionUUID->"d31e3621-baaf-4c39-888a-\
9ea0128f74b6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"Pm", "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"Pm", "[", "t", "]"}], " ", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "-", 
    RowBox[{
     SuperscriptBox["\[Rho]m", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "-", 
    RowBox[{
     SuperscriptBox["\[Delta]\[Rho]m", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["Pm", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Rho]m", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["ux", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["ux", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["Pm", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Rho]m", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["Pm", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Rho]m", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"Pm", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.758368613272914*^9, 3.7583686310508018`*^9}, 
   3.758372565809868*^9, 3.758454609967335*^9, 3.7590432575331373`*^9, 
   3.7615700784794025`*^9, 3.7620812410197563`*^9, 3.762081517265913*^9, 
   3.762081641187313*^9, 
   3.762081748507403*^9},ExpressionUUID->"e9bef96c-0e93-44ba-b578-\
f9c37e0dc961"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cons0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"energcond", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", "zeroorder"}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Rho]m", "'"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.72823333326803*^9, 3.7282333736032867`*^9}, {
  3.748448668138236*^9, 3.7484486757671485`*^9}, {3.758368639560544*^9, 
  3.758368647491086*^9}},ExpressionUUID->"fb8bf662-da8a-4ea9-b71e-\
89398712391b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Rho]m", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Pm", "[", "t", "]"}], "+", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7282333442236867`*^9, 3.7282333748353205`*^9}, 
   3.7282401957379017`*^9, 3.7282807569845076`*^9, 3.728296861547844*^9, 
   3.728893342595481*^9, 3.731907134182128*^9, 3.731919883901698*^9, 
   3.731925014454234*^9, 3.7323538834548874`*^9, 3.7325242219748135`*^9, 
   3.7326104707591586`*^9, 3.7328548237423525`*^9, 3.732858686647619*^9, 
   3.732941508020496*^9, 3.733045146737355*^9, 3.733566219687055*^9, 
   3.7456657179477253`*^9, 3.745824552688678*^9, 3.745831677222546*^9, 
   3.745833552631424*^9, 3.7458529643520355`*^9, 3.7459046913626175`*^9, 
   3.7459050294268007`*^9, 3.7459155148105907`*^9, 3.746184838286575*^9, 
   3.7462531731789336`*^9, 3.746262809601081*^9, 3.7464208398256807`*^9, 
   3.7464278408298693`*^9, 3.748448676741956*^9, 3.748450259259445*^9, 
   3.758368648310441*^9, 3.7583725705295773`*^9, 3.7584546115868006`*^9, 
   3.7590432591232276`*^9, 3.761570081099889*^9, 3.7620812428950295`*^9, 
   3.7620815200254154`*^9, 3.7620816438173504`*^9, 
   3.7620817496254687`*^9},ExpressionUUID->"74049b8e-9e13-4ba0-8b11-\
10ef8ce16422"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en10", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"energcond", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"energcond", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", "zeroorder"}], ")"}]}], "/.", 
   "a2H"}]}]], "Input",
 CellChangeTimes->{{3.7282161794306803`*^9, 3.7282161850099125`*^9}, {
   3.7282311665084667`*^9, 3.7282311958939333`*^9}, {3.728233266678986*^9, 
   3.7282332668416047`*^9}, {3.748450269886175*^9, 3.7484502707698727`*^9}, 
   3.748451009248801*^9},ExpressionUUID->"24784925-2711-447b-bd8e-\
58aae5c6b51d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]Pm", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]\[Rho]m", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], " ", 
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]], "-", 
  RowBox[{
   SuperscriptBox["\[Delta]\[Rho]m", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"Pm", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7282161803104095`*^9, 3.728216186494257*^9}, 
   3.7282311366219163`*^9, {3.7282311696424875`*^9, 3.728231196271249*^9}, 
   3.728231472224601*^9, 3.72823321917756*^9, 3.7282332672255545`*^9, 
   3.7282401957524695`*^9, 3.7282807586878166`*^9, 3.7282968615635023`*^9, 
   3.7288933426105194`*^9, 3.7319071341971426`*^9, 3.731919883917266*^9, 
   3.7319250144698024`*^9, 3.7323538834709363`*^9, 3.732524221996954*^9, 
   3.7326104707801943`*^9, 3.7328548237579727`*^9, 3.7328586866632457`*^9, 
   3.732941513757288*^9, 3.733045146755517*^9, 3.7335662197026978`*^9, 
   3.74566571800776*^9, 3.7458245527578707`*^9, 3.7458316772888203`*^9, 
   3.7458335526873617`*^9, 3.7458529643685055`*^9, 3.7459046914564824`*^9, 
   3.7459050294966116`*^9, 3.7459155148574896`*^9, 3.746184838346408*^9, 
   3.746253173234974*^9, 3.7462628096807775`*^9, 3.7464208398954268`*^9, 
   3.7464278408898287`*^9, 3.748448681608074*^9, {3.7484502638604717`*^9, 
   3.748450271876639*^9}, 3.748451009862173*^9, 3.758368651700549*^9, 
   3.7583725740851364`*^9, 3.7584546129273205`*^9, 3.7590432599933944`*^9, 
   3.761570082169583*^9, 3.7620812451951723`*^9, 3.7620815229401073`*^9, 
   3.7620816448495092`*^9, 
   3.7620817511852007`*^9},ExpressionUUID->"f24b636e-0eff-4380-a928-\
cc06c49d530f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "\[Theta]", "]"}]], "Input",
 CellChangeTimes->{{3.748451095130921*^9, 
  3.748451097254135*^9}},ExpressionUUID->"aae0d7a2-f19e-4979-ad07-\
34d4a8c90310"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Theta]", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"Vm", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
   RowBox[{"1", "+", 
    RowBox[{"wm", "[", "t", "]"}]}]]}]], "Input",
 CellChangeTimes->{{3.758368731300889*^9, 3.758368741681011*^9}, {
   3.7583704850662403`*^9, 3.7583705362922735`*^9}, 3.758370584112078*^9, 
   3.7620812896853704`*^9},ExpressionUUID->"49fe1fe4-76e5-439c-a930-\
1cd41b14574a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Delta]", "'"}], "[", "t", "]"}], "->", 
         RowBox[{"D", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"\[Delta]\[Rho]m", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
            RowBox[{"\[Rho]m", "[", "t", "]"}]], ",", "t"}], "]"}]}], "/.", 
        "cons0"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"en10", "\[Equal]", "0"}], ",", 
          RowBox[{
           SuperscriptBox["\[Delta]\[Rho]m", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", "a2H"}], "/.", 
     RowBox[{
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
      RowBox[{
       RowBox[{"\[Delta]", "[", "a", "]"}], "*", 
       RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "/.", 
    RowBox[{
     RowBox[{"Pm", "[", "t", "]"}], "->", 
     RowBox[{
      RowBox[{"wm", "[", "t", "]"}], 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.72823133576729*^9, 3.7282313508437486`*^9}, {
   3.7282313921395187`*^9, 3.728231399579141*^9}, {3.7282315176878395`*^9, 
   3.7282315512694097`*^9}, {3.7282315973091087`*^9, 3.728231653765546*^9}, 
   3.728231692653243*^9, {3.7282332407501764`*^9, 3.7282332476861534`*^9}, {
   3.728233380790492*^9, 3.728233385274924*^9}, {3.7484486893098097`*^9, 
   3.7484487105403423`*^9}, {3.7484502902639656`*^9, 
   3.7484502910988207`*^9}, {3.7484503299137435`*^9, 3.748450363539217*^9}, {
   3.7484509030201435`*^9, 3.748450903283244*^9}, {3.7484510114532037`*^9, 
   3.7484510120066547`*^9}, {3.7484510884971995`*^9, 3.748451132769088*^9}, {
   3.758368666740664*^9, 3.7583686885808764`*^9}, {3.7583690523209357`*^9, 
   3.7583690626307425`*^9}, 3.7620812564752474`*^9, {3.7620815847280045`*^9, 
   3.76208159708523*^9}},ExpressionUUID->"0e49df56-2086-4124-b342-\
dc2f7159b5ff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Delta]", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Vm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
     RowBox[{"a", "[", "t", "]"}]]}], "+", 
   RowBox[{
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"wm", "[", "t", "]"}], " ", 
       RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"\[Delta]Pm", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[Rho]m", "[", "t", "]"}]]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"wm", "[", "t", "]"}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7484487049021187`*^9, 3.748448711139358*^9}, {
   3.7484502851951084`*^9, 3.7484502915744123`*^9}, {3.7484503309912715`*^9, 
   3.748450364036272*^9}, {3.7484509076123123`*^9, 3.748450931233122*^9}, 
   3.7484510126316986`*^9, {3.7484510916663895`*^9, 3.7484511346686535`*^9}, 
   3.758368689180854*^9, {3.7583690557707744`*^9, 3.7583690660413494`*^9}, 
   3.7583704975667853`*^9, 3.758372577265245*^9, 3.758454619907262*^9, 
   3.7590432616432743`*^9, 3.7615700862043033`*^9, 3.7620812597503877`*^9, 
   3.762081527947632*^9, {3.7620815930176497`*^9, 3.7620816251995635`*^9}, 
   3.762081664630335*^9, 
   3.762081754105579*^9},ExpressionUUID->"17a92702-814f-4ef1-9484-\
a9bffae05a6d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"FullSimplify", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               FractionBox["1", 
                RowBox[{"\[Rho]m", "[", "t", "]"}]], 
               RowBox[{"Div", "[", 
                RowBox[{
                 RowBox[{"energcond", "[", 
                  RowBox[{"[", 
                   RowBox[{"2", ";;", "4"}], "]"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], "/.", 
              "cons0"}], "/.", "a2H"}], "/.", 
            RowBox[{
             SuperscriptBox["kx", "2"], "\[Rule]", 
             RowBox[{
              RowBox[{"k", "^", "2"}], "-", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["ky", "2"], "+", 
                SuperscriptBox["kz", "2"]}], ")"}]}]}]}], "//", "Expand"}], "//",
           "FullSimplify"}], "//", "ApproxFullSimplify"}], "]"}], "/.", 
       "cons0"}], "/.", 
      RowBox[{
       RowBox[{"Pm", "[", "t", "]"}], "->", 
       RowBox[{
        RowBox[{"wm", "[", "t", "]"}], 
        RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "/.", "a2H"}], "//", 
    "FullSimplify"}], "//", "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.748448738847443*^9, 3.748448771422245*^9}, {
   3.7484504047129393`*^9, 3.748450512121004*^9}, {3.7484505538839693`*^9, 
   3.748450664501816*^9}, {3.7484507037962103`*^9, 3.7484507411906157`*^9}, {
   3.7484507990595417`*^9, 3.7484508351490135`*^9}, {3.7484508950548325`*^9, 
   3.7484508953083677`*^9}, {3.7484509403623676`*^9, 
   3.7484509420490603`*^9}, {3.75836869920118*^9, 3.7583687224810524`*^9}, 
   3.762081276185274*^9, {3.762081775995363*^9, 
   3.7620817763154755`*^9}},ExpressionUUID->"aea44dcf-db35-4a99-bb67-\
4b5f68fe31c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"Vm", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[Delta]Pm", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"\[Rho]m", "[", "t", "]"}]], "-", 
  RowBox[{
   SuperscriptBox["k", "2"], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["k", "2"], " ", 
   RowBox[{"wm", "[", "t", "]"}], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{
    RowBox[{"a", "[", "t", "]"}], " ", 
    RowBox[{"Vm", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["Pm", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"wm", "[", "t", "]"}]}], ")"}], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"a", "[", "t", "]"}], " ", 
    RowBox[{"Vm", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{
     SuperscriptBox["wm", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}], 
   RowBox[{"1", "+", 
    RowBox[{"wm", "[", "t", "]"}]}]], "+", 
  RowBox[{
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["Vm", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7484487409543014`*^9, 3.7484487720015774`*^9}, 
   3.748450379366459*^9, {3.7484504146984982`*^9, 3.7484505129233294`*^9}, {
   3.7484505555694733`*^9, 3.7484506140534315`*^9}, {3.7484506550440855`*^9, 
   3.7484506664834356`*^9}, {3.7484507057766104`*^9, 3.74845074241886*^9}, {
   3.7484508074754305`*^9, 3.7484508360018215`*^9}, 3.7484509433693905`*^9, 
   3.7484511428503437`*^9, 3.758368724120596*^9, 3.7583690715908422`*^9, 
   3.758370499721654*^9, 3.7583725898800826`*^9, 3.7584546314818997`*^9, 
   3.759043263723241*^9, 3.7615700916095867`*^9, 3.7620812783249187`*^9, 
   3.762081538915877*^9, 3.762081621415281*^9, 3.7620816825051937`*^9, {
   3.7620817679253144`*^9, 
   3.7620817823675456`*^9}},ExpressionUUID->"490b544f-2cf1-4964-bae7-\
c274a2a9fccf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{"en2", "\[Equal]", "0"}], ",", 
            RowBox[{
             SuperscriptBox["Vm", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", 
         RowBox[{
          RowBox[{"\[Delta]\[Rho]m", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
          RowBox[{
           RowBox[{"\[Delta]", "[", "a", "]"}], "*", 
           RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "/.", 
        RowBox[{
         RowBox[{
          RowBox[{"Pm", "'"}], "[", "t", "]"}], "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"wm", "[", "t", "]"}], 
            RowBox[{"\[Rho]m", "[", "t", "]"}]}], ",", "t"}], "]"}]}]}], "/.",
        "cons0"}], "/.", 
      RowBox[{
       RowBox[{"Pm", "[", "t", "]"}], "->", 
       RowBox[{
        RowBox[{"wm", "[", "t", "]"}], 
        RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "/.", "a2H"}], "//", 
    "FullSimplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.728231876134303*^9, 3.7282318961833067`*^9}, {
   3.728280766673312*^9, 3.728280784504643*^9}, {3.7484506735125136`*^9, 
   3.74845068461707*^9}, {3.7484509599177313`*^9, 3.7484509719935627`*^9}, {
   3.7484510478632927`*^9, 3.7484510761241283`*^9}, {3.758368747370846*^9, 
   3.7583687729508533`*^9}, 3.7583690815911274`*^9, {3.758370523161984*^9, 
   3.758370524631854*^9}, {3.7620813375254126`*^9, 3.7620813797354593`*^9}, {
   3.7620816940058155`*^9, 3.7620817086455283`*^9}, {3.762081879995185*^9, 
   3.7620818822656856`*^9}},ExpressionUUID->"0e876286-d35d-48e2-b7bd-\
b5f5df87d91e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["Vm", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"H", "[", "t", "]"}]}], " ", 
     RowBox[{"Vm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"Vm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"wm", "[", "t", "]"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[Delta]Pm", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"wm", "[", "t", "]"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.728280779018112*^9, 3.7282807848014703`*^9}, 
   3.7282968621260595`*^9, 3.7288933432111516`*^9, 3.731907134808182*^9, 
   3.7319198844907937`*^9, 3.7319250150765996`*^9, 3.732353884070424*^9, 
   3.7325242225977917`*^9, 3.732610471382817*^9, 3.7328548243517847`*^9, 
   3.732858687257057*^9, 3.7329415916773624`*^9, 3.7330451473541393`*^9, 
   3.7335662202808666`*^9, 3.745665719432469*^9, 3.7458245542386475`*^9, 
   3.745831678781186*^9, 3.745833554081523*^9, 3.745852965927546*^9, 
   3.745904692852536*^9, 3.745905031006107*^9, 3.7459155162496777`*^9, 
   3.746184839822194*^9, 3.7462531746893444`*^9, 3.7462628111461987`*^9, 
   3.746420841375271*^9, 3.746427842603588*^9, 3.7484488227237453`*^9, 
   3.748450616806498*^9, {3.748450675412017*^9, 3.7484506848694572`*^9}, 
   3.748450751765408*^9, {3.7484508110003214`*^9, 3.748450839557064*^9}, 
   3.7484509735914536`*^9, {3.7484510520777016`*^9, 3.748451078257039*^9}, 
   3.7484511475497866`*^9, {3.7583687445856485`*^9, 3.7583687734184694`*^9}, 
   3.7583690821911974`*^9, {3.75837048753159*^9, 3.7583705407266912`*^9}, 
   3.7583705885716567`*^9, 3.7583725927600436`*^9, 3.7584546555022936`*^9, 
   3.759043266243574*^9, 3.7615701022946124`*^9, 3.7620812932579737`*^9, {
   3.7620813570436816`*^9, 3.7620813810454564`*^9}, 3.7620815609153223`*^9, {
   3.762081698705572*^9, 3.7620817100151577`*^9}, 3.762081795170248*^9, 
   3.762081883405384*^9},ExpressionUUID->"6dad14a5-a663-4ac7-a31e-\
ee09ccc124e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"continuity", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{
               RowBox[{
                SuperscriptBox["\[Delta]", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "==", 
               RowBox[{
                RowBox[{"-", 
                 FractionBox[
                  RowBox[{"Vm", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                  RowBox[{"a", "[", "t", "]"}]]}], "+", 
                RowBox[{
                 RowBox[{"H", "[", "t", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"3", " ", 
                    RowBox[{"wm", "[", "t", "]"}], " ", 
                    RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
                   FractionBox[
                    RowBox[{"3", " ", 
                    RowBox[{"\[Delta]Pm", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
                    RowBox[{"\[Rho]m", "[", "t", "]"}]]}], ")"}]}], "-", 
                RowBox[{"3", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", 
                   RowBox[{"wm", "[", "t", "]"}]}], ")"}], " ", 
                 RowBox[{
                  SuperscriptBox["\[CapitalPhi]", 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
              ",", 
              RowBox[{
               RowBox[{
                SuperscriptBox["Vm", 
                 TagBox[
                  RowBox[{"(", 
                   RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
                  Derivative],
                 MultilineFunction->None], "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "==", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  RowBox[{"H", "[", "t", "]"}]}], " ", 
                 RowBox[{"Vm", "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
                RowBox[{"3", " ", 
                 RowBox[{"H", "[", "t", "]"}], " ", 
                 RowBox[{"Vm", "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
                 RowBox[{"wm", "[", "t", "]"}]}], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["k", "2"], " ", 
                  RowBox[{"\[Delta]Pm", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
                 RowBox[{
                  RowBox[{"a", "[", "t", "]"}], " ", 
                  RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["k", "2"], " ", 
                  RowBox[{"\[CapitalPsi]", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
                 RowBox[{"a", "[", "t", "]"}]], "+", 
                FractionBox[
                 RowBox[{
                  SuperscriptBox["k", "2"], " ", 
                  RowBox[{"wm", "[", "t", "]"}], " ", 
                  RowBox[{"\[CapitalPsi]", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
                 RowBox[{"a", "[", "t", "]"}]]}]}]}], "}"}], "/.", 
            RowBox[{
             RowBox[{
              SuperscriptBox["\[Delta]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
             RowBox[{"a", " ", 
              RowBox[{"H", "[", "a", "]"}], " ", 
              RowBox[{
               RowBox[{"\[Delta]", "'"}], "[", "a", "]"}]}]}]}], "/.", 
           RowBox[{
            RowBox[{"Vm", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
            RowBox[{"Vm", "[", "a", "]"}]}]}], "/.", 
          RowBox[{
           RowBox[{
            SuperscriptBox["\[CapitalPhi]", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
           RowBox[{"a", " ", 
            RowBox[{"H", "[", "a", "]"}], 
            RowBox[{
             RowBox[{"\[CapitalPhi]", "'"}], "[", "a", "]"}]}]}]}], "/.", 
         RowBox[{
          RowBox[{
           SuperscriptBox["Vm", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
          RowBox[{"a", " ", 
           RowBox[{"H", "[", "a", "]"}], 
           RowBox[{
            RowBox[{"Vm", "'"}], "[", "a", "]"}]}]}]}], "/.", 
        RowBox[{
         RowBox[{"Vm", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
         RowBox[{"Vm", "[", "a", "]"}]}]}], "/.", 
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{"-", 
        RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}]}], "/.", 
     RowBox[{
      RowBox[{"wm", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"wm", "[", "a", "]"}]}]}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["wm", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     RowBox[{"a", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{
       RowBox[{"wm", "'"}], "[", "a", "]"}]}]}]}], "/.", 
   RowBox[{
    RowBox[{"a", "[", "t", "]"}], "\[Rule]", "a"}]}]}]], "Input",
 CellChangeTimes->{{3.758368783070638*^9, 3.7583688268538136`*^9}, {
   3.7583688609410086`*^9, 3.758368940550932*^9}, {3.7583690915410757`*^9, 
   3.7583690995407987`*^9}, {3.758369171413519*^9, 3.7583691729830084`*^9}, {
   3.758372622905011*^9, 3.758372630447587*^9}, {3.75845466300731*^9, 
   3.758454674387332*^9}, 3.7584547574771404`*^9, {3.7620813126474853`*^9, 
   3.762081324130091*^9}, {3.7620813965052648`*^9, 3.7620814289061985`*^9}, {
   3.7620818067453213`*^9, 3.7620818133002195`*^9}, 
   3.7620818898353095`*^9},ExpressionUUID->"461d917b-965e-4cf1-9d73-\
9d2e65537e1c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Delta]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Vm", "[", "a", "]"}], "a"]}], "+", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"wm", "[", "a", "]"}], " ", 
         RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          RowBox[{"\[Delta]Pm", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
         RowBox[{"\[Rho]m", "[", "t", "]"}]]}], ")"}]}], "-", 
     RowBox[{"3", " ", "a", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"wm", "[", "a", "]"}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[CapitalPhi]", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["Vm", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"H", "[", "a", "]"}]}], " ", 
      RowBox[{"Vm", "[", "a", "]"}]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"Vm", "[", "a", "]"}], " ", 
      RowBox[{"wm", "[", "a", "]"}]}], "+", 
     FractionBox[
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"\[Delta]Pm", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{"a", " ", 
       RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "a"], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"wm", "[", "a", "]"}], " ", 
       RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "a"]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7620814067553368`*^9, 3.762081430215381*^9}, 
   3.7620818198877153`*^9, 
   3.7620818911455874`*^9},ExpressionUUID->"ad2ff368-9dca-42df-93af-\
416006354c6a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{"continuity", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Delta]", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}], ",", 
      RowBox[{
       SuperscriptBox["Vm", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}], "}"}]}], "]"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.7620818331901584`*^9, 
  3.7620818431855145`*^9}},ExpressionUUID->"4a79d501-3f45-4a5f-bf92-\
961b8668f993"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Delta]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Vm", "[", "a", "]"}], 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"H", "[", "a", "]"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"wm", "[", "a", "]"}], " ", 
        RowBox[{"\[Delta]", "[", "a", "]"}]}], "a"], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"\[Delta]Pm", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"a", " ", 
        RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
      RowBox[{"3", " ", 
       RowBox[{
        SuperscriptBox["\[CapitalPhi]", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"wm", "[", "a", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CapitalPhi]", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["Vm", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Vm", "[", "a", "]"}], "a"]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"Vm", "[", "a", "]"}], " ", 
        RowBox[{"wm", "[", "a", "]"}]}], "a"], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[Delta]Pm", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}], " ", 
        RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"wm", "[", "a", "]"}], " ", 
        RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.762081828355303*^9, 3.7620818435577655`*^9}, 
   3.7620818948674316`*^9},ExpressionUUID->"0ee88834-c567-4278-ade1-\
a643b47a3fb6"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"continuity", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Delta]", "\[Prime]",
          MultilineFunction->None], "[", "a", "]"}], ",", 
        RowBox[{
         SuperscriptBox["Vm", "\[Prime]",
          MultilineFunction->None], "[", "a", "]"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}]}], 
   "/.", 
   RowBox[{
    RowBox[{"wm", "[", "a", "]"}], "\[Rule]", "0"}]}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.762081940095769*^9, 
  3.7620819456184587`*^9}},ExpressionUUID->"7697c8c6-efe1-4507-b2c8-\
89ec929c1312"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Delta]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Vm", "[", "a", "]"}], 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"H", "[", "a", "]"}]}]]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{
        SuperscriptBox["\[CapitalPhi]", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["Vm", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Vm", "[", "a", "]"}], "a"]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.762081946080188*^9},ExpressionUUID->"3178e101-5f26-4bb1-9e17-\
e6315d3be0a1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.728128098322069*^9, 
  3.7281281014358377`*^9}},ExpressionUUID->"da31141e-3488-477b-9251-\
872a0e1c693f"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Designer", " ", "models"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568076714341516`*^9, 
  3.756807682373931*^9}},ExpressionUUID->"0b06cc52-c0b6-4273-8437-\
ab30654a089f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Designer", " ", "1"}], ":", " ", "K"}], "=", 
   RowBox[{"K", 
    RowBox[{"(", "X", ")"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753006403640971*^9, 
  3.753006415550289*^9}},ExpressionUUID->"8350b594-b769-4719-92dd-\
ebfe821f5153"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"K", "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "->", 
      RowBox[{
       RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7530064367298837`*^9, 3.753006621790902*^9}, {
  3.75300727955118*^9, 
  3.753007280111225*^9}},ExpressionUUID->"c79398b0-5dc0-4e5c-a7af-\
4219ecf72ad8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["2", "3"], "eq00"}], "/.", "des1"}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      SqrtBox[
       RowBox[{"2", "X"}]]}]}], "/.", 
    RowBox[{"G", "\[Rule]", 
     FractionBox[
      RowBox[{"3", 
       RowBox[{"H0", "^", "2"}]}], 
      RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.753006253280596*^9, 3.75300625875047*^9}, {
   3.7530062900909104`*^9, 3.7530062926208367`*^9}, 3.7530065342910233`*^9, {
   3.753006673021145*^9, 3.753006754990944*^9}, 3.7530068120610523`*^9, {
   3.7530069460611134`*^9, 3.7530069526014147`*^9}, 
   3.7530070561008687`*^9},ExpressionUUID->"c6658163-61c5-4f55-800f-\
25861a9950e7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  FractionBox[
   RowBox[{"K", "[", "X", "]"}], "3"], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["H0", "2"], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}], "\[Rho]c"], "+", 
  RowBox[{
   FractionBox["2", "3"], " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.75300625929001*^9, 3.7530062931607666`*^9, 3.753006534780862*^9, 
   3.753006576770675*^9, 3.7530066241651354`*^9, {3.753006696672677*^9, 
   3.7530067556109834`*^9}, 3.7530068125910587`*^9, 3.7530069531110096`*^9, 
   3.7530070572850437`*^9, {3.753007281895488*^9, 3.753007294504588*^9}, 
   3.75302595909354*^9},ExpressionUUID->"938313bb-0c37-49e6-a4d9-\
d6dc2c19820c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       FractionBox["2", "3"], "X", " ", 
       RowBox[{
        RowBox[{"K", "'"}], "[", "X", "]"}]}], "-", 
      FractionBox[
       RowBox[{"K", "[", "X", "]"}], "3"]}], "\[Equal]", 
     "\[CapitalOmega]\[CapitalLambda]0"}], ",", 
    RowBox[{"K", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7530068879111586`*^9, 
  3.753006925421136*^9}},ExpressionUUID->"943b22a8-1c12-4c4f-ad17-\
fa11ed9784cd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
    RowBox[{
     SqrtBox["X"], " ", 
     RowBox[{"C", "[", "1", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530069100906906`*^9, 3.753006925865362*^9}, 
   3.7530072953551435`*^9, 
   3.753025959357368*^9},ExpressionUUID->"21e0b450-0c0b-482f-8432-\
f29882f161a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes12", "=", 
  RowBox[{
   RowBox[{"eqscal", "/.", "des1"}], "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    SqrtBox[
     RowBox[{"2", "X"}]]}]}]}]], "Input",
 CellChangeTimes->{{3.7530063307510242`*^9, 3.753006356440937*^9}, 
   3.753006540180942*^9, {3.7530066326412277`*^9, 3.7530066387050753`*^9}, 
   3.7530067727310743`*^9, {3.753006955360885*^9, 3.753006956890292*^9}, 
   3.753007059370535*^9},ExpressionUUID->"54bd4f3b-afcc-4803-aa5e-\
261d182d0930"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.753006331844735*^9, 3.7530063568907356`*^9}, {
   3.7530065408530493`*^9, 3.7530065863449755`*^9}, {3.75300662512449*^9, 
   3.7530066392010255`*^9}, 3.7530067736489787`*^9, 3.7530069574109864`*^9, 
   3.753007063861037*^9, 3.7530073063309937`*^9, 
   3.7530259593679247`*^9},ExpressionUUID->"b9ba3830-62bb-4a17-9dab-\
660eaf236bdf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes12", "/.", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "3"}], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        RowBox[{
         SqrtBox["X"], " ", 
         RowBox[{"C", "[", "1", "]"}]}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"X", ",", "i"}], "}"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7530069631511106`*^9, 3.7530069840309534`*^9}, 
   3.753007060361372*^9, {3.7530073145212784`*^9, 
   3.753007324031111*^9}},ExpressionUUID->"6e6ff24f-2d70-4161-a528-\
83b5b20b9dbe"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   RowBox[{"C", "[", "1", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], 
  SqrtBox["2"]]], "Output",
 CellChangeTimes->{
  3.7530069850658617`*^9, {3.753007061601309*^9, 3.753007064850794*^9}, {
   3.7530072847510347`*^9, 3.753007324935215*^9}, 
   3.7530259622935095`*^9},ExpressionUUID->"0121869f-ae85-4efb-867a-\
0bdf65a06537"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753103919594767*^9, 
  3.753103921703641*^9}},ExpressionUUID->"76bb049b-e58b-4d67-8fdc-\
2c6f5d15517d"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Designer", " ", "2"}], ":", " ", "G"}], "=", 
   RowBox[{"G", 
    RowBox[{"(", "X", ")"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753007025810972*^9, 3.75300703764139*^9}, 
   3.7530074340625987`*^9},ExpressionUUID->"86a27331-cc83-42b0-a7b1-\
0725c7b397fe"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"des2", ",", "eqdes2", ",", "solf", ",", "eqg3"}], "]"}]], "Input",
 CellChangeTimes->{{3.7530268091552315`*^9, 
  3.753026828954541*^9}},ExpressionUUID->"e6334d38-e86e-4eb2-ad03-\
6f46a4685313"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "''"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7530071402313166`*^9, 3.7530071520712533`*^9}, {
  3.7530073980312834`*^9, 3.7530074020115433`*^9}, {3.7530267947608924`*^9, 
  3.7530267954046335`*^9}},ExpressionUUID->"8c4e10ab-0935-45c8-a629-\
4c045bfa9c51"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["2", "3"], "eq00"}], "/.", "des2"}], "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "t", "]"}], "\[Rho]c"}]}]}], "/.", 
    RowBox[{"t", "\[Rule]", "a"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.753007162370982*^9, 3.7530071639310336`*^9}, {
  3.753007412681366*^9, 3.753007413180858*^9}, {3.7530074538413053`*^9, 
  3.7530074742035904`*^9}, {3.7530268519539814`*^9, 
  3.753026864814765*^9}},ExpressionUUID->"28836f5b-65e9-43b9-b8b7-\
bb14f0cf3a98"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530070956712055`*^9, 3.7530071645856547`*^9, 3.753007359271302*^9, {
   3.7530074043412685`*^9, 3.7530074136313868`*^9}, {3.7530074566310596`*^9, 
   3.75300747484136*^9}, 3.753009479731315*^9, 3.753010399292014*^9, 
   3.7530259723809757`*^9, 3.7530267991530056`*^9, {3.7530268472211742`*^9, 
   3.7530268654142923`*^9}, 
   3.7530272317890463`*^9},ExpressionUUID->"36722b12-18ee-4e04-8873-\
90f091065652"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"eqscal", "/.", "des2"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], "/.", 
       RowBox[{"G", "\[Rule]", 
        FractionBox[
         RowBox[{"3", 
          RowBox[{"H0", "^", "2"}]}], 
         RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "//", "Expand"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7530072546512675`*^9, {3.753007978861573*^9, 3.7530079844517*^9}, {
   3.75300819971229*^9, 3.7530082001136017`*^9}, {3.7530268680858884`*^9, 
   3.7530268991518917`*^9}},ExpressionUUID->"4ce3bef8-1798-4b16-a5c2-\
52177610aa0e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"18", " ", "X", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"6", " ", "a", " ", "X", " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "a", "]"}]}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"X", " ", 
      RowBox[{
       SuperscriptBox["G3", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530072553012924`*^9, 3.75300736155129*^9, 3.7530075454953737`*^9, {
   3.7530079799828978`*^9, 3.753007985875571*^9}, 3.7530082007913494`*^9, 
   3.753009481096099*^9, 3.7530104003049483`*^9, 3.7530259745347195`*^9, 
   3.7530268004690237`*^9, {3.7530268708900013`*^9, 3.7530269002721505`*^9}, 
   3.7530272332545967`*^9},ExpressionUUID->"4ada0c8f-b160-44f4-83d9-\
ac583f2a969d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Ptot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
    "des2"}], "//", "FullSimplify"}]], "Input",ExpressionUUID->"aa537cb5-94a9-\
463e-a101-0af08232172a"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.753008288221882*^9, 3.753009482346419*^9, 
  3.7530104012915435`*^9, 3.753025976743453*^9, 3.7530269098180213`*^9, 
  3.75302723538494*^9},ExpressionUUID->"e4b5c9fb-8904-46ea-8389-ec204c890179"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Jtot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
      "des2"}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}], "/.", 
   RowBox[{"t", "\[Rule]", "a"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.7530082969130588`*^9, 3.7530083295913944`*^9, {3.753026917538438*^9, 
   3.75302691893057*^9}},ExpressionUUID->"4906122a-d823-4c6a-afb1-\
2e3d2ff349f9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", "6"}], " ", "X", " ", 
    RowBox[{"H", "[", "a", "]"}], " ", 
    RowBox[{
     SuperscriptBox["G3", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], ",", "0", ",", "0", ",", 
   "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7530082975415645`*^9, 3.753008330541541*^9, 3.7530094836722317`*^9, 
   3.7530104029223557`*^9, 3.753025977723363*^9, {3.7530269141756024`*^9, 
   3.753026919235218*^9}, 
   3.7530272363194532`*^9},ExpressionUUID->"b3d8090f-0f34-4ae5-800c-\
86f78f9802e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{"Raise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"J", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}],
         ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", "zeroorder"}], "//",
   "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7530083583919115`*^9, 3.753008383591753*^9}, 
   3.7530269380948334`*^9},ExpressionUUID->"b32631c8-aa7c-46bd-9896-\
ad8f03fc9ba2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"J", "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["J", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.753008368031542*^9, 3.75300838394143*^9}, 
   3.7530094861559353`*^9, 3.7530104039620748`*^9, 3.7530259792893887`*^9, {
   3.7530269237358108`*^9, 3.7530269389219027`*^9}, 
   3.7530272449852643`*^9},ExpressionUUID->"14aa4779-81dc-4ae3-bd6b-\
2eda3bb2ade2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
        RowBox[{"a", "[", "t", "]"}]}], " ", 
       RowBox[{"J", "[", "t", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["J", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{"J", "[", "t", "]"}], ",", "t"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.753026941097069*^9, 
  3.7530269583466897`*^9}},ExpressionUUID->"b8eb886f-07fa-4241-b931-\
946a9252eaff"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530269555727863`*^9, 3.7530269586755733`*^9}, 
   3.7530272465369406`*^9},ExpressionUUID->"3885c6ab-8f03-4c96-a916-\
f1fd1c37006e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HL", "=", 
   RowBox[{"H0", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}], "+", "\[CapitalOmega]\[CapitalLambda]0"}]]}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7530269935173016`*^9, 
  3.7530269990121403`*^9}},ExpressionUUID->"1e6aa086-fd80-443a-887c-\
db08c833b896"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", "X", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], "\[Equal]", 
     RowBox[{
      RowBox[{"-", "J0"}], "/", 
      RowBox[{"a", "^", "3"}]}]}], ",", 
    RowBox[{
     SuperscriptBox["G3", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"eqdes21", "/.", 
    RowBox[{"%", "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//", "FullSimplify"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{"X", "\[Rule]", 
    RowBox[{
     FractionBox["1", "2"], 
     SuperscriptBox["a", "2"], 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}]}], "//", 
  "PowerExpand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
   RowBox[{
    RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
    RowBox[{"\[CapitalOmega]m0", " ", 
     SuperscriptBox["a", 
      RowBox[{"-", "3"}]]}]}]}], "//", "Expand"}]}], "Input",
 CellChangeTimes->{{3.7530083914917707`*^9, 3.7530084295017056`*^9}, {
   3.7530084672920847`*^9, 3.753008510661865*^9}, 3.7530085595317974`*^9, {
   3.753008598641674*^9, 3.753008599852062*^9}, 3.753008854561855*^9, 
   3.7530094978267145`*^9, {3.753009757872501*^9, 3.753009809632099*^9}, {
   3.7530099351624074`*^9, 3.7530099736410246`*^9}, {3.7530269689736786`*^9, 
   3.7530270021821313`*^9}, {3.7530272602336264`*^9, 
   3.753027272302599*^9}},ExpressionUUID->"20ab99e2-671e-4d28-a147-\
aca3c4d93ad2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
   FractionBox["J0", 
    RowBox[{"6", " ", 
     SuperscriptBox["a", "3"], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.753008413011854*^9, 3.753008430175683*^9}, {
   3.7530084765316668`*^9, 3.7530085123155136`*^9}, 3.7530085607252445`*^9, 
   3.753008600261757*^9, 3.7530088554741497`*^9, 3.7530094994250584`*^9, {
   3.753009787282061*^9, 3.7530098106313815`*^9}, {3.75300995262211*^9, 
   3.753009974212414*^9}, 3.7530104050524607`*^9, 3.7530259811176276`*^9, 
   3.7530270040013247`*^9, {3.753027265255958*^9, 
   3.7530272732259502`*^9}},ExpressionUUID->"ccc82fa2-489e-4272-b760-\
a51d294d9a98"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["a", "3"]}]], "-", 
  SuperscriptBox[
   RowBox[{"H", "[", "a", "]"}], "2"], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.753008413011854*^9, 3.753008430175683*^9}, {
   3.7530084765316668`*^9, 3.7530085123155136`*^9}, 3.7530085607252445`*^9, 
   3.753008600261757*^9, 3.7530088554741497`*^9, 3.7530094994250584`*^9, {
   3.753009787282061*^9, 3.7530098106313815`*^9}, {3.75300995262211*^9, 
   3.753009974212414*^9}, 3.7530104050524607`*^9, 3.7530259811176276`*^9, 
   3.7530270040013247`*^9, {3.753027265255958*^9, 
   3.753027273271211*^9}},ExpressionUUID->"104d51a7-5904-47c0-ad6e-\
a34c008607d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
  FractionBox[
   RowBox[{"J0", " ", 
    RowBox[{"H", "[", "a", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.753008413011854*^9, 3.753008430175683*^9}, {
   3.7530084765316668`*^9, 3.7530085123155136`*^9}, 3.7530085607252445`*^9, 
   3.753008600261757*^9, 3.7530088554741497`*^9, 3.7530094994250584`*^9, {
   3.753009787282061*^9, 3.7530098106313815`*^9}, {3.75300995262211*^9, 
   3.753009974212414*^9}, 3.7530104050524607`*^9, 3.7530259811176276`*^9, 
   3.7530270040013247`*^9, {3.753027265255958*^9, 
   3.753027273278839*^9}},ExpressionUUID->"af0bac1a-6502-4522-a801-\
0b75527f65f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    SuperscriptBox["H0", "2"]}], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
  "+", 
  FractionBox[
   RowBox[{"H0", " ", "J0", " ", 
    SqrtBox[
     RowBox[{
      FractionBox["\[CapitalOmega]m0", 
       SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
    " ", 
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.753008413011854*^9, 3.753008430175683*^9}, {
   3.7530084765316668`*^9, 3.7530085123155136`*^9}, 3.7530085607252445`*^9, 
   3.753008600261757*^9, 3.7530088554741497`*^9, 3.7530094994250584`*^9, {
   3.753009787282061*^9, 3.7530098106313815`*^9}, {3.75300995262211*^9, 
   3.753009974212414*^9}, 3.7530104050524607`*^9, 3.7530259811176276`*^9, 
   3.7530270040013247`*^9, {3.753027265255958*^9, 
   3.753027273286352*^9}},ExpressionUUID->"1899756b-35ec-4dbe-bbfa-\
b4e3cf8df725"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solf", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["H0", "2"]}], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       FractionBox[
        RowBox[{"H0", " ", "J0", " ", 
         SqrtBox[
          RowBox[{
           FractionBox["\[CapitalOmega]m0", 
            SuperscriptBox["a", "3"]], "+", 
           "\[CapitalOmega]\[CapitalLambda]0"}]], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "a", "]"}]}], 
        RowBox[{"3", " ", 
         SuperscriptBox["a", "2"]}]]}], "\[Equal]", "0"}], ",", 
     RowBox[{"\[Phi]", "[", "a", "]"}], ",", "a"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.753009039621721*^9, 3.753009099132203*^9}, {
   3.753009848292137*^9, 3.7530098717422237`*^9}, {3.75300998829246*^9, 
   3.753009988552499*^9}, 3.753010334942474*^9, {3.7530270458964157`*^9, 
   3.753027078179313*^9}, {3.753027292832443*^9, 
   3.753027293391679*^9}},ExpressionUUID->"8d138719-d007-4f8e-8d91-\
ead2a130502f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Phi]", "[", "a", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"H0", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox["\[CapitalOmega]\[CapitalLambda]0"], " ", 
          RowBox[{"(", 
           RowBox[{"\[CapitalOmega]m0", "+", 
            RowBox[{
             SuperscriptBox["a", "3"], " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "-", 
         RowBox[{"\[CapitalOmega]m0", " ", 
          SqrtBox[
           RowBox[{"\[CapitalOmega]m0", "+", 
            RowBox[{
             SuperscriptBox["a", "3"], " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}]}]], " ", 
          RowBox[{"Log", "[", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", 
              RowBox[{"3", "/", "2"}]], " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
            RowBox[{
             SqrtBox["\[CapitalOmega]\[CapitalLambda]0"], " ", 
             SqrtBox[
              RowBox[{"\[CapitalOmega]m0", "+", 
               RowBox[{
                SuperscriptBox["a", "3"], " ", 
                "\[CapitalOmega]\[CapitalLambda]0"}]}]]}]}], "]"}]}]}], 
        ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", 
        RowBox[{"3", "/", "2"}]], " ", "J0", " ", 
       SqrtBox["\[CapitalOmega]\[CapitalLambda]0"], " ", 
       SqrtBox[
        RowBox[{
         FractionBox["\[CapitalOmega]m0", 
          SuperscriptBox["a", "3"]], "+", 
         "\[CapitalOmega]\[CapitalLambda]0"}]]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7530090672612314`*^9, 3.7530090995197587`*^9}, 
   3.7530098741057715`*^9, 3.753009990045109*^9, 3.75301033639126*^9, 
   3.7530259859751415`*^9, {3.7530270553417473`*^9, 3.753027078666424*^9}, 
   3.7530272945190706`*^9},ExpressionUUID->"db012fed-e14d-495b-91b0-\
3b70c31280ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqg3", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["G3", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}], 
          RowBox[{
           RowBox[{"X", "'"}], "[", "a", "]"}]]}], "+", 
        FractionBox["J0", 
         RowBox[{"6", " ", 
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}]}]]}], "/.", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"X", "[", "a", "]"}], "\[Rule]", 
            RowBox[{
             FractionBox["1", "2"], 
             SuperscriptBox["a", "2"], 
             RowBox[{
              RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], ",", 
           
           RowBox[{"{", 
            RowBox[{"a", ",", "i"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "/.", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
           RowBox[{"H0", 
            SqrtBox[
             RowBox[{
              RowBox[{"\[CapitalOmega]m0", " ", 
               SuperscriptBox["a", 
                RowBox[{"-", "3"}]]}], "+", 
              "\[CapitalOmega]\[CapitalLambda]0"}]]}]}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "i"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "/.", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"solf", ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "i"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}], "]"}]}], "//", 
    "FullSimplify"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"eqg3", "\[Equal]", "0"}], ",", 
     RowBox[{"G3", "[", "a", "]"}], ",", "a"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], "Input",
 CellChangeTimes->{{3.753010079886223*^9, 3.753010270706129*^9}, {
  3.7530104844528456`*^9, 3.753010544606769*^9}, {3.7530105951327314`*^9, 
  3.753010599243032*^9}, {3.7530273280118465`*^9, 
  3.7530273344426546`*^9}},ExpressionUUID->"920eaf20-454d-4f5c-980c-\
5f838f14bdb9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "a", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", "J0", " ", 
       SqrtBox[
        RowBox[{
         FractionBox["\[CapitalOmega]m0", 
          SuperscriptBox["a", "3"]], "+", 
         "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
      RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530101242564526`*^9, 3.753010272112232*^9}, 
   3.7530103389765635`*^9, 3.7530105482122726`*^9, 3.753010601452563*^9, 
   3.7530259987533655`*^9, 
   3.753027353459531*^9},ExpressionUUID->"9393fe51-981e-4ef4-accf-\
8cd19eac3e59"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"X", "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["1", "2"], 
      SuperscriptBox["a", "2"], 
      RowBox[{
       RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], "/.", 
    RowBox[{"D", "[", 
     RowBox[{"solf", ",", "a"}], "]"}]}], "/.", 
   RowBox[{
    RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
    RowBox[{"H0", 
     SqrtBox[
      RowBox[{
       RowBox[{"\[CapitalOmega]m0", " ", 
        SuperscriptBox["a", 
         RowBox[{"-", "3"}]]}], "+", 
       "\[CapitalOmega]\[CapitalLambda]0"}]]}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.753010292561901*^9, 3.753010314466611*^9}, {
  3.7530106217927036`*^9, 
  3.7530106308620663`*^9}},ExpressionUUID->"03a295b5-2e96-41f3-a8e5-\
eb606c2a7b68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "[", "a", "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["a", "6"], " ", 
    SuperscriptBox["H0", "4"], " ", 
    SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["J0", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.753010300792158*^9, 3.753010343902461*^9}, {
   3.753010619136546*^9, 3.7530106313524942`*^9}, 3.7530260055290203`*^9, 
   3.753027206229308*^9, 
   3.753027358507456*^9},ExpressionUUID->"be31b4bc-25f1-4c14-a95a-\
6d58516f6229"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"X", "==", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["H0", "4"], " ", 
       SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["J0", "2"]}]]}], ",", "a"}], "]"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G3", "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2", " ", "J0", " ", 
        SqrtBox[
         RowBox[{
          FractionBox["\[CapitalOmega]m0", 
           SuperscriptBox["a", "3"]], "+", 
          "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
       RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
     RowBox[{"C", "[", "1", "]"}]}]}], "/.", "%"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7530106325167136`*^9, 3.7530106701220016`*^9}, 
   3.753027373431938*^9},ExpressionUUID->"ac5464e0-5b26-468c-8ed9-\
2212994a74cb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["2", 
      RowBox[{"1", "/", "6"}]], " ", 
     SuperscriptBox["J0", 
      RowBox[{"1", "/", "3"}]], " ", 
     SuperscriptBox["X", 
      RowBox[{"1", "/", "6"}]]}], 
    RowBox[{
     SuperscriptBox["3", 
      RowBox[{"1", "/", "3"}]], " ", 
     SuperscriptBox["H0", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", 
      RowBox[{"1", "/", "3"}]]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.753010643062721*^9, 3.753010670696121*^9}, 
   3.753026006849933*^9, 
   3.753027376164796*^9},ExpressionUUID->"e624108e-1b28-45ef-8da0-\
54224a15a6ef"],

Cell[BoxData[
 RowBox[{"G3", "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"J0", " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"4", "+", 
          FractionBox[
           RowBox[{"6", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
           RowBox[{"J0", " ", 
            SqrtBox["X"]}]]}], ")"}], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
     RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
   RowBox[{"C", "[", "1", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.753010643062721*^9, 3.753010670696121*^9}, 
   3.753026006849933*^9, 
   3.753027376570938*^9},ExpressionUUID->"135f995a-568a-4e22-90b7-\
ae521eabd908"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["eqdes21"], "Input",ExpressionUUID->"5860bcb9-1e6b-475a-bf06-84de3a0dd3ae"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530274344147563`*^9},ExpressionUUID->"a75d6e1f-cc32-4305-99ab-\
6346315d6672"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"eqdes21", "/.", 
       RowBox[{
        RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"-", 
           FractionBox[
            RowBox[{"J0", " ", 
             SqrtBox[
              RowBox[{
               RowBox[{"(", 
                RowBox[{"4", "+", 
                 FractionBox[
                  RowBox[{"6", " ", 
                   SqrtBox["2"], " ", 
                   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
                  RowBox[{"J0", " ", 
                   SqrtBox["X"]}]]}], ")"}], " ", 
               "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
            RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
          RowBox[{"C", "[", "1", "]"}]}]}], ",", "X"}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "->", 
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}]}]}], "/.", 
    RowBox[{"X", "->", 
     FractionBox[
      RowBox[{"9", " ", 
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["H0", "4"], " ", 
       SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["J0", "2"]}]]}]}], "//", "FullSimplify"}], "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.7530260437467594`*^9, 3.7530261092095633`*^9}, {
  3.7530261405792646`*^9, 3.7530261529526606`*^9}, {3.7530274188307147`*^9, 
  3.753027440744216*^9}},ExpressionUUID->"f33dbf31-b448-4aee-8cef-\
c2f8891ab5a6"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.75302603461351*^9, 3.7530261105799828`*^9}, {
   3.753026146552576*^9, 3.753026153409706*^9}, 
   3.7530274854635396`*^9},ExpressionUUID->"76fa8c5a-307e-4e4e-862e-\
141fa396caf8"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"solf1", "=", 
   RowBox[{"D", "[", 
    RowBox[{"solf", ",", "a"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solf2", "=", 
   RowBox[{"D", "[", 
    RowBox[{"solf", ",", 
     RowBox[{"{", 
      RowBox[{"a", ",", "2"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7530275978481216`*^9, 
  3.7530276282431602`*^9}},ExpressionUUID->"6272d345-1256-4a9a-bc15-\
43d42a9aa0f6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqscal1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"eqscal", "/.", "des2"}], "/.", 
               RowBox[{
                RowBox[{"H", "[", "t", "]"}], "->", 
                RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
              RowBox[{
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
               RowBox[{"a", " ", 
                RowBox[{"H", "[", "a", "]"}], " ", 
                RowBox[{
                 RowBox[{"\[Phi]", "'"}], "[", "a", "]"}]}]}]}], "/.", 
             RowBox[{
              RowBox[{
               SuperscriptBox["H", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
              RowBox[{"a", " ", 
               RowBox[{"H", "[", "a", "]"}], " ", 
               RowBox[{
                RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "/.", 
            RowBox[{
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
             RowBox[{"a", " ", 
              RowBox[{"H", "[", "a", "]"}], " ", 
              RowBox[{"D", "[", 
               RowBox[{
                RowBox[{"a", " ", 
                 RowBox[{"H", "[", "a", "]"}], 
                 RowBox[{
                  RowBox[{"\[Phi]", "'"}], "[", "a", "]"}]}], ",", "a"}], 
               "]"}]}]}]}], "/.", "solf1"}], "/.", "solf2"}], "/.", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"J0", " ", 
                SqrtBox[
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"4", "+", 
                    FractionBox[
                    RowBox[{"6", " ", 
                    SqrtBox["2"], " ", 
                    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
                    RowBox[{"J0", " ", 
                    SqrtBox["X"]}]]}], ")"}], " ", 
                  "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
               RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
             RowBox[{"C", "[", "1", "]"}]}]}], ",", "X"}], "]"}]}], "/.", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"-", 
             FractionBox[
              RowBox[{"J0", " ", 
               SqrtBox[
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{"4", "+", 
                   FractionBox[
                    RowBox[{"6", " ", 
                    SqrtBox["2"], " ", 
                    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
                    RowBox[{"J0", " ", 
                    SqrtBox["X"]}]]}], ")"}], " ", 
                 "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
              RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
            RowBox[{"C", "[", "1", "]"}]}]}], ",", "X", ",", "X"}], "]"}]}], "/.", 
       RowBox[{
        RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "->", 
        RowBox[{"\[CapitalOmega]m0", " ", 
         SuperscriptBox["a", 
          RowBox[{"-", "3"}]]}]}]}], "/.", 
      RowBox[{"X", "->", 
       FractionBox[
        RowBox[{"9", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["H0", "4"], " ", 
         SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], 
        RowBox[{"2", " ", 
         SuperscriptBox["J0", "2"]}]]}]}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "'"}], "[", "a", "]"}], "\[Rule]", 
     RowBox[{"D", "[", 
      RowBox[{"HL", ",", "a"}], "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7530274997264185`*^9, 3.7530275834435883`*^9}, {
  3.7530276409726596`*^9, 3.753027687662098*^9}, {3.753027741218373*^9, 
  3.753027744275992*^9}},ExpressionUUID->"bd7f5758-f465-4c53-a0b6-\
bfd2bdd58cbe"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"eqscal1", "//", "FullSimplify"}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.7530276930561275`*^9, 
  3.7530277698563633`*^9}},ExpressionUUID->"a0592061-584b-4daa-b312-\
a0331fe15628"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7530277168577175`*^9, 
  3.7530277718771696`*^9}},ExpressionUUID->"8ef7c18e-3b5a-401c-a257-\
936ab92232fb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"X", "->", 
    RowBox[{
     FractionBox["1", "2"], 
     RowBox[{"a", "^", "2"}], " ", 
     RowBox[{"HL", "^", "2"}], " ", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], "/.", 
   "solf1"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.753027843182185*^9, 
  3.7530279028947353`*^9}},ExpressionUUID->"dc932c1a-25b1-4d68-acb8-\
098cf88d1381"],

Cell[BoxData[
 RowBox[{"X", "\[Rule]", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["a", "6"], " ", 
    SuperscriptBox["H0", "4"], " ", 
    SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["J0", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.753027844755409*^9, 
  3.7530279033617105`*^9}},ExpressionUUID->"91834e89-358f-4889-ab02-\
0a186ba1f42d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{"Final", " ", "result", " ", "for", " ", "designer", " ", 
    RowBox[{"G3", "[", "X", "]"}]}], "\[IndentingNewLine]", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"J0", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", "+", 
            FractionBox[
             RowBox[{"6", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
             RowBox[{"J0", " ", 
              SqrtBox["X"]}]]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
       RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
     RowBox[{"C", "[", "1", "]"}]}]}], "\[IndentingNewLine]", 
   RowBox[{"X", "->", 
    FractionBox[
     RowBox[{"9", " ", 
      SuperscriptBox["a", "6"], " ", 
      SuperscriptBox["H0", "4"], " ", 
      SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["J0", "2"]}]]}]}]}]], "Input",
 CellChangeTimes->{{3.7530278028918343`*^9, 3.7530278358787255`*^9}, 
   3.753028433108987*^9},ExpressionUUID->"6487c740-6cc5-496d-a815-\
581ad44ce68e"],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753103919594767*^9, 
  3.753103921703641*^9}},ExpressionUUID->"49f0621c-c706-4da3-bd9e-\
64d6ced51995"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Designer", " ", "3"}], ":", " ", "K"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"K", 
       RowBox[{"(", "X", ")"}]}], " ", "&"}], " ", "G"}], "=", 
    RowBox[{"G", 
     RowBox[{"(", "X", ")"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753007025810972*^9, 3.75300703764139*^9}, 
   3.7530074340625987`*^9, {3.7531040292255526`*^9, 
   3.753104034244852*^9}},ExpressionUUID->"f5da5b19-5f0c-42a0-b7e3-\
5d161febbaa0"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"des3", ",", "eqdes3", ",", "solf", ",", "eqg3"}], "]"}]], "Input",
 CellChangeTimes->{{3.7530268091552315`*^9, 3.753026828954541*^9}, {
  3.753104074960581*^9, 
  3.75310407646391*^9}},ExpressionUUID->"1502c4bf-53fb-4642-a362-\
b2c2d3c41ded"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "''"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"K", "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7530071402313166`*^9, 3.7530071520712533`*^9}, {
  3.7530073980312834`*^9, 3.7530074020115433`*^9}, {3.7530267947608924`*^9, 
  3.7530267954046335`*^9}, {3.7531040546639605`*^9, 
  3.753104106472458*^9}},ExpressionUUID->"4b595f11-de2a-47e6-80ed-\
ffc4269481ef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["2", "3"], "eq00"}], "/.", "des3"}], "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "t", "]"}], "\[Rho]c"}]}]}], "/.", 
    RowBox[{"t", "\[Rule]", "a"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.753007162370982*^9, 3.7530071639310336`*^9}, {
   3.753007412681366*^9, 3.753007413180858*^9}, {3.7530074538413053`*^9, 
   3.7530074742035904`*^9}, {3.7530268519539814`*^9, 3.753026864814765*^9}, 
   3.7531041210612183`*^9},ExpressionUUID->"68909456-a3f0-4513-a659-\
2b394fe59332"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "-", 
  FractionBox[
   RowBox[{"K", "[", "X", "]"}], "3"], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{
   FractionBox["2", "3"], " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530070956712055`*^9, 3.7530071645856547`*^9, 3.753007359271302*^9, {
   3.7530074043412685`*^9, 3.7530074136313868`*^9}, {3.7530074566310596`*^9, 
   3.75300747484136*^9}, 3.753009479731315*^9, 3.753010399292014*^9, 
   3.7530259723809757`*^9, 3.7530267991530056`*^9, {3.7530268472211742`*^9, 
   3.7530268654142923`*^9}, 3.7530272317890463`*^9, 3.753104123529351*^9, 
   3.7531100768157735`*^9, 3.7590389370428114`*^9, 3.759062854815488*^9, 
   3.7590650583349285`*^9, 3.761484087809585*^9, 
   3.7614967834812107`*^9},ExpressionUUID->"aa251b4a-ba27-46ed-94a2-\
3fbebf002b60"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"eqscal", "/.", "des3"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], "/.", 
       RowBox[{"G", "\[Rule]", 
        FractionBox[
         RowBox[{"3", 
          RowBox[{"H0", "^", "2"}]}], 
         RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "//", "Expand"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7530072546512675`*^9, {3.753007978861573*^9, 3.7530079844517*^9}, {
   3.75300819971229*^9, 3.7530082001136017`*^9}, {3.7530268680858884`*^9, 
   3.7530268991518917`*^9}, 
   3.753104155438074*^9},ExpressionUUID->"5f61ec90-938d-409c-9954-\
0a5294582c7a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"18", " ", "X", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"6", " ", "a", " ", "X", " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "a", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{
       SuperscriptBox["K", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G3", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}], "+", 
        RowBox[{"X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530072553012924`*^9, 3.75300736155129*^9, 3.7530075454953737`*^9, {
   3.7530079799828978`*^9, 3.753007985875571*^9}, 3.7530082007913494`*^9, 
   3.753009481096099*^9, 3.7530104003049483`*^9, 3.7530259745347195`*^9, 
   3.7530268004690237`*^9, {3.7530268708900013`*^9, 3.7530269002721505`*^9}, 
   3.7530272332545967`*^9, 3.7531041604460745`*^9, 3.753110080239015*^9, 
   3.759038938386591*^9, 3.759062856120221*^9, 3.759065059235174*^9, 
   3.761484089547599*^9, 
   3.761496785510987*^9},ExpressionUUID->"6ab42396-35ad-43cf-b577-\
528e4c4d2b3f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"eqdes22", "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531050161389294`*^9, 
  3.753105030776743*^9}},ExpressionUUID->"dd533c9d-df01-4533-952e-\
8a4debfe5a69"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "X", " ", 
         RowBox[{"H", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"2", " ", "a", " ", "X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "a", "]"}]}], "+", 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["X"], " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["K", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"], " ", 
       SqrtBox["X"], " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], "+", 
         RowBox[{"X", " ", 
          RowBox[{
           SuperscriptBox["G3", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "X", " ", 
       RowBox[{
        SuperscriptBox["K", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}]}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.7531050241837077`*^9, 3.7531050311628895`*^9}, 
   3.7590389413865633`*^9, 3.759062857975212*^9, 3.759065061014832*^9, 
   3.7614840919615884`*^9, 
   3.76149678736954*^9},ExpressionUUID->"39955abc-56fe-4407-918b-\
ed189a2db940"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Ptot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
    "des3"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.753104165454965*^9},ExpressionUUID->"2940dedf-8d8d-48ef-84c9-\
caef1a3b83f0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.753008288221882*^9, 3.753009482346419*^9, 
  3.7530104012915435`*^9, 3.753025976743453*^9, 3.7530269098180213`*^9, 
  3.75302723538494*^9, 3.753104184074131*^9, 3.7590389432772183`*^9, 
  3.7590628597555776`*^9, 3.759065062024963*^9, 3.76148409319717*^9, 
  3.761496788182303*^9},ExpressionUUID->"c1e565cb-92d2-44e8-b5de-\
9506a57ac700"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Jtot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
      "des3"}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}], "/.", 
   RowBox[{"t", "\[Rule]", "a"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.7530082969130588`*^9, 3.7530083295913944`*^9, {3.753026917538438*^9, 
   3.75302691893057*^9}, 
   3.753104219925988*^9},ExpressionUUID->"89b4819f-0875-4d73-8cac-\
3c84132d0c5e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}], ",", "0", ",", "0", ",",
    "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7530082975415645`*^9, 3.753008330541541*^9, 3.7530094836722317`*^9, 
   3.7530104029223557`*^9, 3.753025977723363*^9, {3.7530269141756024`*^9, 
   3.753026919235218*^9}, 3.7530272363194532`*^9, {3.753104216959204*^9, 
   3.7531042204133034`*^9}, 3.759038944433468*^9, 3.759062860927602*^9, 
   3.759065062785056*^9, 3.761484094817444*^9, 
   3.76149678990131*^9},ExpressionUUID->"1f19c8c4-1bdc-4dac-ba1c-\
b08c72e0f3c7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{"Raise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"J", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}],
         ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", "zeroorder"}], "//",
   "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7530083583919115`*^9, 3.753008383591753*^9}, 
   3.7530269380948334`*^9},ExpressionUUID->"412dd077-5431-4a85-9f5b-\
961eb5284438"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"J", "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["J", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.753008368031542*^9, 3.75300838394143*^9}, 
   3.7530094861559353`*^9, 3.7530104039620748`*^9, 3.7530259792893887`*^9, {
   3.7530269237358108`*^9, 3.7530269389219027`*^9}, 3.7530272449852643`*^9, 
   3.7531042327702336`*^9, 3.7590389453865604`*^9, 3.7590628626477027`*^9, 
   3.7614840963873386`*^9},ExpressionUUID->"925d5056-ce1a-4a2c-beda-\
5c353af1af9b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
        RowBox[{"a", "[", "t", "]"}]}], " ", 
       RowBox[{"J", "[", "t", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["J", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{"J", "[", "t", "]"}], ",", "t"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.753026941097069*^9, 
  3.7530269583466897`*^9}},ExpressionUUID->"b406ad58-618b-4ef3-9d84-\
2e9bf73f56e9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530269555727863`*^9, 3.7530269586755733`*^9}, 
   3.7530272465369406`*^9, 3.7531042352143793`*^9, 3.75903894645088*^9, 
   3.759062863937645*^9, 
   3.7614840984673543`*^9},ExpressionUUID->"71c03766-6393-4592-bbfe-\
8c1a7df67bfd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HL", "=", 
   RowBox[{"H0", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}], "+", "\[CapitalOmega]\[CapitalLambda]0"}]]}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7530269935173016`*^9, 3.7530269990121403`*^9}, {
  3.7531100904488335`*^9, 3.75311009680774*^9}, {3.753110167300049*^9, 
  3.753110168255074*^9}},ExpressionUUID->"5786a6af-1295-4b14-ad20-\
da22bc739b24"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqscal1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"J0", "/", 
     RowBox[{"a", "^", "3"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.753104366141808*^9, 
  3.753104373882861*^9}},ExpressionUUID->"d0b8024b-7e42-46bc-9001-\
7d43940393f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"eqscal1", "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.753105476066646*^9, {3.753105587345478*^9, 
   3.7531055878734922`*^9}},ExpressionUUID->"92dbb22e-1199-4a41-a33a-\
52bd12bfec30"],

Cell[BoxData[
 RowBox[{
  FractionBox["J0", 
   SuperscriptBox["a", "3"]], "-", 
  RowBox[{"6", " ", "H0", " ", "X", " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{3.753105476553343*^9, 3.753105588370403*^9, 
  3.753110137299548*^9, 3.7531101713727765`*^9, 3.759038953745048*^9, 
  3.7590628676254687`*^9, 3.7590650663901415`*^9, 3.7614841029125395`*^9, 
  3.761496795295622*^9},ExpressionUUID->"8353a5f9-d677-4241-ab66-\
a4c5beb72bd4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"3", "eqdes21"}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105447459355*^9, 3.7531054645662947`*^9}, {
  3.753105590708206*^9, 
  3.753105593623171*^9}},ExpressionUUID->"4100a43a-fe82-43bd-9aa5-\
f842a876a94f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", "H0", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7531045533364906`*^9, {3.753105451522622*^9, 3.753105464850565*^9}, 
   3.7531055941314063`*^9, 3.753110138855093*^9, 3.753110172774557*^9, 
   3.759038954745015*^9, 3.7590628695243273`*^9, 3.759065067294776*^9, 
   3.7614841070195956`*^9, 
   3.7614967962610826`*^9},ExpressionUUID->"d99f31a7-6bbd-4563-ab67-\
840ad8b8e446"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"a", "^", "2"}], " ", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.753105511622341*^9, 
  3.753105522319375*^9}},ExpressionUUID->"ae4966ae-ef18-4383-b3ef-\
41f2581f96f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sola", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "^", "2"}], "\[Equal]", 
      RowBox[{"HL", "^", "2"}]}], ",", "a"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7531055988246164`*^9, 3.753105653662197*^9}, 
   3.753110142857869*^9, {3.753110190369815*^9, 
   3.7531101909083433`*^9}},ExpressionUUID->"a63bb419-0763-44ff-a3b1-\
bbde74240136"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["H0", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalOmega]m0", 
      RowBox[{"1", "/", "3"}]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["H", "2"], "-", 
       RowBox[{
        SuperscriptBox["H0", "2"], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.753105604228838*^9, 3.7531056542303205`*^9}, {
   3.7531101482612677`*^9, 3.75311019121295*^9}, 3.759038957249871*^9, 
   3.759062870985124*^9, 3.7590650702351136`*^9, 3.761484109257593*^9, 
   3.7614967990538764`*^9},ExpressionUUID->"d5d3e126-eecf-48ae-bb00-\
c880d08c7563"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQ11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ1", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ2", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]}], "Input",
 CellChangeTimes->{{3.75310563172922*^9, 
  3.7531056909235077`*^9}},ExpressionUUID->"6265b5dd-31b0-4fa6-8c20-\
1e3af2e62944"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"J0", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["H", "2"], "-", 
      RowBox[{
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}]}],
      ")"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"6", " ", "H", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.7614968009621935`*^9},ExpressionUUID->"44810eb2-1082-4798-b460-\
9ed3be509562"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", "H", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.761496801013178*^9},ExpressionUUID->"90046e18-890c-411a-9be0-\
1209b83ca9ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq3", "=", 
  RowBox[{
   RowBox[{"EQ11", "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"EQ22", "\[Equal]", "0"}], ",", "H"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7531056952815824`*^9, 
  3.7531057296901493`*^9}},ExpressionUUID->"a8f0bf45-d865-4789-8213-\
ac520a847f86"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"72", " ", 
    SuperscriptBox["X", "3"], " ", "\[CapitalOmega]m0"}]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "36"}], " ", 
     SuperscriptBox["X", 
      RowBox[{"5", "/", "2"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "J0", " ", 
        SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       RowBox[{
        SqrtBox["2"], " ", "\[CapitalOmega]m0", " ", 
        RowBox[{"K", "[", "X", "]"}]}]}], ")"}]}], "+", 
    FractionBox[
     RowBox[{"J0", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["H0", "2"], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{"K", "[", "X", "]"}], "-", 
         RowBox[{"2", " ", "X", " ", 
          RowBox[{
           SuperscriptBox["K", "\[Prime]",
            MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], "2"]}], 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["G3", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}], "2"]}]]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.7531057027783995`*^9, 3.753105730229594*^9}, 
   3.7531101961399784`*^9, 3.7590389643123875`*^9, 3.7590628845050073`*^9, 
   3.75906507560981*^9, 3.761484113041687*^9, 
   3.7614968033696947`*^9},ExpressionUUID->"831539e7-b592-40c1-adac-\
43124c9cef05"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"eq3", "/.", 
  RowBox[{"J0", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"%", "\[Equal]", "0"}], ",", 
   RowBox[{"K", "[", "X", "]"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.759065315141009*^9, 
  3.7590653463597746`*^9}},ExpressionUUID->"6150d43d-1336-4196-afed-\
f2f436c69095"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    RowBox[{"3", " ", 
     SqrtBox["2"], " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
     "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
    RowBox[{
     SqrtBox["2"], " ", "\[CapitalOmega]m0", " ", 
     RowBox[{"K", "[", "X", "]"}]}]}], 
   RowBox[{"2", " ", 
    SqrtBox["X"], " ", "\[CapitalOmega]m0"}]]}]], "Output",
 CellChangeTimes->{{3.759065320395187*^9, 3.7590653469697227`*^9}, 
   3.7614841219972754`*^9, 
   3.761496824184975*^9},ExpressionUUID->"3198a932-d1c3-4fc4-a343-\
429a6ed4f2f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.759065320395187*^9, 3.7590653469697227`*^9}, 
   3.7614841219972754`*^9, 
   3.761496824205529*^9},ExpressionUUID->"df4d255e-af8d-4605-94c7-\
63fbe7ee9504"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solG3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"eq3", "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3", "'"}], "[", "X", "]"}]}], "]"}], "//", "FullSimplify"}],
     "//", "PowerExpand"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105730847949*^9, 
  3.7531058052531075`*^9}},ExpressionUUID->"56d2a161-dc81-448e-af6d-\
e3693b0d6e7b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SqrtBox["J0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["H0", "2"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{"K", "[", "X", "]"}], "-", 
          RowBox[{"2", " ", "X", " ", 
           RowBox[{
            SuperscriptBox["K", "\[Prime]",
             MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], 
       RowBox[{"6", " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"5", "/", "4"}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "J0", " ", 
           SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{"3", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{
           SqrtBox["2"], " ", "\[CapitalOmega]m0", " ", 
           RowBox[{"K", "[", "X", "]"}]}]}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       SqrtBox["J0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["H0", "2"], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{"K", "[", "X", "]"}], "-", 
         RowBox[{"2", " ", "X", " ", 
          RowBox[{
           SuperscriptBox["K", "\[Prime]",
            MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], 
      RowBox[{"6", " ", "H0", " ", 
       SuperscriptBox["X", 
        RowBox[{"5", "/", "4"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", "J0", " ", 
          SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"K", "[", "X", "]"}]}]}]]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.75310576637265*^9, 3.753105805737559*^9}, 
   3.753110198800361*^9, 3.7590389660956964`*^9, 3.759062929365452*^9, 
   3.7590650769848385`*^9, 3.7614841248122864`*^9, 
   3.761496829430309*^9},ExpressionUUID->"543d62a0-20b3-4dc1-acd5-\
e63f9a73b710"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"\[CapitalLambda]CDM", " ", "limit"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.761485380936985*^9, 
  3.7614853870070353`*^9}},ExpressionUUID->"ad30f333-6243-4ec1-8e13-\
3f81f696ba0c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQ1", "/.", 
  RowBox[{"J0", "\[Rule]", "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3", "'"}], "[", "X", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{"EQ2", "/.", "%"}]}], "Input",
 CellChangeTimes->{{3.7614852358696275`*^9, 3.7614852377972755`*^9}, {
  3.761485273007039*^9, 
  3.7614853161168714`*^9}},ExpressionUUID->"e0d8e5a8-6125-4132-96e2-\
d8a4f690696a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", "H0", " ", "X", " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7614852382707667`*^9, {3.7614852739973803`*^9, 3.7614853166191635`*^9}, 
   3.761485502307206*^9, 
   3.761496835270949*^9},ExpressionUUID->"d176d246-3c0a-4f7e-9334-\
3af886ebc7b9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], 
     RowBox[{"3", " ", 
      SqrtBox["2"], " ", "H0", " ", 
      SqrtBox["X"], " ", 
      SqrtBox[
       RowBox[{
        FractionBox["\[CapitalOmega]m0", 
         SuperscriptBox["a", "3"]], "+", 
        "\[CapitalOmega]\[CapitalLambda]0"}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7614852382707667`*^9, {3.7614852739973803`*^9, 3.7614853166191635`*^9}, 
   3.761485502307206*^9, 
   3.761496835278466*^9},ExpressionUUID->"95ba464b-b16d-4b76-96e0-\
dd79f6a7cd3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}]}]], "Output",
 CellChangeTimes->{
  3.7614852382707667`*^9, {3.7614852739973803`*^9, 3.7614853166191635`*^9}, 
   3.761485502307206*^9, 
   3.7614968352904344`*^9},ExpressionUUID->"83886450-308d-45b2-a1c7-\
b05019adcd27"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Case", " ", "4"}], " ", "*)"}]], "Input",
 CellChangeTimes->{
  3.759067023794694*^9},ExpressionUUID->"700e9cc3-337f-46a0-a1c5-\
c5302211ff13"],

Cell[BoxData[
 RowBox[{"solk", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SqrtBox["J0"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["H0", "2"], " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
            RowBox[{"K", "[", "X", "]"}], "-", 
            RowBox[{"2", " ", "X", " ", 
             RowBox[{
              SuperscriptBox["K", "\[Prime]",
               MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], ")"}], 
        "/", 
        RowBox[{"(", 
         RowBox[{"6", " ", "H0", " ", 
          SuperscriptBox["X", 
           RowBox[{"5", "/", "4"}]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"2", " ", "J0", " ", 
             SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
            RowBox[{"3", " ", 
             SqrtBox["2"], " ", 
             SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
            RowBox[{
             SqrtBox["2"], " ", "\[CapitalOmega]m0", " ", 
             RowBox[{"K", "[", "X", "]"}]}]}]]}], ")"}]}], "\[Equal]", 
       "G30"}], ",", 
      RowBox[{"K", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
    RowBox[{"\[Alpha]", "/", "H0"}]}]}]}]], "Input",
 CellChangeTimes->{{3.7590652331648655`*^9, 3.759065249585198*^9}, {
  3.7590653896050053`*^9, 3.759065416415245*^9}, {3.7590655589148207`*^9, 
  3.7590655608850007`*^9}, {3.7590657586008773`*^9, 3.7590657780170217`*^9}, {
  3.759065842434733*^9, 3.759065843124859*^9}, {3.7590665061848717`*^9, 
  3.759066507524785*^9}, {3.7590665507746124`*^9, 
  3.7590665577346735`*^9}},ExpressionUUID->"fb2e2925-f0de-4ddc-b093-\
195f7cd45d6a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"2", " ", 
        SqrtBox["2"], " ", "J0", " ", "\[CapitalOmega]m0"}]]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "9"}], " ", 
        SuperscriptBox["G30", "2"], " ", 
        SuperscriptBox["H0", "2"], " ", 
        SuperscriptBox["X", 
         RowBox[{"5", "/", "2"}]], " ", 
        SuperscriptBox["\[CapitalOmega]m0", "2"]}], "+", 
       RowBox[{"18", " ", 
        SuperscriptBox["G30", "2"], " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"3", "/", "2"}]], " ", "\[Alpha]", " ", 
        SuperscriptBox["\[CapitalOmega]m0", "2"]}], "-", 
       RowBox[{"9", " ", 
        SuperscriptBox["G30", "2"], " ", 
        SqrtBox["X"], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SuperscriptBox["\[CapitalOmega]m0", "2"]}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["J0", "2"], " ", 
        SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       RowBox[{"6", " ", 
        SqrtBox["2"], " ", 
        SuperscriptBox["H0", "2"], " ", "J0", " ", "\[CapitalOmega]m0", " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}]}], "}"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.761982741059128*^9, 
  3.7619827513391886`*^9}},ExpressionUUID->"62e3b469-0b80-45fb-a60c-\
65ccf465bc91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"9", " ", 
      SuperscriptBox["G30", "2"], " ", 
      SqrtBox["X"], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "H0"}], " ", "X"}], "+", "\[Alpha]"}], ")"}], "2"], 
      " ", 
      SuperscriptBox["\[CapitalOmega]m0", "2"]}], "-", 
     RowBox[{"2", " ", "J0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "J0", " ", 
         SqrtBox["X"]}], "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]}], ")"}], " ", 
      "\[CapitalOmega]\[CapitalLambda]0"}]}], 
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", "J0", " ", "\[CapitalOmega]m0"}]]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.761982751958827*^9},ExpressionUUID->"4e73ceda-85a0-407a-a143-\
5dc921f2d69e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"9", " ", 
     SuperscriptBox["G30", "2"], " ", 
     SqrtBox["X"], " ", 
     SuperscriptBox["dX1", "2"], " ", 
     SuperscriptBox["\[CapitalOmega]m0", "2"]}], "-", 
    RowBox[{"2", " ", "J0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "J0", " ", 
        SqrtBox["X"]}], "+", 
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]}], ")"}], " ", 
     "\[CapitalOmega]\[CapitalLambda]0"}]}], 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", "J0", " ", "\[CapitalOmega]m0"}]], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.761982779659004*^9, 
  3.761982786211532*^9}},ExpressionUUID->"03ec9911-3546-433e-91e7-\
ba77b7c2889c"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["dX1", "2"], " ", 
    SuperscriptBox["G30", "2"], " ", 
    SqrtBox["X"], " ", "\[CapitalOmega]m0"}], 
   RowBox[{"2", " ", 
    SqrtBox["2"], " ", "J0"}]], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
   "\[CapitalOmega]m0"]}]], "Output",
 CellChangeTimes->{
  3.761982786628894*^9},ExpressionUUID->"5475c6e3-bc0c-469e-9e19-\
ddd88f2ec072"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"solk", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"J0", ",", "0", ",", "10"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7614844393171425`*^9, 3.761484454277438*^9}, {
  3.7614854563346863`*^9, 
  3.7614854563973885`*^9}},ExpressionUUID->"9dd68612-87d7-46bd-9654-\
9e09f9626529"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"9", " ", 
     SuperscriptBox["G30", "2"], " ", 
     SqrtBox["X"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "H0"}], " ", "X"}], "+", "\[Alpha]"}], ")"}], "2"], " ",
      "\[CapitalOmega]m0"}], 
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", "J0"}]], "-", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
     ")"}]}], "-", 
   FractionBox[
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0", " ", "J0"}], 
    "\[CapitalOmega]m0"], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "J0", "]"}], "11"],
    SeriesData[$CellContext`J0, 0, {}, -1, 11, 1],
    Editable->False]}],
  SeriesData[$CellContext`J0, 0, {
   Rational[9, 2] 
    2^Rational[-1, 2] $CellContext`G30^2 $CellContext`X^
     Rational[1, 
       2] (-$CellContext`H0 $CellContext`X + $CellContext`\[Alpha])^2 \
$CellContext`\[CapitalOmega]m0, (-3) $CellContext`H0^2 $CellContext`\
\[CapitalOmega]\[CapitalLambda]0, -2^Rational[1, 2] $CellContext`X^
     Rational[1, 
       2] $CellContext`\[CapitalOmega]m0^(-1) $CellContext`\[CapitalOmega]\
\[CapitalLambda]0}, -1, 11, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614844499474225`*^9, 3.761484454697563*^9}, 
   3.7614854568092732`*^9, 
   3.76149690986384*^9},ExpressionUUID->"3063ecf7-4e51-4c39-a5b0-\
f068fe229e79"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"EQ22", "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"G3", "'"}], "[", "X", "]"}], "\[Rule]", "G30"}]}], "/.", 
    "solk"}], "/.", 
   RowBox[{"D", "[", 
    RowBox[{"solk", ",", "X"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"solX", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"%", "\[Equal]", "0"}], ",", "X"}], "]"}], "/.", 
   RowBox[{"H", "\[Rule]", 
    RowBox[{"H", "[", "a", "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "->", 
     RowBox[{"H0", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[CapitalOmega]m0", " ", 
         SuperscriptBox["a", 
          RowBox[{"-", "3"}]]}], "+", "1", "-", "\[CapitalOmega]m0"}]]}]}]}], 
   "//", "FullSimplify"}], "//", "Factor"}]}], "Input",
 CellChangeTimes->{{3.7590657070553217`*^9, 3.7590657355269604`*^9}, 
   3.7590666808296747`*^9, {3.7614859533893347`*^9, 
   3.7614859624471865`*^9}},ExpressionUUID->"2e63370d-830a-4214-a22f-\
061fa329520c"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   SqrtBox["2"], " ", "G30", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "H", " ", "J0"}], "+", 
     RowBox[{"3", " ", "G30", " ", "H0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"H0", " ", "X"}], "-", "\[Alpha]"}], ")"}], " ", 
      "\[CapitalOmega]m0"}]}], ")"}]}], "J0"]], "Output",
 CellChangeTimes->{{3.759065700274951*^9, 3.75906573677492*^9}, 
   3.75906582899479*^9, 3.7590659160250025`*^9, 3.7590666816448727`*^9, 
   3.7614859637470293`*^9, 
   3.761496916680171*^9},ExpressionUUID->"ddf35fb1-6a52-4eef-948e-\
43d4d81aa714"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{
       "3", " ", "G30", " ", "H0", " ", "\[Alpha]", " ", 
        "\[CapitalOmega]m0"}], "-", 
       RowBox[{"2", " ", "J0", " ", 
        RowBox[{"H", "[", "a", "]"}]}]}], 
      RowBox[{"3", " ", "G30", " ", 
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.759065700274951*^9, 3.75906573677492*^9}, 
   3.75906582899479*^9, 3.7590659160250025`*^9, 3.7590666816448727`*^9, 
   3.7614859637470293`*^9, 
   3.761496916695983*^9},ExpressionUUID->"5220e12f-7755-4cc4-b7fa-\
577475b8c086"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     FractionBox[
      RowBox[{
       RowBox[{"3", " ", "G30", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], 
       "-", 
       RowBox[{"2", " ", "J0", " ", 
        SqrtBox[
         RowBox[{"1", "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             FractionBox["1", 
              SuperscriptBox["a", "3"]]}], ")"}], " ", 
           "\[CapitalOmega]m0"}]}]]}]}], 
      RowBox[{"3", " ", "G30", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.759065700274951*^9, 3.75906573677492*^9}, 
   3.75906582899479*^9, 3.7590659160250025`*^9, 3.7590666816448727`*^9, 
   3.7614859637470293`*^9, 
   3.761496916874384*^9},ExpressionUUID->"8f0c327e-7490-4298-aaa1-\
813184bfd8e0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLogPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
           "3", " ", "G30", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "-", 
           
           RowBox[{"2", " ", "J0", " ", 
            SqrtBox[
             RowBox[{"1", "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "1"}], "+", 
                 FractionBox["1", 
                  SuperscriptBox["a", "3"]]}], ")"}], " ", 
               "\[CapitalOmega]m0"}]}]]}]}], 
          RowBox[{"3", " ", "G30", " ", "H0", " ", "\[CapitalOmega]m0"}]], "/.", 
         RowBox[{"H0", "\[Rule]", "1"}]}], "/.", 
        RowBox[{"\[CapitalOmega]m0", "\[Rule]", ".3"}]}], "/.", 
       RowBox[{"J0", "\[Rule]", "1"}]}], "/.", 
      RowBox[{"G30", "\[Rule]", "1"}]}], "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", "1"}]}], "//", "Abs"}], ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     SuperscriptBox["10", 
      RowBox[{"-", "14"}]], ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.761560216916318*^9, 3.76156025212356*^9}, {
  3.761560525519066*^9, 
  3.7615605289614553`*^9}},ExpressionUUID->"d5ace2c0-84ea-48fa-8102-\
6b701551f916"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVxXk4FGgcAOChVTk2EirrvhLjKrdpvp/GMZL7eNSSxYqiSG08tasDU+1u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       "]]},
     Annotation[#, "Charting`Private`Tag$2834#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->NCache[{-Log[100000000000000], 0.}, {-32.23619130191664, 0.}],
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Exp[
       Part[#, 1]], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->
   NCache[{{-Log[100000000000000], 0}, {0., 
     48.550807260107575`}}, {{-32.23619130191664, 0}, {0., 
     48.550807260107575`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledTicks[{Log, Exp}]}, {{{-25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "11"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-16.11809565095832, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "7"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-6.907755278982137, 
       FormBox[
        TemplateBox[{"10", 
          RowBox[{"-", "3"}]}, "Superscript", SyntaxForm -> SuperscriptBox], 
        TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-34.538776394910684`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-32.23619130191664, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-29.933606208922594`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-27.631021115928547`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-23.025850929940457`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-20.72326583694641, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-18.420680743952367`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-13.815510557964274`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-11.512925464970229`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-9.210340371976182, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.605170185988091, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.70805020110221, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {2.995732273553991, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}, {{-2.3025850929940455`, 
       FormBox["0.1`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {6.907755278982137, 
       FormBox[
        TagBox[
         InterpretationBox["\"1000.0\"", 1000., AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 1}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {16.11809565095832, 
       FormBox[
        TemplateBox[{"10", "7"}, "Superscript", SyntaxForm -> SuperscriptBox],
         TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {25.328436022934504`, 
       FormBox[
        TemplateBox[{"10", "11"}, "Superscript", SyntaxForm -> 
         SuperscriptBox], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {34.538776394910684`, 
       FormBox[
        TemplateBox[{"10", "15"}, "Superscript", SyntaxForm -> 
         SuperscriptBox], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {43.74911676688687, 
       FormBox[
        TemplateBox[{"10", "19"}, "Superscript", SyntaxForm -> 
         SuperscriptBox], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {52.95945713886305, 
       FormBox[
        TemplateBox[{"10", "23"}, "Superscript", SyntaxForm -> 
         SuperscriptBox], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {2.302585092994046, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {11.512925464970229`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {20.72326583694641, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {29.933606208922594`, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {39.14394658089878, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {48.35428695287496, 
       FormBox[
        TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{{3.761560240133144*^9, 3.7615602528571806`*^9}, 
   3.761560529632303*^9},ExpressionUUID->"6bc9a8c7-846c-42a5-bbc1-\
71270eabdbb3"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]K", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "X", 
       RowBox[{"(", 
        RowBox[{"G2X", "+", 
         RowBox[{"2", "X", " ", "G2XX"}]}], ")"}]}], "+", 
      RowBox[{"12", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", 
       RowBox[{"(", 
        RowBox[{"G3X", "+", 
         RowBox[{"X", " ", "G3XX"}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]B", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", " ", "G3X"}], ")"}], 
    "/", 
    RowBox[{"H", "[", "a", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.761485763251938*^9, 3.761485828157342*^9}, {
   3.761486002066842*^9, 3.761486002316814*^9}, 3.761486085036993*^9, 
   3.761496991174667*^9, {3.7614974480869627`*^9, 3.7614974946617217`*^9}, 
   3.7614975458951664`*^9},ExpressionUUID->"013883ae-fcb9-4720-8527-\
49eb83ea18b0"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Alpha]K1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Alpha]K", "/.", 
           RowBox[{"G2X", "\[Rule]", 
            RowBox[{
             RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
          RowBox[{"G2XX", "\[Rule]", 
           RowBox[{
            RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
         RowBox[{"G3X", "\[Rule]", "G30"}]}], "/.", 
        RowBox[{"G3XX", "\[Rule]", "0"}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", "solk"}], "/.", 
     RowBox[{"D", "[", 
      RowBox[{"solk", ",", "X"}], "]"}]}], "/.", 
    RowBox[{"D", "[", 
     RowBox[{"solk", ",", "X", ",", "X"}], "]"}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]B1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Alpha]B", "/.", 
           RowBox[{"G2X", "\[Rule]", 
            RowBox[{
             RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
          RowBox[{"G2XX", "\[Rule]", 
           RowBox[{
            RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
         RowBox[{"G3X", "\[Rule]", "G30"}]}], "/.", 
        RowBox[{"G3XX", "\[Rule]", "0"}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", "solk"}], "/.", 
     RowBox[{"D", "[", 
      RowBox[{"solk", ",", "X"}], "]"}]}], "/.", 
    RowBox[{"D", "[", 
     RowBox[{"solk", ",", "X", ",", "X"}], "]"}]}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.7614858410119333`*^9, 3.761485936096927*^9}, {
  3.761486022507202*^9, 3.7614860237974825`*^9}, {3.7614975151724834`*^9, 
  3.761497522781365*^9}},ExpressionUUID->"f6a5eefd-702a-4b2c-88ff-\
8abf6645f95c"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   SqrtBox["2"], " ", "G30", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", "G30", " ", "H0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"5", " ", "H0", " ", "X"}], "-", 
        RowBox[{"3", " ", "\[Alpha]"}]}], ")"}], " ", "\[CapitalOmega]m0"}], 
     "+", 
     RowBox[{"4", " ", "J0", " ", 
      RowBox[{"H", "[", "a", "]"}]}]}], ")"}]}], 
  RowBox[{"J0", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.7614858433072987`*^9, 3.76148593660946*^9}, {
   3.7614860051770372`*^9, 3.76148602424174*^9}, 3.76148608748674*^9, 
   3.7614861345470753`*^9, 3.7614970403830156`*^9, {3.7614975245487556`*^9, 
   3.761497548386054*^9}},ExpressionUUID->"d66a3154-d59a-46e7-a34a-\
2b6804920f6f"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", "G30", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]]}], 
  RowBox[{"H", "[", "a", "]"}]]], "Output",
 CellChangeTimes->{{3.7614858433072987`*^9, 3.76148593660946*^9}, {
   3.7614860051770372`*^9, 3.76148602424174*^9}, 3.76148608748674*^9, 
   3.7614861345470753`*^9, 3.7614970403830156`*^9, {3.7614975245487556`*^9, 
   3.7614975483911*^9}},ExpressionUUID->"a964109c-de05-4e89-b3ef-\
085ece2e87eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Alpha]K2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]K1", "/.", 
      RowBox[{"solX", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "//", "FullSimplify"}], "//", 
    "PowerExpand"}], "//", "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]B2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]B1", "/.", 
      RowBox[{"solX", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], "//", "FullSimplify"}], "//", 
    "PowerExpand"}], "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.761486027277251*^9, 3.761486034866727*^9}, {
  3.761486159967154*^9, 3.761486161309965*^9}, {3.7614970877567654`*^9, 
  3.7614970894498186`*^9}, {3.7614972787782865`*^9, 3.7614972802411757`*^9}, {
  3.761497615571643*^9, 
  3.761497622502199*^9}},ExpressionUUID->"9dbd43d1-2f63-4170-bbf0-\
05bf625e130b"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SqrtBox["6"], " ", "G30", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"G30", " ", "H0", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], 
     "-", 
     RowBox[{"J0", " ", 
      RowBox[{"H", "[", "a", "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "H0", " ", "\[Alpha]"}], "-", 
      FractionBox[
       RowBox[{"2", " ", "J0", " ", 
        RowBox[{"H", "[", "a", "]"}]}], 
       RowBox[{"G30", " ", "\[CapitalOmega]m0"}]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}], 
  RowBox[{
   SuperscriptBox["H0", "3"], " ", "J0", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.7614860316006927`*^9, 3.7614860353871117`*^9}, 
   3.7614860908092427`*^9, {3.7614861487492523`*^9, 3.7614861616967535`*^9}, {
   3.7614970687589626`*^9, 3.761497089825795*^9}, 3.7614972818778515`*^9, 
   3.7614976235047803`*^9},ExpressionUUID->"106156b1-2f89-4cef-9c8b-\
97e938606fea"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SqrtBox[
    FractionBox["2", "3"]], " ", "G30", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "H0", " ", "\[Alpha]"}], "-", 
      FractionBox[
       RowBox[{"2", " ", "J0", " ", 
        RowBox[{"H", "[", "a", "]"}]}], 
       RowBox[{"G30", " ", "\[CapitalOmega]m0"}]]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}], 
  RowBox[{"3", " ", 
   SuperscriptBox["H0", "3"], " ", 
   RowBox[{"H", "[", "a", "]"}]}]]], "Output",
 CellChangeTimes->{{3.7614860316006927`*^9, 3.7614860353871117`*^9}, 
   3.7614860908092427`*^9, {3.7614861487492523`*^9, 3.7614861616967535`*^9}, {
   3.7614970687589626`*^9, 3.761497089825795*^9}, 3.7614972818778515`*^9, 
   3.7614976237180214`*^9},ExpressionUUID->"7104deb8-3482-4380-b6b7-\
322c27cdc347"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D2", "=", 
  RowBox[{
   RowBox[{"\[Alpha]K2", "+", 
    RowBox[{
     FractionBox["3", "2"], 
     RowBox[{"\[Alpha]B2", "^", "2"}]}]}], "//", "FullSimplify"}]}]], "Input",\

 CellChangeTimes->{{3.7614976317666836`*^9, 
  3.7614976850385494`*^9}},ExpressionUUID->"78526f40-97ad-4ecf-85d2-\
a8f54fb25ae0"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"9", " ", 
    SuperscriptBox["H0", "6"], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], "2"]}]], 
  RowBox[{"2", " ", "G30", " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox[
      RowBox[{"9", " ", 
       SqrtBox["6"], " ", 
       SuperscriptBox["H0", "3"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
         "G30", " ", "H0", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "-", 
         RowBox[{"J0", " ", 
          RowBox[{"H", "[", "a", "]"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "H0", " ", "\[Alpha]"}], "-", 
          FractionBox[
           RowBox[{"2", " ", "J0", " ", 
            RowBox[{"H", "[", "a", "]"}]}], 
           RowBox[{"G30", " ", "\[CapitalOmega]m0"}]]}], ")"}], 
        RowBox[{"3", "/", "2"}]]}], "J0"], "+", 
     RowBox[{"2", " ", "G30", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "H0", " ", "\[Alpha]"}], "-", 
         FractionBox[
          RowBox[{"2", " ", "J0", " ", 
           RowBox[{"H", "[", "a", "]"}]}], 
          RowBox[{"G30", " ", "\[CapitalOmega]m0"}]]}], ")"}], "3"]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7614976455186605`*^9, 
  3.761497685320673*^9}},ExpressionUUID->"d05277c8-9778-4a54-88dd-\
a49ca4ef0ece"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tt", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]K2", "/.", 
      RowBox[{"G30", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "\[Epsilon]"}], " ", "G30t", " ", 
        RowBox[{"H0", "^", "n1"}]}]}]}], "/.", 
     RowBox[{"J0", "\[Rule]", 
      RowBox[{"\[Epsilon]", " ", "J0t", " ", 
       RowBox[{"H0", "^", "n1"}]}]}]}], "//", "FullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"tt1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"tt", "/.", 
          RowBox[{"\[Epsilon]", "\[Rule]", "1"}]}], "/.", 
         RowBox[{
          RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
          RowBox[{"H0", " ", 
           RowBox[{"h", "[", "a", "]"}]}]}]}], "/.", 
        RowBox[{"n1", "\[Rule]", 
         RowBox[{"5", "/", "2"}]}]}], "//", "FullSimplify"}], "//", 
      "PowerExpand"}], "//", "Factor"}], "//", "PowerExpand"}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.7614978989181976`*^9, 3.7614979922066517`*^9}, 
   3.761498042451666*^9, {3.761498112292881*^9, 3.7614981125571785`*^9}, {
   3.761498192337699*^9, 3.761498253986645*^9}, {3.7614984022432117`*^9, 
   3.7614984450930157`*^9}, {3.7614984890187097`*^9, 3.761498525588055*^9}, {
   3.761498578893421*^9, 
   3.7614986996505637`*^9}},ExpressionUUID->"3b445363-c0b4-4754-bfcf-\
5718c36dd636"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   SqrtBox["6"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"G30t", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
     RowBox[{"J0t", " ", 
      RowBox[{"h", "[", "a", "]"}]}]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", "G30t", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], 
      "+", 
      RowBox[{"2", " ", "J0t", " ", 
       RowBox[{"h", "[", "a", "]"}]}]}], ")"}], 
    RowBox[{"3", "/", "2"}]]}], 
  RowBox[{
   SqrtBox["G30t"], " ", "J0t", " ", 
   SuperscriptBox["\[CapitalOmega]m0", 
    RowBox[{"3", "/", "2"}]], " ", 
   SuperscriptBox[
    RowBox[{"h", "[", "a", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.76149789641956*^9, 3.7614979931205063`*^9}, 
   3.76149804340584*^9, 3.7614981128817205`*^9, 3.7614981931257315`*^9, {
   3.7614982254909315`*^9, 3.761498255286788*^9}, {3.7614984079524317`*^9, 
   3.761498445463214*^9}, {3.7614984984379463`*^9, 3.7614985260014324`*^9}, {
   3.7614985891180067`*^9, 
   3.7614987013058343`*^9}},ExpressionUUID->"70be0198-a1a2-4ed8-af84-\
350ec2275b69"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"tt1", ",", 
    RowBox[{"{", 
     RowBox[{"\[Alpha]", ",", "0", ",", "1"}], "}"}]}], "]"}], "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.7614981066849747`*^9, 3.761498122699813*^9}, {
   3.7614981551519556`*^9, 3.761498168846949*^9}, {3.761498276559185*^9, 
   3.76149830979895*^9}, {3.7614984539515877`*^9, 3.761498455475556*^9}, 
   3.7614987038790197`*^9},ExpressionUUID->"4555ea88-6909-41a1-815e-\
b546fa314161"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"8", " ", 
     SqrtBox["3"], " ", 
     SuperscriptBox["J0t", 
      RowBox[{"3", "/", "2"}]], " ", 
     SqrtBox[
      RowBox[{"h", "[", "a", "]"}]]}], 
    RowBox[{
     SqrtBox["G30t"], " ", 
     SuperscriptBox["\[CapitalOmega]m0", 
      RowBox[{"3", "/", "2"}]]}]], "+", 
   FractionBox[
    RowBox[{"26", " ", 
     SqrtBox["3"], " ", 
     SqrtBox["G30t"], " ", 
     SqrtBox["J0t"], " ", "\[Alpha]"}], 
    RowBox[{
     SqrtBox["\[CapitalOmega]m0"], " ", 
     SqrtBox[
      RowBox[{"h", "[", "a", "]"}]]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Alpha]", "]"}], "2"],
    SeriesData[$CellContext`\[Alpha], 0, {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Alpha], 0, {
   8 3^Rational[1, 2] $CellContext`G30t^Rational[-1, 2] $CellContext`J0t^
     Rational[3, 2] $CellContext`\[CapitalOmega]m0^
     Rational[-3, 2] $CellContext`h[$CellContext`a]^Rational[1, 2], 26 
    3^Rational[1, 2] $CellContext`G30t^Rational[1, 2] $CellContext`J0t^
     Rational[1, 2] $CellContext`\[CapitalOmega]m0^
     Rational[-1, 2] $CellContext`h[$CellContext`a]^Rational[-1, 2]}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7614981522304845`*^9, 3.7614981708779507`*^9}, {
   3.761498304648291*^9, 3.7614983105711265`*^9}, {3.7614984501210737`*^9, 
   3.761498455822553*^9}, 
   3.7614987048413453`*^9},ExpressionUUID->"c9bd996e-9b0a-44dc-acaf-\
2202f840b0ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["J0t", 
       RowBox[{"3", "/", "2"}]], " ", 
      SqrtBox[
       RowBox[{"h", "[", "a", "]"}]]}], 
     SqrtBox["G30t"]], "<", "1"}], "&&", 
   RowBox[{"G30t", ">", "0"}], "&&", 
   RowBox[{"J0t", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.761498368668503*^9, 3.7614983954469786`*^9}, {
  3.761498742763791*^9, 
  3.7614988043437862`*^9}},ExpressionUUID->"2b16c43f-2305-4796-af95-\
c3c91f6d242a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"G30t", ">", "0"}], "&&", 
  RowBox[{"J0t", ">", "0"}], "&&", 
  RowBox[{"0", "\[LessEqual]", 
   RowBox[{"h", "[", "a", "]"}], "<", 
   FractionBox["G30t", 
    SuperscriptBox["J0t", "3"]]}]}]], "Output",
 CellChangeTimes->{{3.7614987556301203`*^9, 
  3.761498804764988*^9}},ExpressionUUID->"97652fbd-522f-4e67-bea1-\
dfb3f71206e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{"\[Alpha]K2", ",", "\[Alpha]B2", ",", "D2"}], "}"}], "/.", 
           RowBox[{
            RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
          RowBox[{"H0", "\[Rule]", "1"}]}], "/.", 
         RowBox[{"\[CapitalOmega]\[CapitalLambda]0", "\[Rule]", 
          RowBox[{"1", "-", "\[CapitalOmega]m0"}]}]}], "/.", 
        RowBox[{"\[CapitalOmega]m0", "\[Rule]", 
         RowBox[{"3", "/", "10"}]}]}], "/.", 
       RowBox[{"J0", "\[Rule]", 
        SuperscriptBox["10", 
         RowBox[{"-", "7"}]]}]}], "/.", 
      RowBox[{"\[Alpha]", "\[Rule]", "1"}]}], "/.", 
     RowBox[{"G30", "\[Rule]", 
      RowBox[{"-", 
       SuperscriptBox["10", "7"]}]}]}], "/.", 
    RowBox[{"a", "\[Rule]", 
     SuperscriptBox["10", 
      RowBox[{"-", "15"}]]}]}], ",", "20"}], "]"}]], "Input",
 CellChangeTimes->{{3.761486171101898*^9, 3.7614862325571795`*^9}, {
   3.761497170648766*^9, 3.761497190057301*^9}, {3.761497241902691*^9, 
   3.76149731325695*^9}, {3.7614973820751486`*^9, 3.761497405826297*^9}, {
   3.7614976953175726`*^9, 3.7614977472586517`*^9}, {3.7614978560490847`*^9, 
   3.7614978776079416`*^9}, 3.761498072298647*^9, {3.761498822491708*^9, 
   3.761498888247693*^9}},ExpressionUUID->"979147a1-f617-430a-8fc6-\
6d1ff96779da"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.11098110596573942772718843291605039581`20.", ",", 
   RowBox[{"-", "0.01233123397483494598303173654394728202`20."}], ",", 
   "0.11120919496275261321902072594981450527`20."}], "}"}]], "Output",
 CellChangeTimes->{{3.7614861962599316`*^9, 3.761486232916933*^9}, {
   3.7614971678752723`*^9, 3.7614971868827286`*^9}, {3.7614972444010687`*^9, 
   3.7614973139478693`*^9}, {3.7614973832202067`*^9, 3.761497408134145*^9}, {
   3.7614976961907153`*^9, 3.7614977477055063`*^9}, {3.7614978570692234`*^9, 
   3.7614978786412897`*^9}, 3.7614980744104595`*^9, {3.7614988250309677`*^9, 
   3.761498889059971*^9}},ExpressionUUID->"7e8a3413-b6ab-4756-90e4-\
ee00f6ca2a02"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", "\[Alpha]"}], "-", 
     FractionBox[
      RowBox[{"2", " ", "J0", " ", 
       RowBox[{"H", "[", "a", "]"}]}], 
      RowBox[{"G30", " ", "\[CapitalOmega]m0"}]]}], ">", "0"}], "&&", 
   RowBox[{
    RowBox[{"H", "[", "a", "]"}], ">", "1"}], "&&", 
   RowBox[{"\[CapitalOmega]m0", ">", "0"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7614972180495415`*^9, 3.761497233196741*^9}, {
  3.7614977880464215`*^9, 
  3.7614978110783806`*^9}},ExpressionUUID->"4d6bf96e-b112-47b6-8727-\
f92637c4a160"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Alpha]", "\[Element]", 
   TemplateBox[{},
    "Reals"]}], "&&", 
  RowBox[{"\[CapitalOmega]m0", ">", "0"}], "&&", 
  RowBox[{
   RowBox[{"H", "[", "a", "]"}], ">", "1"}], "&&", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G30", "<", "0"}], "&&", 
      RowBox[{"J0", ">", 
       FractionBox[
        RowBox[{"3", " ", "G30", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], 
        
        RowBox[{"2", " ", 
         RowBox[{"H", "[", "a", "]"}]}]]}]}], ")"}], "||", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"G30", ">", "0"}], "&&", 
      RowBox[{"J0", "<", 
       FractionBox[
        RowBox[{"3", " ", "G30", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], 
        
        RowBox[{"2", " ", 
         RowBox[{"H", "[", "a", "]"}]}]]}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.761497789418313*^9, 
  3.761497811768436*^9}},ExpressionUUID->"77f797e4-9121-4058-8649-\
e1433e963b30"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{"\[Alpha]K2", "/."}]}]], "Input",
 CellChangeTimes->{{3.7614861570385995`*^9, 
  3.761486167102107*^9}},ExpressionUUID->"243564ce-a009-49a1-a1b9-\
9945a99e0051"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solX", "[", 
   RowBox[{"[", "2", "]"}], "]"}], ">", "0"}]], "Input",
 CellChangeTimes->{{3.7614859703694963`*^9, 
  3.7614859854819293`*^9}},ExpressionUUID->"19428e88-2400-4b49-8091-\
fe3daa04d0d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"X", "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
      "3", " ", "G30", " ", "H0", " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}],
       "-", 
      RowBox[{"2", " ", "J0", " ", 
       RowBox[{"H", "[", "a", "]"}]}]}], 
     RowBox[{"3", " ", "G30", " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}], "}"}], ">", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7614859687972574`*^9, 
  3.7614859861720457`*^9}},ExpressionUUID->"2f0c1e21-df1d-42e9-a2ed-\
ea407452179a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Case", " ", "3"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7590631281852975`*^9, 
  3.7590631383058505`*^9}},ExpressionUUID->"82f79fc9-7867-42b1-9f90-\
0ecaf90147b7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solk", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"2", " ", "J0", " ", 
         SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        RowBox[{"3", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
         "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        RowBox[{
         SqrtBox["2"], " ", "\[CapitalOmega]m0", " ", 
         RowBox[{"K", "[", "X", "]"}]}]}], "\[Equal]", 
       RowBox[{"\[Alpha]", " ", "X"}]}], ",", 
      RowBox[{"K", "[", "X", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7590629509557266`*^9, 3.7590629528302717`*^9}, {
  3.7590629883255134`*^9, 3.759063029565671*^9}, {3.7590630614082146`*^9, 
  3.7590631124656353`*^9}, {3.7590633702452197`*^9, 
  3.7590633712957635`*^9}},ExpressionUUID->"02b652a9-43a7-4660-ab5f-\
e391259dff51"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     FractionBox[
      RowBox[{"X", " ", "\[Alpha]"}], 
      SqrtBox["2"]], "-", 
     RowBox[{
      SqrtBox["2"], " ", "J0", " ", 
      SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
      "\[CapitalOmega]\[CapitalLambda]0"}]}], "\[CapitalOmega]m0"]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7590629956754503`*^9, 3.759063030055399*^9}, {
   3.7590630620652137`*^9, 3.7590631129691324`*^9}, 
   3.7590633723855953`*^9},ExpressionUUID->"7a066c4f-da8b-4ab4-852a-\
fd4b68903dcb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solG31", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"solG3", "/.", "solk"}], "/.", 
     RowBox[{"D", "[", 
      RowBox[{"solk", ",", "X"}], "]"}]}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.75906302534566*^9, 3.759063068782917*^9}, 
   3.759063120335638*^9, {3.7590632621157193`*^9, 
   3.7590632634555583`*^9}},ExpressionUUID->"a0a5ede9-0de5-4663-8099-\
dbdd79d27bfc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       SqrtBox["J0"], " ", 
       SqrtBox["\[Alpha]"]}], 
      RowBox[{"6", " ", 
       SqrtBox["2"], " ", "H0", " ", 
       SuperscriptBox["X", 
        RowBox[{"3", "/", "4"}]], " ", "\[CapitalOmega]m0"}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SqrtBox["J0"], " ", 
        SqrtBox["\[Alpha]"]}], 
       RowBox[{"6", " ", 
        SqrtBox["2"], " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"3", "/", "4"}]], " ", "\[CapitalOmega]m0"}]]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7590630262453356`*^9, 3.759063120915394*^9}, 
   3.7590632643552275`*^9, 
   3.759063374892679*^9},ExpressionUUID->"5413458a-f74f-413a-ac43-\
6db80790403c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SqrtBox["J0"], " ", 
        SqrtBox["\[Alpha]"]}], 
       RowBox[{"6", " ", 
        SqrtBox["2"], " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"3", "/", "4"}]], " ", "\[CapitalOmega]m0"}]]}], "\[Equal]", 
     
     RowBox[{
      RowBox[{"G3", "'"}], "[", "X", "]"}]}], ",", 
    RowBox[{"G3", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.759063144631484*^9, 3.759063172565452*^9}, 
   3.7590633814251127`*^9, 
   3.7590636703753853`*^9},ExpressionUUID->"5142d9c7-15e2-4904-9bda-\
0ae609a97e78"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["J0"], " ", 
       SuperscriptBox["X", 
        RowBox[{"1", "/", "4"}]], " ", 
       SqrtBox["\[Alpha]"]}], 
      RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.759063162045387*^9, 3.759063172915544*^9}, 
   3.7590633822453604`*^9, 
   3.759063671235471*^9},ExpressionUUID->"61279f0e-b681-4b64-84a4-\
38dacf23e86c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"EQ22", "/.", 
     RowBox[{"solG31", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], "/.", "solk"}], "/.", 
   RowBox[{"D", "[", 
    RowBox[{"solk", ",", "X"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", "X"}], "]"}], "/.", 
  RowBox[{"H", "\[Rule]", 
   RowBox[{"H", "[", "a", "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"%", "/.", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "->", 
     RowBox[{"H0", 
      SqrtBox[
       RowBox[{
        RowBox[{"\[CapitalOmega]m0", " ", 
         SuperscriptBox["a", 
          RowBox[{"-", "3"}]]}], "+", "1", "-", "\[CapitalOmega]m0"}]]}]}]}], 
   "//", "FullSimplify"}], "//", "Factor"}]}], "Input",
 CellChangeTimes->{{3.7590632509402676`*^9, 3.759063346125227*^9}, {
  3.7590636936052527`*^9, 3.7590637035552135`*^9}, {3.7590639745651693`*^9, 
  3.75906399382557*^9}},ExpressionUUID->"447c4566-16e7-483b-bc0f-\
942924f8e894"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"H", " ", 
    SqrtBox["J0"], " ", 
    SuperscriptBox["X", 
     RowBox[{"3", "/", "4"}]], " ", 
    SqrtBox["\[Alpha]"]}], 
   RowBox[{"H0", " ", "\[CapitalOmega]m0"}]], "+", 
  FractionBox[
   RowBox[{"X", " ", "\[Alpha]"}], 
   RowBox[{
    SqrtBox["2"], " ", "\[CapitalOmega]m0"}]]}]], "Output",
 CellChangeTimes->{
  3.759063253305413*^9, {3.7590632879400654`*^9, 3.759063291795041*^9}, {
   3.759063325855414*^9, 3.759063346585436*^9}, 3.759063392435459*^9, {
   3.7590636847573013`*^9, 3.7590637040049477`*^9}, {3.7590639760349426`*^9, 
   3.759063994308709*^9}},ExpressionUUID->"abc0a9da-94b6-4aba-ab4d-\
4844bc595536"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["J0", "2"], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "a", "]"}], "4"]}], 
      RowBox[{
       SuperscriptBox["H0", "4"], " ", 
       SuperscriptBox["\[Alpha]", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.759063253305413*^9, {3.7590632879400654`*^9, 3.759063291795041*^9}, {
   3.759063325855414*^9, 3.759063346585436*^9}, 3.759063392435459*^9, {
   3.7590636847573013`*^9, 3.7590637040049477`*^9}, {3.7590639760349426`*^9, 
   3.759063994327503*^9}},ExpressionUUID->"8376662d-e99f-43ca-8ed4-\
e24252e9b6f4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     FractionBox[
      RowBox[{"4", " ", 
       SuperscriptBox["J0", "2"], " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "3"]}], "-", "\[CapitalOmega]m0", "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", "\[CapitalOmega]m0"}]}], ")"}], 
        "2"]}], 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["\[Alpha]", "2"]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.759063253305413*^9, {3.7590632879400654`*^9, 3.759063291795041*^9}, {
   3.759063325855414*^9, 3.759063346585436*^9}, 3.759063392435459*^9, {
   3.7590636847573013`*^9, 3.7590637040049477`*^9}, {3.7590639760349426`*^9, 
   3.759063994340144*^9}},ExpressionUUID->"2206266f-9d50-4989-b564-\
47720c419e94"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"case", " ", "0", " ", 
   RowBox[{"K", "~", "\[Alpha]"}], " ", 
   RowBox[{
    RowBox[{"X", "^", "1"}], "/", "2"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7531063588095603`*^9, 3.7531063667643137`*^9}, {
  3.7590390089663324`*^9, 
  3.759039014181384*^9}},ExpressionUUID->"0d7d3c49-1466-40d4-bae9-\
3ef4f31ae4f8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dd0", "=", 
  RowBox[{
   RowBox[{"solG3", "/.", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
         RowBox[{"\[Alpha]", " ", 
          SuperscriptBox["X", 
           RowBox[{"1", "/", "2"}]]}]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "i"}], "}"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.759039020205593*^9, 3.759039023486617*^9}, {
  3.759039111151961*^9, 
  3.7590391118744373`*^9}},ExpressionUUID->"5e9e1ba5-829b-47d5-b677-\
1c15c4fcb835"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"H0", " ", 
        SqrtBox["J0"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
       RowBox[{"2", " ", 
        SuperscriptBox["X", 
         RowBox[{"5", "/", "4"}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"3", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{
           SqrtBox["X"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
             
             RowBox[{
             "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
            ")"}]}]}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"H0", " ", 
       SqrtBox["J0"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
      RowBox[{"2", " ", 
       SuperscriptBox["X", 
        RowBox[{"5", "/", "4"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{
          SqrtBox["X"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
            RowBox[{
            "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
           ")"}]}]}]]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.759039036951456*^9, 
  3.7590391128567305`*^9},ExpressionUUID->"fad1bfa4-6861-4abf-9c8d-\
db3b2d5a8601"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dd", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"G3", "'"}], "[", "X", "]"}], "\[Equal]", 
       RowBox[{"\[Epsilon]", 
        FractionBox[
         RowBox[{"H0", " ", 
          SqrtBox["J0"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
         RowBox[{"2", " ", 
          SuperscriptBox["X", 
           RowBox[{"5", "/", "4"}]], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"3", " ", 
             SqrtBox["2"], " ", 
             SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
            RowBox[{
             SqrtBox["X"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], 
               "+", 
               RowBox[{
               "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
              ")"}]}]}]]}]]}]}], ",", 
      RowBox[{"G3", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.759039058231519*^9, 3.759039072846711*^9}, 
   3.759039124701481*^9, {3.7590418862227693`*^9, 
   3.759041886497468*^9}},ExpressionUUID->"04df4761-5db2-4287-91cc-\
e6171c68acfc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SqrtBox["J0"], " ", "\[Epsilon]", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["X"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
            RowBox[{
            "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
           ")"}]}]}]]}], 
      RowBox[{"3", " ", "H0", " ", 
       SuperscriptBox["X", 
        RowBox[{"1", "/", "4"}]], " ", "\[CapitalOmega]m0"}]]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7590390521416197`*^9, 3.7590390738413925`*^9}, 
   3.7590391253264666`*^9, 
   3.759041888012427*^9},ExpressionUUID->"e362ee5d-3882-4d58-b52e-\
8346eb2c10ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["EQ11"], "Input",ExpressionUUID->"7ff08513-f4ca-4a7a-b121-cb6230f2228e"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"J0", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["H", "2"], "-", 
      RowBox[{
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}]}],
      ")"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"6", " ", "H", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7590391986316776`*^9},ExpressionUUID->"c50cd9e7-6763-4fdb-a328-\
d59c506baaed"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"H0", " ", 
     SqrtBox["J0"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
    RowBox[{"2", " ", 
     SuperscriptBox["X", 
      RowBox[{"5", "/", "4"}]], " ", 
     SqrtBox[
      RowBox[{
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       RowBox[{
        SqrtBox["X"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
          RowBox[{"2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}],
          ")"}]}]}]]}]]}], "}"}]], "Input",ExpressionUUID->"5d3c69b7-add6-\
47b0-9223-9137590deace"],

Cell[BoxData[
 RowBox[{"dd0", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",ExpressionUUID->"858ac8a2-f7e2-46c7-863d-192022d48c8c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ221", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"EQ22", "/.", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G3", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
        RowBox[{"\[Epsilon]", 
         FractionBox[
          RowBox[{"H0", " ", 
           SqrtBox["J0"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
          RowBox[{"2", " ", 
           SuperscriptBox["X", 
            RowBox[{"5", "/", "4"}]], " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"3", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
              "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
             RowBox[{
              SqrtBox["X"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], 
                "+", 
                RowBox[{
                "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
               ")"}]}]}]]}]]}]}], "}"}]}], "/.", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
          RowBox[{"\[Alpha]", " ", 
           SuperscriptBox["X", 
            RowBox[{"1", "/", "2"}]]}]}], ",", 
         RowBox[{"{", 
          RowBox[{"X", ",", "i"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "/.", 
    RowBox[{"H", "\[Rule]", 
     RowBox[{"H", "[", "a", "]"}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7590392177418814`*^9, 3.759039237541519*^9}, {
  3.759039531954715*^9, 3.75903953482176*^9}, {3.759041946542444*^9, 
  3.759041957442813*^9}},ExpressionUUID->"db8b5c43-727b-463b-a793-\
74d6ce3398ea"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
  
  FractionBox[
   RowBox[{"3", " ", 
    SqrtBox["2"], " ", "H0", " ", 
    SqrtBox["J0"], " ", 
    SuperscriptBox["X", 
     RowBox[{"1", "/", "4"}]], " ", "\[Epsilon]", " ", 
    "\[CapitalOmega]\[CapitalLambda]0", " ", 
    RowBox[{"H", "[", "a", "]"}]}], 
   SqrtBox[
    RowBox[{
     RowBox[{"3", " ", 
      SqrtBox["2"], " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
      "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
     RowBox[{
      SqrtBox["X"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
        RowBox[{"2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
       ")"}]}]}]]]}]], "Output",
 CellChangeTimes->{{3.7590392104016647`*^9, 3.7590392382018557`*^9}, 
   3.759039536551858*^9, {3.7590419504823666`*^9, 
   3.759041958457359*^9}},ExpressionUUID->"eb9d3296-6485-412f-9770-\
b2d1a17d27f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", "EQ221", ")"}], "\[Equal]", "0"}], ",", "X"}], "]"}], "//",
    "Expand"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{
       SuperscriptBox["\[Epsilon]", "2"], "\[Rule]", "1"}]}], "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}],
         "-", 
        SuperscriptBox[
         RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"H0", "^", "2"}]}], " ", "\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}]}]}], "/.", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["H0", "2"]}], " ", 
         "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        SuperscriptBox[
         RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "2"], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"H0", "^", "2"}], " ", "\[CapitalOmega]m0", " ", 
        SuperscriptBox["a", 
         RowBox[{"-", "3"}]]}], ")"}], "^", "2"}]}]}], "//", "FullSimplify"}],
   "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.759039312211963*^9, 3.759039317816534*^9}, {
  3.7590412558628035`*^9, 3.759041298984419*^9}, {3.7590416765348845`*^9, 
  3.759041688082836*^9}, {3.7590419774325757`*^9, 
  3.7590420004230676`*^9}},ExpressionUUID->"7e8fb56d-6f8d-44f7-ae91-\
54ef3bd72913"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"X", "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"9", " ", 
       SuperscriptBox["H0", "8"], " ", 
       SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
       SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], ")"}], "/", 
     
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["H0", "4"], " ", 
        SuperscriptBox["\[Alpha]", "2"], " ", 
        SuperscriptBox["\[CapitalOmega]m0", "2"]}], "+", 
       RowBox[{"2", " ", 
        SqrtBox["2"], " ", 
        SuperscriptBox["H0", "2"], " ", "J0", " ", "\[Alpha]", " ", 
        "\[CapitalOmega]m0", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["H0", "2"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
          RowBox[{
           SuperscriptBox["\[Epsilon]", "2"], " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "a", "]"}], "2"]}]}], ")"}]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["J0", "2"], " ", 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           RowBox[{
            SuperscriptBox["\[Epsilon]", "2"], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "a", "]"}], "2"]}]}], ")"}], "2"]}]}], 
      ")"}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.759039318261587*^9, 3.759039541061763*^9, {3.7590412792925854`*^9, 
   3.759041299437787*^9}, 3.759041691152337*^9, {3.759041970102545*^9, 
   3.7590420022325416`*^9}},ExpressionUUID->"2e5055c7-4275-4e7f-a26c-\
bf5f3f590b26"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"X", "\[Rule]", 
    FractionBox[
     RowBox[{"9", " ", 
      SuperscriptBox["a", "6"], " ", 
      SuperscriptBox["H0", "4"], " ", 
      SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], 
     RowBox[{
      RowBox[{"2", " ", 
       SuperscriptBox["J0", "2"]}], "-", 
      RowBox[{"2", " ", 
       SqrtBox["2"], " ", 
       SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
      RowBox[{
       SuperscriptBox["a", "6"], " ", 
       SuperscriptBox["\[Alpha]", "2"]}]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.759039318261587*^9, 3.759039541061763*^9, {3.7590412792925854`*^9, 
   3.759041299437787*^9}, 3.759041691152337*^9, {3.759041970102545*^9, 
   3.7590420022527514`*^9}},ExpressionUUID->"b5fb972d-ffe0-45d6-bfec-\
e7bbae753699"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solfp11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"EQ221", "/.", 
          RowBox[{"X", "\[Rule]", 
           RowBox[{
            FractionBox["1", "2"], 
            SuperscriptBox["a", "2"], 
            RowBox[{
             RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
            RowBox[{
             RowBox[{
              RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}]}], 
         ")"}], "\[Equal]", "0"}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "a", "]"}]}], "]"}], "//", 
     "FullSimplify"}], "//", "Expand"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7590392390120354`*^9, 3.759039301436473*^9}, {
  3.759039373572098*^9, 3.7590393761017103`*^9}, {3.759039476701536*^9, 
  3.7590395140564733`*^9}},ExpressionUUID->"afdc2ad3-352f-4cb4-901c-\
5ae5257a2ed4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "4"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"\[Sqrt]", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "a", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SuperscriptBox["H0", "4"], " ", 
               SuperscriptBox["\[Alpha]", "2"], " ", 
               SuperscriptBox["\[CapitalOmega]m0", "2"]}], "+", 
              RowBox[{"2", " ", 
               SqrtBox["2"], " ", 
               SuperscriptBox["H0", "2"], " ", "J0", " ", "\[Alpha]", " ", 
               "\[CapitalOmega]m0", " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["H0", "2"], " ", 
                  "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
                 SuperscriptBox[
                  RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}]}], "+", 
              RowBox[{"2", " ", 
               SuperscriptBox["J0", "2"], " ", 
               SuperscriptBox[
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    SuperscriptBox["H0", "2"]}], " ", 
                   "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
                  SuperscriptBox[
                   RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "2"]}]}], 
             ")"}]}], ")"}]}], ")"}]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"3", " ", 
        SqrtBox["2"], " ", 
        SuperscriptBox["H0", "4"], " ", "\[CapitalOmega]m0", " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"\[Sqrt]", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["H0", "4"], " ", 
             SuperscriptBox["\[Alpha]", "2"], " ", 
             SuperscriptBox["\[CapitalOmega]m0", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["2"], " ", 
             SuperscriptBox["H0", "2"], " ", "J0", " ", "\[Alpha]", " ", 
             "\[CapitalOmega]m0", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["H0", "2"], " ", 
                "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
               SuperscriptBox[
                RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["J0", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", 
                  SuperscriptBox["H0", "2"]}], " ", 
                 "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
                SuperscriptBox[
                 RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "2"]}]}], 
           ")"}]}], ")"}]}], ")"}]}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.759039244791636*^9, 3.759039249811427*^9}, {
   3.7590392845669107`*^9, 3.75903930189183*^9}, 3.7590393773418155`*^9, {
   3.7590394790716715`*^9, 3.7590395145915833`*^9}, 
   3.7590395448317533`*^9},ExpressionUUID->"b3b10da3-71eb-44b0-86fc-\
2ea4f25fa505"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"solfp11", "/.", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["H0", "2"], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "->", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
         SuperscriptBox["a", "3"]]}]}]}], "/.", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["H0", "2"]}], " ", 
         "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        SuperscriptBox[
         RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "->", 
      FractionBox[
       RowBox[{
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
       SuperscriptBox["a", "3"]]}]}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.759039594261771*^9, 3.7590396185162516`*^9}, {
  3.759039652682343*^9, 
  3.759039709732353*^9}},ExpressionUUID->"f30bc793-8f83-4320-bcd3-\
4a610afffd1e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
       
       RowBox[{
        SqrtBox[
         RowBox[{
          SuperscriptBox["J0", "2"], "-", 
          RowBox[{
           SqrtBox["2"], " ", 
           SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["\[Alpha]", "2"]}], "2"]}]], " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["J0", "2"], "-", 
         RowBox[{
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", "6"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}], "2"]}]], " ", 
       RowBox[{"H", "[", "a", "]"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7590396064567785`*^9, 3.759039618804093*^9}, {
  3.759039671606742*^9, 
  3.7590397123017654`*^9}},ExpressionUUID->"47477ba9-74f3-4dbe-a3a1-\
0de4d16dc173"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"%159", "/.", 
   RowBox[{"\[Alpha]", "\[Rule]", "0"}]}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.759039734396983*^9, 
  3.759039745132117*^9}},ExpressionUUID->"240af923-08d8-42f2-b13d-\
db4bad527994"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
       
       RowBox[{"J0", " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
      RowBox[{"J0", " ", 
       RowBox[{"H", "[", "a", "]"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.759039741421784*^9, 
  3.759039745492016*^9}},ExpressionUUID->"6650dd59-c915-4b9a-a42f-\
c1604386ad88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"solfp11", "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["H0", "2"]}], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       SuperscriptBox[
        RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "->", 
     FractionBox[
      RowBox[{
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
      SuperscriptBox["a", "3"]]}]}], "//", "FullSimplify"}], "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.759039380871624*^9, 3.7590393899320393`*^9}, {
  3.7590394896823053`*^9, 3.7590394927116566`*^9}, {3.759039550232001*^9, 
  3.759039584881986*^9}, {3.759039627591897*^9, 
  3.759039631001895*^9}},ExpressionUUID->"c27c9cc9-754e-4e18-a008-\
81a223c5322a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
       
       RowBox[{"J0", " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"3", " ", 
       SuperscriptBox["a", "2"], " ", 
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
      RowBox[{"J0", " ", 
       RowBox[{"H", "[", "a", "]"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7590393866017337`*^9, 3.7590393903516264`*^9}, 
   3.759039487167014*^9, {3.75903954794209*^9, 3.7590395852768707`*^9}, 
   3.7590396318217955`*^9},ExpressionUUID->"c98a145b-01a4-446d-ba74-\
248c48bbda89"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rub", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
      FractionBox[
       RowBox[{"21", " ", 
        SuperscriptBox["a", "2"]}], 
       RowBox[{"5", 
        RowBox[{"H", "[", "a", "]"}], 
        SqrtBox[
         RowBox[{
          RowBox[{"4", 
           SuperscriptBox["J0", "2"]}], "-", 
          RowBox[{"4", 
           SqrtBox["2"], " ", 
           SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
          RowBox[{"2", 
           SuperscriptBox["a", "6"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}]]}]]}], "}"}]}], "/.", 
   RowBox[{"\[Alpha]", "\[Rule]", "0"}]}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.7590397832418737`*^9, 3.7590398181071386`*^9}, {
  3.7590398540721393`*^9, 
  3.75903985523214*^9}},ExpressionUUID->"a49bb790-9fe8-4dd9-a504-\
422e0d33478f"],

Cell[BoxData[
 RowBox[{"rub", "\[Rule]", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{"21", " ", 
      SuperscriptBox["a", "2"]}], 
     RowBox[{"10", " ", "J0", " ", 
      RowBox[{"H", "[", "a", "]"}]}]]}], "}"}]}]], "Output",
 CellChangeTimes->{{3.759039807201888*^9, 3.759039818462305*^9}, 
   3.7590398557122393`*^9},ExpressionUUID->"082662fa-9b35-459d-a3fb-\
aee2415dfe5b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqfried", "=", 
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox[
      RowBox[{"H", "[", "a", "]"}], "2"]}], "-", 
    FractionBox[
     RowBox[{"K", "[", "X", "]"}], "3"], "+", 
    RowBox[{
     SuperscriptBox["H0", "2"], " ", 
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", 
     SuperscriptBox["X", 
      RowBox[{"3", "/", "2"}]], " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{
     FractionBox["2", "3"], " ", "X", " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7590401230723667`*^9, 
  3.7590401241823072`*^9}},ExpressionUUID->"b36bd80d-46d0-4ed9-adb4-\
e79a2ce550a3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqfried1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"eqfried", "/.", "dd0"}], "/.", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
            RowBox[{"\[Alpha]", " ", 
             SuperscriptBox["X", 
              RowBox[{"1", "/", "2"}]]}]}], ",", 
           RowBox[{"{", 
            RowBox[{"X", ",", "i"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "/.", 
      RowBox[{"X", "\[Rule]", 
       RowBox[{
        FractionBox["1", "2"], 
        SuperscriptBox["a", "2"], 
        RowBox[{
         RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}], "->", 
      FractionBox[
       RowBox[{"3", " ", 
        SuperscriptBox["a", "2"], " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
       
       RowBox[{
        SqrtBox[
         RowBox[{
          SuperscriptBox["J0", "2"], "-", 
          RowBox[{
           SqrtBox["2"], " ", 
           SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["\[Alpha]", "2"]}], "2"]}]], " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}]}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.7590401481929007`*^9, 
  3.7590402758724527`*^9}},ExpressionUUID->"a0df9969-b14e-453f-b67a-\
86822d7ad702"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SqrtBox["2"], " ", 
       SuperscriptBox["a", 
        RowBox[{"3", "/", "2"}]], " ", 
       SuperscriptBox["H0", "2"], " ", 
       SqrtBox["J0"], " ", 
       SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", 
        RowBox[{"3", "/", "2"}]], " ", 
       RowBox[{"H", "[", "a", "]"}]}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["J0", "2"]}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
          RowBox[{
           SuperscriptBox["a", "6"], " ", 
           SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], 
        RowBox[{"1", "/", "4"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0",
            " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
             
             RowBox[{
             "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
            ")"}]}], 
          SqrtBox[
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["J0", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["2"], " ", 
             SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
            RowBox[{
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["\[Alpha]", "2"]}]}]]]}]]}]]}], "-", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], "2"], "+", 
    RowBox[{
     SuperscriptBox["H0", "2"], " ", 
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}], ",", 
   RowBox[{
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["a", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox["H0", "2"], " ", 
      SqrtBox["J0"], " ", 
      SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", 
       RowBox[{"3", "/", "2"}]], " ", 
      RowBox[{"H", "[", "a", "]"}]}], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["J0", "2"]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
         RowBox[{
          SuperscriptBox["a", "6"], " ", 
          SuperscriptBox["\[Alpha]", "2"]}]}], ")"}], 
       RowBox[{"1", "/", "4"}]], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{
         SqrtBox["2"], " ", 
         SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
         "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        FractionBox[
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0", 
          " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0"}], "+", 
            RowBox[{
            "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
           ")"}]}], 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["J0", "2"]}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "3"], " ", "J0", " ", "\[Alpha]"}], "+", 
           RowBox[{
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["\[Alpha]", "2"]}]}]]]}]]}]], "-", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], "2"], "+", 
    RowBox[{
     SuperscriptBox["H0", "2"], " ", 
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7590402491622534`*^9, 
  3.7590402778621554`*^9}},ExpressionUUID->"8b5cba03-a4ab-451d-ad2e-\
f066892891a0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"Series", "[", 
         RowBox[{"eqfried1", ",", 
          RowBox[{"{", 
           RowBox[{"\[Alpha]", ",", "0", ",", "5"}], "}"}]}], "]"}], "/.", 
        RowBox[{
         RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "->", 
         RowBox[{"\[CapitalOmega]m0", " ", 
          SuperscriptBox["a", 
           RowBox[{"-", "3"}]]}]}]}], "//", "PowerExpand"}], "//", 
      "FullSimplify"}], "//", "PowerExpand"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.759040281804839*^9, 3.7590403016722403`*^9}, {
   3.759040351442687*^9, 3.7590403596325574`*^9}, 3.759040426742552*^9, {
   3.7590404708723783`*^9, 
   3.759040495894822*^9}},ExpressionUUID->"ff18487f-3b6f-40c8-a8a1-\
f964d3b14e45"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
        SuperscriptBox["a", "3"]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["a", 
          RowBox[{"3", "/", "2"}]], " ", "H0", " ", 
         "\[CapitalOmega]\[CapitalLambda]0", " ", 
         RowBox[{"H", "[", "a", "]"}]}], 
        SqrtBox[
         RowBox[{"\[CapitalOmega]m0", "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}]]], "-", 
       SuperscriptBox[
        RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Alpha]", "]"}], "6"],
      SeriesData[$CellContext`\[Alpha], 0, {}, 0, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`\[Alpha], 
     0, {($CellContext`a^(-3) $CellContext`H0^2) \
$CellContext`\[CapitalOmega]m0 - ((($CellContext`a^
          Rational[
           3, 2] $CellContext`H0) \
$CellContext`\[CapitalOmega]\[CapitalLambda]0) \
($CellContext`\[CapitalOmega]m0 + $CellContext`a^3 $CellContext`\
\[CapitalOmega]\[CapitalLambda]0)^
        Rational[-1, 
          2]) $CellContext`H[$CellContext`a] - \
$CellContext`H[$CellContext`a]^2}, 0, 6, 1],
    Editable->False], ",", 
   InterpretationBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
        SuperscriptBox["a", "3"]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["a", 
          RowBox[{"3", "/", "2"}]], " ", "H0", " ", 
         "\[CapitalOmega]\[CapitalLambda]0", " ", 
         RowBox[{"H", "[", "a", "]"}]}], 
        SqrtBox[
         RowBox[{"\[CapitalOmega]m0", "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}]]], "-", 
       SuperscriptBox[
        RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "+", 
     InterpretationBox[
      SuperscriptBox[
       RowBox[{"O", "[", "\[Alpha]", "]"}], "6"],
      SeriesData[$CellContext`\[Alpha], 0, {}, 0, 6, 1],
      Editable->False]}],
    SeriesData[$CellContext`\[Alpha], 
     0, {($CellContext`a^(-3) $CellContext`H0^2) \
$CellContext`\[CapitalOmega]m0 + ((($CellContext`a^
           Rational[
            3, 2] $CellContext`H0) $CellContext`\[CapitalOmega]\
\[CapitalLambda]0) ($CellContext`\[CapitalOmega]m0 + $CellContext`a^3 \
$CellContext`\[CapitalOmega]\[CapitalLambda]0)^
         Rational[-1, 
           2]) $CellContext`H[$CellContext`a] - \
$CellContext`H[$CellContext`a]^2}, 0, 6, 1],
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.759040287094818*^9, 3.7590403024725704`*^9}, 
   3.759040360492355*^9, 3.759040427797161*^9, {3.759040471782539*^9, 
   3.75904049667286*^9}},ExpressionUUID->"28ee93e7-463a-4186-8365-\
0008958b35e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
          SuperscriptBox["a", "3"]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", 
            RowBox[{"3", "/", "2"}]], " ", "H0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0", " ", 
           RowBox[{"H", "[", "a", "]"}]}], 
          SqrtBox[
           RowBox[{"\[CapitalOmega]m0", "+", 
            RowBox[{
             SuperscriptBox["a", "3"], " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}]}]]], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "\[Equal]", "0"}], ",", 
      RowBox[{"H", "[", "a", "]"}]}], "]"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
          SuperscriptBox["a", "3"]], "+", 
         FractionBox[
          RowBox[{
           SuperscriptBox["a", 
            RowBox[{"3", "/", "2"}]], " ", "H0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0", " ", 
           RowBox[{"H", "[", "a", "]"}]}], 
          SqrtBox[
           RowBox[{"\[CapitalOmega]m0", "+", 
            RowBox[{
             SuperscriptBox["a", "3"], " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}]}]]], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "a", "]"}], "2"]}], ")"}], "\[Equal]", "0"}], ",", 
      RowBox[{"H", "[", "a", "]"}]}], "]"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}], "//", "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7590403170345078`*^9, 3.759040333126773*^9}, {
  3.759040365442074*^9, 3.7590404629625196`*^9}, {3.7590405018923883`*^9, 
  3.7590405313426228`*^9}},ExpressionUUID->"d0ece97f-baee-4841-9a2e-\
13a1821ed10c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"H0", " ", 
        SqrtBox[
         RowBox[{"\[CapitalOmega]m0", "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}]]}], 
       SuperscriptBox["a", 
        RowBox[{"3", "/", "2"}]]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"H0", " ", "\[CapitalOmega]m0"}], 
      RowBox[{
       SuperscriptBox["a", 
        RowBox[{"3", "/", "2"}]], " ", 
       SqrtBox[
        RowBox[{"\[CapitalOmega]m0", "+", 
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}]}]]}]]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.759040417562519*^9, 3.7590404634023404`*^9}, {
  3.7590405024484*^9, 
  3.7590405328175344`*^9}},ExpressionUUID->"c1b366ec-a81f-4d5a-946d-\
4c1622c9d977"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"H0", " ", "\[CapitalOmega]m0"}], 
       RowBox[{
        SuperscriptBox["a", 
         RowBox[{"3", "/", "2"}]], " ", 
        SqrtBox[
         RowBox[{"\[CapitalOmega]m0", "+", 
          RowBox[{
           SuperscriptBox["a", "3"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"H0", " ", 
       SqrtBox[
        RowBox[{"\[CapitalOmega]m0", "+", 
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}]}]]}], 
      SuperscriptBox["a", 
       RowBox[{"3", "/", "2"}]]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.759040417562519*^9, 3.7590404634023404`*^9}, {
  3.7590405024484*^9, 
  3.759040532837202*^9}},ExpressionUUID->"041b16a7-a120-4140-a1fe-\
622ad2709253"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"case", " ", "1", " ", 
   RowBox[{
    RowBox[{"K", "~", "X"}], "^", "n"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7531063588095603`*^9, 
  3.7531063667643137`*^9}},ExpressionUUID->"bae05997-e4bb-4d13-9f74-\
087e94c2310c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solG3", "/.", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"X", "^", "n"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"X", ",", "i"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531058069981284`*^9, 3.7531058410291724`*^9}, {
  3.753105892322482*^9, 
  3.7531059153298244`*^9}},ExpressionUUID->"c5f9bf19-97a1-4723-bc87-\
254f81312291"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox["J0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "n"}]}], ")"}], " ", 
           SuperscriptBox["X", "n"], " ", "\[Alpha]"}], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox["H0", "2"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"6", " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"5", "/", "4"}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{
           SqrtBox["2"], " ", 
           SuperscriptBox["X", "n"], " ", "\[Alpha]", " ", 
           "\[CapitalOmega]m0"}], "+", 
          RowBox[{"2", " ", "J0", " ", 
           SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{"3", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}]]}], ")"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SqrtBox["J0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           SuperscriptBox["X", "n"], " ", 
           RowBox[{"(", 
            RowBox[{"\[Alpha]", "-", 
             RowBox[{"2", " ", "n", " ", "\[Alpha]"}]}], ")"}]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["H0", "2"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"6", " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"5", "/", "4"}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{
           SqrtBox["2"], " ", 
           SuperscriptBox["X", "n"], " ", "\[Alpha]", " ", 
           "\[CapitalOmega]m0"}], "+", 
          RowBox[{"2", " ", "J0", " ", 
           SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{"3", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}]]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7531058416691785`*^9, {3.7531059079901304`*^9, 
   3.7531059160917625`*^9}},ExpressionUUID->"22a133bc-e31f-40e1-a241-\
ed16ec2d213e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dd", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"G3", "'"}], "[", "X", "]"}], "==", 
       FractionBox[
        RowBox[{
         SqrtBox["J0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["X", "n"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Alpha]", "-", 
              RowBox[{"2", " ", "n", " ", "\[Alpha]"}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], 
        RowBox[{"6", " ", "H0", " ", 
         SuperscriptBox["X", 
          RowBox[{"5", "/", "4"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", 
            SuperscriptBox["X", "n"], " ", "\[Alpha]", " ", 
            "\[CapitalOmega]m0"}], "+", 
           RowBox[{"2", " ", "J0", " ", 
            SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}]}]]}]]}], ",", 
      RowBox[{"G3", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105918591773*^9, 3.7531059721079226`*^9}, {
  3.753106056934339*^9, 3.753106125485626*^9}, {3.75310622116893*^9, 
  3.7531062466371284`*^9}},ExpressionUUID->"e866959e-05d8-46bf-8026-\
7bdf80c39371"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"3", " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"1", "/", "4"}]], " ", "\[CapitalOmega]m0"}]], 
      RowBox[{
       SqrtBox["J0"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["X", "n"], " ", "\[Alpha]", " ", 
          "\[CapitalOmega]m0"}], "+", 
         RowBox[{"4", " ", "J0", " ", 
          SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}]}]]}]}]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.753105963177185*^9, 3.753105972747184*^9}, {
  3.753106061850077*^9, 3.7531061260651007`*^9}, {3.7531062223267827`*^9, 
  3.7531062471645756`*^9}},ExpressionUUID->"af3a26b0-cfd4-4ce9-859d-\
a9c23d5b542d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dd", "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", "0"}]}], "//", "FullSimplify"}], "//", 
   "Factor"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531061375623384`*^9, 3.7531061522115917`*^9}, {
  3.753106228118154*^9, 
  3.7531062564200315`*^9}},ExpressionUUID->"677c8237-cd1b-451b-8bfe-\
8b1bb62adfa9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["J0"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "J0", " ", 
            SqrtBox["X"]}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]}], ")"}], 
         " ", "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
      RowBox[{"3", " ", "H0", " ", 
       SuperscriptBox["X", 
        RowBox[{"1", "/", "4"}]], " ", "\[CapitalOmega]m0"}]]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7531061478127966`*^9, 3.7531061532170863`*^9}, {
  3.753106228686987*^9, 
  3.753106256653495*^9}},ExpressionUUID->"112ba199-b6cc-4379-84e4-\
9ab3fe560e54"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Designer", " ", "case", " ", "2"}], ":", " ", 
     RowBox[{"G3", "[", "X", "]"}]}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"J0", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"(", 
           RowBox[{"4", "+", 
            FractionBox[
             RowBox[{"6", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}], 
             RowBox[{"J0", " ", 
              SqrtBox["X"]}]]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
       RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}], "+", 
     RowBox[{"C", "[", "1", "]"}]}]}], " ", "//", " ", 
   RowBox[{"Agreement", "!"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7531061850855885`*^9, 
  3.7531061989111433`*^9}},ExpressionUUID->"c7b3cf21-16d8-4fdf-b65f-\
4aaf38645949"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"case", " ", "2", " ", 
   RowBox[{"K", "~", 
    RowBox[{"sin", "[", "X", "]"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7531063785686665`*^9, 
  3.7531063847446547`*^9}},ExpressionUUID->"c8219de5-9523-4137-894c-\
5b809fd6955d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solG3", "/.", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"Sin", "[", "X", "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"X", ",", "i"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531063942026668`*^9, 
  3.7531063974581003`*^9}},ExpressionUUID->"08784c06-84eb-4954-9135-\
5725e2544fb2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SqrtBox["J0"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["H0", "2"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
          RowBox[{"2", " ", "X", " ", "\[Alpha]", " ", 
           RowBox[{"Cos", "[", "X", "]"}]}], "+", 
          RowBox[{"\[Alpha]", " ", 
           RowBox[{"Sin", "[", "X", "]"}]}]}], ")"}]}], 
       RowBox[{"6", " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"5", "/", "4"}]], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"2", " ", "J0", " ", 
           SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{"3", " ", 
           SqrtBox["2"], " ", 
           SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          RowBox[{
           SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0", " ", 
           RowBox[{"Sin", "[", "X", "]"}]}]}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       SqrtBox["J0"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SuperscriptBox["H0", "2"], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
         RowBox[{"2", " ", "X", " ", "\[Alpha]", " ", 
          RowBox[{"Cos", "[", "X", "]"}]}], "+", 
         RowBox[{"\[Alpha]", " ", 
          RowBox[{"Sin", "[", "X", "]"}]}]}], ")"}]}], 
      RowBox[{"6", " ", "H0", " ", 
       SuperscriptBox["X", 
        RowBox[{"5", "/", "4"}]], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", "J0", " ", 
          SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{
          SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"Sin", "[", "X", "]"}]}]}]]}]]}], "}"}]}], "}"}]], "Output",\

 CellChangeTimes->{
  3.753106399292227*^9},ExpressionUUID->"ad0cf556-08fa-41c2-a46a-\
8b6f1dcefd82"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dd", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"G3", "'"}], "[", "X", "]"}], "==", 
       FractionBox[
        RowBox[{
         SqrtBox["J0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           RowBox[{"2", " ", "X", " ", "\[Alpha]", " ", 
            RowBox[{"Cos", "[", "X", "]"}]}], "+", 
           RowBox[{"\[Alpha]", " ", 
            RowBox[{"Sin", "[", "X", "]"}]}]}], ")"}]}], 
        RowBox[{"6", " ", "H0", " ", 
         SuperscriptBox["X", 
          RowBox[{"5", "/", "4"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{"2", " ", "J0", " ", 
            SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
           RowBox[{
            SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0", " ", 
            RowBox[{"Sin", "[", "X", "]"}]}]}]]}]]}], ",", 
      RowBox[{"G3", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7531064112390957`*^9},ExpressionUUID->"e795ea4c-7b44-4d71-83b2-\
b00dcca41c35"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"C", "[", "1", "]"}], "-", 
    FractionBox[
     RowBox[{
      SqrtBox["J0"], " ", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", "J0", " ", 
         SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        RowBox[{"6", " ", 
         SqrtBox["2"], " ", 
         SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
         "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["2"], " ", "\[Alpha]", " ", "\[CapitalOmega]m0", " ", 
         RowBox[{"Sin", "[", "X", "]"}]}]}]]}], 
     RowBox[{"3", " ", "H0", " ", 
      SuperscriptBox["X", 
       RowBox[{"1", "/", "4"}]], " ", "\[CapitalOmega]m0"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7531064183294716`*^9},ExpressionUUID->"79bbdec6-2237-487c-86c8-\
54fb0c74c99b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753103919594767*^9, 
  3.753103921703641*^9}},ExpressionUUID->"5d9964cb-5d0f-4523-8e9e-\
83685e135b19"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Designer", " ", "3", 
    RowBox[{"a", ":", " ", "K"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"K", 
       RowBox[{"(", "X", ")"}]}], " ", "&"}], " ", "G"}], "=", 
    RowBox[{"G", 
     RowBox[{"(", "X", ")"}], " ", "good"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753007025810972*^9, 3.75300703764139*^9}, 
   3.7530074340625987`*^9, {3.7531040292255526`*^9, 3.753104034244852*^9}, 
   3.7615610651974173`*^9, {3.761985057639552*^9, 
   3.7619850581299787`*^9}},ExpressionUUID->"263c1ee1-6cdc-4bcc-b4c1-\
9dcd897dd939"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"des3", ",", "eqdes3", ",", "solf", ",", "eqg3"}], "]"}]], "Input",
 CellChangeTimes->{{3.7530268091552315`*^9, 3.753026828954541*^9}, {
  3.753104074960581*^9, 
  3.75310407646391*^9}},ExpressionUUID->"777a0497-8364-4262-85d6-\
1622b765f4e3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "''"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"K", "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7530071402313166`*^9, 3.7530071520712533`*^9}, {
  3.7530073980312834`*^9, 3.7530074020115433`*^9}, {3.7530267947608924`*^9, 
  3.7530267954046335`*^9}, {3.7531040546639605`*^9, 
  3.753104106472458*^9}},ExpressionUUID->"8579583d-d98f-46ce-8ac7-\
d3803b799e41"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["2", "3"], "eq00"}], "/.", "des3"}], "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "t", "]"}], "\[Rho]c"}]}]}], "/.", 
    RowBox[{"t", "\[Rule]", "a"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.753007162370982*^9, 3.7530071639310336`*^9}, {
   3.753007412681366*^9, 3.753007413180858*^9}, {3.7530074538413053`*^9, 
   3.7530074742035904`*^9}, {3.7530268519539814`*^9, 3.753026864814765*^9}, 
   3.7531041210612183`*^9},ExpressionUUID->"821d790d-77a2-4ffc-b2d1-\
d294d6b98662"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "-", 
  FractionBox[
   RowBox[{"K", "[", "X", "]"}], "3"], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{
   FractionBox["2", "3"], " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530070956712055`*^9, 3.7530071645856547`*^9, 3.753007359271302*^9, {
   3.7530074043412685`*^9, 3.7530074136313868`*^9}, {3.7530074566310596`*^9, 
   3.75300747484136*^9}, 3.753009479731315*^9, 3.753010399292014*^9, 
   3.7530259723809757`*^9, 3.7530267991530056`*^9, {3.7530268472211742`*^9, 
   3.7530268654142923`*^9}, 3.7530272317890463`*^9, 3.753104123529351*^9, 
   3.7531100768157735`*^9, 3.7590389370428114`*^9, 3.759062854815488*^9, 
   3.7590650583349285`*^9, 3.761484087809585*^9, 3.7614967834812107`*^9, 
   3.7615611005792503`*^9},ExpressionUUID->"93c526ef-298b-4507-bc90-\
15f437bada57"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"eqscal", "/.", "des3"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], "/.", 
       RowBox[{"G", "\[Rule]", 
        FractionBox[
         RowBox[{"3", 
          RowBox[{"H0", "^", "2"}]}], 
         RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "//", "Expand"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7530072546512675`*^9, {3.753007978861573*^9, 3.7530079844517*^9}, {
   3.75300819971229*^9, 3.7530082001136017`*^9}, {3.7530268680858884`*^9, 
   3.7530268991518917`*^9}, 
   3.753104155438074*^9},ExpressionUUID->"4f46c90c-3399-4820-8e7b-\
1c79faf3fd28"],

Cell[BoxData[
 RowBox[{
  RowBox[{"18", " ", "X", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"6", " ", "a", " ", "X", " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "a", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{
       SuperscriptBox["K", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G3", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}], "+", 
        RowBox[{"X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530072553012924`*^9, 3.75300736155129*^9, 3.7530075454953737`*^9, {
   3.7530079799828978`*^9, 3.753007985875571*^9}, 3.7530082007913494`*^9, 
   3.753009481096099*^9, 3.7530104003049483`*^9, 3.7530259745347195`*^9, 
   3.7530268004690237`*^9, {3.7530268708900013`*^9, 3.7530269002721505`*^9}, 
   3.7530272332545967`*^9, 3.7531041604460745`*^9, 3.753110080239015*^9, 
   3.759038938386591*^9, 3.759062856120221*^9, 3.759065059235174*^9, 
   3.761484089547599*^9, 3.761496785510987*^9, 
   3.7615611030372133`*^9},ExpressionUUID->"41c8391e-831b-4455-86ca-\
45a20d02ed67"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"eqdes22", "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531050161389294`*^9, 
  3.753105030776743*^9}},ExpressionUUID->"7755da1a-f2fc-4d89-8f5e-\
75c177d35a80"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "X", " ", 
         RowBox[{"H", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"2", " ", "a", " ", "X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "a", "]"}]}], "+", 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["X"], " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["K", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"], " ", 
       SqrtBox["X"], " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], "+", 
         RowBox[{"X", " ", 
          RowBox[{
           SuperscriptBox["G3", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "X", " ", 
       RowBox[{
        SuperscriptBox["K", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}]}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.7531050241837077`*^9, 3.7531050311628895`*^9}, 
   3.7590389413865633`*^9, 3.759062857975212*^9, 3.759065061014832*^9, 
   3.7614840919615884`*^9, 3.76149678736954*^9, 
   3.7615611100068965`*^9},ExpressionUUID->"11bce863-c380-4089-b8e7-\
b698bea9dbf7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Ptot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
    "des3"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.753104165454965*^9},ExpressionUUID->"7643abec-c08e-4677-b209-\
21400d8d1cda"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.753008288221882*^9, 3.753009482346419*^9, 
  3.7530104012915435`*^9, 3.753025976743453*^9, 3.7530269098180213`*^9, 
  3.75302723538494*^9, 3.753104184074131*^9, 3.7590389432772183`*^9, 
  3.7590628597555776`*^9, 3.759065062024963*^9, 3.76148409319717*^9, 
  3.761496788182303*^9, 
  3.7615611116570077`*^9},ExpressionUUID->"201fd865-a774-4872-8b6a-\
b7d3617fd530"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Jtot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
      "des3"}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}], "/.", 
   RowBox[{"t", "\[Rule]", "a"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.7530082969130588`*^9, 3.7530083295913944`*^9, {3.753026917538438*^9, 
   3.75302691893057*^9}, 
   3.753104219925988*^9},ExpressionUUID->"b7010bda-9cea-4387-bcea-\
96ce08e6e302"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}], ",", "0", ",", "0", ",",
    "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7530082975415645`*^9, 3.753008330541541*^9, 3.7530094836722317`*^9, 
   3.7530104029223557`*^9, 3.753025977723363*^9, {3.7530269141756024`*^9, 
   3.753026919235218*^9}, 3.7530272363194532`*^9, {3.753104216959204*^9, 
   3.7531042204133034`*^9}, 3.759038944433468*^9, 3.759062860927602*^9, 
   3.759065062785056*^9, 3.761484094817444*^9, 3.76149678990131*^9, 
   3.7615611127072563`*^9},ExpressionUUID->"abfdbb7a-b172-44a5-ac5b-\
dea40acc4728"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{"Raise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"J", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}],
         ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", "zeroorder"}], "//",
   "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7530083583919115`*^9, 3.753008383591753*^9}, 
   3.7530269380948334`*^9},ExpressionUUID->"22ca6321-bcde-4e4d-9aa0-\
90d077429efb"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"J", "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["J", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.753008368031542*^9, 3.75300838394143*^9}, 
   3.7530094861559353`*^9, 3.7530104039620748`*^9, 3.7530259792893887`*^9, {
   3.7530269237358108`*^9, 3.7530269389219027`*^9}, 3.7530272449852643`*^9, 
   3.7531042327702336`*^9, 3.7590389453865604`*^9, 3.7590628626477027`*^9, 
   3.7614840963873386`*^9, 
   3.7615611145971985`*^9},ExpressionUUID->"8f5b49f1-86a3-4c63-acf6-\
197bfe3edeed"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
        RowBox[{"a", "[", "t", "]"}]}], " ", 
       RowBox[{"J", "[", "t", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["J", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{"J", "[", "t", "]"}], ",", "t"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.753026941097069*^9, 
  3.7530269583466897`*^9}},ExpressionUUID->"3768658a-6cec-4f36-8b42-\
051f4957f20e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530269555727863`*^9, 3.7530269586755733`*^9}, 
   3.7530272465369406`*^9, 3.7531042352143793`*^9, 3.75903894645088*^9, 
   3.759062863937645*^9, 3.7614840984673543`*^9, 
   3.761561115762085*^9},ExpressionUUID->"e520d46d-884d-4030-895f-\
7f739bdf6b23"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HL", "=", 
   RowBox[{"H0", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}], "+", "\[CapitalOmega]\[CapitalLambda]0"}]]}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7530269935173016`*^9, 3.7530269990121403`*^9}, {
  3.7531100904488335`*^9, 3.75311009680774*^9}, {3.753110167300049*^9, 
  3.753110168255074*^9}},ExpressionUUID->"f5053aa1-846a-41ae-8833-\
6c014b8255c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqscal1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"J0", "/", 
     RowBox[{"a", "^", "3"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.753104366141808*^9, 
  3.753104373882861*^9}},ExpressionUUID->"25aafd11-ccf9-4e95-8d13-\
39251009e39a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"eqscal1", "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.753105476066646*^9, {3.753105587345478*^9, 
   3.7531055878734922`*^9}},ExpressionUUID->"7f6ccc18-63b7-48a6-b7c5-\
97a787e6990d"],

Cell[BoxData[
 RowBox[{
  FractionBox["J0", 
   SuperscriptBox["a", "3"]], "-", 
  RowBox[{"6", " ", "H0", " ", "X", " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{3.753105476553343*^9, 3.753105588370403*^9, 
  3.753110137299548*^9, 3.7531101713727765`*^9, 3.759038953745048*^9, 
  3.7590628676254687`*^9, 3.7590650663901415`*^9, 3.7614841029125395`*^9, 
  3.761496795295622*^9, 
  3.761561142447031*^9},ExpressionUUID->"f2d6ff26-8155-422b-a24b-\
b43617604fa3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"3", "eqdes21"}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105447459355*^9, 3.7531054645662947`*^9}, {
  3.753105590708206*^9, 
  3.753105593623171*^9}},ExpressionUUID->"5733dac0-4003-4408-a29a-\
3962dabe1db8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", "H0", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7531045533364906`*^9, {3.753105451522622*^9, 3.753105464850565*^9}, 
   3.7531055941314063`*^9, 3.753110138855093*^9, 3.753110172774557*^9, 
   3.759038954745015*^9, 3.7590628695243273`*^9, 3.759065067294776*^9, 
   3.7614841070195956`*^9, 3.7614967962610826`*^9, 
   3.7615611452468944`*^9},ExpressionUUID->"a4427ff3-6340-4f2a-9ba6-\
b0cf5e771ce0"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"a", "^", "2"}], " ", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.753105511622341*^9, 
  3.753105522319375*^9}},ExpressionUUID->"65b6094d-b46e-438a-8ce5-\
31b73c661c85"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sola", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "^", "2"}], "\[Equal]", 
      RowBox[{"HL", "^", "2"}]}], ",", "a"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7531055988246164`*^9, 3.753105653662197*^9}, 
   3.753110142857869*^9, {3.753110190369815*^9, 
   3.7531101909083433`*^9}},ExpressionUUID->"81f574e3-ecef-4482-a600-\
64cddaa66d21"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["H0", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalOmega]m0", 
      RowBox[{"1", "/", "3"}]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["H", "2"], "-", 
       RowBox[{
        SuperscriptBox["H0", "2"], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.753105604228838*^9, 3.7531056542303205`*^9}, {
   3.7531101482612677`*^9, 3.75311019121295*^9}, 3.759038957249871*^9, 
   3.759062870985124*^9, 3.7590650702351136`*^9, 3.761484109257593*^9, 
   3.7614967990538764`*^9, 
   3.7615611636670475`*^9},ExpressionUUID->"1e6e3f00-ea19-45da-be77-\
95a36121581b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQ11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ1", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ2", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]}], "Input",
 CellChangeTimes->{{3.75310563172922*^9, 
  3.7531056909235077`*^9}},ExpressionUUID->"faaf5c90-ea77-4d25-ad1e-\
a48ea6df589f"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"J0", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["H", "2"], "-", 
      RowBox[{
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}]}],
      ")"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"6", " ", "H", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.7614968009621935`*^9, 
   3.7615611652568974`*^9},ExpressionUUID->"932a6130-5400-451d-a4cd-\
1412d5956314"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", "H", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.7614968009621935`*^9, 
   3.761561165336784*^9},ExpressionUUID->"a14ef191-16a0-4231-8689-\
28b8eb724212"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"X", "==", 
    RowBox[{"c0", "/", 
     RowBox[{"H", "^", "n"}]}]}], ",", "H"}], "]"}]], "Input",
 CellChangeTimes->{{3.7615612872188935`*^9, 
  3.761561305649625*^9}},ExpressionUUID->"0b7d0eed-e4da-46f7-8ccd-\
1b0e83a8f7c9"],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,138,3,17625714166509442095,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761561306204009*^9},ExpressionUUID->"90925043-3f6c-4275-84b9-\
c82d30110a25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"H", "\[Rule]", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["X", "c0"], ")"}], 
     RowBox[{
      RowBox[{"-", "1"}], "/", "n"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7615613062071204`*^9},ExpressionUUID->"4647f354-5f00-45c6-afc2-\
ea68d6b5b7b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQ13", "=", 
  RowBox[{
   RowBox[{"EQ11", "/.", 
    RowBox[{"H", "\[Rule]", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["X", "c0"], ")"}], 
      RowBox[{
       RowBox[{"-", "1"}], "/", "n"}]]}]}], "//", 
   "PowerExpand"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ23", "=", 
  RowBox[{
   RowBox[{"EQ22", "/.", 
    RowBox[{"H", "\[Rule]", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["X", "c0"], ")"}], 
      RowBox[{
       RowBox[{"-", "1"}], "/", "n"}]]}]}], "//", "PowerExpand"}]}]}], "Input",\

 CellChangeTimes->{{3.7615612672472167`*^9, 3.761561268559741*^9}, {
  3.761561310387038*^9, 3.7615613341468725`*^9}, {3.7615613656041236`*^9, 
  3.7615613836866255`*^9}},ExpressionUUID->"ad9483bf-3ac1-4771-b6b6-\
11006554615f"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"J0", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["c0", 
        RowBox[{"2", "/", "n"}]], " ", 
       SuperscriptBox["X", 
        RowBox[{
         RowBox[{"-", "2"}], "/", "n"}]]}], "-", 
      RowBox[{
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}]}],
      ")"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"6", " ", 
   SuperscriptBox["c0", 
    FractionBox["1", "n"]], " ", 
   SuperscriptBox["X", 
    RowBox[{"1", "-", 
     FractionBox["1", "n"]}]], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7615613118290024`*^9, 3.7615613346490655`*^9}, 
   3.761561384671564*^9},ExpressionUUID->"cee10d33-98ab-4459-afb5-\
9299a9ef7a08"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["c0", 
    FractionBox["1", "n"]], " ", 
   SuperscriptBox["X", 
    RowBox[{
     FractionBox["3", "2"], "-", 
     FractionBox["1", "n"]}]], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7615613118290024`*^9, 3.7615613346490655`*^9}, 
   3.7615613846919184`*^9},ExpressionUUID->"84389573-4954-4d54-80eb-\
e1c9d7ead166"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solG3X", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"EQ13", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3", "'"}], "[", "X", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7615613924877477`*^9, 
  3.761561415216736*^9}},ExpressionUUID->"6e0677a0-2dc7-4ca8-8ae7-\
51cab8f0e808"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["c0", 
      RowBox[{
       RowBox[{"-", "1"}], "/", "n"}]], " ", 
     SuperscriptBox["X", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1", "+", "n"}], "n"]}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"J0", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["c0", 
           RowBox[{"2", "/", "n"}]], "-", 
          RowBox[{
           SuperscriptBox["H0", "2"], " ", 
           SuperscriptBox["X", 
            RowBox[{"2", "/", "n"}]], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "-", 
       RowBox[{
        SqrtBox["2"], " ", 
        SuperscriptBox["H0", "2"], " ", 
        SuperscriptBox["X", 
         RowBox[{
          FractionBox["1", "2"], "+", 
          FractionBox["2", "n"]}]], " ", "\[CapitalOmega]m0", " ", 
        RowBox[{
         SuperscriptBox["K", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], 
    RowBox[{"6", " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7615614021166925`*^9, 
  3.7615614156870475`*^9}},ExpressionUUID->"77217442-56d8-4a34-91b7-\
c4ef1ba4129e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQ23", "/.", "solG3X"}], "//", "Expand"}], "\[IndentingNewLine]", 
 RowBox[{"solKX", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"%", "\[Equal]", "0"}], ",", 
      RowBox[{"K", "[", "X", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.761561419311491*^9, 3.761561459236927*^9}, {
  3.761561618419253*^9, 
  3.761561647757162*^9}},ExpressionUUID->"f1a1e496-83e1-43ac-bf90-\
eca9796044a4"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", 
    SuperscriptBox["c0", 
     RowBox[{"2", "/", "n"}]], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{
      FractionBox["1", "2"], "-", 
      FractionBox["2", "n"]}]]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
   "\[CapitalOmega]m0"], "-", 
  RowBox[{"K", "[", "X", "]"}]}]], "Output",
 CellChangeTimes->{{3.761561421802811*^9, 3.761561459617717*^9}, {
  3.7615616193166685`*^9, 
  3.7615616481469297`*^9}},ExpressionUUID->"669b4e49-f412-456d-9f2a-\
cda16901e4dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", 
      SuperscriptBox["c0", 
       RowBox[{"2", "/", "n"}]], " ", "J0", " ", 
      SuperscriptBox["X", 
       RowBox[{
        FractionBox["1", "2"], "-", 
        FractionBox["2", "n"]}]]}], 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
    RowBox[{"3", " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
    "-", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", "J0", " ", 
      SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
     "\[CapitalOmega]m0"]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761561421802811*^9, 3.761561459617717*^9}, {
  3.7615616193166685`*^9, 
  3.7615616481669035`*^9}},ExpressionUUID->"d7b3487e-9c41-4f66-8b2a-\
37b6d9329011"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solG3X", "/.", 
   RowBox[{"D", "[", 
    RowBox[{"solKX", ",", "X"}], "]"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7615616340966806`*^9, 
  3.761561659111493*^9}},ExpressionUUID->"8a38e12a-6813-41ea-8082-\
38df595c3256"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["c0", 
      FractionBox["1", "n"]], " ", "J0", " ", 
     SuperscriptBox["X", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"1", "+", "n"}], "n"]}]]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["H0", "2"], " ", "n", " ", "\[CapitalOmega]m0"}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761561656066698*^9, 
  3.7615616595867934`*^9}},ExpressionUUID->"b6a31697-5a57-4f56-ab42-\
5fa7ee976b58"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solG3", "=", 
  RowBox[{
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "==", 
      FractionBox[
       RowBox[{"2", " ", 
        SuperscriptBox["c0", 
         FractionBox["1", "n"]], " ", "J0", " ", 
        SuperscriptBox["X", 
         RowBox[{"-", 
          FractionBox[
           RowBox[{"1", "+", "n"}], "n"]}]]}], 
       RowBox[{"3", " ", 
        SuperscriptBox["H0", "2"], " ", "n", " ", "\[CapitalOmega]m0"}]]}], 
     ",", 
     RowBox[{"G3", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.761561669807068*^9, 3.761561691136895*^9}, {
  3.7615617363567033`*^9, 
  3.761561738147277*^9}},ExpressionUUID->"f5c92ec3-9cd0-4026-bb9f-\
56884ee31583"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["c0", 
        FractionBox["1", "n"]], " ", "J0", " ", 
       SuperscriptBox["X", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "n"}]]}], 
      RowBox[{"3", " ", 
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761561687958352*^9, 3.761561691536804*^9}, 
   3.761561738736647*^9},ExpressionUUID->"fd4fd6ad-64c8-4b6d-adc6-\
4af5e7ce1995"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"G3X", "\[Rule]", 
  RowBox[{"D", "[", 
   RowBox[{
    RowBox[{"solG3", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.761561816066992*^9, 
  3.7615618171667824`*^9}},ExpressionUUID->"63b98ff7-a5bb-47df-9edc-\
c0ad1291d9c4"],

Cell[BoxData[
 RowBox[{"G3X", "\[Rule]", 
  FractionBox[
   RowBox[{"2", " ", 
    SuperscriptBox["c0", 
     FractionBox["1", "n"]], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{
      RowBox[{"-", "1"}], "-", 
      FractionBox["1", "n"]}]]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["H0", "2"], " ", "n", " ", 
    "\[CapitalOmega]m0"}]]}]], "Output",
 CellChangeTimes->{{3.7615617986366286`*^9, 
  3.7615618175788703`*^9}},ExpressionUUID->"1da0c5bc-63ea-4329-b95c-\
7f2832cebf9d"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]K", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "X", 
       RowBox[{"(", 
        RowBox[{"G2X", "+", 
         RowBox[{"2", "X", " ", "G2XX"}]}], ")"}]}], "+", 
      RowBox[{"12", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", 
       RowBox[{"(", 
        RowBox[{"G3X", "+", 
         RowBox[{"X", " ", "G3XX"}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]B", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", " ", "G3X"}], ")"}], 
    "/", 
    RowBox[{"H", "[", "a", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.761485763251938*^9, 3.761485828157342*^9}, {
   3.761486002066842*^9, 3.761486002316814*^9}, 3.761486085036993*^9, 
   3.761496991174667*^9, {3.7614974480869627`*^9, 3.7614974946617217`*^9}, 
   3.7614975458951664`*^9},ExpressionUUID->"aa21fd2a-42a7-4987-bade-\
1a36d06f7313"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Alpha]K1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Alpha]K", "/.", 
           RowBox[{"G2X", "\[Rule]", 
            RowBox[{
             RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
          RowBox[{"G2XX", "\[Rule]", 
           RowBox[{
            RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
         RowBox[{"G3X", "\[Rule]", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"solG3", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X"}], "]"}]}]}], "/.", 
        RowBox[{"G3XX", "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"solG3", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X", ",", "X"}], 
          "]"}]}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", "solKX"}], "/.", 
     RowBox[{"D", "[", 
      RowBox[{"solKX", ",", "X"}], "]"}]}], "/.", 
    RowBox[{"D", "[", 
     RowBox[{"solKX", ",", "X", ",", "X"}], "]"}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]B1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Alpha]B", "/.", 
           RowBox[{"G2X", "\[Rule]", 
            RowBox[{
             RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
          RowBox[{"G2XX", "\[Rule]", 
           RowBox[{
            RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
         RowBox[{"G3X", "\[Rule]", 
          RowBox[{"D", "[", 
           RowBox[{
            RowBox[{"solG3", "[", 
             RowBox[{"[", 
              RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X"}], "]"}]}]}], "/.", 
        RowBox[{"G3XX", "\[Rule]", 
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"solG3", "[", 
            RowBox[{"[", 
             RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X", ",", "X"}], 
          "]"}]}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", "solKX"}], "/.", 
     RowBox[{"D", "[", 
      RowBox[{"solKX", ",", "X"}], "]"}]}], "/.", 
    RowBox[{"D", "[", 
     RowBox[{"solKX", ",", "X", ",", "X"}], "]"}]}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.7614858410119333`*^9, 3.761485936096927*^9}, {
  3.761486022507202*^9, 3.7614860237974825`*^9}, {3.7614975151724834`*^9, 
  3.761497522781365*^9}, {3.7615617203869843`*^9, 3.7615617762767396`*^9}, {
  3.761561820466493*^9, 
  3.7615618238565245`*^9}},ExpressionUUID->"99d1828d-f656-443b-8739-\
d324ef19e7bb"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", 
    SqrtBox["2"], " ", 
    SuperscriptBox["c0", 
     FractionBox["1", "n"]], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{
      RowBox[{"-", "2"}], "/", "n"}]], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["c0", 
        FractionBox["1", "n"]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], "+", "n"}], ")"}], " ", 
       SqrtBox["X"]}], "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["X", 
        RowBox[{
         FractionBox["1", "2"], "+", 
         FractionBox["1", "n"]}]], " ", 
       RowBox[{"H", "[", "a", "]"}]}]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", 
    SuperscriptBox["n", "2"], " ", "\[CapitalOmega]m0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], "2"]}]]}]], "Output",
 CellChangeTimes->{{3.7614858433072987`*^9, 3.76148593660946*^9}, {
   3.7614860051770372`*^9, 3.76148602424174*^9}, 3.76148608748674*^9, 
   3.7614861345470753`*^9, 3.7614970403830156`*^9, {3.7614975245487556`*^9, 
   3.761497548386054*^9}, {3.7615617700267286`*^9, 3.7615617769531946`*^9}, 
   3.7615618272565603`*^9},ExpressionUUID->"2ab000f7-db1e-42c9-a637-\
de96893d3bf3"],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["c0", 
    FractionBox["1", "n"]], " ", "J0", " ", 
   SuperscriptBox["X", 
    RowBox[{
     FractionBox["1", "2"], "-", 
     FractionBox["1", "n"]}]]}], 
  RowBox[{"3", " ", 
   SuperscriptBox["H0", "2"], " ", "n", " ", "\[CapitalOmega]m0", " ", 
   RowBox[{"H", "[", "a", "]"}]}]]], "Output",
 CellChangeTimes->{{3.7614858433072987`*^9, 3.76148593660946*^9}, {
   3.7614860051770372`*^9, 3.76148602424174*^9}, 3.76148608748674*^9, 
   3.7614861345470753`*^9, 3.7614970403830156`*^9, {3.7614975245487556`*^9, 
   3.761497548386054*^9}, {3.7615617700267286`*^9, 3.7615617769531946`*^9}, 
   3.761561827276884*^9},ExpressionUUID->"e9f08a8b-2c2b-4d94-831f-\
b75ba46ee3e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"\[Alpha]K2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]K1", "/.", 
      RowBox[{"X", "->", 
       RowBox[{"c0", "/", 
        RowBox[{
         RowBox[{"H", "[", "a", "]"}], "^", "n"}]}]}]}], "//", 
     "FullSimplify"}], "//", "PowerExpand"}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]B2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]B1", "/.", 
      RowBox[{"X", "->", 
       RowBox[{"c0", "/", 
        RowBox[{
         RowBox[{"H", "[", "a", "]"}], "^", "n"}]}]}]}], "//", 
     "FullSimplify"}], "//", "PowerExpand"}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.761486027277251*^9, 3.761486034866727*^9}, {
  3.761486159967154*^9, 3.761486161309965*^9}, {3.7614970877567654`*^9, 
  3.7614970894498186`*^9}, {3.7614972787782865`*^9, 3.7614972802411757`*^9}, {
  3.761497615571643*^9, 3.761497622502199*^9}, {3.7615618490369453`*^9, 
  3.761561856916596*^9}},ExpressionUUID->"f79c4acd-89c8-4d2d-a8c1-\
eac0a196ad3a"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", 
    SqrtBox["2"], " ", 
    SqrtBox["c0"], " ", "J0", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "2"}], "+", "n"}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], 
     RowBox[{
      RowBox[{"-", "n"}], "/", "2"}]]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", 
    SuperscriptBox["n", "2"], " ", "\[CapitalOmega]m0"}]]}]], "Output",
 CellChangeTimes->{{3.7614860316006927`*^9, 3.7614860353871117`*^9}, 
   3.7614860908092427`*^9, {3.7614861487492523`*^9, 3.7614861616967535`*^9}, {
   3.7614970687589626`*^9, 3.761497089825795*^9}, 3.7614972818778515`*^9, 
   3.7614976235047803`*^9, 
   3.7615618578868017`*^9},ExpressionUUID->"7fa7d1e1-d402-4f1d-b2aa-\
bfef9607c8a9"],

Cell[BoxData[
 FractionBox[
  RowBox[{"4", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["c0"], " ", "J0", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], 
    RowBox[{
     RowBox[{"-", "n"}], "/", "2"}]]}], 
  RowBox[{"3", " ", 
   SuperscriptBox["H0", "2"], " ", "n", " ", "\[CapitalOmega]m0"}]]], "Output",\

 CellChangeTimes->{{3.7614860316006927`*^9, 3.7614860353871117`*^9}, 
   3.7614860908092427`*^9, {3.7614861487492523`*^9, 3.7614861616967535`*^9}, {
   3.7614970687589626`*^9, 3.761497089825795*^9}, 3.7614972818778515`*^9, 
   3.7614976235047803`*^9, 
   3.7615618579269695`*^9},ExpressionUUID->"318cab7c-d91b-41f6-9e7a-\
255127535ee2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]K2", "+", 
     RowBox[{
      FractionBox["3", "2"], 
      RowBox[{"\[Alpha]B2", "^", "2"}]}]}], "//", "FullSimplify"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7614976317666836`*^9, 3.7614976850385494`*^9}, {
  3.7615619904966493`*^9, 
  3.7615619917118998`*^9}},ExpressionUUID->"79c004b1-9de5-43b8-83ff-\
05dee41afd07"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"16", " ", "c0", " ", 
    SuperscriptBox["J0", "2"], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], 
     RowBox[{"-", "n"}]]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["H0", "4"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["\[CapitalOmega]m0", "2"]}]], "+", 
  FractionBox[
   RowBox[{"8", " ", 
    SqrtBox["2"], " ", 
    SqrtBox["c0"], " ", "J0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], 
     RowBox[{
      RowBox[{"-", "n"}], "/", "2"}]]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", 
    SuperscriptBox["n", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  FractionBox[
   RowBox[{"4", " ", 
    SqrtBox["2"], " ", 
    SqrtBox["c0"], " ", "J0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], 
     RowBox[{
      RowBox[{"-", "n"}], "/", "2"}]]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "n", " ", 
    "\[CapitalOmega]m0"}]]}]], "Output",
 CellChangeTimes->{{3.7614976455186605`*^9, 3.761497685320673*^9}, 
   3.761561866936619*^9, 
   3.761561992131601*^9},ExpressionUUID->"6708ea10-49b8-4657-9fb2-\
1737dcfb22b9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Reduce", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"8", " ", 
       SqrtBox["2"]}], 
      SuperscriptBox["n", "2"]], "-", 
     FractionBox[
      RowBox[{"4", " ", 
       SqrtBox["2"], " "}], "n"]}], "\[GreaterEqual]", "0"}], ",", "n"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7615620410266623`*^9, 3.761562049599347*^9}, {
  3.7615655240705013`*^9, 
  3.7615655745604796`*^9}},ExpressionUUID->"f4522fe2-06c6-4cff-b2ba-\
aea2b22b5f68"],

Cell[BoxData[
 RowBox[{
  RowBox[{"n", "<", "0"}], "||", 
  RowBox[{"0", "<", "n", "\[LessEqual]", "2"}]}]], "Output",
 CellChangeTimes->{
  3.7615620502764893`*^9, {3.7615655323905773`*^9, 
   3.7615655752627087`*^9}},ExpressionUUID->"995d8280-1520-4347-a3fb-\
1b430d20ac7c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"\[Alpha]K2", ",", "\[Alpha]B2", ",", "D2"}], "}"}], "/.", 
  RowBox[{"n", "\[Rule]", "2"}]}]], "Input",
 CellChangeTimes->{{3.7615620579065175`*^9, 
  3.7615620655868597`*^9}},ExpressionUUID->"bc43e2e5-5afc-469c-afee-\
c504a4763a12"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{"2", " ", 
     SqrtBox["2"], " ", 
     SqrtBox["c0"], " ", "J0"}], 
    RowBox[{"3", " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
     RowBox[{"H", "[", "a", "]"}]}]], ",", 
   FractionBox[
    RowBox[{"4", " ", "c0", " ", 
     SuperscriptBox["J0", "2"]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["H0", "4"], " ", 
     SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "a", "]"}], "2"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.761562066156722*^9},ExpressionUUID->"7b660d43-2253-4720-820b-\
b03bcf99e35c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753103919594767*^9, 
  3.753103921703641*^9}},ExpressionUUID->"c699c5ff-382d-4602-b543-\
2c86af86ff10"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Designer", " ", "3", 
    RowBox[{"b", ":", " ", "K"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"K", 
       RowBox[{"(", "X", ")"}]}], " ", "&"}], " ", "G"}], "=", 
    RowBox[{"G", 
     RowBox[{"(", "X", ")"}], " ", "BEST"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753007025810972*^9, 3.75300703764139*^9}, 
   3.7530074340625987`*^9, {3.7531040292255526`*^9, 3.753104034244852*^9}, 
   3.7615610651974173`*^9, 3.7616481734489803`*^9, {3.7619787793281713`*^9, 
   3.7619787803380485`*^9}},ExpressionUUID->"ce775d9e-0ce7-4946-b31a-\
942c460e077c"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"des3", ",", "eqdes21", ",", "eqdes3", ",", "solf", ",", "eqg3"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7530268091552315`*^9, 3.753026828954541*^9}, {
  3.753104074960581*^9, 3.75310407646391*^9}, {3.7616681819880934`*^9, 
  3.7616681826387157`*^9}},ExpressionUUID->"8d94ac51-7f9d-4620-98d8-\
0ea167484627"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "''"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"K", "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7530071402313166`*^9, 3.7530071520712533`*^9}, {
  3.7530073980312834`*^9, 3.7530074020115433`*^9}, {3.7530267947608924`*^9, 
  3.7530267954046335`*^9}, {3.7531040546639605`*^9, 
  3.753104106472458*^9}},ExpressionUUID->"e2f9b93f-35f5-40cf-80a1-\
7a754d9eec5e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["2", "3"], "eq00"}], "/.", "des3"}], "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "t", "]"}], "\[Rho]c"}]}]}], "/.", 
    RowBox[{"t", "\[Rule]", "a"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.753007162370982*^9, 3.7530071639310336`*^9}, {
   3.753007412681366*^9, 3.753007413180858*^9}, {3.7530074538413053`*^9, 
   3.7530074742035904`*^9}, {3.7530268519539814`*^9, 3.753026864814765*^9}, 
   3.7531041210612183`*^9},ExpressionUUID->"7fc23a12-af78-4689-a4a9-\
1342924513e5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "-", 
  FractionBox[
   RowBox[{"K", "[", "X", "]"}], "3"], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{
   FractionBox["2", "3"], " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530070956712055`*^9, 3.7530071645856547`*^9, 3.753007359271302*^9, {
   3.7530074043412685`*^9, 3.7530074136313868`*^9}, {3.7530074566310596`*^9, 
   3.75300747484136*^9}, 3.753009479731315*^9, 3.753010399292014*^9, 
   3.7530259723809757`*^9, 3.7530267991530056`*^9, {3.7530268472211742`*^9, 
   3.7530268654142923`*^9}, 3.7530272317890463`*^9, 3.753104123529351*^9, 
   3.7531100768157735`*^9, 3.7590389370428114`*^9, 3.759062854815488*^9, 
   3.7590650583349285`*^9, 3.761484087809585*^9, 3.7614967834812107`*^9, 
   3.7615611005792503`*^9, 3.7616485333708615`*^9, 3.761655124072006*^9, 
   3.7616571885202293`*^9, 3.7616681741257553`*^9, 3.761668215349597*^9, 
   3.761903528717801*^9, 3.761978784087512*^9, 
   3.7620869356877017`*^9},ExpressionUUID->"cc95b246-1717-4a3f-9282-\
d86f3732b0ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"eqscal", "/.", "des3"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], "/.", 
       RowBox[{"G", "\[Rule]", 
        FractionBox[
         RowBox[{"3", 
          RowBox[{"H0", "^", "2"}]}], 
         RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "//", "Expand"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7530072546512675`*^9, {3.753007978861573*^9, 3.7530079844517*^9}, {
   3.75300819971229*^9, 3.7530082001136017`*^9}, {3.7530268680858884`*^9, 
   3.7530268991518917`*^9}, 
   3.753104155438074*^9},ExpressionUUID->"42c46795-e01d-4c43-bd6c-\
a74812f7e4d5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"18", " ", "X", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"6", " ", "a", " ", "X", " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "a", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{
       SuperscriptBox["K", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G3", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}], "+", 
        RowBox[{"X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530072553012924`*^9, 3.75300736155129*^9, 3.7530075454953737`*^9, {
   3.7530079799828978`*^9, 3.753007985875571*^9}, 3.7530082007913494`*^9, 
   3.753009481096099*^9, 3.7530104003049483`*^9, 3.7530259745347195`*^9, 
   3.7530268004690237`*^9, {3.7530268708900013`*^9, 3.7530269002721505`*^9}, 
   3.7530272332545967`*^9, 3.7531041604460745`*^9, 3.753110080239015*^9, 
   3.759038938386591*^9, 3.759062856120221*^9, 3.759065059235174*^9, 
   3.761484089547599*^9, 3.761496785510987*^9, 3.7615611030372133`*^9, 
   3.7616485335957584`*^9, 3.7616551303696938`*^9, 3.761657188762367*^9, 
   3.761668217675481*^9, 3.7619035301581755`*^9, 3.7619787842774467`*^9, 
   3.7620869359249954`*^9},ExpressionUUID->"79814219-c863-4fdf-b6e5-\
cd51bd9b43f3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solfp2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eqdes22", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7531050161389294`*^9, 3.753105030776743*^9}, {
  3.761657230145095*^9, 
  3.761657231640313*^9}},ExpressionUUID->"b1122f7c-db6d-4e33-9cf6-\
ccfef1a20162"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "X", " ", 
         RowBox[{"H", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"2", " ", "a", " ", "X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "a", "]"}]}], "+", 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["X"], " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["K", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"], " ", 
       SqrtBox["X"], " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], "+", 
         RowBox[{"X", " ", 
          RowBox[{
           SuperscriptBox["G3", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "X", " ", 
       RowBox[{
        SuperscriptBox["K", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}]}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.7531050241837077`*^9, 3.7531050311628895`*^9}, 
   3.7590389413865633`*^9, 3.759062857975212*^9, 3.759065061014832*^9, 
   3.7614840919615884`*^9, 3.76149678736954*^9, 3.7615611100068965`*^9, 
   3.761648533783295*^9, 3.7616551331099515`*^9, 3.7616571889802094`*^9, 
   3.761657232780237*^9, 3.7616682187930336`*^9, 3.7619035315978127`*^9, 
   3.7619787864574614`*^9, 
   3.7620869361218395`*^9},ExpressionUUID->"dbbae6eb-832c-4831-bc14-\
237d744ac930"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Ptot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
    "des3"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.753104165454965*^9},ExpressionUUID->"d77a980f-2825-4f81-8856-\
764d7635a6d2"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.753008288221882*^9, 3.753009482346419*^9, 
  3.7530104012915435`*^9, 3.753025976743453*^9, 3.7530269098180213`*^9, 
  3.75302723538494*^9, 3.753104184074131*^9, 3.7590389432772183`*^9, 
  3.7590628597555776`*^9, 3.759065062024963*^9, 3.76148409319717*^9, 
  3.761496788182303*^9, 3.7615611116570077`*^9, 3.7616485348134108`*^9, 
  3.7616551347698417`*^9, 3.761657189062636*^9, 3.7616682218712764`*^9, 
  3.761903533418062*^9, 3.7619787873428354`*^9, 
  3.7620869362402897`*^9},ExpressionUUID->"7167e2d2-d1ec-4169-834f-\
69c914033813"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Jtot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
      "des3"}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}], "/.", 
   RowBox[{"t", "\[Rule]", "a"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.7530082969130588`*^9, 3.7530083295913944`*^9, {3.753026917538438*^9, 
   3.75302691893057*^9}, 
   3.753104219925988*^9},ExpressionUUID->"82e620b9-a674-40c6-8b3b-\
ce734c1623ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}], ",", "0", ",", "0", ",",
    "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7530082975415645`*^9, 3.753008330541541*^9, 3.7530094836722317`*^9, 
   3.7530104029223557`*^9, 3.753025977723363*^9, {3.7530269141756024`*^9, 
   3.753026919235218*^9}, 3.7530272363194532`*^9, {3.753104216959204*^9, 
   3.7531042204133034`*^9}, 3.759038944433468*^9, 3.759062860927602*^9, 
   3.759065062785056*^9, 3.761484094817444*^9, 3.76149678990131*^9, 
   3.7615611127072563`*^9, 3.761648535573395*^9, 3.761655136239571*^9, 
   3.761657189144579*^9, 3.7616682231003118`*^9, 3.761903534498027*^9, 
   3.761978788327742*^9, 
   3.762086936350083*^9},ExpressionUUID->"40c98180-f745-4d8d-8b47-\
ae0406de7f61"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{"Raise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"J", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}],
         ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", "zeroorder"}], "//",
   "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7530083583919115`*^9, 3.753008383591753*^9}, 
   3.7530269380948334`*^9},ExpressionUUID->"933d0e89-435e-4c65-a9ba-\
6f7c2812ae6e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"J", "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["J", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.753008368031542*^9, 3.75300838394143*^9}, 
   3.7530094861559353`*^9, 3.7530104039620748`*^9, 3.7530259792893887`*^9, {
   3.7530269237358108`*^9, 3.7530269389219027`*^9}, 3.7530272449852643`*^9, 
   3.7531042327702336`*^9, 3.7590389453865604`*^9, 3.7590628626477027`*^9, 
   3.7614840963873386`*^9, 3.7615611145971985`*^9, 3.7616551385797377`*^9, 
   3.761657189210157*^9, 3.761668224624529*^9, 3.7619035354681053`*^9, 
   3.7619787900188804`*^9, 
   3.7620869373251076`*^9},ExpressionUUID->"3df6507c-7daf-49c5-b604-\
57f909b30800"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
        RowBox[{"a", "[", "t", "]"}]}], " ", 
       RowBox[{"J", "[", "t", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["J", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{"J", "[", "t", "]"}], ",", "t"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.753026941097069*^9, 
  3.7530269583466897`*^9}},ExpressionUUID->"2d904464-68b0-44a7-9f0d-\
fc48d354af64"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530269555727863`*^9, 3.7530269586755733`*^9}, 
   3.7530272465369406`*^9, 3.7531042352143793`*^9, 3.75903894645088*^9, 
   3.759062863937645*^9, 3.7614840984673543`*^9, 3.761561115762085*^9, 
   3.761657189527293*^9, 3.7616682259958873`*^9, 3.7619035365080166`*^9, 
   3.761978790947689*^9, 
   3.7620869381597633`*^9},ExpressionUUID->"7b5355a7-16f2-4b16-810b-\
d036eaab194a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HL", "=", 
   RowBox[{"H0", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}], "+", "\[CapitalOmega]\[CapitalLambda]0"}]]}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7530269935173016`*^9, 3.7530269990121403`*^9}, {
  3.7531100904488335`*^9, 3.75311009680774*^9}, {3.753110167300049*^9, 
  3.753110168255074*^9}},ExpressionUUID->"a426c4b3-fa7e-4a07-95b8-\
1495d862fcff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqscal1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"J0", "/", 
     RowBox[{"a", "^", "3"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.753104366141808*^9, 
  3.753104373882861*^9}},ExpressionUUID->"45d62a8b-6827-401b-9eea-\
444aa0755ee9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"eqscal1", "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.753105476066646*^9, {3.753105587345478*^9, 
   3.7531055878734922`*^9}},ExpressionUUID->"59157c93-4757-4616-9b9c-\
abcadfdaa341"],

Cell[BoxData[
 RowBox[{
  FractionBox["J0", 
   SuperscriptBox["a", "3"]], "-", 
  RowBox[{"6", " ", "H0", " ", "X", " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{3.753105476553343*^9, 3.753105588370403*^9, 
  3.753110137299548*^9, 3.7531101713727765`*^9, 3.759038953745048*^9, 
  3.7590628676254687`*^9, 3.7590650663901415`*^9, 3.7614841029125395`*^9, 
  3.761496795295622*^9, 3.761561142447031*^9, 3.7616485393837657`*^9, 
  3.7616551514698305`*^9, 3.7616571929155607`*^9, 3.7616682298153048`*^9, 
  3.761903540578003*^9, 3.7619787946878304`*^9, 
  3.762086942039768*^9},ExpressionUUID->"30000aa3-e6c7-49f4-b7a2-\
aa5b065a071e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"3", "eqdes21"}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105447459355*^9, 3.7531054645662947`*^9}, {
  3.753105590708206*^9, 
  3.753105593623171*^9}},ExpressionUUID->"bc44f4ad-09ad-40f8-859c-\
e7cd7c14c61f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", "H0", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7531045533364906`*^9, {3.753105451522622*^9, 3.753105464850565*^9}, 
   3.7531055941314063`*^9, 3.753110138855093*^9, 3.753110172774557*^9, 
   3.759038954745015*^9, 3.7590628695243273`*^9, 3.759065067294776*^9, 
   3.7614841070195956`*^9, 3.7614967962610826`*^9, 3.7615611452468944`*^9, 
   3.761648540363484*^9, 3.7616551555796213`*^9, 3.7616571937903814`*^9, 
   3.7616682307877164`*^9, 3.76190354146287*^9, 3.761978796487605*^9, 
   3.7620869430265813`*^9},ExpressionUUID->"6991b267-84cc-4e6d-818e-\
5f6c64ad9c91"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"a", "^", "2"}], " ", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.753105511622341*^9, 
  3.753105522319375*^9}},ExpressionUUID->"5f443977-0048-4641-b9cd-\
6375ad5dbd0c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sola", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"H", "[", "X", "]"}], "^", "2"}], "\[Equal]", 
      RowBox[{"HL", "^", "2"}]}], ",", "a"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7531055988246164`*^9, 3.753105653662197*^9}, 
   3.753110142857869*^9, {3.753110190369815*^9, 3.7531101909083433`*^9}, {
   3.761668244505377*^9, 
   3.761668251779143*^9}},ExpressionUUID->"39fc8bf9-ef2a-4cc6-b90f-\
a504c17d2df1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["H0", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalOmega]m0", 
      RowBox[{"1", "/", "3"}]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["H0", "2"]}], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       SuperscriptBox[
        RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], 
     RowBox[{"1", "/", "3"}]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.753105604228838*^9, 3.7531056542303205`*^9}, {
   3.7531101482612677`*^9, 3.75311019121295*^9}, 3.759038957249871*^9, 
   3.759062870985124*^9, 3.7590650702351136`*^9, 3.761484109257593*^9, 
   3.7614967990538764`*^9, 3.7615611636670475`*^9, 3.761648543876787*^9, 
   3.761655167799542*^9, 3.761657196070372*^9, {3.7616682334725285`*^9, 
   3.761668252499737*^9}, 3.7619035759839582`*^9, 3.761978798217918*^9, 
   3.76208694492002*^9},ExpressionUUID->"56795774-e090-4c96-9045-\
7108778f1b80"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQ11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ1", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ2", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]}], "Input",
 CellChangeTimes->{{3.75310563172922*^9, 
  3.7531056909235077`*^9}},ExpressionUUID->"ddc399d0-929a-4a40-a244-\
1a7fab1f013c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
    "\[CapitalOmega]m0"]}], "+", 
  FractionBox[
   RowBox[{"J0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "X", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"6", " ", "X", " ", 
   RowBox[{"H", "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.7614968009621935`*^9, 3.7615611652568974`*^9, 3.7616485457335176`*^9, 
   3.7616551703099627`*^9, 3.7616571968100815`*^9, 3.7616682573708363`*^9, 
   3.7619035774678493`*^9, 3.7619788001877985`*^9, 
   3.762086946985115*^9},ExpressionUUID->"e3834f76-6f4e-4810-ab95-\
2589b1015621"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.7614968009621935`*^9, 3.7615611652568974`*^9, 3.7616485457335176`*^9, 
   3.7616551703099627`*^9, 3.7616571968100815`*^9, 3.7616682573708363`*^9, 
   3.7619035774678493`*^9, 3.7619788001877985`*^9, 
   3.7620869471042876`*^9},ExpressionUUID->"011d93df-dc93-4b56-b624-\
72fc4622ad81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SqrtBox["2"], " ", 
    SqrtBox["X"], "EQ11"}], "+", "EQ22"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{"solk", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"%", "\[Equal]", "0"}], ",", 
      RowBox[{"K", "[", "X", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.761655176199666*^9, 3.76165518363995*^9}, {
   3.761655266329954*^9, 3.7616553101898484`*^9}, {3.7616572817705436`*^9, 
   3.7616573063207617`*^9}, 
   3.7616682634104195`*^9},ExpressionUUID->"cb206038-4317-4a10-b20f-\
0aadeda3f877"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
   "\[CapitalOmega]m0"], "+", 
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "X", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"K", "[", "X", "]"}]}]], "Output",
 CellChangeTimes->{{3.761655180279476*^9, 3.7616551840718074`*^9}, {
   3.7616552766299005`*^9, 3.761655310609615*^9}, 3.7616572003952436`*^9, {
   3.761657287790165*^9, 3.761657307140463*^9}, 3.7616682642803464`*^9, 
   3.761903599647788*^9, 3.7619788032683225`*^9, 
   3.7620869492300086`*^9},ExpressionUUID->"0ab5e863-0406-467a-a708-\
7d25789d915e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
    "-", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", "J0", " ", 
      SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
     "\[CapitalOmega]m0"], "+", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", "J0", " ", 
      SqrtBox["X"], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "X", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761655180279476*^9, 3.7616551840718074`*^9}, {
   3.7616552766299005`*^9, 3.761655310609615*^9}, 3.7616572003952436`*^9, {
   3.761657287790165*^9, 3.761657307140463*^9}, 3.7616682642803464`*^9, 
   3.761903599647788*^9, 3.7619788032683225`*^9, 
   3.762086949290313*^9},ExpressionUUID->"29434768-bbe0-4e31-824e-\
a13ac42dd4be"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQ11", "/.", 
   RowBox[{"D", "[", 
    RowBox[{"solk", ",", "X"}], "]"}]}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{"solG3X", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"%", "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "'"}], "[", "X", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "->", 
   RowBox[{"Integrate", "[", 
    RowBox[{
     RowBox[{"solG3X", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X"}], "]"}]}], 
  "}"}]}], "Input",
 CellChangeTimes->{{3.76165531324988*^9, 3.7616553818700523`*^9}, {
  3.7616554264000854`*^9, 3.761655426939768*^9}, {3.7616554687498984`*^9, 
  3.7616554706499343`*^9}, {3.76166828772336*^9, 3.7616682933385134`*^9}, {
  3.7616683533156605`*^9, 
  3.7616683606201887`*^9}},ExpressionUUID->"df192910-b439-4888-a3eb-\
1efe028b914a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", "X", " ", 
   RowBox[{"H", "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  FractionBox[
   RowBox[{"4", " ", "J0", " ", "X", " ", 
    RowBox[{"H", "[", "X", "]"}], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}]], "Output",
 CellChangeTimes->{{3.761655305460038*^9, 3.7616553835597706`*^9}, 
   3.761655427304183*^9, 3.761655471509678*^9, 3.7616572033002977`*^9, 
   3.761668295705279*^9, 3.7616683539958076`*^9, 3.7616687189076176`*^9, 
   3.761903601692958*^9, 3.7619788312978864`*^9, 
   3.7620869503401613`*^9},ExpressionUUID->"fb0f4aa8-51e4-49cc-9823-\
2a422449b6a4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "J0", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], 
     RowBox[{"3", " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761655305460038*^9, 3.7616553835597706`*^9}, 
   3.761655427304183*^9, 3.761655471509678*^9, 3.7616572033002977`*^9, 
   3.761668295705279*^9, 3.7616683539958076`*^9, 3.7616687189076176`*^9, 
   3.761903601692958*^9, 3.7619788312978864`*^9, 
   3.7620869503497753`*^9},ExpressionUUID->"dd039e9f-fb8e-4837-9343-\
042652ea5c15"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", "J0", " ", 
      RowBox[{"H", "[", "X", "]"}]}], 
     RowBox[{"3", " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761655305460038*^9, 3.7616553835597706`*^9}, 
   3.761655427304183*^9, 3.761655471509678*^9, 3.7616572033002977`*^9, 
   3.761668295705279*^9, 3.7616683539958076`*^9, 3.7616687189076176`*^9, 
   3.761903601692958*^9, 3.7619788312978864`*^9, 
   3.76208695036215*^9},ExpressionUUID->"e2e9ddf2-8f73-451d-a44c-\
3afe48ff9f5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cs2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"4", " ", 
                    SqrtBox["2"], " ", 
                    SqrtBox["X"], " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "a", "]"}]}], "+", 
                    RowBox[{"KX", "[", "t", "]"}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], "+", 
                    RowBox[{"X", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    SuperscriptBox[
                    RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
                    RowBox[{"2", " ", "a", " ", 
                    RowBox[{"H", "[", "a", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "a", "]"}]}], "+", 
                    RowBox[{"X", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"G3X", "[", "t", "]"}]}], "+", 
                    RowBox[{"X", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
                    ")"}]}], ")"}], "/", 
                    RowBox[{"(", 
                    RowBox[{"X", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", "X", " ", 
                    SuperscriptBox[
                    RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    SuperscriptBox["k", "2"], "+", 
                    RowBox[{"12", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    RowBox[{"H", "[", "a", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"H", "[", "a", "]"}], "-", 
                    RowBox[{"a", " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}]}], 
                    ")"}]}], "+", 
                    RowBox[{
                    SuperscriptBox["a", "2"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    SqrtBox["2"], " ", 
                    SuperscriptBox["X", 
                    RowBox[{"3", "/", "2"}]], " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "a", "]"}]}], "+", 
                    RowBox[{"KX", "[", "t", "]"}], "+", 
                    RowBox[{"2", " ", "X", " ", 
                    RowBox[{"KXX", "[", "t", "]"}]}]}], ")"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], "+", 
                    RowBox[{"2", " ", "X", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    "+", 
                    RowBox[{"2", " ", 
                    SuperscriptBox["a", "2"], " ", 
                    SqrtBox["X"], " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", 
                    SqrtBox["X"]}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    RowBox[{"KXX", "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", "X", " ", 
                    RowBox[{"KXXX", "[", "t", "]"}]}]}], ")"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"6", " ", "X", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "a", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SqrtBox["X"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"H", "[", "a", "]"}], "-", 
                    RowBox[{"a", " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}], 
                    "-", 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                    "+", 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{"H", "[", "a", "]"}], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"KX", "[", "t", "]"}]}], "+", 
                    RowBox[{"X", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"KXX", "[", "t", "]"}], "-", 
                    RowBox[{"6", " ", "X", " ", 
                    RowBox[{"G3XXX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/.", "des3"}], "/.",
                   "solfp2"}], "/.", 
                 RowBox[{
                  RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
                  RowBox[{"H", "[", "X", "]"}]}]}], "/.", 
                RowBox[{
                 RowBox[{
                  RowBox[{"H", "'"}], "[", "a", "]"}], "\[Rule]", 
                 RowBox[{"D", "[", 
                  RowBox[{"HL", ",", "a"}], "]"}]}]}], "/.", "sola"}], "/.", 
              RowBox[{
               RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", 
               RowBox[{
                RowBox[{"G3", "'''"}], "[", "X", "]"}]}]}], "/.", 
             RowBox[{
              RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", 
              RowBox[{
               RowBox[{"K", "'''"}], "[", "X", "]"}]}]}], "/.", "solG3X"}], "/.", 
           RowBox[{"D", "[", 
            RowBox[{"solG3X", ",", "X"}], "]"}]}], "/.", 
          RowBox[{"D", "[", 
           RowBox[{"solG3X", ",", 
            RowBox[{"{", 
             RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], "/.", "solk"}], "/.", 
        
        RowBox[{"D", "[", 
         RowBox[{"solk", ",", "X"}], "]"}]}], "/.", 
       RowBox[{"D", "[", 
        RowBox[{"solk", ",", 
         RowBox[{"{", 
          RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], "/.", 
      RowBox[{"D", "[", 
       RowBox[{"solk", ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "3"}], "}"}]}], "]"}]}], "//", "FullSimplify"}], "//",
     "PowerExpand"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7616572213602753`*^9, 3.7616572691203794`*^9}, {
  3.761657301900629*^9, 3.761657313970295*^9}, {3.7616687872573195`*^9, 
  3.761668790630724*^9}, {3.761668830339209*^9, 3.761668865133524*^9}, {
  3.761668898057623*^9, 3.7616689327810307`*^9}, {3.7616689896005125`*^9, 
  3.7616689951447697`*^9}, {3.761669047542927*^9, 3.7616690907788553`*^9}, {
  3.7616691441019487`*^9, 3.7616691626923885`*^9}, {3.7616692153956327`*^9, 
  3.7616692278813505`*^9}, {3.761669577739636*^9, 
  3.7616695891668243`*^9}},ExpressionUUID->"91157d42-555d-4417-a144-\
e434dec362ad"],

Cell[BoxData[
 RowBox[{"-", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"3", " ", 
      SuperscriptBox["H0", 
       RowBox[{"4", "/", "3"}]], " ", 
      SuperscriptBox["\[CapitalOmega]m0", 
       RowBox[{"2", "/", "3"}]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"9", " ", 
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           RowBox[{"9", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "X", "]"}], "2"]}], "+", 
           RowBox[{"4", " ", "X", " ", 
            RowBox[{"H", "[", "X", "]"}], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
        RowBox[{"6", " ", "X", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           SuperscriptBox[
            RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["H0", "2"], " ", "J0", " ", 
            SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
           RowBox[{
            SqrtBox["2"], " ", 
            SuperscriptBox["H0", "4"], " ", "\[CapitalOmega]m0", " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           RowBox[{"J0", " ", 
            SqrtBox["X"], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "X", "]"}], "2"]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"4", " ", "J0", " ", 
         SuperscriptBox["X", 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"H", "[", "X", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "X", "]"}], "2"]}], "+", 
        RowBox[{"2", " ", "J0", " ", 
         SuperscriptBox["X", 
          RowBox[{"3", "/", "2"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           SuperscriptBox[
            RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"4", " ", "J0", " ", 
      SuperscriptBox["X", 
       RowBox[{"3", "/", "2"}]], " ", 
      SuperscriptBox[
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "X", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", 
         SuperscriptBox["H0", 
          RowBox[{"4", "/", "3"}]], " ", "X", " ", 
         SuperscriptBox["\[CapitalOmega]m0", 
          RowBox[{"2", "/", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           SuperscriptBox[
            RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "X", "]"}], "2"]}], "+", 
        RowBox[{"4", " ", 
         SuperscriptBox["k", "2"], " ", "X", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["H0", "2"]}], " ", 
             "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
            SuperscriptBox[
             RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], 
          RowBox[{"2", "/", "3"}]], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "X", "]"}], "2"]}], "+", 
        RowBox[{"48", " ", 
         SuperscriptBox["H0", 
          RowBox[{"4", "/", "3"}]], " ", 
         SuperscriptBox["X", "2"], " ", 
         SuperscriptBox["\[CapitalOmega]m0", 
          RowBox[{"2", "/", "3"}]], " ", 
         RowBox[{"H", "[", "X", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "X", "]"}], "3"]}], "+", 
        RowBox[{"18", " ", 
         SuperscriptBox["H0", 
          RowBox[{"4", "/", "3"}]], " ", "X", " ", 
         SuperscriptBox["\[CapitalOmega]m0", 
          RowBox[{"2", "/", "3"}]], " ", 
         RowBox[{"H", "[", "X", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           SuperscriptBox[
            RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"9", " ", 
         SuperscriptBox["H0", 
          RowBox[{"4", "/", "3"}]], " ", 
         SuperscriptBox["\[CapitalOmega]m0", 
          RowBox[{"2", "/", "3"}]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
           SuperscriptBox[
            RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            RowBox[{"H", "[", "X", "]"}]}], "+", 
           RowBox[{"4", " ", 
            SuperscriptBox["X", "2"], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}]}], 
       ")"}]}], ")"}]}], ")"}]}]], "Output",
 CellChangeTimes->{
  3.761669190384582*^9, {3.7616692253102193`*^9, 3.7616692427634735`*^9}, 
   3.761669612989208*^9, 
   3.7619036904880304`*^9},ExpressionUUID->"a38e95b1-c340-4675-a12a-\
8d5cde78f54e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]K", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "X", 
       RowBox[{"(", 
        RowBox[{"G2X", "+", 
         RowBox[{"2", "X", " ", "G2XX"}]}], ")"}]}], "+", 
      RowBox[{"12", 
       RowBox[{"H", "[", "X", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", 
       RowBox[{"(", 
        RowBox[{"G3X", "+", 
         RowBox[{"X", " ", "G3XX"}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"H", "[", "X", "]"}], "^", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]B", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", " ", "G3X"}], ")"}], 
    "/", 
    RowBox[{"H", "[", "X", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]K1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"\[Alpha]K", "/.", 
          RowBox[{"G2X", "\[Rule]", 
           RowBox[{
            RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
         RowBox[{"G2XX", "\[Rule]", 
          RowBox[{
           RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
        RowBox[{"G3X", "\[Rule]", 
         RowBox[{"solG3X", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "/.", 
       RowBox[{"G3XX", "\[Rule]", 
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"solG3X", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X"}], "]"}]}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
       SqrtBox[
        RowBox[{"2", "X"}]]}]}], "/.", 
     RowBox[{"Flatten", "[", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{"solk", ",", 
          RowBox[{"{", 
           RowBox[{"X", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}]}], "//", 
    "FullSimplify"}], "//", "Expand"}]}], "\[IndentingNewLine]", 
 RowBox[{"\[Alpha]B1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]B", "/.", 
         RowBox[{"G2X", "\[Rule]", 
          RowBox[{
           RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
        RowBox[{"G2XX", "\[Rule]", 
         RowBox[{
          RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
       RowBox[{"G3X", "\[Rule]", 
        RowBox[{"solG3X", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "2"}], "]"}], "]"}]}]}], "/.", 
      RowBox[{"G3XX", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"solG3X", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", "X"}], "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
      SqrtBox[
       RowBox[{"2", "X"}]]}]}], "/.", 
    RowBox[{"Flatten", "[", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"solk", ",", 
         RowBox[{"{", 
          RowBox[{"X", ",", "n"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "0", ",", "3"}], "}"}]}], "]"}], "]"}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"D2", "=", 
  RowBox[{
   RowBox[{"\[Alpha]K1", "+", 
    RowBox[{
     FractionBox["3", "2"], 
     RowBox[{"\[Alpha]B1", "^", "2"}]}]}], "//", "Expand"}]}]}], "Input",
 CellChangeTimes->{{3.7614858410119333`*^9, 3.761485936096927*^9}, {
  3.761486022507202*^9, 3.7614860237974825`*^9}, {3.7614975151724834`*^9, 
  3.761497522781365*^9}, {3.7615617203869843`*^9, 3.7615617762767396`*^9}, {
  3.761561820466493*^9, 3.7615618238565245`*^9}, {3.761655478239848*^9, 
  3.7616555152901545`*^9}, {3.7619089462963123`*^9, 3.761908951276369*^9}, {
  3.761978855877634*^9, 
  3.7619789472675467`*^9}},ExpressionUUID->"1996e739-b68e-4f65-be70-\
a29dc218055e"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"4", " ", 
    SqrtBox["2"], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
    RowBox[{"H", "[", "X", "]"}]}]], "+", 
  FractionBox[
   RowBox[{"8", " ", 
    SqrtBox["2"], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "X", "]"}], "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.7619089676861506`*^9, {3.7619789333079944`*^9, 3.761978947732628*^9}, 
   3.7619812092693415`*^9, 
   3.7620869565199156`*^9},ExpressionUUID->"e680d066-dab0-499d-baa2-\
f4c548fe2221"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"4", " ", 
    SqrtBox["2"], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
    RowBox[{"H", "[", "X", "]"}]}]]}]], "Output",
 CellChangeTimes->{
  3.7619089676861506`*^9, {3.7619789333079944`*^9, 3.761978947732628*^9}, 
   3.7619812092693415`*^9, 
   3.7620869565301666`*^9},ExpressionUUID->"0033e0e4-4967-451d-a342-\
094e8afbca80"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"4", " ", 
    SqrtBox["2"], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{"3", "/", "2"}]], " ", 
    RowBox[{
     SuperscriptBox["H", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
    RowBox[{"H", "[", "X", "]"}]}]], "+", 
  FractionBox[
   RowBox[{"16", " ", 
    SuperscriptBox["J0", "2"], " ", 
    SuperscriptBox["X", "3"], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "2"]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["H0", "4"], " ", 
    SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "X", "]"}], "2"]}]], "+", 
  FractionBox[
   RowBox[{"8", " ", 
    SqrtBox["2"], " ", "J0", " ", 
    SuperscriptBox["X", 
     RowBox[{"5", "/", "2"}]], " ", 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "X", "]"}], "2"]}]]}]], "Output",
 CellChangeTimes->{
  3.7619089676861506`*^9, {3.7619789333079944`*^9, 3.761978947732628*^9}, 
   3.7619812092693415`*^9, 
   3.762086956554529*^9},ExpressionUUID->"25d1b29e-897e-4606-b0ed-\
6395534a5963"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{"X", "\[Equal]", 
    FractionBox["c0", 
     SuperscriptBox[
      RowBox[{"H", "[", "a", "]"}], "n"]]}], ",", 
   RowBox[{"H", "[", "a", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.762086998204835*^9, 
  3.7620870183798757`*^9}},ExpressionUUID->"8a59054b-76bb-4d03-a1ee-\
39baf27fde1f"],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,146,3,17629146601644241660,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7620870188700395`*^9},ExpressionUUID->"7f27ebfc-516c-4009-bb54-\
1ad1714757f9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
    SuperscriptBox[
     RowBox[{"(", 
      FractionBox["X", "c0"], ")"}], 
     RowBox[{
      RowBox[{"-", "1"}], "/", "n"}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7620870188801203`*^9},ExpressionUUID->"21c42717-20ce-4502-a338-\
7f0671f34307"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"solh", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "[", "X", "]"}], "\[Rule]", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["X", "c0"], ")"}], 
      RowBox[{
       RowBox[{"-", "1"}], "/", "n"}]]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.7620870304300604`*^9},ExpressionUUID->"777d1cca-9020-4420-a818-\
3ac9a8d7d700"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\[Alpha]K1", ",", "\[Alpha]B1"}], "}"}], "/.", "solh"}], "/.", 
     RowBox[{"D", "[", 
      RowBox[{"solh", ",", "X"}], "]"}]}], "/.", 
    RowBox[{"X", "->", 
     FractionBox["c0", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], "n"]]}]}], "//", "FullSimplify"}], "//", 
  "PowerExpand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"%", "/.", 
      RowBox[{"c0", "\[Rule]", 
       RowBox[{"C0", " ", 
        SuperscriptBox["H0", 
         RowBox[{"n", "+", "2"}]]}]}]}], "/.", 
     RowBox[{"J0", "\[Rule]", "H0"}]}], "/.", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"H0", " ", 
      RowBox[{"h", "[", "a", "]"}]}]}]}], "//", "PowerExpand"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7620870513404655`*^9, 3.762087096140051*^9}, {
  3.7620872162902007`*^9, 
  3.7620872507146697`*^9}},ExpressionUUID->"6de30c6e-f598-416b-a654-\
ced41b6dd5b8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"4", " ", 
      SqrtBox["2"], " ", 
      SqrtBox["c0"], " ", "J0", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"-", "n"}], "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", 
      SuperscriptBox["n", "2"], " ", "\[CapitalOmega]m0"}]]}], ",", 
   FractionBox[
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     SqrtBox["c0"], " ", "J0", " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "a", "]"}], 
      RowBox[{
       RowBox[{"-", "n"}], "/", "2"}]]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["H0", "2"], " ", "n", " ", "\[CapitalOmega]m0"}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7620870409724894`*^9, 3.762087096650239*^9}, {
  3.7620872318199663`*^9, 
  3.762087251130141*^9}},ExpressionUUID->"85035bb7-e426-41dd-b691-\
17a360dff8c8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"4", " ", 
      SqrtBox["2"], " ", 
      SqrtBox["C0"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "n"}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"h", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"-", "n"}], "/", "2"}]]}], 
     RowBox[{
      SuperscriptBox["n", "2"], " ", "\[CapitalOmega]m0"}]]}], ",", 
   FractionBox[
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     SqrtBox["C0"], " ", 
     SuperscriptBox[
      RowBox[{"h", "[", "a", "]"}], 
      RowBox[{
       RowBox[{"-", "n"}], "/", "2"}]]}], 
    RowBox[{"3", " ", "n", " ", "\[CapitalOmega]m0"}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7620870409724894`*^9, 3.762087096650239*^9}, {
  3.7620872318199663`*^9, 
  3.762087251195247*^9}},ExpressionUUID->"1b38ed92-64ed-4eab-8220-\
90949d545a4c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"4", " ", 
     SqrtBox["2"], " ", 
     SqrtBox["c0"], " ", "J0", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "2"}], "+", "n"}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "a", "]"}], 
      RowBox[{
       RowBox[{"-", "n"}], "/", "2"}]]}], 
    RowBox[{
     SuperscriptBox["H0", "2"], " ", 
     SuperscriptBox["n", "2"], " ", "\[CapitalOmega]m0"}]]}], "//", 
  "CForm"}]], "Input",
 CellChangeTimes->{{3.762088074420847*^9, 
  3.7620880977052145`*^9}},ExpressionUUID->"78a104fc-7713-4e6d-ab16-\
afa2e8b023cb"],

Cell["\<\
(-4*Sqrt(2)*Sqrt(c0)*J0*(-2 + n))/
   (Power(H0,2)*Power(n,2)*\[CapitalOmega]m0*Power(H(a),n/2.))\
\>", "Output",
 CellChangeTimes->{{3.7620880779808006`*^9, 
  3.762088098135083*^9}},ExpressionUUID->"296af237-5622-4565-888b-\
a2953eb942c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"4", " ", 
    SqrtBox["2"], " ", 
    SqrtBox["c0"], " ", "J0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "a", "]"}], 
     RowBox[{
      RowBox[{"-", "n"}], "/", "2"}]]}], 
   RowBox[{"3", " ", 
    SuperscriptBox["H0", "2"], " ", "n", " ", "\[CapitalOmega]m0"}]], "//", 
  "CForm"}]], "Input",ExpressionUUID->"6389bb1d-a829-4854-a4de-1343b8685128"],

Cell["\<\
(4*Sqrt(2)*Sqrt(c0)*J0)/
   (3.*Power(H0,2)*n*\[CapitalOmega]m0*Power(H(a),n/2.))\
\>", "Output",
 CellChangeTimes->{
  3.762088192912841*^9},ExpressionUUID->"1758362a-842c-40ff-8fe1-\
8602196e10c3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"solk", "/.", 
       RowBox[{"c0", "\[Rule]", 
        RowBox[{"C0", " ", 
         SuperscriptBox["H0", 
          RowBox[{"n", "+", "2"}]]}]}]}], "/.", 
      RowBox[{"J0", "\[Rule]", "H0"}]}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "X", "]"}], "\[Rule]", 
      RowBox[{"H0", " ", 
       RowBox[{"h", "[", "X", "]"}]}]}]}], "//", "PowerExpand"}], "//", 
   "FullSimplify"}], "//", "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"solG3X", "/.", 
       RowBox[{"c0", "\[Rule]", 
        RowBox[{"C0", " ", 
         SuperscriptBox["H0", 
          RowBox[{"n", "+", "2"}]]}]}]}], "/.", 
      RowBox[{"J0", "\[Rule]", "H0"}]}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "X", "]"}], "\[Rule]", 
      RowBox[{"H0", " ", 
       RowBox[{"h", "[", "X", "]"}]}]}]}], "//", "PowerExpand"}], "//", 
   "FullSimplify"}], "//", "Expand"}]}], "Input",
 CellChangeTimes->{{3.7620872795754175`*^9, 
  3.762087409624938*^9}},ExpressionUUID->"5a5c5c1d-e251-4c1c-bb0d-\
2fcd9efe4590"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
    "-", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", "H0", " ", 
      SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
     "\[CapitalOmega]m0"], "+", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", "H0", " ", 
      SqrtBox["X"], " ", 
      SuperscriptBox[
       RowBox[{"h", "[", "X", "]"}], "2"]}], "\[CapitalOmega]m0"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7620872940951977`*^9, 3.7620873136125183`*^9}, 
   3.762087345380034*^9, {3.762087381211796*^9, 
   3.7620874104951305`*^9}},ExpressionUUID->"2ce542e2-5ba5-4c42-b8fb-\
8237c37c651b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"2", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}], 
     RowBox[{"3", " ", "H0", " ", "\[CapitalOmega]m0"}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{{3.7620872940951977`*^9, 3.7620873136125183`*^9}, 
   3.762087345380034*^9, {3.762087381211796*^9, 
   3.762087410512351*^9}},ExpressionUUID->"05ad1cc0-5579-4416-bb2a-\
03e54d4f62bd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753103919594767*^9, 
  3.753103921703641*^9}},ExpressionUUID->"c046dce7-0bf4-4f19-b4b5-\
9e91befd731a"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Designer", " ", "3", 
    RowBox[{"c", ":", " ", "K"}]}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"K", 
       RowBox[{"(", "X", ")"}]}], " ", "&"}], " ", "G"}], "=", 
    RowBox[{"G", 
     RowBox[{"(", "X", ")"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753007025810972*^9, 3.75300703764139*^9}, 
   3.7530074340625987`*^9, {3.7531040292255526`*^9, 3.753104034244852*^9}, 
   3.7615610651974173`*^9, 
   3.7619130802176104`*^9},ExpressionUUID->"2e71b9a0-c3cf-4e62-8259-\
9c3e1528a2d3"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"des3", ",", "eqdes3", ",", "solf", ",", "eqg3"}], "]"}]], "Input",
 CellChangeTimes->{{3.7530268091552315`*^9, 3.753026828954541*^9}, {
  3.753104074960581*^9, 
  3.75310407646391*^9}},ExpressionUUID->"9f6f8c4f-7ff2-4799-91ab-\
5c4a2a14fa79"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "''"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"K", "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7530071402313166`*^9, 3.7530071520712533`*^9}, {
  3.7530073980312834`*^9, 3.7530074020115433`*^9}, {3.7530267947608924`*^9, 
  3.7530267954046335`*^9}, {3.7531040546639605`*^9, 
  3.753104106472458*^9}},ExpressionUUID->"18cf4007-8932-4eaa-a685-\
e103fc274b63"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["2", "3"], "eq00"}], "/.", "des3"}], "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "t", "]"}], "\[Rho]c"}]}]}], "/.", 
    RowBox[{"t", "\[Rule]", "a"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.753007162370982*^9, 3.7530071639310336`*^9}, {
   3.753007412681366*^9, 3.753007413180858*^9}, {3.7530074538413053`*^9, 
   3.7530074742035904`*^9}, {3.7530268519539814`*^9, 3.753026864814765*^9}, 
   3.7531041210612183`*^9},ExpressionUUID->"98a3facb-150e-4f28-b5c7-\
244de884f50c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "-", 
  FractionBox[
   RowBox[{"K", "[", "X", "]"}], "3"], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{
   FractionBox["2", "3"], " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530070956712055`*^9, 3.7530071645856547`*^9, 3.753007359271302*^9, {
   3.7530074043412685`*^9, 3.7530074136313868`*^9}, {3.7530074566310596`*^9, 
   3.75300747484136*^9}, 3.753009479731315*^9, 3.753010399292014*^9, 
   3.7530259723809757`*^9, 3.7530267991530056`*^9, {3.7530268472211742`*^9, 
   3.7530268654142923`*^9}, 3.7530272317890463`*^9, 3.753104123529351*^9, 
   3.7531100768157735`*^9, 3.7590389370428114`*^9, 3.759062854815488*^9, 
   3.7590650583349285`*^9, 3.761484087809585*^9, 3.7614967834812107`*^9, 
   3.7615611005792503`*^9, 3.7619137072470026`*^9, 3.7619151338674216`*^9, 
   3.761926822908912*^9, 3.7619276185614195`*^9, 
   3.7619285015510015`*^9},ExpressionUUID->"ce4b3507-7231-407f-9c41-\
503c61d0bbc1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"eqscal", "/.", "des3"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], "/.", 
       RowBox[{"G", "\[Rule]", 
        FractionBox[
         RowBox[{"3", 
          RowBox[{"H0", "^", "2"}]}], 
         RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "//", "Expand"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7530072546512675`*^9, {3.753007978861573*^9, 3.7530079844517*^9}, {
   3.75300819971229*^9, 3.7530082001136017`*^9}, {3.7530268680858884`*^9, 
   3.7530268991518917`*^9}, 
   3.753104155438074*^9},ExpressionUUID->"264207c3-f8bb-422c-8ee9-\
db4ea6f6a764"],

Cell[BoxData[
 RowBox[{
  RowBox[{"18", " ", "X", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"6", " ", "a", " ", "X", " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "a", "]"}]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{
       SuperscriptBox["K", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G3", "\[Prime]",
          MultilineFunction->None], "[", "X", "]"}], "+", 
        RowBox[{"X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530072553012924`*^9, 3.75300736155129*^9, 3.7530075454953737`*^9, {
   3.7530079799828978`*^9, 3.753007985875571*^9}, 3.7530082007913494`*^9, 
   3.753009481096099*^9, 3.7530104003049483`*^9, 3.7530259745347195`*^9, 
   3.7530268004690237`*^9, {3.7530268708900013`*^9, 3.7530269002721505`*^9}, 
   3.7530272332545967`*^9, 3.7531041604460745`*^9, 3.753110080239015*^9, 
   3.759038938386591*^9, 3.759062856120221*^9, 3.759065059235174*^9, 
   3.761484089547599*^9, 3.761496785510987*^9, 3.7615611030372133`*^9, 
   3.761913708409008*^9, 3.761915137227212*^9, 3.7619268270132484`*^9, 
   3.7619276187338*^9, 
   3.7619285017210965`*^9},ExpressionUUID->"0f724e8d-e645-439c-a035-\
408844c34f56"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solfp2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"eqdes22", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",Express\
ionUUID->"ce18cca5-f23c-49aa-8611-806e51be9ab0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6", " ", "X", " ", 
         RowBox[{"H", "[", "a", "]"}], " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}], "+", 
        RowBox[{"2", " ", "a", " ", "X", " ", 
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "a", "]"}]}], "+", 
        RowBox[{
         SqrtBox["2"], " ", 
         SqrtBox["X"], " ", 
         RowBox[{
          SuperscriptBox["K", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], 
     RowBox[{
      RowBox[{
       SuperscriptBox["K", "\[Prime]",
        MultilineFunction->None], "[", "X", "]"}], "+", 
      RowBox[{"6", " ", 
       SqrtBox["2"], " ", 
       SqrtBox["X"], " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["G3", "\[Prime]",
           MultilineFunction->None], "[", "X", "]"}], "+", 
         RowBox[{"X", " ", 
          RowBox[{
           SuperscriptBox["G3", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "X", "]"}]}]}], ")"}]}], "+", 
      RowBox[{"2", " ", "X", " ", 
       RowBox[{
        SuperscriptBox["K", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "X", "]"}]}]}]]}]}], "}"}]], "Output",\

 CellChangeTimes->{3.761915249979834*^9, 3.7619268285570655`*^9, 
  3.7619276188861885`*^9, 
  3.761928501873377*^9},ExpressionUUID->"882cd167-9e4f-4a17-a644-\
f251e5d7a3b4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Ptot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
    "des3"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.753104165454965*^9},ExpressionUUID->"88766868-8f33-4556-bbf1-\
e6420485990f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.753008288221882*^9, 3.753009482346419*^9, 
  3.7530104012915435`*^9, 3.753025976743453*^9, 3.7530269098180213`*^9, 
  3.75302723538494*^9, 3.753104184074131*^9, 3.7590389432772183`*^9, 
  3.7590628597555776`*^9, 3.759065062024963*^9, 3.76148409319717*^9, 
  3.761496788182303*^9, 3.7615611116570077`*^9, 3.761913711446867*^9, 
  3.7619151400072966`*^9},ExpressionUUID->"0abfc230-6131-411b-b68c-\
321503386152"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Jtot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
      "des3"}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}], "/.", 
   RowBox[{"t", "\[Rule]", "a"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.7530082969130588`*^9, 3.7530083295913944`*^9, {3.753026917538438*^9, 
   3.75302691893057*^9}, 
   3.753104219925988*^9},ExpressionUUID->"6adb290a-78ab-40df-9e02-\
de881cbb9811"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}]}], ",", "0", ",", "0", ",",
    "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7530082975415645`*^9, 3.753008330541541*^9, 3.7530094836722317`*^9, 
   3.7530104029223557`*^9, 3.753025977723363*^9, {3.7530269141756024`*^9, 
   3.753026919235218*^9}, 3.7530272363194532`*^9, {3.753104216959204*^9, 
   3.7531042204133034`*^9}, 3.759038944433468*^9, 3.759062860927602*^9, 
   3.759065062785056*^9, 3.761484094817444*^9, 3.76149678990131*^9, 
   3.7615611127072563`*^9, 3.761913712151559*^9, 
   3.761915140994841*^9},ExpressionUUID->"8bba2d6f-993c-4115-9127-\
f6e5dbc81700"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{"Raise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"J", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}],
         ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", "zeroorder"}], "//",
   "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7530083583919115`*^9, 3.753008383591753*^9}, 
   3.7530269380948334`*^9},ExpressionUUID->"8c25b43e-11c7-44ef-b634-\
f6a0aadbc7c6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"J", "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["J", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.753008368031542*^9, 3.75300838394143*^9}, 
   3.7530094861559353`*^9, 3.7530104039620748`*^9, 3.7530259792893887`*^9, {
   3.7530269237358108`*^9, 3.7530269389219027`*^9}, 3.7530272449852643`*^9, 
   3.7531042327702336`*^9, 3.7590389453865604`*^9, 3.7590628626477027`*^9, 
   3.7614840963873386`*^9, 3.7615611145971985`*^9, 3.7619137131269064`*^9, 
   3.7619151421078978`*^9},ExpressionUUID->"2609abda-a156-4995-9460-\
f65b93f570dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
        RowBox[{"a", "[", "t", "]"}]}], " ", 
       RowBox[{"J", "[", "t", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["J", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{"J", "[", "t", "]"}], ",", "t"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.753026941097069*^9, 
  3.7530269583466897`*^9}},ExpressionUUID->"6cbe7ba1-7e29-4057-bb0e-\
509c79202405"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530269555727863`*^9, 3.7530269586755733`*^9}, 
   3.7530272465369406`*^9, 3.7531042352143793`*^9, 3.75903894645088*^9, 
   3.759062863937645*^9, 3.7614840984673543`*^9, 3.761561115762085*^9, 
   3.7619137147220993`*^9, 
   3.7619151436097984`*^9},ExpressionUUID->"50582299-33f1-4673-a208-\
65c39aa689c2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HL", "=", 
   RowBox[{"H0", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}], "+", "\[CapitalOmega]\[CapitalLambda]0"}]]}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7530269935173016`*^9, 3.7530269990121403`*^9}, {
  3.7531100904488335`*^9, 3.75311009680774*^9}, {3.753110167300049*^9, 
  3.753110168255074*^9}},ExpressionUUID->"9c3f1a57-8d0a-4747-94b5-\
a264767e68a9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqscal1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", "X", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["G3", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "-", 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"], " ", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "X", "]"}]}], "+", 
    RowBox[{"J0", "/", 
     RowBox[{"a", "^", "3"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.753104366141808*^9, 
  3.753104373882861*^9}},ExpressionUUID->"8bcb7f7c-c40c-4a29-906b-\
0c203284ca71"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"eqscal1", "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.753105476066646*^9, {3.753105587345478*^9, 
   3.7531055878734922`*^9}},ExpressionUUID->"1bc4b3a7-831c-459a-a0e2-\
265e61e0d81c"],

Cell[BoxData[
 RowBox[{
  FractionBox["J0", 
   SuperscriptBox["a", "3"]], "-", 
  RowBox[{"6", " ", "H0", " ", "X", " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{3.753105476553343*^9, 3.753105588370403*^9, 
  3.753110137299548*^9, 3.7531101713727765`*^9, 3.759038953745048*^9, 
  3.7590628676254687`*^9, 3.7590650663901415`*^9, 3.7614841029125395`*^9, 
  3.761496795295622*^9, 3.761561142447031*^9, 3.761913718076908*^9, 
  3.761915148988073*^9, 3.7619268481740313`*^9, 3.7619276225030994`*^9, 
  3.7619285040600395`*^9},ExpressionUUID->"828b659f-8775-4ece-8471-\
e329fb48665c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"3", "eqdes21"}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105447459355*^9, 3.7531054645662947`*^9}, {
  3.753105590708206*^9, 
  3.753105593623171*^9}},ExpressionUUID->"18c8ff53-cb6f-40ff-a7ca-\
b3350a576c11"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", "H0", " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   SqrtBox[
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}]], 
   " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7531045533364906`*^9, {3.753105451522622*^9, 3.753105464850565*^9}, 
   3.7531055941314063`*^9, 3.753110138855093*^9, 3.753110172774557*^9, 
   3.759038954745015*^9, 3.7590628695243273`*^9, 3.759065067294776*^9, 
   3.7614841070195956`*^9, 3.7614967962610826`*^9, 3.7615611452468944`*^9, 
   3.7619137189083843`*^9, 3.761915150967121*^9, 3.761926849524723*^9, 
   3.7619276241284018`*^9, 
   3.761928505287078*^9},ExpressionUUID->"70f639f9-5dd3-418b-a6bd-\
ad627f2483bc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"a", "^", "2"}], " ", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.753105511622341*^9, 
  3.753105522319375*^9}},ExpressionUUID->"67b51265-ae10-4642-9ba0-\
f280ed1a4f4d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sola", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"H", "[", "X", "]"}], "^", "2"}], "\[Equal]", 
      RowBox[{"HL", "^", "2"}]}], ",", "a"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7531055988246164`*^9, 3.753105653662197*^9}, 
   3.753110142857869*^9, {3.753110190369815*^9, 3.7531101909083433`*^9}, {
   3.761913738929058*^9, 
   3.761913740217235*^9}},ExpressionUUID->"e9de9094-4763-426c-8ce8-\
e366505707d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["H0", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalOmega]m0", 
      RowBox[{"1", "/", "3"}]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["H0", "2"]}], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
       SuperscriptBox[
        RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}], 
     RowBox[{"1", "/", "3"}]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.753105604228838*^9, 3.7531056542303205`*^9}, {
   3.7531101482612677`*^9, 3.75311019121295*^9}, 3.759038957249871*^9, 
   3.759062870985124*^9, 3.7590650702351136`*^9, 3.761484109257593*^9, 
   3.7614967990538764`*^9, 3.7615611636670475`*^9, {3.7619137211867037`*^9, 
   3.7619137415700274`*^9}, 3.7619151535270824`*^9, 3.761926853050236*^9, 
   3.7619276259571133`*^9, 
   3.761928507257653*^9},ExpressionUUID->"1623bc67-fb7a-49ee-b884-\
fda7bb52a7cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQ11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ1", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ2", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]}], "Input",
 CellChangeTimes->{{3.75310563172922*^9, 
  3.7531056909235077`*^9}},ExpressionUUID->"d49d0c38-528f-45ab-beb0-\
ea8043cd728e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
    "\[CapitalOmega]m0"]}], "+", 
  FractionBox[
   RowBox[{"J0", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "X", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"6", " ", "X", " ", 
   RowBox[{"H", "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "-", 
  RowBox[{
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.7614968009621935`*^9, 3.7615611652568974`*^9, {3.761913722827035*^9, 
   3.7619137444466147`*^9}, 3.7619151549373565`*^9, 3.7619268588303785`*^9, 
   3.7619276285170555`*^9, 
   3.7619285088984566`*^9},ExpressionUUID->"a2293bb9-5b7c-4f8b-9c6d-\
bf1b629a70c5"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  RowBox[{"K", "[", "X", "]"}], "+", 
  RowBox[{"6", " ", 
   SqrtBox["2"], " ", 
   SuperscriptBox["X", 
    RowBox[{"3", "/", "2"}]], " ", 
   RowBox[{"H", "[", "X", "]"}], " ", 
   RowBox[{
    SuperscriptBox["G3", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}], "+", 
  RowBox[{"2", " ", "X", " ", 
   RowBox[{
    SuperscriptBox["K", "\[Prime]",
     MultilineFunction->None], "[", "X", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 3.75903895990613*^9, 
   3.7590628730297947`*^9, 3.7590650716849947`*^9, 3.7614841109523487`*^9, 
   3.7614968009621935`*^9, 3.7615611652568974`*^9, {3.761913722827035*^9, 
   3.7619137444466147`*^9}, 3.7619151549373565`*^9, 3.7619268588303785`*^9, 
   3.7619276285170555`*^9, 
   3.7619285089969807`*^9},ExpressionUUID->"b8a27272-fa7c-4b3a-ad20-\
04cf37da1ea5"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]K", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"2", "X", 
       RowBox[{"(", 
        RowBox[{"G2X", "+", 
         RowBox[{"2", "X", " ", "G2XX"}]}], ")"}]}], "+", 
      RowBox[{"12", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", 
       RowBox[{"(", 
        RowBox[{"G3X", "+", 
         RowBox[{"X", " ", "G3XX"}]}], ")"}]}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]B", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "X", " ", "G3X"}], ")"}], 
    "/", 
    RowBox[{"H", "[", "a", "]"}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.761915413709377*^9, 
  3.7619154229898157`*^9}},ExpressionUUID->"3decb33a-38ff-444a-a828-\
50f21981e6f1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cs2", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"4", " ", 
                SqrtBox["2"], " ", 
                SqrtBox["X"], " ", 
                RowBox[{"G3X", "[", "t", "]"}], " ", 
                RowBox[{"H", "[", "a", "]"}]}], "+", 
               RowBox[{"KX", "[", "t", "]"}], "+", 
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"G3X", "[", "t", "]"}], "+", 
                  RowBox[{"X", " ", 
                   RowBox[{"G3XX", "[", "t", "]"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"3", " ", 
                SuperscriptBox[
                 RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
               RowBox[{"2", " ", "a", " ", 
                RowBox[{"H", "[", "a", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["H", "\[Prime]",
                  MultilineFunction->None], "[", "a", "]"}]}], "+", 
               RowBox[{"X", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"KX", "[", "t", "]"}], "-", 
                  RowBox[{"2", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"G3X", "[", "t", "]"}]}], "+", 
                    RowBox[{"X", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}]}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
              ")"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"X", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "X", " ", 
                SuperscriptBox[
                 RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["k", "2"], "+", 
                  RowBox[{"12", " ", 
                   SuperscriptBox["a", "2"], " ", 
                   RowBox[{"H", "[", "a", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"H", "[", "a", "]"}], "-", 
                    RowBox[{"a", " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}]}], 
                 ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"6", " ", 
                   SqrtBox["2"], " ", 
                   SuperscriptBox["X", 
                    RowBox[{"3", "/", "2"}]], " ", 
                   RowBox[{"G3XX", "[", "t", "]"}], " ", 
                   RowBox[{"H", "[", "a", "]"}]}], "+", 
                  RowBox[{"KX", "[", "t", "]"}], "+", 
                  RowBox[{"2", " ", "X", " ", 
                   RowBox[{"KXX", "[", "t", "]"}]}]}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"KX", "[", "t", "]"}], "+", 
                  RowBox[{"2", " ", "X", " ", 
                   RowBox[{"G3XX", "[", "t", "]"}], " ", 
                   RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
               "+", 
               RowBox[{"2", " ", 
                SuperscriptBox["a", "2"], " ", 
                SqrtBox["X"], " ", 
                RowBox[{"G3X", "[", "t", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", 
                    SqrtBox["X"]}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"3", " ", 
                    RowBox[{"KXX", "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", "X", " ", 
                    RowBox[{"KXXX", "[", "t", "]"}]}]}], ")"}], " ", 
                   RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                  RowBox[{"6", " ", "X", " ", 
                   RowBox[{"G3XX", "[", "t", "]"}], " ", 
                   RowBox[{"H", "[", "a", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    SqrtBox["X"], " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"H", "[", "a", "]"}], "-", 
                    RowBox[{"a", " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}], 
                    "-", 
                    RowBox[{
                    SqrtBox["2"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
                  "+", 
                  RowBox[{
                   SqrtBox["2"], " ", 
                   RowBox[{"H", "[", "a", "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"5", " ", 
                    RowBox[{"KX", "[", "t", "]"}]}], "+", 
                    RowBox[{"X", " ", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"KXX", "[", "t", "]"}], "-", 
                    RowBox[{"6", " ", "X", " ", 
                    RowBox[{"G3XXX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}], ")"}]}], "/.", "des3"}], "/.",
          "solfp2"}], "/.", 
        RowBox[{
         RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
         RowBox[{"H", "[", "X", "]"}]}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"H", "'"}], "[", "a", "]"}], "\[Rule]", 
        RowBox[{"D", "[", 
         RowBox[{"HL", ",", "a"}], "]"}]}]}], "/.", "sola"}], "/.", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"G3", "'''"}], "[", "X", "]"}]}]}], "/.", 
    RowBox[{
     RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"K", "'''"}], "[", "X", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.761915256527565*^9, 3.7619152690397453`*^9}, {
  3.7619153170426593`*^9, 
  3.761915318449913*^9}},ExpressionUUID->"5a9bd638-0394-4804-89f5-\
10dd69fe994c"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    SqrtBox["2"], " ", 
    SqrtBox["X"], "EQ11"}], "+", "EQ22"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"%", "\[Equal]", "0"}], ",", 
     RowBox[{"K", "[", "X", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "Expand"}]}], "Input",
 CellChangeTimes->{{3.761915464929809*^9, 3.7619154669083743`*^9}, {
  3.761915526577644*^9, 3.7619155772278147`*^9}, {3.7619156075773726`*^9, 
  3.7619156753172865`*^9}, {3.761927675739996*^9, 
  3.7619276763142242`*^9}},ExpressionUUID->"a21f4925-9de1-4a6c-a3ed-\
9f5b14327eff"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
  
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
   "\[CapitalOmega]m0"], "+", 
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "X", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]], "-", 
  RowBox[{"K", "[", "X", "]"}]}]], "Output",
 CellChangeTimes->{{3.76191546736725*^9, 3.761915483087492*^9}, {
   3.7619155219574156`*^9, 3.7619155777820845`*^9}, {3.7619156085377474`*^9, 
   3.761915633677339*^9}, {3.7619156721774993`*^9, 3.761915675667404*^9}, 
   3.76192767663056*^9, 
   3.7619285137491207`*^9},ExpressionUUID->"cefb8469-a6af-4c50-b70b-\
10b76b73b89e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"K", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
    "-", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", "J0", " ", 
      SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
     "\[CapitalOmega]m0"], "+", 
    FractionBox[
     RowBox[{
      SqrtBox["2"], " ", "J0", " ", 
      SqrtBox["X"], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "X", "]"}], "2"]}], 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.76191546736725*^9, 3.761915483087492*^9}, {
   3.7619155219574156`*^9, 3.7619155777820845`*^9}, {3.7619156085377474`*^9, 
   3.761915633677339*^9}, {3.7619156721774993`*^9, 3.761915675667404*^9}, 
   3.76192767663056*^9, 
   3.7619285137593718`*^9},ExpressionUUID->"01df3aa1-55d1-476a-9199-\
49b967278150"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"K", "[", "X_", "]"}], ":=", 
  RowBox[{"K0", " ", 
   SuperscriptBox["H0", "2"], " ", 
   "\[CapitalOmega]\[CapitalLambda]0"}]}]], "Input",
 CellChangeTimes->{{3.7619156968303022`*^9, 3.7619157030877295`*^9}, {
   3.7619157501578383`*^9, 3.7619157608975253`*^9}, {3.7619158924172983`*^9, 
   3.7619158965725174`*^9}, 3.7619159577777495`*^9, 3.7619162282079377`*^9, {
   3.7619269276466913`*^9, 3.761926934035603*^9}, {3.761927101380516*^9, 
   3.761927111620875*^9}, {3.7619276810587673`*^9, 3.7619276813230114`*^9}, {
   3.7619278101481276`*^9, 
   3.761927810379063*^9}},ExpressionUUID->"a588f749-70bd-4684-89c1-\
944c9d7296f0"],

Cell[BoxData[{
 RowBox[{"Clear", "[", 
  RowBox[{"K", ",", "solG3X", ",", "H"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"K", "[", "X_", "]"}], ":=", 
  RowBox[{
   RowBox[{"K0", " ", 
    SqrtBox["X"]}], "+", 
   RowBox[{"K1", " ", "X"}]}]}]}], "Input",
 CellChangeTimes->{{3.76192830759146*^9, 3.761928308400629*^9}, {
   3.7619284056230984`*^9, 3.7619284271970162`*^9}, 3.7619284576431055`*^9, {
   3.7619287627100763`*^9, 3.761928777744774*^9}, {3.7619288368920174`*^9, 
   3.761928851669928*^9}, {3.7619290224579816`*^9, 3.761929040825652*^9}, {
   3.761929091309416*^9, 3.761929097717389*^9}, {3.7619291337293577`*^9, 
   3.7619291378619957`*^9}, {3.7619293039871035`*^9, 
   3.7619293091584325`*^9}},ExpressionUUID->"931516f5-b198-464c-8990-\
1ecfdcdc1531"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solG3X", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"EQ11", "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "'"}], "[", "X", "]"}]}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7619269521177855`*^9, 3.761926953835155*^9}, {
  3.7619269851570415`*^9, 
  3.761927030604209*^9}},ExpressionUUID->"bd63c8c2-df38-4a1d-9575-\
c8a304283b4a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["G3", "\[Prime]",
      MultilineFunction->None], "[", "X", "]"}], "\[Rule]", 
    FractionBox[
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["H0", "2"]}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SqrtBox["2"], " ", 
          RowBox[{"(", 
           RowBox[{"K0", "+", 
            RowBox[{"2", " ", "K1", " ", 
             SqrtBox["X"]}]}], ")"}], " ", "\[CapitalOmega]m0"}], "+", 
         RowBox[{"2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
        ")"}]}], "+", 
      RowBox[{"2", " ", "J0", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "X", "]"}], "2"]}]}], 
     RowBox[{"12", " ", 
      SuperscriptBox["H0", "2"], " ", "X", " ", "\[CapitalOmega]m0", " ", 
      RowBox[{"H", "[", "X", "]"}]}]]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7619269542919927`*^9, {3.761926992295758*^9, 3.7619270310921636`*^9}, 
   3.7619271181522565`*^9, 3.7619276855581684`*^9, 3.7619278145256033`*^9, 
   3.761928313134471*^9, {3.7619284117476315`*^9, 3.761928474688794*^9}, {
   3.7619285178128753`*^9, 3.7619285352674327`*^9}, {3.7619287687332115`*^9, 
   3.761928779278199*^9}, {3.761928842508107*^9, 3.761928874313472*^9}, {
   3.7619290327812347`*^9, 3.761929046759071*^9}, 3.761929105213169*^9, 
   3.7619291423718243`*^9, 
   3.761929311545309*^9},ExpressionUUID->"958dbdf2-65a6-4314-b8d7-\
9201d56a36e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Clear", "[", "H", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQ22", "/.", 
   RowBox[{"solG3X", "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"solh", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"%", "\[Equal]", "0"}], ",", 
     RowBox[{"H", "[", "X", "]"}]}], "]"}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.7619277018228135`*^9, 3.761927754262437*^9}, {
  3.7619283309531293`*^9, 
  3.7619283333200207`*^9}},ExpressionUUID->"5e2936ce-248d-4049-9895-\
b46585fce1e0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "K0"}], " ", 
   SqrtBox["X"]}], "-", 
  RowBox[{"K1", " ", "X"}], "-", 
  RowBox[{"3", " ", 
   SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
  
  FractionBox[
   RowBox[{
    SqrtBox["2"], " ", "J0", " ", 
    SqrtBox["X"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["H0", "2"]}], " ", 
       "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
      SuperscriptBox[
       RowBox[{"H", "[", "X", "]"}], "2"]}], ")"}]}], 
   RowBox[{
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]]}]], "Output",
 CellChangeTimes->{{3.761927697982438*^9, 3.7619277546885686`*^9}, 
   3.761927816038472*^9, {3.7619283214471593`*^9, 3.7619283346198406`*^9}, 
   3.761928542731291*^9, 3.761928782879671*^9, 3.7619288771324387`*^9, 
   3.7619290501402626`*^9, 3.761929109508051*^9, 3.761929147332589*^9, 
   3.7619293147780857`*^9},ExpressionUUID->"6b3c6eef-6234-4400-93f3-\
93bbfca35e59"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "[", "X", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"H0", " ", 
        SqrtBox["\[CapitalOmega]m0"], " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"K1", " ", "X"}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["H0", "2"], " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
          FractionBox[
           RowBox[{
            SqrtBox["X"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"K0", " ", "\[CapitalOmega]m0"}], "+", 
              RowBox[{
               SqrtBox["2"], " ", "J0", " ", 
               "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], 
           "\[CapitalOmega]m0"]}]]}], 
       RowBox[{
        SuperscriptBox["2", 
         RowBox[{"1", "/", "4"}]], " ", 
        SqrtBox["J0"], " ", 
        SuperscriptBox["X", 
         RowBox[{"1", "/", "4"}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"H", "[", "X", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{"H0", " ", 
       SqrtBox["\[CapitalOmega]m0"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"K1", " ", "X"}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["H0", "2"], " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         FractionBox[
          RowBox[{
           SqrtBox["X"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"K0", " ", "\[CapitalOmega]m0"}], "+", 
             RowBox[{
              SqrtBox["2"], " ", "J0", " ", 
              "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], 
          "\[CapitalOmega]m0"]}]]}], 
      RowBox[{
       SuperscriptBox["2", 
        RowBox[{"1", "/", "4"}]], " ", 
       SqrtBox["J0"], " ", 
       SuperscriptBox["X", 
        RowBox[{"1", "/", "4"}]]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761927697982438*^9, 3.7619277546885686`*^9}, 
   3.761927816038472*^9, {3.7619283214471593`*^9, 3.7619283346198406`*^9}, 
   3.761928542731291*^9, 3.761928782879671*^9, 3.7619288771324387`*^9, 
   3.7619290501402626`*^9, 3.761929109508051*^9, 3.761929147332589*^9, 
   3.7619293150499263`*^9},ExpressionUUID->"bc0fa30d-2fc3-41e1-a077-\
f0cc0fbf357b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "[", "X_", "]"}], ":=", 
  FractionBox[
   RowBox[{"H0", " ", 
    SqrtBox["\[CapitalOmega]m0"], " ", 
    SqrtBox[
     RowBox[{
      RowBox[{"K1", " ", "X"}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
      "+", 
      FractionBox[
       RowBox[{
        SqrtBox["X"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"K0", " ", "\[CapitalOmega]m0"}], "+", 
          RowBox[{
           SqrtBox["2"], " ", "J0", " ", 
           "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], 
       "\[CapitalOmega]m0"]}]]}], 
   RowBox[{
    SuperscriptBox["2", 
     RowBox[{"1", "/", "4"}]], " ", 
    SqrtBox["J0"], " ", 
    SuperscriptBox["X", 
     RowBox[{"1", "/", "4"}]]}]]}]], "Input",
 CellChangeTimes->{{3.7619278737389264`*^9, 3.761927876098248*^9}, 
   3.761928352204754*^9, 3.7619285524160237`*^9, 3.7619287987933826`*^9, 
   3.7619288928332167`*^9, 3.761929062473152*^9, 3.761929116754198*^9, 
   3.7619291707145324`*^9, 
   3.7619293207002907`*^9},ExpressionUUID->"a8ce2983-9186-4343-a68c-\
87d64c44f0e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solX", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "X", "]"}], "\[Equal]", "Ha"}], ",", "X"}], "]"}], "//",
      "FullSimplify"}], "//", "PowerExpand"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7619279326623735`*^9, 3.761927962973773*^9}, 
   3.761928373386425*^9, {3.7619285594815655`*^9, 3.761928564213036*^9}, {
   3.7619286196671143`*^9, 
   3.761928634293559*^9}},ExpressionUUID->"afaa9c8c-2714-42ec-b96b-\
4ebfe083f1bd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SuperscriptBox["H0", "4"], " ", 
        SuperscriptBox["K1", "2"], " ", 
        SuperscriptBox["\[CapitalOmega]m0", "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["Ha", "4"], " ", 
         SuperscriptBox["J0", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["H0", "2"], " ", 
         SuperscriptBox["Ha", "2"], " ", "J0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", "K0", " ", "\[CapitalOmega]m0"}], "+", 
           RowBox[{
           "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["H0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SqrtBox["2"], " ", "J0", " ", "K0", " ", "\[CapitalOmega]m0", " ",
             "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["J0", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["K0", "2"], "-", 
              RowBox[{"6", " ", 
               SuperscriptBox["H0", "2"], " ", "K1", " ", 
               "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}]}], ")"}]}], 
        "-", 
        RowBox[{
         SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "36"}], " ", 
            SuperscriptBox["H0", "12"], " ", 
            SuperscriptBox["K1", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["J0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["Ha", "2"], "-", 
                   RowBox[{
                    SuperscriptBox["H0", "2"], " ", 
                    "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}], "2"]}], 
               "+", 
               RowBox[{"2", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["H0", "2"], " ", "J0", " ", "K0", " ", 
                "\[CapitalOmega]m0", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["Ha", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["H0", "2"], " ", 
                   "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["H0", "4"], " ", 
                SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["K0", "2"], "-", 
                  RowBox[{"6", " ", 
                   SuperscriptBox["H0", "2"], " ", "K1", " ", 
                   "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}]}], ")"}], 
             "2"], 
            SuperscriptBox["\[CapitalOmega]m0", "4"]]}]]}]}], ")"}]}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SuperscriptBox["H0", "4"], " ", 
        SuperscriptBox["K1", "2"], " ", 
        SuperscriptBox["\[CapitalOmega]m0", "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["Ha", "4"], " ", 
         SuperscriptBox["J0", "2"]}], "-", 
        RowBox[{"2", " ", 
         SuperscriptBox["H0", "2"], " ", 
         SuperscriptBox["Ha", "2"], " ", "J0", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", "K0", " ", "\[CapitalOmega]m0"}], "+", 
           RowBox[{
           "2", " ", "J0", " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["H0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SqrtBox["2"], " ", "J0", " ", "K0", " ", "\[CapitalOmega]m0", " ",
             "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["J0", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], "+", 
           RowBox[{
            SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["K0", "2"], "-", 
              RowBox[{"6", " ", 
               SuperscriptBox["H0", "2"], " ", "K1", " ", 
               "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}]}], ")"}]}], 
        "+", 
        RowBox[{
         SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "36"}], " ", 
            SuperscriptBox["H0", "12"], " ", 
            SuperscriptBox["K1", "2"], " ", 
            SuperscriptBox["\[CapitalOmega]\[CapitalLambda]0", "2"]}], "+", 
           FractionBox[
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["J0", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"(", 
                  RowBox[{
                   SuperscriptBox["Ha", "2"], "-", 
                   RowBox[{
                    SuperscriptBox["H0", "2"], " ", 
                    "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}], "2"]}], 
               "+", 
               RowBox[{"2", " ", 
                SqrtBox["2"], " ", 
                SuperscriptBox["H0", "2"], " ", "J0", " ", "K0", " ", 
                "\[CapitalOmega]m0", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   SuperscriptBox["Ha", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["H0", "2"], " ", 
                   "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["H0", "4"], " ", 
                SuperscriptBox["\[CapitalOmega]m0", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["K0", "2"], "-", 
                  RowBox[{"6", " ", 
                   SuperscriptBox["H0", "2"], " ", "K1", " ", 
                   "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}]}], ")"}], 
             "2"], 
            SuperscriptBox["\[CapitalOmega]m0", "4"]]}]]}]}], ")"}]}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761927940474083*^9, 3.76192796370471*^9}, {
   3.7619283721161723`*^9, 3.7619283986403856`*^9}, {3.761928556141598*^9, 
   3.761928565223285*^9}, {3.761928630391641*^9, 3.761928635359582*^9}, 
   3.7619288331407113`*^9, 3.7619288983313403`*^9, 3.761929082049117*^9, 
   3.7619291304963255`*^9, 3.7619291796037607`*^9, 
   3.7619293311361623`*^9},ExpressionUUID->"a957330b-820b-41f8-a713-\
f062f5d45850"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solx1", "=", 
  RowBox[{
   RowBox[{"solX", "/.", 
    RowBox[{"Ha", "\[Rule]", "HL"}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.761929463704361*^9, 
  3.7619294648885407`*^9}},ExpressionUUID->"3104a41b-abdb-4daa-a37d-\
596b38da7622"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     RowBox[{
      FractionBox[
       SuperscriptBox["J0", "2"], 
       RowBox[{
        SuperscriptBox["a", "6"], " ", 
        SuperscriptBox["K1", "2"]}]], "-", 
      FractionBox[
       RowBox[{
        SqrtBox["2"], " ", "J0", " ", "K0"}], 
       RowBox[{
        SuperscriptBox["a", "3"], " ", 
        SuperscriptBox["K1", "2"]}]], "-", 
      FractionBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["H0", "4"]}], " ", 
         SuperscriptBox["K0", "2"]}], "+", 
        RowBox[{"6", " ", 
         SuperscriptBox["H0", "6"], " ", "K1", " ", 
         "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        SqrtBox[
         FractionBox[
          RowBox[{
           SuperscriptBox["H0", "8"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"4", " ", 
              SuperscriptBox["J0", "4"]}], "-", 
             RowBox[{"8", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["a", "3"], " ", 
              SuperscriptBox["J0", "3"], " ", "K0"}], "+", 
             RowBox[{
              SuperscriptBox["a", "12"], " ", 
              SuperscriptBox["K0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["K0", "2"], "-", 
                RowBox[{"12", " ", 
                 SuperscriptBox["H0", "2"], " ", "K1", " ", 
                 "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "-", 
             RowBox[{"4", " ", 
              SqrtBox["2"], " ", 
              SuperscriptBox["a", "9"], " ", "J0", " ", "K0", " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["K0", "2"], "-", 
                RowBox[{"6", " ", 
                 SuperscriptBox["H0", "2"], " ", "K1", " ", 
                 "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "+", 
             RowBox[{"12", " ", 
              SuperscriptBox["a", "6"], " ", 
              SuperscriptBox["J0", "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                SuperscriptBox["K0", "2"], "-", 
                RowBox[{"2", " ", 
                 SuperscriptBox["H0", "2"], " ", "K1", " ", 
                 "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}]}], ")"}]}], 
          SuperscriptBox["a", "12"]]]}], 
       RowBox[{"2", " ", 
        SuperscriptBox["H0", "4"], " ", 
        SuperscriptBox["K1", "2"]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"X", "\[Rule]", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"2", " ", 
        SuperscriptBox["a", "6"], " ", 
        SuperscriptBox["H0", "4"], " ", 
        SuperscriptBox["K1", "2"]}]], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H0", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["J0", "2"]}], "-", 
           RowBox[{"2", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "3"], " ", "J0", " ", "K0"}], "+", 
           RowBox[{
            SuperscriptBox["a", "6"], " ", 
            SuperscriptBox["K0", "2"]}]}], ")"}]}], "-", 
        RowBox[{"6", " ", 
         SuperscriptBox["a", "6"], " ", 
         SuperscriptBox["H0", "6"], " ", "K1", " ", 
         "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
        RowBox[{
         SuperscriptBox["a", "6"], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{
            SuperscriptBox["H0", "8"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", 
               SuperscriptBox["J0", "4"]}], "-", 
              RowBox[{"8", " ", 
               SqrtBox["2"], " ", 
               SuperscriptBox["a", "3"], " ", 
               SuperscriptBox["J0", "3"], " ", "K0"}], "+", 
              RowBox[{
               SuperscriptBox["a", "12"], " ", 
               SuperscriptBox["K0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["K0", "2"], "-", 
                 RowBox[{"12", " ", 
                  SuperscriptBox["H0", "2"], " ", "K1", " ", 
                  "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "-", 
              RowBox[{"4", " ", 
               SqrtBox["2"], " ", 
               SuperscriptBox["a", "9"], " ", "J0", " ", "K0", " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["K0", "2"], "-", 
                 RowBox[{"6", " ", 
                  SuperscriptBox["H0", "2"], " ", "K1", " ", 
                  "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], "+", 
              RowBox[{"12", " ", 
               SuperscriptBox["a", "6"], " ", 
               SuperscriptBox["J0", "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["K0", "2"], "-", 
                 RowBox[{"2", " ", 
                  SuperscriptBox["H0", "2"], " ", "K1", " ", 
                  "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}]}], ")"}]}], 
           
           SuperscriptBox["a", "12"]]]}]}], ")"}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761929458059518*^9, 
  3.7619294651921177`*^9}},ExpressionUUID->"48778062-9544-4e1f-ab23-\
e3f2441efe7d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"solx1", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", 
         RowBox[{"H0", "\[Rule]", "1"}]}], "/.", 
        RowBox[{"J0", "\[Rule]", 
         RowBox[{"1", "/", "10"}]}]}], "/.", 
       RowBox[{"K0", "\[Rule]", "2"}]}], "/.", 
      RowBox[{"K1", "\[Rule]", 
       RowBox[{"-", "3"}]}]}], "/.", 
     RowBox[{"\[CapitalOmega]\[CapitalLambda]0", "\[Rule]", 
      RowBox[{"1", "-", "\[CapitalOmega]m0"}]}]}], "/.", 
    RowBox[{"\[CapitalOmega]m0", "\[Rule]", 
     RowBox[{"3", "/", "10"}]}]}], "/.", 
   RowBox[{"a", "\[Rule]", 
    RowBox[{"1", "/", "10"}]}]}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.7619293987507095`*^9, 
  3.7619295213744354`*^9}},ExpressionUUID->"88912fa0-7ff9-443b-a8e4-\
634d7d4f2021"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"X", "\[Rule]", "0.0002267245813527552`"}], "}"}]], "Output",
 CellChangeTimes->{{3.761929403818041*^9, 
  3.761929521912243*^9}},ExpressionUUID->"a1236468-d0b5-48cb-983f-\
4f0e778a3334"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Alpha]K1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]K", "/.", 
         RowBox[{"G2X", "\[Rule]", 
          RowBox[{
           RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
        RowBox[{"G2XX", "\[Rule]", 
         RowBox[{
          RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
       RowBox[{"G3X", "\[Rule]", 
        RowBox[{"solG3X", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], "/.", 
      RowBox[{"G3XX", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"solG3X", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], ",", "X"}], 
        "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
      SqrtBox[
       RowBox[{"2", "X"}]]}]}], "/.", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"H", "[", "X", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]B1", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"\[Alpha]B", "/.", 
         RowBox[{"G2X", "\[Rule]", 
          RowBox[{
           RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
        RowBox[{"G2XX", "\[Rule]", 
         RowBox[{
          RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
       RowBox[{"G3X", "\[Rule]", 
        RowBox[{"solG3X", "[", 
         RowBox[{"[", 
          RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}]}]}], "/.", 
      RowBox[{"G3XX", "\[Rule]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"solG3X", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "1", ",", "2"}], "]"}], "]"}], ",", "X"}], 
        "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
      SqrtBox[
       RowBox[{"2", "X"}]]}]}], "/.", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"H", "[", "X", "]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"D2", "=", 
   RowBox[{"\[Alpha]K1", "+", 
    RowBox[{
     FractionBox["3", "2"], 
     RowBox[{"\[Alpha]B1", "^", "2"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cs21", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"cs2", "/.", 
          RowBox[{"G2X", "\[Rule]", 
           RowBox[{
            RowBox[{"K", "'"}], "[", "X", "]"}]}]}], "/.", 
         RowBox[{"G2XX", "\[Rule]", 
          RowBox[{
           RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "/.", 
        RowBox[{"solG3X", "[", 
         RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"solG3X", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", "X"}], "]"}]}], "/.", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"solG3X", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
      SqrtBox[
       RowBox[{"2", "X"}]]}]}], "/.", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"H", "[", "X", "]"}]}]}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7619270119247227`*^9, 3.761927023250402*^9}, {
  3.7619271535969768`*^9, 3.761927154653223*^9}, {3.761928675415922*^9, 
  3.7619286758624167`*^9}, {3.7619292147941527`*^9, 
  3.761929221538597*^9}},ExpressionUUID->"a82054d7-9ae1-4488-85cd-\
1451127126d1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"cs21", "/.", 
            RowBox[{"solX", "[", 
             RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
           RowBox[{"Ha", "\[Rule]", "HL"}]}], "/.", 
          RowBox[{"H0", "\[Rule]", "1"}]}], "/.", 
         RowBox[{"J0", "\[Rule]", 
          RowBox[{"1", "/", "10"}]}]}], "/.", 
        RowBox[{"K0", "\[Rule]", 
         RowBox[{"2", "/", "10"}]}]}], "/.", 
       RowBox[{"K1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "100"}]}]}], "/.", 
      RowBox[{"\[CapitalOmega]\[CapitalLambda]0", "\[Rule]", 
       RowBox[{"1", "-", "\[CapitalOmega]m0"}]}]}], "/.", 
     RowBox[{"\[CapitalOmega]m0", "\[Rule]", 
      RowBox[{"3", "/", "10"}]}]}], "/.", 
    RowBox[{"a", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["10", 
        RowBox[{"-", "5"}]], ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]], ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "1"}]], ",", 
       SuperscriptBox["10", "0"]}], "}"}]}]}], "/.", 
   RowBox[{"k", "\[Rule]", "300"}]}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.7619279847229834`*^9, 3.7619280613609085`*^9}, {
  3.7619281467954135`*^9, 3.7619282703363028`*^9}, {3.761928711276497*^9, 
  3.761928723115015*^9}, {3.761928919815948*^9, 3.76192898314535*^9}, {
  3.761929229615443*^9, 3.7619292462147303`*^9}, {3.761929343944683*^9, 
  3.7619293472635913`*^9}, {3.7619294802115393`*^9, 
  3.761929597495384*^9}},ExpressionUUID->"b85e602c-a9d1-4ee7-945d-\
366a6806597c"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0.`\\\"]\\) \
encountered.\"",2,310,163,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7619295997077217`*^9},ExpressionUUID->"3c044a48-1840-44d6-b44b-\
b73a960f202a"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \
SuperscriptBox[\\\"0.`\\\", \\\"1.`\\\"]]\\) encountered.\"",2,310,164,
   27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7619295997645397`*^9},ExpressionUUID->"a6e4e1fe-0512-439b-83e7-\
984b8f12d360"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \
SqrtBox[\\\"0.`\\\"]]\\) encountered.\"",2,310,165,27880539197621546896,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7619295998297195`*^9},ExpressionUUID->"dbda66b0-6894-44bc-adbc-\
fcf1ac50ff7b"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Power\\\", \\\"::\\\", \
\\\"infy\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,310,166,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929599880768*^9},ExpressionUUID->"716d89e1-545e-4fba-95f9-\
4a8cca9f4bac"],

Cell[BoxData[
 TemplateBox[{
  "Infinity","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"0.`\\\", \\\" \\\", \
\\\"ComplexInfinity\\\"}]\\) encountered.\"",2,310,167,27880539197621546896,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929599943637*^9},ExpressionUUID->"044c121f-4943-4bb8-9a12-\
497dcb76d47d"],

Cell[BoxData[
 TemplateBox[{
  "Infinity","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"0.`\\\", \\\" \\\", \
\\\"ComplexInfinity\\\", \\\" \\\", \\\"ComplexInfinity\\\"}]\\) encountered.\
\"",2,310,168,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929600002281*^9},ExpressionUUID->"8405b937-6178-4ba8-911e-\
2fd716e58107"],

Cell[BoxData[
 TemplateBox[{
  "Infinity","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"ComplexInfinity\\\", \
\\\"+\\\", \\\"ComplexInfinity\\\", \\\"+\\\", \\\"ComplexInfinity\\\"}]\\) \
encountered.\"",2,310,169,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7619296000630584`*^9},ExpressionUUID->"3f1c6d2c-6eac-4037-8f87-\
6a789ed535d7"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Infinity\\\", \
\\\"::\\\", \\\"indet\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"",2,310,170,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7619296001240177`*^9},ExpressionUUID->"31e8e79d-be4c-4595-93a5-\
838a36e545a5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"0.002308764577754953`", "\[VeryThinSpace]", "-", 
    RowBox[{"0.0039704793371509355`", " ", "\[ImaginaryI]"}]}], ",", 
   "Indeterminate", ",", "0.00012536161572317364`", ",", 
   RowBox[{"-", "0.00007569095667245802`"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.761927987648204*^9, {3.7619280214062276`*^9, 3.7619280623074436`*^9}, {
   3.7619281547923594`*^9, 3.7619282707826653`*^9}, {3.7619286972562227`*^9, 
   3.7619287254271564`*^9}, {3.7619289135889816`*^9, 
   3.7619289836110067`*^9}, {3.7619292399563274`*^9, 3.761929249155652*^9}, 
   3.761929350686516*^9, {3.7619294871691666`*^9, 
   3.7619296001240177`*^9}},ExpressionUUID->"eb9ffa2f-954f-4255-bc5f-\
6f533cb48077"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"D2", "/.", "solX"}], "/.", 
           RowBox[{"Ha", "\[Rule]", "HL"}]}], "/.", 
          RowBox[{"H0", "\[Rule]", "1"}]}], "/.", 
         RowBox[{"J0", "\[Rule]", 
          RowBox[{"1", "/", "10"}]}]}], "/.", 
        RowBox[{"K0", "\[Rule]", 
         RowBox[{"2", "/", "10"}]}]}], "/.", 
       RowBox[{"K1", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "1"}], "/", "100"}]}]}], "/.", 
      RowBox[{"\[CapitalOmega]\[CapitalLambda]0", "\[Rule]", 
       RowBox[{"1", "-", "\[CapitalOmega]m0"}]}]}], "/.", 
     RowBox[{"\[CapitalOmega]m0", "\[Rule]", 
      RowBox[{"3", "/", "10"}]}]}], "/.", 
    RowBox[{"a", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       SuperscriptBox["10", 
        RowBox[{"-", "5"}]], ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]], ",", 
       SuperscriptBox["10", 
        RowBox[{"-", "1"}]], ",", 
       SuperscriptBox["10", "0"]}], "}"}]}]}], "/.", 
   RowBox[{"k", "\[Rule]", "300"}]}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.761928064501433*^9, 3.7619282647490015`*^9}, 
   3.7619287407257595`*^9, {3.761928924122389*^9, 3.7619289811962614`*^9}, {
   3.761929260863264*^9, 3.761929293818263*^9}, {3.761929361935819*^9, 
   3.7619293635697947`*^9}, {3.761929585607929*^9, 
   3.761929613808852*^9}},ExpressionUUID->"12079e2c-5e0d-4315-ba17-\
eafbe7404665"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \
SqrtBox[\\\"0.`\\\"]]\\) encountered.\"",2,311,171,27880539197621546896,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929614709155*^9},ExpressionUUID->"6a106451-1e41-4a4b-a5ad-\
111d0d9a18ba"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \
SuperscriptBox[\\\"0.`\\\", \\\"0.5`\\\"]]\\) encountered.\"",2,311,172,
   27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929614732794*^9},ExpressionUUID->"5577e8ad-86b1-426b-80a5-\
2d7b33faa429"],

Cell[BoxData[
 TemplateBox[{
  "Infinity","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"0.`\\\", \\\" \\\", \
\\\"ComplexInfinity\\\"}]\\) encountered.\"",2,311,173,27880539197621546896,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929614747881*^9},ExpressionUUID->"e5b2cba4-35ff-4177-9f06-\
0bc9a7c02197"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \
SuperscriptBox[\\\"0.`\\\", RowBox[{\\\"3\\\", \\\"/\\\", \\\"4\\\"}]]]\\) \
encountered.\"",2,311,174,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929614763057*^9},ExpressionUUID->"0e1ce675-e1a4-40bd-83e7-\
494178419b45"],

Cell[BoxData[
 TemplateBox[{
  "General","stop",
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Power\\\", \\\"::\\\", \
\\\"infy\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"",2,311,175,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929614783552*^9},ExpressionUUID->"7bc4f3d4-75d5-44b7-a0d8-\
34fe3ebddb4a"],

Cell[BoxData[
 TemplateBox[{
  "Infinity","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"ComplexInfinity\\\", \
\\\"+\\\", \\\"ComplexInfinity\\\", \\\"+\\\", \\\"ComplexInfinity\\\"}]\\) \
encountered.\"",2,311,176,27880539197621546896,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.761929614798864*^9},ExpressionUUID->"bd7b4587-431f-488d-a17f-\
ea479b43a4d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.0516513219490796`*^18"}], "-", 
      RowBox[{"1.2559758377053537`*^9", " ", "\[ImaginaryI]"}]}], ",", 
     "Indeterminate", ",", 
     RowBox[{"-", "0.015425832992045545`"}], ",", 
     RowBox[{"-", "0.13998108851900976`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.576215139845906`*^42"}], "-", 
      RowBox[{"1.5376354281066893`*^21", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.5649906816800039`*^25"}], "-", 
      RowBox[{"4.845086171266629`*^12", " ", "\[ImaginaryI]"}]}], ",", 
     RowBox[{
      RowBox[{"-", "1.463451110289964`*^8"}], "-", 
      RowBox[{"14746.987434801778`", " ", "\[ImaginaryI]"}]}], ",", 
     "0.8304722002770092`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7619280679026566`*^9, 3.7619282651011295`*^9}, 
   3.7619287413657284`*^9, {3.76192891545833*^9, 3.761928984769267*^9}, {
   3.7619292621481686`*^9, 3.761929294803612*^9}, 3.761929364535539*^9, {
   3.7619295865319233`*^9, 
   3.7619296148141212`*^9}},ExpressionUUID->"d451cfb2-c108-4234-b38c-\
625ffeaeb301"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753103919594767*^9, 
  3.753103921703641*^9}},ExpressionUUID->"a3e5ba54-be0f-448e-bd84-\
b06bfad4aab0"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"Designer", " ", "4"}], ":", " ", "G4"}], "=", 
   RowBox[{"G4", 
    RowBox[{"(", "\[Phi]", ")"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753007025810972*^9, 3.75300703764139*^9}, 
   3.7530074340625987`*^9, {3.7531040292255526`*^9, 3.753104034244852*^9}, {
   3.754053242656372*^9, 
   3.754053251589407*^9}},ExpressionUUID->"8443877a-8614-4d12-aa5b-\
7efb9d013949"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"des3", ",", "eqdes3", ",", "solf", ",", "eqg3"}], "]"}]], "Input",
 CellChangeTimes->{{3.7530268091552315`*^9, 3.753026828954541*^9}, {
  3.753104074960581*^9, 
  3.75310407646391*^9}},ExpressionUUID->"97a7f01a-0fe9-4bf8-885f-\
77206e44d767"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"1", "/", "2"}], "+", 
       RowBox[{"g4", "[", "\[Phi]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"g4", "''"}], "[", "\[Phi]", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"g4", "'"}], "[", "\[Phi]", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"K", "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "'"}], "[", "X", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "''"}], "[", "X", "]"}]}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7530071402313166`*^9, 3.7530071520712533`*^9}, {
  3.7530073980312834`*^9, 3.7530074020115433`*^9}, {3.7530267947608924`*^9, 
  3.7530267954046335`*^9}, {3.7531040546639605`*^9, 3.753104106472458*^9}, {
  3.754053270064109*^9, 3.754053318189396*^9}, {3.7540533957465725`*^9, 
  3.7540534124704857`*^9}},ExpressionUUID->"55d274b2-6a6d-4e00-92c8-\
e05dccad1348"],

Cell[BoxData[
 RowBox[{
  RowBox[{"des3", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"1", "/", "2"}], "+", 
       RowBox[{"g4", "[", "\[Phi]", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"g4", "''"}], "[", "\[Phi]", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"g4", "'"}], "[", "\[Phi]", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"K", "[", "\[Phi]", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"K", "'"}], "[", "\[Phi]", "]"}]}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7540534832861586`*^9, 
  3.7540534956165915`*^9}},ExpressionUUID->"83273432-f356-4cdc-8574-\
fcc6ee2a0859"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         FractionBox["2", "3"], "eq00"}], "/.", "des3"}], "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "t", "]"}], "\[Rho]c"}]}]}], "/.", 
    RowBox[{"t", "\[Rule]", "a"}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.753007162370982*^9, 3.7530071639310336`*^9}, {
   3.753007412681366*^9, 3.753007413180858*^9}, {3.7530074538413053`*^9, 
   3.7530074742035904`*^9}, {3.7530268519539814`*^9, 3.753026864814765*^9}, 
   3.7531041210612183`*^9},ExpressionUUID->"ea2565ce-833c-47c7-9a68-\
f793cf4a4b9a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"g4", "[", "\[Phi]", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "-", 
  FractionBox[
   RowBox[{"K", "[", "\[Phi]", "]"}], "3"], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "-", 
  RowBox[{"2", " ", 
   SqrtBox["2"], " ", 
   SqrtBox["X"], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["g4", "\[Prime]",
     MultilineFunction->None], "[", "\[Phi]", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7530070956712055`*^9, 3.7530071645856547`*^9, 3.753007359271302*^9, {
   3.7530074043412685`*^9, 3.7530074136313868`*^9}, {3.7530074566310596`*^9, 
   3.75300747484136*^9}, 3.753009479731315*^9, 3.753010399292014*^9, 
   3.7530259723809757`*^9, 3.7530267991530056`*^9, {3.7530268472211742`*^9, 
   3.7530268654142923`*^9}, 3.7530272317890463`*^9, 3.753104123529351*^9, 
   3.7531100768157735`*^9, {3.7540533107965107`*^9, 3.7540533200964155`*^9}, 
   3.754053414755929*^9, 
   3.754053498546113*^9},ExpressionUUID->"51688221-a275-43e8-8317-\
66c5e1215b05"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eqdes22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"eqscal", "/.", "des3"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], "/.", 
       RowBox[{"G", "\[Rule]", 
        FractionBox[
         RowBox[{"3", 
          RowBox[{"H0", "^", "2"}]}], 
         RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], 
       RowBox[{
        RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "//", "Expand"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7530072546512675`*^9, {3.753007978861573*^9, 3.7530079844517*^9}, {
   3.75300819971229*^9, 3.7530082001136017`*^9}, {3.7530268680858884`*^9, 
   3.7530268991518917`*^9}, 
   3.753104155438074*^9},ExpressionUUID->"83595097-9000-475e-a387-\
15b583d3a642"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   RowBox[{"H", "[", "a", "]"}], " ", 
   RowBox[{
    SuperscriptBox["g4", "\[Prime]",
     MultilineFunction->None], "[", "\[Phi]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      RowBox[{"H", "[", "a", "]"}]}], "+", 
     RowBox[{"a", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}], "-", 
  RowBox[{
   SuperscriptBox["K", "\[Prime]",
    MultilineFunction->None], "[", "\[Phi]", "]"}]}]], "Output",
 CellChangeTimes->{
  3.7530072553012924`*^9, 3.75300736155129*^9, 3.7530075454953737`*^9, {
   3.7530079799828978`*^9, 3.753007985875571*^9}, 3.7530082007913494`*^9, 
   3.753009481096099*^9, 3.7530104003049483`*^9, 3.7530259745347195`*^9, 
   3.7530268004690237`*^9, {3.7530268708900013`*^9, 3.7530269002721505`*^9}, 
   3.7530272332545967`*^9, 3.7531041604460745`*^9, 3.753110080239015*^9, 
   3.754053330846294*^9, 3.7540534215863924`*^9, 
   3.754053501249671*^9},ExpressionUUID->"94c2953a-f368-4bb7-8e73-\
34be77861d77"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"eqdes22", "\[Equal]", "0"}], ",", 
     RowBox[{
      RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531050161389294`*^9, 
  3.753105030776743*^9}},ExpressionUUID->"1505188b-b02f-4519-bf0c-\
e47f373b39fb"],

Cell[BoxData[
 TemplateBox[{
  "Part","partw",
   "\"Part \\!\\(\\*RowBox[{\\\"1\\\"}]\\) of \\!\\(\\*RowBox[{\\\"{\\\", \
\\\"}\\\"}]\\) does not exist.\"",2,103,2,17576510523720636449,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.754053503596304*^9},ExpressionUUID->"8ce8eef4-ed32-4b65-874b-\
a47e18103143"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", "}"}], "\[LeftDoubleBracket]", "1", 
  "\[RightDoubleBracket]"}]], "Output",
 CellChangeTimes->{{3.7531050241837077`*^9, 3.7531050311628895`*^9}, 
   3.7540534284463344`*^9, 
   3.754053503605979*^9},ExpressionUUID->"eee37f6c-b1ff-40b1-969c-\
1fcd48231e2b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Ptot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
    "des3"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.753104165454965*^9},ExpressionUUID->"6130cc1e-85c6-47a7-8559-\
cb0605a9facb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", 
   RowBox[{
    SuperscriptBox["g4", "\[Prime]",
     MultilineFunction->None], "[", "\[Phi]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["K", "\[Prime]",
    MultilineFunction->None], "[", "\[Phi]", "]"}]}]], "Output",
 CellChangeTimes->{3.753008288221882*^9, 3.753009482346419*^9, 
  3.7530104012915435`*^9, 3.753025976743453*^9, 3.7530269098180213`*^9, 
  3.75302723538494*^9, 3.753104184074131*^9, 3.7540534322163453`*^9, 
  3.7540535154803514`*^9},ExpressionUUID->"42b58f1e-156b-4257-9fd9-\
6e09440fc45b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Jtot", "/.", "zeroorder"}], "/.", "rules"}], "/.", "a2H"}], "/.",
      "des3"}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}], "/.", 
   RowBox[{"t", "\[Rule]", "a"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{
  3.7530082969130588`*^9, 3.7530083295913944`*^9, {3.753026917538438*^9, 
   3.75302691893057*^9}, 
   3.753104219925988*^9},ExpressionUUID->"8e5b41be-a492-402d-82cd-\
c61e0bde53e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{
  3.7530082975415645`*^9, 3.753008330541541*^9, 3.7530094836722317`*^9, 
   3.7530104029223557`*^9, 3.753025977723363*^9, {3.7530269141756024`*^9, 
   3.753026919235218*^9}, 3.7530272363194532`*^9, {3.753104216959204*^9, 
   3.7531042204133034`*^9}, 
   3.7540535222500105`*^9},ExpressionUUID->"815540cb-ebac-4240-af25-\
bde57f78ead7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"covDiv", "[", 
     RowBox[{
      RowBox[{"Raise", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"J", "[", "t", "]"}], ",", "0", ",", "0", ",", "0"}], "}"}],
         ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", "zeroorder"}], "//",
   "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7530083583919115`*^9, 3.753008383591753*^9}, 
   3.7530269380948334`*^9},ExpressionUUID->"0d1e5864-47d7-4bff-b135-\
c914b40f89a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"J", "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["J", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.753008368031542*^9, 3.75300838394143*^9}, 
   3.7530094861559353`*^9, 3.7530104039620748`*^9, 3.7530259792893887`*^9, {
   3.7530269237358108`*^9, 3.7530269389219027`*^9}, 3.7530272449852643`*^9, 
   3.7531042327702336`*^9, 
   3.754053750300988*^9},ExpressionUUID->"e13b0584-f429-42fa-8c41-\
6677aa3a8521"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "'"}], "[", "t", "]"}], "/", 
        RowBox[{"a", "[", "t", "]"}]}], " ", 
       RowBox[{"J", "[", "t", "]"}]}], "-", 
      RowBox[{
       SuperscriptBox["J", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{"J", "[", "t", "]"}], ",", "t"}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.753026941097069*^9, 
  3.7530269583466897`*^9}},ExpressionUUID->"23e604ef-9f11-49a1-bb90-\
b6a2510e2a56"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"J", "[", "t", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"C", "[", "1", "]"}], 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "3"]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7530269555727863`*^9, 3.7530269586755733`*^9}, 
   3.7530272465369406`*^9, 3.7531042352143793`*^9, 
   3.754053751606406*^9},ExpressionUUID->"c8054526-7b71-4e39-8bb8-\
4bfc8c94c90a"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"HL", "=", 
   RowBox[{"H0", 
    SqrtBox[
     RowBox[{
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}], "+", "\[CapitalOmega]\[CapitalLambda]0"}]]}]}],
   ";"}]], "Input",
 CellChangeTimes->{{3.7530269935173016`*^9, 3.7530269990121403`*^9}, {
  3.7531100904488335`*^9, 3.75311009680774*^9}, {3.753110167300049*^9, 
  3.753110168255074*^9}},ExpressionUUID->"49ed0338-a2c0-4344-9ba0-\
7bf7e6c2f7b4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqscal1", "=", 
   RowBox[{
    RowBox[{"6", " ", 
     RowBox[{
      SuperscriptBox["g4", "\[Prime]",
       MultilineFunction->None], "[", "\[Phi]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
       RowBox[{"a", " ", 
        RowBox[{"H", "[", "a", "]"}], 
        RowBox[{
         RowBox[{"H", "'"}], "[", "a", "]"}]}]}], ")"}]}], "+", 
    RowBox[{
     SuperscriptBox["K", "\[Prime]",
      MultilineFunction->None], "[", "\[Phi]", "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.753104366141808*^9, 3.753104373882861*^9}, {
  3.754053763485999*^9, 
  3.754053783776803*^9}},ExpressionUUID->"7b9172f7-a6f5-4d8b-b261-\
dd0be06330f6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"eqscal1", "/.", 
      RowBox[{
       RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "'"}], "[", "a", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{"HL", ",", "a"}], "]"}]}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.753105476066646*^9, {3.753105587345478*^9, 3.7531055878734922`*^9}, {
   3.7540537977401752`*^9, 
   3.7540538032862053`*^9}},ExpressionUUID->"27fd33dd-ed2d-4233-84f4-\
08c36b2a474f"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["H0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"\[CapitalOmega]m0", "+", 
      RowBox[{"4", " ", 
       SuperscriptBox["a", "3"], " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
     ")"}], " ", 
    RowBox[{
     SuperscriptBox["g4", "\[Prime]",
      MultilineFunction->None], "[", "\[Phi]", "]"}]}], 
   SuperscriptBox["a", "3"]], "+", 
  RowBox[{
   SuperscriptBox["K", "\[Prime]",
    MultilineFunction->None], "[", "\[Phi]", "]"}]}]], "Output",
 CellChangeTimes->{
  3.753105476553343*^9, 3.753105588370403*^9, 3.753110137299548*^9, 
   3.7531101713727765`*^9, {3.754053772205767*^9, 
   3.7540538038662586`*^9}},ExpressionUUID->"a8939816-76f2-4aec-9aff-\
74a2597f7b65"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"3", "eqdes21"}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], "\[Rule]", "HL"}]}], "/.", 
    RowBox[{
     RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "\[Rule]", 
     RowBox[{"\[CapitalOmega]m0", " ", 
      SuperscriptBox["a", 
       RowBox[{"-", "3"}]]}]}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105447459355*^9, 3.7531054645662947`*^9}, {
  3.753105590708206*^9, 
  3.753105593623171*^9}},ExpressionUUID->"bc7fd261-d90b-4e9e-a043-\
8cbf380cf4fe"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     FractionBox["\[CapitalOmega]m0", 
      SuperscriptBox["a", "3"]], "+", "\[CapitalOmega]\[CapitalLambda]0"}], 
    ")"}], " ", 
   RowBox[{"g4", "[", "\[Phi]", "]"}]}], "-", 
  RowBox[{"K", "[", "\[Phi]", "]"}], "-", 
  RowBox[{"3", " ", "H0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"H0", " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["2"], " ", 
      SqrtBox["X"], " ", 
      SqrtBox[
       RowBox[{
        FractionBox["\[CapitalOmega]m0", 
         SuperscriptBox["a", "3"]], "+", 
        "\[CapitalOmega]\[CapitalLambda]0"}]], " ", 
      RowBox[{
       SuperscriptBox["g4", "\[Prime]",
        MultilineFunction->None], "[", "\[Phi]", "]"}]}]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.7531045533364906`*^9, {3.753105451522622*^9, 3.753105464850565*^9}, 
   3.7531055941314063`*^9, 3.753110138855093*^9, 3.753110172774557*^9, 
   3.754053811406353*^9},ExpressionUUID->"9044c2a5-9c4b-45de-ab1f-\
174b14467b20"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"X", "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], 
    RowBox[{"a", "^", "2"}], " ", 
    RowBox[{
     RowBox[{"H", "[", "a", "]"}], "^", "2"}], " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "^", "2"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.753105511622341*^9, 
  3.753105522319375*^9}},ExpressionUUID->"e1c641a5-22d4-4afb-bef9-\
6914c8f9d021"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sola", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"H", "^", "2"}], "\[Equal]", 
      RowBox[{"HL", "^", "2"}]}], ",", "a"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7531055988246164`*^9, 3.753105653662197*^9}, 
   3.753110142857869*^9, {3.753110190369815*^9, 
   3.7531101909083433`*^9}},ExpressionUUID->"fba65895-e01f-463f-ad0a-\
8ae60f3c9f45"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"a", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["H0", 
      RowBox[{"2", "/", "3"}]], " ", 
     SuperscriptBox["\[CapitalOmega]m0", 
      RowBox[{"1", "/", "3"}]]}], 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["H", "2"], "-", 
       RowBox[{
        SuperscriptBox["H0", "2"], " ", 
        "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}], 
     RowBox[{"1", "/", "3"}]]]}], "}"}]], "Output",
 CellChangeTimes->{{3.753105604228838*^9, 3.7531056542303205`*^9}, {
   3.7531101482612677`*^9, 3.75311019121295*^9}, 
   3.7540538220903845`*^9},ExpressionUUID->"e0137029-be31-4e8c-88aa-\
5cbdea0ebb4b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"EQ11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ1", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}], "\[IndentingNewLine]", 
 RowBox[{"EQ22", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"EQ2", "/.", "sola"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]}], "Input",
 CellChangeTimes->{{3.75310563172922*^9, 
  3.7531056909235077`*^9}},ExpressionUUID->"748edf63-af89-495c-8dc2-\
adc79b49f933"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["H", "2"], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}]}], 
    ")"}], " ", 
   RowBox[{
    SuperscriptBox["g4", "\[Prime]",
     MultilineFunction->None], "[", "\[Phi]", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["K", "\[Prime]",
    MultilineFunction->None], "[", "\[Phi]", "]"}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 
   3.754053824940747*^9},ExpressionUUID->"bb273b40-a5ec-4c52-a543-\
37ea84d6f435"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   SuperscriptBox["H", "2"], " ", 
   RowBox[{"g4", "[", "\[Phi]", "]"}]}], "-", 
  RowBox[{"K", "[", "\[Phi]", "]"}], "-", 
  RowBox[{"3", " ", "H0", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"H0", " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SqrtBox["2"], " ", "H", " ", 
       SqrtBox["X"], " ", 
       RowBox[{
        SuperscriptBox["g4", "\[Prime]",
         MultilineFunction->None], "[", "\[Phi]", "]"}]}], "H0"]}], 
    ")"}]}]}]], "Output",
 CellChangeTimes->{{3.7531056362999487`*^9, 3.7531056938493214`*^9}, {
   3.7531101797632627`*^9, 3.7531101937934017`*^9}, 
   3.7540538250260496`*^9},ExpressionUUID->"eec6eef8-7b10-4e1a-8112-\
e195ffd8679e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"eq3", "=", 
  RowBox[{
   RowBox[{"EQ11", "/.", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"EQ22", "\[Equal]", "0"}], ",", "H"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7531056952815824`*^9, 
  3.7531057296901493`*^9}},ExpressionUUID->"faf43546-163c-4eb5-a65d-\
c63ecb827b74"],

Cell[BoxData[
 RowBox[{
  RowBox[{"3", " ", 
   RowBox[{
    SuperscriptBox["g4", "\[Prime]",
     MultilineFunction->None], "[", "\[Phi]", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
     "+", 
     FractionBox[
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", 
          SqrtBox["X"], " ", 
          RowBox[{
           SuperscriptBox["g4", "\[Prime]",
            MultilineFunction->None], "[", "\[Phi]", "]"}]}], "+", 
         SqrtBox[
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            RowBox[{"g4", "[", "\[Phi]", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox["H0", "2"], " ", 
               "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
              RowBox[{"K", "[", "\[Phi]", "]"}]}], ")"}]}], "+", 
           RowBox[{"18", " ", "X", " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["g4", "\[Prime]",
               MultilineFunction->None], "[", "\[Phi]", "]"}], "2"]}]}]]}], 
        ")"}], "2"], 
      RowBox[{"36", " ", 
       SuperscriptBox[
        RowBox[{"g4", "[", "\[Phi]", "]"}], "2"]}]]}], ")"}]}], "+", 
  RowBox[{
   SuperscriptBox["K", "\[Prime]",
    MultilineFunction->None], "[", "\[Phi]", "]"}]}]], "Output",
 CellChangeTimes->{{3.7531057027783995`*^9, 3.753105730229594*^9}, 
   3.7531101961399784`*^9, 
   3.754053833059519*^9},ExpressionUUID->"69e2d52f-6186-4bee-832d-\
f9b36d440e40"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solG3", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"eq3", "\[Equal]", "0"}], ",", 
     RowBox[{
      SuperscriptBox["K", "\[Prime]",
       MultilineFunction->None], "[", "\[Phi]", "]"}]}], "]"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105730847949*^9, 3.7531058052531075`*^9}, {
  3.7540538548262625`*^9, 
  3.754053872395888*^9}},ExpressionUUID->"de6b3bb1-cc65-4468-a51f-\
7cac8cbe32d9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["K", "\[Prime]",
      MultilineFunction->None], "[", "\[Phi]", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     RowBox[{
      SuperscriptBox["g4", "\[Prime]",
       MultilineFunction->None], "[", "\[Phi]", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
       "+", 
       FractionBox[
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SqrtBox["X"], " ", 
            RowBox[{
             SuperscriptBox["g4", "\[Prime]",
              MultilineFunction->None], "[", "\[Phi]", "]"}]}], "+", 
           SqrtBox[
            RowBox[{
             RowBox[{
              RowBox[{"-", "6"}], " ", 
              RowBox[{"g4", "[", "\[Phi]", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 SuperscriptBox["H0", "2"], " ", 
                 "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
                RowBox[{"K", "[", "\[Phi]", "]"}]}], ")"}]}], "+", 
             RowBox[{"18", " ", "X", " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["g4", "\[Prime]",
                 MultilineFunction->None], "[", "\[Phi]", "]"}], "2"]}]}]]}], 
          ")"}], "2"], 
        RowBox[{"36", " ", 
         SuperscriptBox[
          RowBox[{"g4", "[", "\[Phi]", "]"}], "2"]}]]}], ")"}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.75310576637265*^9, 3.753105805737559*^9}, 
   3.753110198800361*^9, {3.754053860440261*^9, 
   3.754053875376135*^9}},ExpressionUUID->"b316cb02-fd62-491a-b3a6-\
5e6864a24a9f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"case", " ", "1", " ", 
   RowBox[{
    RowBox[{"K", "~", "X"}], "^", "n"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7531063588095603`*^9, 
  3.7531063667643137`*^9}},ExpressionUUID->"9e1aa4ca-d98c-4537-abcf-\
99fa8fb63ac4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"solG3", "/.", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"g4", "[", "\[Phi]", "]"}], "\[Rule]", 
        RowBox[{"\[Alpha]", " ", 
         RowBox[{"\[Phi]", "^", "n"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"\[Phi]", ",", "i"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "2"}], "}"}]}], "]"}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531058069981284`*^9, 3.7531058410291724`*^9}, {
  3.753105892322482*^9, 3.7531059153298244`*^9}, {3.75405388676448*^9, 
  3.754053895488241*^9}},ExpressionUUID->"39529cfb-e950-45d0-ad17-\
fb3343960447"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SuperscriptBox["K", "\[Prime]",
      MultilineFunction->None], "[", "\[Phi]", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", "n", " ", "\[Alpha]", " ", 
     SuperscriptBox["\[Phi]", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "n"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], 
       "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["\[Phi]", 
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}]], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", "n", " ", 
             SqrtBox["X"], " ", "\[Alpha]", " ", 
             SuperscriptBox["\[Phi]", "n"]}], "+", 
            RowBox[{
             SqrtBox["3"], " ", "\[Phi]", " ", 
             SqrtBox[
              RowBox[{"\[Alpha]", " ", 
               SuperscriptBox["\[Phi]", "n"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"3", " ", 
                  SuperscriptBox["n", "2"], " ", "X", " ", "\[Alpha]", " ", 
                  SuperscriptBox["\[Phi]", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "n"}]]}], "-", 
                 RowBox[{"3", " ", 
                  SuperscriptBox["H0", "2"], " ", 
                  "\[CapitalOmega]\[CapitalLambda]0"}], "-", 
                 RowBox[{"K", "[", "\[Phi]", "]"}]}], ")"}]}]]}]}], ")"}], 
          "2"]}], 
        RowBox[{"18", " ", 
         SuperscriptBox["\[Alpha]", "2"]}]]}], ")"}]}]}], "}"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7531058416691785`*^9, {3.7531059079901304`*^9, 3.7531059160917625`*^9}, 
   3.754053899742778*^9},ExpressionUUID->"db4ca517-d745-42ca-8ef9-\
b5177ee1839c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dd", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"DSolve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"G3", "'"}], "[", "X", "]"}], "==", 
       FractionBox[
        RowBox[{
         SqrtBox["J0"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SuperscriptBox["X", "n"], " ", 
            RowBox[{"(", 
             RowBox[{"\[Alpha]", "-", 
              RowBox[{"2", " ", "n", " ", "\[Alpha]"}]}], ")"}]}], "+", 
           RowBox[{"3", " ", 
            SuperscriptBox["H0", "2"], " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}]}], ")"}]}], 
        RowBox[{"6", " ", "H0", " ", 
         SuperscriptBox["X", 
          RowBox[{"5", "/", "4"}]], " ", 
         SqrtBox[
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", 
            SuperscriptBox["X", "n"], " ", "\[Alpha]", " ", 
            "\[CapitalOmega]m0"}], "+", 
           RowBox[{"2", " ", "J0", " ", 
            SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
            "\[CapitalOmega]\[CapitalLambda]0"}]}]]}]]}], ",", 
      RowBox[{"G3", "[", "X", "]"}], ",", "X"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753105918591773*^9, 3.7531059721079226`*^9}, {
  3.753106056934339*^9, 3.753106125485626*^9}, {3.75310622116893*^9, 
  3.7531062466371284`*^9}},ExpressionUUID->"e7094d57-1fef-4c4e-b139-\
814aabdc3c11"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     RowBox[{
      FractionBox["1", 
       RowBox[{"3", " ", "H0", " ", 
        SuperscriptBox["X", 
         RowBox[{"1", "/", "4"}]], " ", "\[CapitalOmega]m0"}]], 
      RowBox[{
       SqrtBox["J0"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["X", "n"], " ", "\[Alpha]", " ", 
          "\[CapitalOmega]m0"}], "+", 
         RowBox[{"4", " ", "J0", " ", 
          SqrtBox["X"], " ", "\[CapitalOmega]\[CapitalLambda]0"}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          "\[CapitalOmega]\[CapitalLambda]0"}]}]]}]}]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.753105963177185*^9, 3.753105972747184*^9}, {
  3.753106061850077*^9, 3.7531061260651007`*^9}, {3.7531062223267827`*^9, 
  3.7531062471645756`*^9}},ExpressionUUID->"29ea6418-50d5-4d1b-92f8-\
ba371b1352d9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"dd", "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", "0"}]}], "//", "FullSimplify"}], "//", 
   "Factor"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7531061375623384`*^9, 3.7531061522115917`*^9}, {
  3.753106228118154*^9, 
  3.7531062564200315`*^9}},ExpressionUUID->"6d284f67-7051-40bb-9de5-\
4bd65bd1cdc8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"G3", "[", "X", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       SqrtBox["2"], " ", 
       SqrtBox["J0"], " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "J0", " ", 
            SqrtBox["X"]}], "+", 
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0"}]}], ")"}], 
         " ", "\[CapitalOmega]\[CapitalLambda]0"}]]}], 
      RowBox[{"3", " ", "H0", " ", 
       SuperscriptBox["X", 
        RowBox[{"1", "/", "4"}]], " ", "\[CapitalOmega]m0"}]]}], "+", 
    RowBox[{"C", "[", "1", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7531061478127966`*^9, 3.7531061532170863`*^9}, {
  3.753106228686987*^9, 
  3.753106256653495*^9}},ExpressionUUID->"ed64d883-f2a9-4798-89d7-\
ee2d0c725448"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.753103919594767*^9, 
  3.753103921703641*^9}},ExpressionUUID->"d3f65622-c89b-41dd-9780-\
4e1e8ce67607"]
}, Closed]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568076779654055`*^9, 
  3.756807679653149*^9}},ExpressionUUID->"958b6a9f-860e-49bf-89bd-\
90daa377aa47"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"KBG", " ", "model", " ", "perturbations"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.757919363943246*^9, 3.7579193687991076`*^9}, 
   3.7579244512066727`*^9, {3.7590588668862963`*^9, 
   3.7590588760977716`*^9}},ExpressionUUID->"ad32ba00-e531-4fbb-8559-\
e5cba0776777"],

Cell[CellGroupData[{

Cell[BoxData["dX"], "Input",
 CellChangeTimes->{{3.757917119601478*^9, 
  3.7579171199017425`*^9}},ExpressionUUID->"42b5791e-44fb-4b41-aa93-\
a767510d28bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7579171204312725`*^9, 3.7583541401963615`*^9, 
  3.7583632196694374`*^9, 3.758372467434967*^9, 3.7584545270068655`*^9, 
  3.7590609876257763`*^9, 3.760600153920245*^9, 3.7607058342989445`*^9, 
  3.7608662008446317`*^9},ExpressionUUID->"c3c570ce-f566-45f4-98e8-\
987000cf58cb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesKGB0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.757917907265218*^9, 
  3.7579179389622374`*^9}},ExpressionUUID->"1dc670ae-962a-4e55-ab3b-\
371f2f142603"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesKGB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "X"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"X", "^", "n"}]}]}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "1"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "->", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "3"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.757916381634555*^9, 3.757916423887743*^9}, {
  3.757916557500442*^9, 3.757916558410334*^9}, {3.7579168359191437`*^9, 
  3.757916837039179*^9}, {3.7579169687664423`*^9, 3.7579170554777555`*^9}, {
  3.757917204573306*^9, 3.757917205547558*^9}, {3.7579174403747964`*^9, 
  3.7579176769574594`*^9}, {3.757917787720805*^9, 
  3.757917804564814*^9}},ExpressionUUID->"c8f994ad-b53b-4945-8b39-\
eff37fc0a007"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soldx", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"dX", "\[Equal]", 
      RowBox[{"\[Delta]X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7579179554840155`*^9, 3.7579180115651007`*^9}, {
  3.758355025257509*^9, 3.758355025507535*^9}, {3.758363224552236*^9, 
  3.7583632281896715`*^9}},ExpressionUUID->"050cc75b-86ae-4f95-a429-\
57df6fbaa5a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"\[Delta]X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.758354189661841*^9, 3.758355026241912*^9, 
  3.7583632645536985`*^9, 3.758372471387169*^9, 3.7584545303267717`*^9, 
  3.7590609902855277`*^9, 3.7606001540525484`*^9, 3.760705886169163*^9, 
  3.760866228584202*^9},ExpressionUUID->"f09b3434-5c38-4f7a-bdec-\
f4736eab127a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Use", " ", "that", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]X", "'"}], "[", "t", "]"}], "~", "0"}], " ", "to", " ",
     "eliminate", " ", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "'"}], "[", "t", "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"solps", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"dX", ",", "t"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       SuperscriptBox["\[CapitalPsi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7579200296408415`*^9, 3.757920063710582*^9}, {
  3.757920614887021*^9, 
  3.7579206373067665`*^9}},ExpressionUUID->"f5b72dfa-9336-43d4-a5a4-\
6c099e830f29"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.758354190864962*^9, 3.758355030587587*^9, 
  3.7583632680597258`*^9, 3.7583724724802*^9, 3.7584545312317944`*^9, 
  3.7590609916757574`*^9, 3.760600154103397*^9, 3.7607058883933687`*^9, 
  3.760866233390362*^9},ExpressionUUID->"74e3cd97-42cc-4cbf-968f-\
470e160f9f38"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"solft2", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"X0", ",", "t"}], "]"}], "==", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["H0", 
            FractionBox[
             RowBox[{"4", " ", "n"}], 
             RowBox[{
              RowBox[{"-", "1"}], "+", 
              RowBox[{"2", " ", "n"}]}]]], " ", 
           "\[CapitalOmega]\[CapitalLambda]", " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "a", "]"}], 
            FractionBox["2", 
             RowBox[{"1", "-", 
              RowBox[{"2", " ", "n"}]}]]]}], ",", "a"}], "]"}], " ", "a", " ", 
        RowBox[{"H", "[", "a", "]"}]}]}], ",", 
      RowBox[{
       RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sdx0", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"dX", "\[Equal]", 
       RowBox[{"\[Delta]X", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sdx1", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"dX", ",", "t"}], "]"}], "\[Equal]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Delta]X", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", "t"}], 
        "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sdx2", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"dX", ",", "t", ",", "t"}], "]"}], "\[Equal]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Delta]X", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", "t", ",", 
         "t"}], "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7579224074331045`*^9, 3.757922407701745*^9}, {
  3.758363236159485*^9, 3.7583632620993247`*^9}, {3.7583643543598747`*^9, 
  3.7583643558447037`*^9}},ExpressionUUID->"c39cd311-87ec-495a-acfa-\
0c410e681a02"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", "background", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7583549647491107`*^9, 
  3.7583549695150185`*^9}},ExpressionUUID->"eca19379-f815-48f7-9aa4-\
67cbece8433d"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Jtot", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", "rulesKGB0"}], "/.", 
     "zeroorder"}], "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["X", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     RowBox[{"D", "[", 
      RowBox[{"X0", ",", "t"}], "]"}]}]}], "/.", 
   RowBox[{
    RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
    RowBox[{"-", "1"}]}]}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"attr", "=", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Phi]", "'"}], "[", "t", "]"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.757918406085178*^9, 3.757918419245304*^9}, {
  3.7579184636510124`*^9, 3.757918470019801*^9}, {3.757918502177478*^9, 
  3.757918550282708*^9}, {3.7579186958187213`*^9, 
  3.7579186966188064`*^9}},ExpressionUUID->"700c9aa1-9e99-444c-8e30-\
f52ee858b44d"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Phi]", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.7579184593557773`*^9, 3.757918470650233*^9}, {
   3.757918511396525*^9, 3.7579185511318693`*^9}, 3.757918697178364*^9, 
   3.758354142165101*^9, 3.7583541954430623`*^9, 3.7583633187043233`*^9, 
   3.758372490455039*^9, 3.7584545383468122`*^9, 3.76070593795894*^9, 
   3.7608662721444645`*^9},ExpressionUUID->"e19163df-e9b7-43ba-8219-\
abab5ddd393c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     FractionBox["1", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7579184593557773`*^9, 3.757918470650233*^9}, {
   3.757918511396525*^9, 3.7579185511318693`*^9}, 3.757918697178364*^9, 
   3.758354142165101*^9, 3.7583541954430623`*^9, 3.7583633187043233`*^9, 
   3.758372490455039*^9, 3.7584545383468122`*^9, 3.76070593795894*^9, 
   3.7608662721540623`*^9},ExpressionUUID->"5a19dbeb-a46e-4199-99a4-\
de053af2c6db"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solfkgb", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
         RowBox[{"(", 
          RowBox[{
           FractionBox["1", 
            RowBox[{"3", " ", 
             RowBox[{"G3X", "[", "t", "]"}], " ", 
             RowBox[{"H", "[", "t", "]"}]}]], "/.", 
           RowBox[{
            RowBox[{"G3X", "[", "t", "]"}], "->", 
            RowBox[{"D", "[", 
             RowBox[{
              RowBox[{"\[Alpha]", " ", 
               SuperscriptBox["X", "n"]}], ",", 
              RowBox[{"{", 
               RowBox[{"X", ",", "1"}], "}"}]}], "]"}]}]}], ")"}]}], "/.", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], ",", "X"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}]}]], "Input",
 CellChangeTimes->{{3.757918714427039*^9, 3.757918785893795*^9}, {
  3.7579188485511265`*^9, 
  3.7579188998486586`*^9}},ExpressionUUID->"5dd1417d-87e0-45d4-ae1d-\
8ed61bcf2bbc"],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,128,2,17621159532487489457,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.7579187475549927`*^9, 3.7579187862634745`*^9}, {
   3.757918860130337*^9, 3.7579189002085423`*^9}, 3.7583543690300303`*^9, 
   3.7583633187795157`*^9, 3.7583724918299203`*^9, 3.758454538403157*^9, 
   3.7607059380120296`*^9, 
   3.7608662737541633`*^9},ExpressionUUID->"181c659c-aa76-4457-9f6a-\
2460f6c107e1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"X", "\[Rule]", 
   RowBox[{
    SuperscriptBox["18", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "n"}]}]]], " ", 
    SuperscriptBox["n", 
     RowBox[{"-", 
      FractionBox["2", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "n"}]}]]}]], " ", 
    SuperscriptBox["\[Alpha]", 
     RowBox[{"-", 
      FractionBox["2", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "n"}]}]]}]], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], 
     RowBox[{"-", 
      FractionBox["2", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "n"}]}]]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.757918747568358*^9, 3.7579187863131795`*^9}, {
   3.757918860180134*^9, 3.7579189002584257`*^9}, 3.7583543690769053`*^9, 
   3.7583633188194246`*^9, 3.7583724918802648`*^9, 3.758454538442192*^9, 
   3.760705938038974*^9, 
   3.760866273799205*^9},ExpressionUUID->"261d0bfc-ccaa-4d9a-8e65-\
22f7b22bfb2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"HubKGB", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"eq00", "/.", "rulesKGB0"}], "/.", "rulesKGB"}], "/.", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
         SqrtBox[
          RowBox[{"2", "X"}]]}]}], "/.", "solfkgb"}], "//", "FullSimplify"}], 
     "//", "PowerExpand"}], "//", "FullSimplify"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7579182823425927`*^9, 3.757918299041701*^9}, {
  3.7579186929588323`*^9, 3.75791870243827*^9}, {3.7579187904033833`*^9, 
  3.757918795228794*^9}, {3.757918877573387*^9, 3.757918878398737*^9}, {
  3.7579189090613413`*^9, 
  3.7579189442669125`*^9}},ExpressionUUID->"87085f85-2fa6-4168-ac89-\
0caf5185f3cc"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["3", "2"]}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "n"}]}]]}]], " ", 
   SuperscriptBox["9", 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox["n", 
    FractionBox["2", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox["\[Alpha]", 
    FractionBox["2", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], 
    FractionBox["2", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]]}], "+", 
  RowBox[{"4", " ", "G", " ", "\[Pi]", " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7579182834384975`*^9, 3.757918300180554*^9}, 
   3.757918694093255*^9, 3.7579187963164215`*^9, {3.757918909646865*^9, 
   3.757918944836916*^9}, 3.75835437132907*^9, 3.7583633192344646`*^9, 
   3.758372494010105*^9, 3.758454538851157*^9, 3.760705938440172*^9, 
   3.7608662757741947`*^9},ExpressionUUID->"7b266d69-46fa-461b-8ed4-\
82a51e35c347"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"H1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"HubKGB", "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], " ", "\[Rho]c"}]}]}], "/.", 
    RowBox[{"t", "\[Rule]", "a"}]}], "/.", 
   RowBox[{
    RowBox[{"H", "[", "a", "]"}], "\[Rule]", 
    SqrtBox[
     RowBox[{"H2", "[", "a", "]"}]]}]}]}]], "Input",
 CellChangeTimes->{{3.7579189482170277`*^9, 3.757919066411661*^9}, {
   3.757919129898951*^9, 3.7579191332993608`*^9}, 
   3.7579194005880127`*^9},ExpressionUUID->"98c40058-608f-48d2-8d13-\
3df926b8b7c4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"H2", "[", "a", "]"}]}], "2"]}], "+", 
  RowBox[{
   SuperscriptBox["2", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox["1", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "n"}]}]]}]], " ", 
   SuperscriptBox["9", 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox["n", 
    FractionBox["2", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox["\[Alpha]", 
    FractionBox["2", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox[
    RowBox[{"H2", "[", "a", "]"}], 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.757918949696336*^9, 3.757919001993272*^9}, {
   3.7579190330686665`*^9, 3.75791906796177*^9}, 3.7579191337490416`*^9, 
   3.757919401317219*^9, 3.7583543723446918`*^9, 3.7583633192898207`*^9, 
   3.7583724947351637`*^9, 3.758454538906793*^9, 3.76070593848943*^9, 
   3.7608662765591555`*^9},ExpressionUUID->"31c8aaaa-5068-4ac1-87cc-\
70e4a2900911"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"H1", "/.", 
     RowBox[{"a", "\[Rule]", "1"}]}], "/.", 
    RowBox[{
     RowBox[{"H2", "[", "1", "]"}], "\[Rule]", 
     RowBox[{"H0", "^", "2"}]}]}], "//", "PowerExpand"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"sola", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"%", "\[Equal]", "0"}], ",", "\[Alpha]"}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{"\[CapitalOmega]m", "[", "1", "]"}], "\[Rule]", 
       RowBox[{"1", "-", "\[CapitalOmega]\[CapitalLambda]"}]}]}], "//", 
     "FullSimplify"}], "//", "PowerExpand"}], "//", 
   "FullSimplify"}]}]}], "Input",
 CellChangeTimes->{{3.757919054042508*^9, 3.7579191418643017`*^9}, {
  3.757919177001234*^9, 3.7579191993261127`*^9}, {3.757919408511975*^9, 
  3.7579194696748967`*^9}},ExpressionUUID->"23d9a407-f784-4d93-bedf-\
d3158f523994"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["18", 
      FractionBox["1", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "n"}]}]]], " ", 
     SuperscriptBox["H0", 
      FractionBox["2", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "n"}]}]]], " ", 
     SuperscriptBox["n", 
      FractionBox["2", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "n"}]}]]], " ", 
     SuperscriptBox["\[Alpha]", 
      FractionBox["2", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "n"}]}]]]}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox["H0", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"\[CapitalOmega]m", "[", "1", "]"}]}], ")"}]}]}], 
   ")"}]}]], "Output",
 CellChangeTimes->{{3.75791907164132*^9, 3.757919109749798*^9}, 
   3.7579191434686966`*^9, {3.75791919488629*^9, 3.757919199716002*^9}, {
   3.757919405297472*^9, 3.7579194705551343`*^9}, 3.7583543749540253`*^9, 
   3.758363319433915*^9, 3.7583724957497993`*^9, 3.7584545390170336`*^9, 
   3.760705938594329*^9, 
   3.7608662779867954`*^9},ExpressionUUID->"202d59e1-dfa3-4fd0-a65b-\
40be1e91dc7b"],

Cell[BoxData[
 TemplateBox[{
  "Solve","ifun",
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"",2,132,3,17621159532487489457,
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{{3.757919405377755*^9, 3.7579194706090107`*^9}, 
   3.7583543750633984`*^9, 3.758363319449559*^9, 3.7583724958183746`*^9, 
   3.7584545390569997`*^9, 3.760705938623293*^9, 
   3.760866278094582*^9},ExpressionUUID->"bab18367-307c-488f-8a38-\
c72f6e89ae6b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Alpha]", "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["3", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], "-", "n"}]], " ", 
     SuperscriptBox["H0", 
      RowBox[{
       RowBox[{"-", "2"}], " ", "n"}]], " ", 
     SuperscriptBox["\[CapitalOmega]\[CapitalLambda]", 
      RowBox[{
       FractionBox["1", "2"], "-", "n"}]]}], 
    RowBox[{
     SqrtBox["2"], " ", "n"}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.75791907164132*^9, 3.757919109749798*^9}, 
   3.7579191434686966`*^9, {3.75791919488629*^9, 3.757919199716002*^9}, {
   3.757919405297472*^9, 3.7579194705551343`*^9}, 3.7583543749540253`*^9, 
   3.758363319433915*^9, 3.7583724957497993`*^9, 3.7584545390170336`*^9, 
   3.760705938594329*^9, 
   3.760866278274535*^9},ExpressionUUID->"7c339ac0-5a6b-464f-97a7-\
423f7123500c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"X", "\[Rule]", 
        RowBox[{
         SuperscriptBox["18", 
          FractionBox["1", 
           RowBox[{"1", "-", 
            RowBox[{"2", " ", "n"}]}]]], " ", 
         SuperscriptBox["n", 
          RowBox[{"-", 
           FractionBox["2", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "n"}]}]]}]], " ", 
         SuperscriptBox["\[Alpha]", 
          RowBox[{"-", 
           FractionBox["2", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "n"}]}]]}]], " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], 
          RowBox[{"-", 
           FractionBox["2", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"2", " ", "n"}]}]]}]]}]}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{"\[Alpha]", "\[Rule]", 
        FractionBox[
         RowBox[{
          SuperscriptBox["3", 
           RowBox[{
            RowBox[{"-", 
             FractionBox["1", "2"]}], "-", "n"}]], " ", 
          SuperscriptBox["H0", 
           RowBox[{
            RowBox[{"-", "2"}], " ", "n"}]], " ", 
          SuperscriptBox["\[CapitalOmega]\[CapitalLambda]", 
           RowBox[{
            FractionBox["1", "2"], "-", "n"}]]}], 
         RowBox[{
          SqrtBox["2"], " ", "n"}]]}], "}"}]}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"H0", " ", 
       RowBox[{"h", "[", "a", "]"}]}]}]}], "//", "FullSimplify"}], "//", 
   "PowerExpand"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.763881879059097*^9, 3.7638818972108994`*^9}, {
  3.763881927604664*^9, 
  3.7638819358545923`*^9}},ExpressionUUID->"f228fdfb-fd2d-4636-bbf7-\
cc7061c887ca"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"X", "\[Rule]", 
   RowBox[{"3", " ", 
    SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]", " ", 
    SuperscriptBox[
     RowBox[{"h", "[", "a", "]"}], 
     FractionBox["2", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "n"}]}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7638818822264366`*^9, 3.763881897606125*^9}, 
   3.763881936584354*^9},ExpressionUUID->"73c54dba-7927-48f3-bf4f-\
bcb3230d3e78"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"2", "/", "3"}], "H1"}], "/.", "sola"}], "//", "PowerExpand"}], "//",
   "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{"%", ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "\[Infinity]", ",", "0"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{{3.7579197014557295`*^9, 3.7579197137550735`*^9}, {
  3.757921552356902*^9, 
  3.75792155576658*^9}},ExpressionUUID->"b9ac7706-f997-4b8a-a602-\
2368a4ec7a13"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"H2", "[", "a", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["H0", 
    FractionBox[
     RowBox[{"4", " ", "n"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "n"}]}]]], " ", "\[CapitalOmega]\[CapitalLambda]", 
   " ", 
   SuperscriptBox[
    RowBox[{"H2", "[", "a", "]"}], 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]]}], "+", 
  RowBox[{
   SuperscriptBox["H0", "2"], " ", 
   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.757919702636074*^9, 3.757919714134592*^9}, {
   3.7579215531169343`*^9, 3.7579215562505155`*^9}, 3.758354378282132*^9, 
   3.758363319859271*^9, 3.75837249763719*^9, 3.758454539418931*^9, 
   3.7607059390638247`*^9, 
   3.760866282284362*^9},ExpressionUUID->"10a9c323-ed57-4816-bdfd-\
5a7ef847f93c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"H2", "[", "a", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", 
      RowBox[{"(", 
       RowBox[{"\[CapitalOmega]\[CapitalLambda]", "+", 
        RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], ")"}]}]}], ")"}], "+", 
   
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "1"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[
   1], {-$CellContext`H2[$CellContext`a] + $CellContext`H0^2 ($CellContext`\
\[CapitalOmega]\[CapitalLambda] + \
$CellContext`\[CapitalOmega]m[$CellContext`a])}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.757919702636074*^9, 3.757919714134592*^9}, {
   3.7579215531169343`*^9, 3.7579215562505155`*^9}, 3.758354378282132*^9, 
   3.758363319859271*^9, 3.75837249763719*^9, 3.758454539418931*^9, 
   3.7607059390638247`*^9, 
   3.7608662823291607`*^9},ExpressionUUID->"f6529a29-58c9-4735-98c6-\
9ff4d3cceeb4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solXn", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"solfkgb", "/.", "sola"}], "//", "FullSimplify"}], "//", 
    "PowerExpand"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7579195304227953`*^9, 
  3.7579195781796627`*^9}},ExpressionUUID->"ad007463-a0c0-4406-a082-\
659d9f24a73d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"X", "\[Rule]", 
   RowBox[{"3", " ", 
    SuperscriptBox["H0", 
     FractionBox[
      RowBox[{"4", " ", "n"}], 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "n"}]}]]], " ", "\[CapitalOmega]\[CapitalLambda]", 
    " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], 
     FractionBox["2", 
      RowBox[{"1", "-", 
       RowBox[{"2", " ", "n"}]}]]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7579195286666327`*^9, 3.7579195482014327`*^9}, 
   3.7579195787192774`*^9, 3.7583543807196493`*^9, 3.758363320089383*^9, 
   3.7583724990848293`*^9, 3.758454539658992*^9, 3.7607059393238397`*^9, 
   3.7608662849266357`*^9},ExpressionUUID->"15e04151-87a0-405d-b1a1-\
882ead0f2e2a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"H1", "/.", 
          RowBox[{"n", "\[Rule]", "1"}]}], ")"}], "\[Equal]", "0"}], ",", 
       RowBox[{"H2", "[", "a", "]"}]}], "]"}], "[", 
     RowBox[{"[", "2", "]"}], "]"}], "/.", 
    RowBox[{"(", 
     RowBox[{"sola", "/.", 
      RowBox[{"n", "\[Rule]", "1"}]}], ")"}]}], "//", "FullSimplify"}], "//", 
  "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.7579191129400053`*^9, 3.7579191595178785`*^9}, {
  3.75791920574617*^9, 3.7579192334147973`*^9}, {3.757919420247168*^9, 
  3.757919458715371*^9}},ExpressionUUID->"6364fc60-e602-4fb1-9ed8-\
4d6449457f09"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"H2", "[", "a", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    SuperscriptBox["H0", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "+", 
      SqrtBox[
       RowBox[{
        RowBox[{"4", " ", "\[CapitalOmega]\[CapitalLambda]"}], "+", 
        SuperscriptBox[
         RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "2"]}]]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7579191224096513`*^9, 3.7579191617873435`*^9}, {
   3.757919203005241*^9, 3.757919234264571*^9}, {3.757919422096834*^9, 
   3.75791942816648*^9}, 3.757919459505216*^9, 3.758354384375879*^9, 
   3.7583633202295027`*^9, 3.7583724999998536`*^9, 3.7584545397718787`*^9, 
   3.7607059394240527`*^9, 
   3.760866286314575*^9},ExpressionUUID->"0c94fc60-92b6-4a79-9626-\
93b311234eb0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]", " ", 
      SuperscriptBox["X", "n"]}], "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["3", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], "-", "n"}]], " ", 
        SuperscriptBox["H0", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "n"}]], " ", 
        SuperscriptBox["\[CapitalOmega]\[CapitalLambda]", 
         RowBox[{
          FractionBox["1", "2"], "-", "n"}]]}], 
       RowBox[{
        SqrtBox["2"], " ", "n"}]]}]}], "/.", 
    RowBox[{"X", "\[Rule]", 
     RowBox[{"3", " ", 
      SuperscriptBox["H0", 
       FractionBox[
        RowBox[{"4", " ", "n"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}]]], " ", "\[CapitalOmega]\[CapitalLambda]", 
      " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], 
       FractionBox["2", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "n"}]}]]]}]}]}], "//", "PowerExpand"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "\[Infinity]", ",", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7579296768865485`*^9, 
  3.7579296784608808`*^9}},ExpressionUUID->"4fad4bda-5257-4ab7-b7eb-\
d9139343b5d7"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["H0", 
    RowBox[{"1", "+", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "n"}]}]]}]], " ", 
   SqrtBox["\[CapitalOmega]\[CapitalLambda]"], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], 
    FractionBox[
     RowBox[{"2", " ", "n"}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]]}], 
  RowBox[{
   SqrtBox["6"], " ", "n"}]]], "Output",
 CellChangeTimes->{3.757929679695593*^9, 3.758354386157093*^9, 
  3.75836332037936*^9, 3.7583725017951584`*^9, 3.7584545399189105`*^9, 
  3.7607059395288916`*^9, 
  3.760866293794248*^9},ExpressionUUID->"d696f5b0-b215-4881-a3e4-\
ab8b33ce245e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{"H0", " ", 
     SqrtBox["\[CapitalOmega]\[CapitalLambda]"]}], 
    RowBox[{
     SqrtBox["6"], " ", 
     RowBox[{"H", "[", "a", "]"}], " ", "n"}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "2"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, 1, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[1], {
   6^Rational[-1, 
       2] $CellContext`H0 $CellContext`\[CapitalOmega]\[CapitalLambda]^
     Rational[1, 2]/$CellContext`H[$CellContext`a]}, 1, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.757929679695593*^9, 3.758354386157093*^9, 
  3.75836332037936*^9, 3.7583725017951584`*^9, 3.7584545399189105`*^9, 
  3.7607059395288916`*^9, 
  3.7608662938141775`*^9},ExpressionUUID->"b96404a9-16e8-409c-ac9e-\
ea4e796a87ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Alpha]", " ", "n", " ", 
      SuperscriptBox["X", 
       RowBox[{"n", "-", "1"}]]}], "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", 
      FractionBox[
       RowBox[{
        SuperscriptBox["3", 
         RowBox[{
          RowBox[{"-", 
           FractionBox["1", "2"]}], "-", "n"}]], " ", 
        SuperscriptBox["H0", 
         RowBox[{
          RowBox[{"-", "2"}], " ", "n"}]], " ", 
        SuperscriptBox["\[CapitalOmega]\[CapitalLambda]", 
         RowBox[{
          FractionBox["1", "2"], "-", "n"}]]}], 
       RowBox[{
        SqrtBox["2"], " ", "n"}]]}]}], "/.", 
    RowBox[{"X", "\[Rule]", 
     RowBox[{"3", " ", 
      SuperscriptBox["H0", 
       FractionBox[
        RowBox[{"4", " ", "n"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}]]], " ", "\[CapitalOmega]\[CapitalLambda]", 
      " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], 
       FractionBox["2", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "n"}]}]]]}]}]}], "//", "PowerExpand"}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "\[Infinity]", ",", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.757929584400195*^9, 
  3.757929662376972*^9}},ExpressionUUID->"8056e4c2-a0ce-4b1d-8cbf-\
f6fb21b0d732"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["H0", 
    FractionBox[
     RowBox[{"2", " ", "n"}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     FractionBox["1", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "n"}]}]]}]]}], 
  RowBox[{"3", " ", 
   SqrtBox["6"], " ", 
   SqrtBox["\[CapitalOmega]\[CapitalLambda]"]}]]], "Output",
 CellChangeTimes->{{3.7579295950161495`*^9, 3.7579296232923975`*^9}, {
   3.757929659051406*^9, 3.757929663032139*^9}, 3.758363320559574*^9, 
   3.7583725042650223`*^9, 3.7584545400369644`*^9, 
   3.760705939644141*^9},ExpressionUUID->"0be33ee4-d4c8-4bf0-9fef-\
b7bee5e15610"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{"3", " ", 
     SqrtBox["6"], " ", "H0", " ", 
     SqrtBox["\[CapitalOmega]\[CapitalLambda]"], " ", 
     RowBox[{"H", "[", "a", "]"}]}]], "+", 
   FractionBox[
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       SqrtBox["6"]}], " ", 
      RowBox[{"Log", "[", "H0", "]"}]}], "+", 
     RowBox[{
      SqrtBox["6"], " ", 
      RowBox[{"Log", "[", 
       RowBox[{"H", "[", "a", "]"}], "]"}]}]}], 
    RowBox[{"36", " ", "H0", " ", 
     SqrtBox["\[CapitalOmega]\[CapitalLambda]"], " ", 
     RowBox[{"H", "[", "a", "]"}], " ", "n"}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "2"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, 0, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[1], {
   Rational[1, 3] 
    6^Rational[-1, 
       2] $CellContext`H0^(-1) $CellContext`\[CapitalOmega]\[CapitalLambda]^
     Rational[-1, 2]/$CellContext`H[$CellContext`a], 
    Rational[1, 
      36] $CellContext`H0^(-1) $CellContext`\[CapitalOmega]\[CapitalLambda]^
     Rational[-1, 2] $CellContext`H[$CellContext`a]^(-1) (-6^Rational[1, 2] 
      Log[$CellContext`H0] + 6^Rational[1, 2] Log[
        $CellContext`H[$CellContext`a]])}, 0, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7579295950161495`*^9, 3.7579296232923975`*^9}, {
   3.757929659051406*^9, 3.757929663032139*^9}, 3.758363320559574*^9, 
   3.7583725042650223`*^9, 3.7584545400369644`*^9, 
   3.7607059396589546`*^9},ExpressionUUID->"d4f7e06b-4a31-4ad3-8ec8-\
0fa7f8d67239"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           FractionBox["1", "2"], 
           RowBox[{
            RowBox[{
             RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "2"}]}], ",", 
          "t"}], "]"}], "==", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{"3", " ", 
            SuperscriptBox["H0", 
             FractionBox[
              RowBox[{"4", " ", "n"}], 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "n"}]}]]], " ", 
            "\[CapitalOmega]\[CapitalLambda]", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "a", "]"}], 
             FractionBox["2", 
              RowBox[{"1", "-", 
               RowBox[{"2", " ", "n"}]}]]]}], ",", "a"}], "]"}], " ", "a", 
         " ", 
         RowBox[{"H", "[", "a", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
     SqrtBox[
      RowBox[{"2", "X"}]]}]}], "/.", 
   RowBox[{"X", "\[Rule]", 
    RowBox[{"3", " ", 
     SuperscriptBox["H0", 
      FractionBox[
       RowBox[{"4", " ", "n"}], 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        RowBox[{"2", " ", "n"}]}]]], " ", "\[CapitalOmega]\[CapitalLambda]", 
     " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "a", "]"}], 
      FractionBox["2", 
       RowBox[{"1", "-", 
        RowBox[{"2", " ", "n"}]}]]]}]}]}], "//", "PowerExpand"}]], "Input",
 CellChangeTimes->{{3.757929737078767*^9, 3.7579297413764067`*^9}, {
   3.7579297783919687`*^9, 3.7579297911143465`*^9}, 
   3.759651444071395*^9},ExpressionUUID->"efe09db8-b598-454c-8a5c-\
1e931341b7df"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SqrtBox["6"], " ", "a", " ", 
      SuperscriptBox["H0", 
       FractionBox[
        RowBox[{"2", " ", "n"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}]]], " ", 
      SqrtBox["\[CapitalOmega]\[CapitalLambda]"], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], 
       FractionBox["1", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "n"}]}]]], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "n"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7579297326023703`*^9, 3.757929741946783*^9}, {
   3.7579297874337482`*^9, 3.7579297915847244`*^9}, 3.758363320639395*^9, 
   3.7583725078374443`*^9, 3.758454540171976*^9, 3.759651447133601*^9, 
   3.7607059396990848`*^9},ExpressionUUID->"dfcf36c1-7146-4923-baa5-\
0e032c949fa3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SqrtBox["6"], " ", "a", " ", 
      SuperscriptBox["H0", 
       FractionBox[
        RowBox[{"2", " ", "n"}], 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}]]], " ", 
      SqrtBox["\[CapitalOmega]\[CapitalLambda]"], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], 
       FractionBox["1", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "n"}]}]]], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "n"}]}]]}], ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "\[Infinity]", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.7579297993375635`*^9, 
  3.75965147230357*^9},ExpressionUUID->"d321cf8e-414d-406c-8312-0da37d22532f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SqrtBox[
       FractionBox["3", "2"]], " ", "a", " ", "H0", " ", 
      SqrtBox["\[CapitalOmega]\[CapitalLambda]"], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}], "n"]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "2"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, 1, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[
   1], {-Rational[3, 2]^
     Rational[1, 
       2] $CellContext`a $CellContext`H0 $CellContext`\[CapitalOmega]\
\[CapitalLambda]^Rational[1, 2] 
    Derivative[1][$CellContext`H][$CellContext`a]}, 1, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.7579298004880624`*^9, 3.758363320679139*^9, 
  3.7584545402716093`*^9, 3.759651473231309*^9, 
  3.7607059397341795`*^9},ExpressionUUID->"6653ce58-dc78-4f1b-ad8a-\
0300201ef802"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7583549782043457`*^9, 
  3.7583549799721456`*^9}},ExpressionUUID->"e0674789-8987-40c3-aedb-\
9f69d37e85ad"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"RHS", " ", "of", " ", 
    RowBox[{"Eq", ".", " ", 
     RowBox[{"(", "4.4", ")"}]}], " ", "of", " ", "Kimura"}], " ", "*)"}],
  FontSize->16]], "Input",
 CellChangeTimes->{
  3.7583546274405675`*^9},ExpressionUUID->"e5061296-b4e1-4961-b831-\
77a9030f6ba7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eqsii", "/", "3"}], "/.", "rulesKGB0"}], ")"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Eqsii", "/", "3"}], "/.", "rulesGR"}], ")"}]}], "/.", 
   "soldx"}], "//", "Expand"}]], "Input",
 CellChangeTimes->{
  3.758354465531599*^9},ExpressionUUID->"1612bfe4-9f11-4db7-97ae-\
c11b995d2d33"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7583725143500137`*^9, 3.7584545408069115`*^9, 
  3.760705897514333*^9, 
  3.760866300096941*^9},ExpressionUUID->"8cec0389-08aa-4de9-b826-\
16cee64e2fd0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Eqsii", "/", "3"}], "/.", "rulesKGB0"}], ")"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Eqsii", "/", "3"}], "/.", "rulesGR"}], ")"}]}], "/.", 
      "soldx"}], "/.", "sdx2"}], "/.", "sdx1"}], "/.", "sdx0"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.757916628530964*^9, 3.757916652767982*^9}, {
  3.7579168299884214`*^9, 3.757916863866147*^9}, {3.7579169094516287`*^9, 
  3.757916955797043*^9}, {3.7579170669399295`*^9, 3.757917090683976*^9}, {
  3.7579178144878397`*^9, 3.7579178878670883`*^9}, {3.75791794520072*^9, 
  3.757917946597911*^9}, {3.75791801516461*^9, 3.757918051891244*^9}, {
  3.7579181068158736`*^9, 3.7579181110454044`*^9}, {3.758354423305936*^9, 
  3.7583544461675787`*^9}, {3.7583544955852365`*^9, 
  3.7583545002260036`*^9}},ExpressionUUID->"ba3db77d-e958-462a-8a51-\
d572b8bee448"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]X", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.757917818417412*^9, 3.757917857983447*^9}, 
   3.7579178895411043`*^9, 3.7579179471604905`*^9, {3.7579180202842493`*^9, 
   3.7579180525710063`*^9}, {3.7579181084055185`*^9, 
   3.7579181115552535`*^9}, {3.7583544090671215`*^9, 3.758354446995677*^9}, {
   3.7583544965069933`*^9, 3.7583545007101116`*^9}, 3.7583550443087835`*^9, 
   3.758355100292222*^9, 3.7583632823896093`*^9, 3.75836436062519*^9, 
   3.758372519637514*^9, 3.758454542999835*^9, 
   3.7608663014242163`*^9},ExpressionUUID->"9124ffc6-8807-4978-bdbb-\
5294d2a1e695"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eq44", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eqsii", "/", "3"}], "/.", "rulesKGB"}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eqsii", "/", "3"}], "/.", "rulesGR"}], ")"}]}], "/.", 
    "soldx"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.7579182433916664`*^9, {3.7579196016198883`*^9, 3.7579196034625883`*^9}, {
   3.7579205381107483`*^9, 
   3.757920539230682*^9}},ExpressionUUID->"56b95b6a-5223-46ba-a38d-\
aa215d6e701b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"4", " ", "n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "2"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", "n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{"n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.7579182446324472`*^9, 3.757919603899617*^9, 
  3.757920539970329*^9, 3.758355101198469*^9, 3.7583632850397015`*^9, 
  3.75836436153999*^9, 3.7583725211800556`*^9, 3.7584545440120125`*^9, 
  3.7607059122590537`*^9, 
  3.760866302419148*^9},ExpressionUUID->"f830c7ce-bd51-4ef4-b60f-\
afaccaaf5768"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"Eq44", "/.", 
             RowBox[{
              RowBox[{"\[Delta]X", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
              "0"}]}], "/.", "solps"}], "/.", "sola"}], "/.", "solXn"}], "/.",
          "solft2"}], "/.", "sdx0"}], "/.", 
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
      RowBox[{
       RowBox[{
        RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
       SqrtBox[
        RowBox[{"2", "X"}]]}]}], "/.", "solXn"}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]X", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}]}], 
   "//", "PowerExpand"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "\[Infinity]", ",", "1"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7579214126193256`*^9, 3.7579214639887795`*^9}, {
   3.757922354232687*^9, 3.757922386292746*^9}, {3.758355094462109*^9, 
   3.7583550952902355`*^9}, 3.758363299059365*^9, 
   3.758363332134547*^9},ExpressionUUID->"21ce6ac3-1454-4b2e-803c-\
f07042f7dc03"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", "a", " ", 
   SuperscriptBox["H0", 
    FractionBox[
     RowBox[{"4", " ", "n"}], 
     RowBox[{
      RowBox[{"-", "1"}], "+", 
      RowBox[{"2", " ", "n"}]}]]], " ", "\[CapitalOmega]\[CapitalLambda]", 
   " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], 
    FractionBox[
     RowBox[{"2", " ", "n"}], 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], 
    FractionBox["1", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "a", "]"}]}], 
  RowBox[{"1", "-", 
   RowBox[{"2", " ", "n"}]}]]], "Output",
 CellChangeTimes->{{3.7579214405119543`*^9, 3.757921464568638*^9}, {
   3.7579223561567726`*^9, 3.757922387124004*^9}, {3.7583550968368387`*^9, 
   3.7583551063859687`*^9}, {3.758363301541566*^9, 3.7583633331895375`*^9}, 
   3.7583643629979553`*^9, 3.7583725238549647`*^9, 3.758454545122135*^9, 
   3.760866304238493*^9},ExpressionUUID->"14ebdf0c-0ffc-449d-bbd8-\
b24c4cc52f37"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"a", " ", 
      SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]\[CapitalLambda]", " ", 
      
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}], 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], " ", "n"}]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "2"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, 1, 2, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[
   1], {-$CellContext`a $CellContext`H0^2 $CellContext`\[CapitalOmega]\
\[CapitalLambda] $CellContext`H[$CellContext`a]^(-1) $CellContext`\
\[CapitalPsi][$CellContext`t, $CellContext`x, $CellContext`y, $CellContext`z] 
    Derivative[1][$CellContext`H][$CellContext`a]}, 1, 2, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7579214405119543`*^9, 3.757921464568638*^9}, {
   3.7579223561567726`*^9, 3.757922387124004*^9}, {3.7583550968368387`*^9, 
   3.7583551063859687`*^9}, {3.758363301541566*^9, 3.7583633331895375`*^9}, 
   3.7583643629979553`*^9, 3.7583725238549647`*^9, 3.758454545122135*^9, 
   3.760866304259472*^9},ExpressionUUID->"3d05daf5-ac4d-40a1-a56f-\
68f33fcbb23c"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"RHS", " ", "of", " ", 
    RowBox[{"Eq", ".", " ", 
     RowBox[{"(", "4.6", ")"}]}], " ", "of", " ", "Kimura"}], " ", "*)"}],
  FontSize->16]], "Input",
 CellChangeTimes->{
  3.757921599665413*^9},ExpressionUUID->"ff4d1809-5d57-4cb5-9ff3-\
19f9a4e6d48c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Eqs0i", "/", "3"}], "/.", "rulesKGB0"}], ")"}], "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Eqs0i", "/", "3"}], "/.", "rulesGR"}], ")"}]}], "/.", 
      "soldx"}], "/.", "sdx2"}], "/.", "sdx1"}], "/.", "sdx0"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.758354549972373*^9, 
  3.7583545557230425`*^9}},ExpressionUUID->"004fab7a-7d4d-4f0d-b5a0-\
94f10ec011cf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "3"]}], " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.7583545504567614`*^9, 3.7583545564574127`*^9}, {
   3.7583550837705135`*^9, 3.7583551091516027`*^9}, 3.7583633372194414`*^9, 
   3.758364364652463*^9, 3.7583725287802515`*^9, 3.760705927019079*^9, 
   3.76086630601412*^9},ExpressionUUID->"80150e92-b6f6-4b14-83ee-\
92d8579a4ea9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Eq46", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eqs0i", "/", "3"}], "/.", "rulesKGB"}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Eqs0i", "/", "3"}], "/.", "rulesGR"}], ")"}]}], "/.", 
    "soldx"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7579199230462785`*^9, 3.757919926596168*^9}, {
  3.7579205758234453`*^9, 
  3.7579205794034877`*^9}},ExpressionUUID->"4aa91a47-1bb8-40e4-9719-\
fd1a2901019f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "3"]}], " ", "n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   RowBox[{"\[Delta]X", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   FractionBox["1", "3"], " ", 
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"n", " ", 
   SuperscriptBox["X", 
    RowBox[{
     RowBox[{"-", "1"}], "+", "n"}]], " ", "\[Alpha]", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{
  3.757919928240314*^9, 3.757920580098637*^9, {3.758355086210413*^9, 
   3.758355111107071*^9}, 3.758363343179496*^9, 3.758364365587865*^9, 
   3.7583725300692043`*^9, 3.7584545479969444`*^9, 3.7607059300514016`*^9, 
   3.760866306716434*^9},ExpressionUUID->"f0bf3796-0d4d-4f50-b16d-\
0094291ccc53"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"Eq46", "/.", 
       RowBox[{
        RowBox[{"\[Delta]X", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
        "0"}]}], "/.", "solps"}], "/.", "sola"}], "/.", "solXn"}], "//", 
   "PowerExpand"}], "//", "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"%", "/.", 
     RowBox[{
      RowBox[{
       RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
      SqrtBox[
       RowBox[{"2", "X"}]]}]}], "/.", "solXn"}], "//", "PowerExpand"}], "//", 
  "FullSimplify"}]}], "Input",
 CellChangeTimes->{
  3.757920391299828*^9, {3.757920503952032*^9, 3.757920520385043*^9}, 
   3.757920582511123*^9, {3.758355090382554*^9, 3.7583550920089893`*^9}, 
   3.758363347089552*^9},ExpressionUUID->"512e4d9e-67d9-4bb7-a070-\
ba696bd0b912"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6"}], " ", 
      SqrtBox["\[CapitalOmega]\[CapitalLambda]"]}], "+", 
     RowBox[{
      SqrtBox["6"], " ", 
      SuperscriptBox["H0", 
       FractionBox[
        RowBox[{"2", " ", "n"}], 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "n"}]}]]], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "t", "]"}], 
       FractionBox["1", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}]]], " ", 
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
  RowBox[{"18", " ", 
   SqrtBox["\[CapitalOmega]\[CapitalLambda]"]}]]], "Output",
 CellChangeTimes->{
  3.7579203922867146`*^9, {3.7579205110617523`*^9, 3.7579205214558325`*^9}, 
   3.757920584422263*^9, 3.758355113513316*^9, 3.758363350249338*^9, 
   3.7583643669798636`*^9, 3.7583725315575137`*^9, 
   3.760866311008693*^9},ExpressionUUID->"8ea1a833-af79-4931-abd4-\
370f76d634ee"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7579203922867146`*^9, {3.7579205110617523`*^9, 3.7579205214558325`*^9}, 
   3.757920584422263*^9, 3.758355113513316*^9, 3.758363350249338*^9, 
   3.7583643669798636`*^9, 3.7583725315575137`*^9, 
   3.7608663110142455`*^9},ExpressionUUID->"09f49b7a-904b-4fdd-99bd-\
195cfeb5b437"]
}, Open  ]],

Cell[BoxData[
 StyleBox[
  RowBox[{"(*", " ", 
   RowBox[{"RHS", " ", "of", " ", 
    RowBox[{"Eq", ".", " ", 
     RowBox[{"(", "4.7", ")"}]}], " ", "of", " ", "Kimura"}], " ", "*)"}],
  FontSize->16]], "Input",
 CellChangeTimes->{
  3.7579216118251514`*^9},ExpressionUUID->"4850e69f-4cb7-4bf9-a4f9-\
4c2979cc3534"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqsc", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"Eqscal", "/.", "rulesKGB"}], "/.", "sdx2"}], "/.", 
              "sdx1"}], "/.", "sdx0"}], "/.", "sola"}], "/.", "solXn"}], "/.",
           "solft2"}], "/.", 
         RowBox[{
          RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
        RowBox[{
         RowBox[{
          RowBox[{"H", "'"}], "[", "t", "]"}], "\[Rule]", 
         RowBox[{"a", " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{
           RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "/.", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "\[Rule]", 
        SqrtBox[
         RowBox[{"2", "X"}]]}]}], "/.", "solXn"}], "//", "PowerExpand"}], "//",
     "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.75792071874531*^9, 3.757920722442583*^9}, {
  3.7579207837806215`*^9, 3.7579208103452177`*^9}, {3.7579209600277095`*^9, 
  3.7579209796817226`*^9}, {3.757921015666535*^9, 3.757921068285369*^9}, {
  3.7579212059030323`*^9, 3.7579212675019045`*^9}, {3.75792226082464*^9, 
  3.757922270964666*^9}},ExpressionUUID->"ed60dd4f-42b9-45e1-8401-\
021aadc769c2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{"eqsc", ",", 
   RowBox[{"{", 
    RowBox[{"n", ",", "\[Infinity]", ",", 
     RowBox[{"-", "1"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.75792227549477*^9, 
  3.7579222794943414`*^9}},ExpressionUUID->"bcec9317-786e-4bb2-beb4-\
8e4dc746cfea"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      SqrtBox[
       FractionBox["2", "3"]], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"H", "[", "a", "]"}], " ", 
         RowBox[{"\[Delta]X", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
        RowBox[{
         SuperscriptBox["\[Delta]X", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], " ", 
      "n"}], 
     RowBox[{"H0", " ", 
      SqrtBox["\[CapitalOmega]\[CapitalLambda]"]}]]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "0"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, -1, 0, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[
   1], {-Rational[2, 3]^
     Rational[1, 
       2] $CellContext`H0^(-1) $CellContext`\[CapitalOmega]\[CapitalLambda]^
     Rational[-1, 2] (
     3 $CellContext`H[$CellContext`a] $CellContext`\[Delta]X[$CellContext`t, \
$CellContext`x, $CellContext`y, $CellContext`z] + 
     Derivative[
      1, 0, 0, 0][$CellContext`\[Delta]X][$CellContext`t, $CellContext`x, \
$CellContext`y, $CellContext`z])}, -1, 0, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7579222766439323`*^9, 3.7579222797281504`*^9}, 
   3.75835511935706*^9, 3.7583633562395315`*^9, {3.758364368500107*^9, 
   3.7583643702199116`*^9}, 3.758372535754862*^9, 
   3.7607059438859744`*^9},ExpressionUUID->"61e9fc01-d5f3-4b6a-9b00-\
5d9920531027"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"2", "Eqsij"}], "\[Equal]", "0"}], "/.", "rulesKGB0"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pots", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "n"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "2"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7583647449004154`*^9, 3.7583647678603373`*^9}, {
  3.7584545631571193`*^9, 
  3.7584545633773355`*^9}},ExpressionUUID->"de1e8804-8fa2-4ff9-af1d-\
bb77e2eeb2e0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7583647461603208`*^9, 3.758364768392604*^9}, 
   3.758372538900096*^9, 3.7584545714319115`*^9, 3.7607059570616426`*^9, 
   3.760866318474414*^9},ExpressionUUID->"959e65ff-15d6-44bb-9315-\
9b715359640f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqsall", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Eqs00", "\[Equal]", "0"}], ",", 
           RowBox[{"Eqsii", "\[Equal]", "0"}], ",", 
           RowBox[{"Eqs0i", "\[Equal]", "0"}], ",", 
           RowBox[{"Eqscal", "\[Equal]", "0"}]}], "}"}], "/.", "rulesKGB0"}], 
        "/.", "sdx2"}], "/.", "sdx1"}], "/.", "sdx0"}], "/.", "pots"}], "//", 
    "Expand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.758364449009985*^9, 3.758364484049914*^9}, {
   3.758364524643022*^9, 3.7583645602603936`*^9}, 3.7583646425801353`*^9, {
   3.7583647040701766`*^9, 
   3.758364773970118*^9}},ExpressionUUID->"34991300-e872-43c7-bf34-\
34fcd8158c97"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solFdf", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"eqsall", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"eqsall", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CapitalPhi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], "]"}],
     "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7583647843803496`*^9, 
  3.75836483605457*^9}},ExpressionUUID->"8e97ca42-bebe-4466-8b05-\
dfa0470b14e0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqs23", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqsall", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"eqsall", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "/.", "solFdf"}], "//", 
    "FullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.758365016700528*^9, 
  3.758365061732859*^9}},ExpressionUUID->"b6d48d4a-d6d2-4e4f-931b-\
26c82c97e95a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eq231", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"eqs23", "/.", "rulesKGB"}], "/.", "sola"}], "/.",
                     "solXn"}], "/.", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
                    SqrtBox[
                    RowBox[{"2", "X"}]]}]}], "/.", 
                    RowBox[{
                    RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
                    RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
                    RowBox[{"a", " ", 
                    RowBox[{"H", "[", "a", "]"}], " ", 
                    RowBox[{
                    RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "/.", 
                    RowBox[{
                    RowBox[{"a", "[", "t", "]"}], "\[Rule]", "a"}]}], "/.", 
                    RowBox[{
                    RowBox[{"\[CapitalPhi]", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
                    
                    RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}], "/.", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["\[CapitalPhi]", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                    "\[Rule]", 
                    RowBox[{
                    RowBox[{"\[CapitalPhi]", "'"}], "[", "a", "]"}]}]}], "/.", 
                  RowBox[{
                   RowBox[{"\[Delta]\[Rho]m", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                   "\[Rule]", 
                   RowBox[{"\[Rho]c", " ", 
                    RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], 
                    RowBox[{"\[Delta]", "[", "a", "]"}]}]}]}], "/.", 
                 RowBox[{
                  RowBox[{"\[Delta]X", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
                  RowBox[{"\[Delta]X", "[", "a", "]"}]}]}], "/.", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["\[Delta]X", 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                 "\[Rule]", 
                 RowBox[{"a", " ", 
                  RowBox[{"H", "[", "a", "]"}], " ", 
                  RowBox[{
                   RowBox[{"\[Delta]X", "'"}], "[", "a", "]"}]}]}]}], "/.", 
               RowBox[{
                RowBox[{
                 SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
                FractionBox[
                 RowBox[{
                  RowBox[{"X", "'"}], "[", "a", "]"}], 
                 RowBox[{
                  RowBox[{"\[Phi]", "'"}], "[", "a", "]"}]]}]}], "/.", 
              RowBox[{
               RowBox[{
                RowBox[{"X", "'"}], "[", "a", "]"}], "\[Rule]", 
               RowBox[{"D", "[", 
                RowBox[{
                 RowBox[{
                  RowBox[{"solXn", "[", 
                   RowBox[{"[", 
                    RowBox[{"1", ",", "2"}], "]"}], "]"}], "/.", 
                  RowBox[{"t", "\[Rule]", "a"}]}], ",", "a"}], "]"}]}]}], "/.", 
             RowBox[{
              RowBox[{
               RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "\[Rule]", 
              SqrtBox[
               FractionBox[
                RowBox[{"2", "X"}], 
                RowBox[{
                 RowBox[{"a", "^", "2"}], " ", 
                 RowBox[{
                  RowBox[{"H", "[", "a", "]"}], "^", "2"}]}]]]}]}], "/.", 
            "solXn"}], "/.", 
           RowBox[{
            RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
            RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
          RowBox[{
           RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
           RowBox[{
            RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], " ", "\[Rho]c"}]}]}],
          "/.", 
         RowBox[{
          RowBox[{"\[Theta]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
          RowBox[{"\[Theta]", "[", "a", "]"}]}]}], "/.", 
        RowBox[{"G", "\[Rule]", 
         FractionBox[
          RowBox[{"3", 
           RowBox[{"H0", "^", "2"}]}], 
          RowBox[{"8", " ", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
       RowBox[{"H0", "\[Rule]", "1"}]}], ")"}], "//.", "solXn"}], "//", 
    "PowerExpand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7583661444012914`*^9, 3.758366253761351*^9}, {
  3.7583672793019094`*^9, 3.75836738391988*^9}, {3.7583674442501745`*^9, 
  3.7583674464798727`*^9}, {3.7583675174598665`*^9, 3.7583676258905096`*^9}, {
  3.758367767360464*^9, 3.758367773970215*^9}, {3.7583678385875998`*^9, 
  3.758367886004718*^9}, {3.758367925420168*^9, 
  3.7583679273154573`*^9}},ExpressionUUID->"3422f7b9-66ef-46c3-bc48-\
359b9764fcd7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sols", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{"eq231", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[CapitalPhi]", "'"}], "[", "a", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]X", "'"}], "[", "a", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.7583645153800097`*^9, 3.7583645458301973`*^9}, {
   3.758364577050356*^9, 3.7583645949702997`*^9}, 3.758365066942402*^9, {
   3.758365213975073*^9, 3.758365219630674*^9}, {3.7583654624408245`*^9, 
   3.7583654629506655`*^9}, {3.758367635189952*^9, 3.7583676833103366`*^9}, {
   3.7583677282104826`*^9, 3.7583677294324703`*^9}, {3.75836796264067*^9, 
   3.7583679631604347`*^9}},ExpressionUUID->"7b212192-1267-4972-9bd1-\
769586b6c98a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Delta]X", "[", "a", "]"}], 
        RowBox[{"H", "[", "a", "]"}]], "-", 
       RowBox[{"6", " ", 
        RowBox[{"H", "[", "a", "]"}], " ", 
        RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
       FractionBox[
        RowBox[{"9", " ", "a", " ", 
         RowBox[{"\[Theta]", "[", "a", "]"}], " ", 
         RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], 
        SuperscriptBox["k", "2"]]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Delta]X", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"H", "[", "a", "]"}], 
        RowBox[{"1", "+", 
         FractionBox["2", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "n"}]}]]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"1", "+", 
             RowBox[{"6", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["k", "2"], " ", 
             RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox["2", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"\[Theta]", "[", "a", "]"}], " ", 
          RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"8", " ", "n"}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox["\[CapitalOmega]\[CapitalLambda]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"2", "+", 
             RowBox[{"8", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"4", " ", "n"}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["n", "2"]}]}], ")"}], " ", 
             RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["k", "2"], " ", "n", " ", 
             RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["a", "2"], " ", "n", " ", 
             RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
             RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"2", "+", 
             RowBox[{"4", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"\[Theta]", "[", "a", "]"}], " ", 
             RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["k", "2"], " ", 
             RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
             RowBox[{
              SuperscriptBox["H", "\[Prime]",
               MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["k", "2"], " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", "n"}]}], ")"}], "2"], " ", 
             RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["k", "4"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", 
             RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
            RowBox[{"3", " ", 
             SuperscriptBox["a", "2"], " ", 
             RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["k", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  RowBox[{"2", " ", "n"}]}], ")"}], " ", 
                RowBox[{"\[Delta]", "[", "a", "]"}]}], "+", 
               RowBox[{"6", " ", 
                SuperscriptBox["a", "2"], " ", "n", " ", 
                RowBox[{"\[Theta]", "[", "a", "]"}], " ", 
                RowBox[{
                 SuperscriptBox["H", "\[Prime]",
                  MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}], "+", 
         RowBox[{"\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"4", " ", "n"}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]]}]}], ")"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.758367647715232*^9, 3.7583676852697544`*^9}, 
   3.7583677410198245`*^9, 3.7583677872301908`*^9, {3.7583678531035404`*^9, 
   3.758367876055213*^9}, {3.758367942155346*^9, 3.7583679637902374`*^9}, 
   3.7583725585692744`*^9, 3.7584545947369623`*^9, 3.760706050718758*^9, 
   3.760866439656288*^9},ExpressionUUID->"5e3c1a1f-d057-44ff-badc-\
825e6a13f538"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"sols", "[", 
     RowBox[{"[", 
      RowBox[{"2", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "\[Infinity]", ",", "0"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7583679751604757`*^9, 3.7583680007300773`*^9}, 
   3.758368306210658*^9, 
   3.758368395552659*^9},ExpressionUUID->"28213f0a-4fdd-475b-a557-\
5cc4d7a89741"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "a"]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}], 
       RowBox[{"H", "[", "a", "]"}]]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "1"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[
   1], {$CellContext`\[Delta]X[$CellContext`a] ((-2)/$CellContext`a - \
$CellContext`H[$CellContext`a]^(-1) 
     Derivative[1][$CellContext`H][$CellContext`a])}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7583679770199723`*^9, 3.7583680012404275`*^9}, 
   3.758368306882688*^9, 3.758368396030382*^9, 3.758372562375046*^9, 
   3.7607060626441464`*^9, 
   3.7608664416244946`*^9},ExpressionUUID->"fc251dab-c33e-4613-8bbe-\
d44088db3334"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", " ", "The"}]}]}]}], " ", "continuity", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"equations", " ", "--"}], "--"}], "--"}], "--"}]}], "-"}], " ",
   "*)"}]], "Input",
 CellChangeTimes->{
  3.728128064348237*^9, 3.7282399499899187`*^9, {3.7484488576593175`*^9, 
   3.748448864323157*^9}, {3.7484511672777033`*^9, 
   3.748451182923294*^9}},ExpressionUUID->"708976f8-7cb8-48b5-85b8-\
3f182b15f1dd"],

Cell[BoxData[{
 RowBox[{"\[Delta]Pm", "//", "Clear"}], "\[IndentingNewLine]", 
 RowBox[{"\[Sigma]m", "//", "Clear"}]}], "Input",
 CellChangeTimes->{{3.7606007140956674`*^9, 
  3.7606007189218435`*^9}},ExpressionUUID->"53bfd5a7-e913-4426-9b54-\
98d4bb45f64e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"energcond", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"covDiv", "[", 
       RowBox[{"TmUd", ",", 
        RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", 
     RowBox[{
      RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"w", "[", "t", "]"}], " ", 
       RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "//", "Expand"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.7484486578165584`*^9, {3.7583686109610558`*^9, 3.758368630533529*^9}, {
   3.760600170449314*^9, 3.7606001715563707`*^9}, {3.760600326528186*^9, 
   3.7606003321559277`*^9}},ExpressionUUID->"dbaea814-c3a3-4f34-8a23-\
77e5bf23d513"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "-", 
    FractionBox[
     RowBox[{
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "-", 
    RowBox[{
     SuperscriptBox["\[Rho]m", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "-", 
    RowBox[{
     SuperscriptBox["\[Delta]\[Rho]m", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[Sigma]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[Sigma]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kx", " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["Pm", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"ux", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Rho]m", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["ux", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["ux", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[Sigma]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["kx", "2"], " ", "ky", " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["ky", "3"], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", "ky", " ", 
      SuperscriptBox["kz", "2"], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[Sigma]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["kx", "2"], " ", "ky", " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["ky", "3"], " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", "ky", " ", 
      SuperscriptBox["kz", "2"], " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "+", 
    RowBox[{"\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "ky", " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["Pm", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uy", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Rho]m", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uy", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[Sigma]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["kx", "2"], " ", "kz", " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["ky", "2"], " ", "kz", " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["kz", "3"], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "+", 
    RowBox[{
     FractionBox["1", "2"], " ", "\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[Sigma]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["kx", "2"], " ", "kz", " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["ky", "2"], " ", "kz", " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "-", 
    FractionBox[
     RowBox[{"3", " ", "\[ImaginaryI]", " ", 
      SuperscriptBox["kz", "3"], " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"]}]], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"\[ImaginaryI]", " ", "kz", " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["Pm", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"uz", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Rho]m", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["uz", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.758368613272914*^9, 3.7583686310508018`*^9}, 
   3.758372565809868*^9, 3.758454609967335*^9, 3.7606001726531277`*^9, 
   3.7606007228321323`*^9, 
   3.7608664505792084`*^9},ExpressionUUID->"da0b01ca-284f-4003-be48-\
17d73f315b00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cons0", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"energcond", "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", "zeroorder"}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"\[Rho]m", "'"}], "[", "t", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.72823333326803*^9, 3.7282333736032867`*^9}, {
  3.748448668138236*^9, 3.7484486757671485`*^9}, {3.758368639560544*^9, 
  3.758368647491086*^9}},ExpressionUUID->"facf3541-ddaa-41dd-8af1-\
4ff51063206e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Rho]m", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"-", "3"}], " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"w", "[", "t", "]"}]}], ")"}], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7282333442236867`*^9, 3.7282333748353205`*^9}, 
   3.7282401957379017`*^9, 3.7282807569845076`*^9, 3.728296861547844*^9, 
   3.728893342595481*^9, 3.731907134182128*^9, 3.731919883901698*^9, 
   3.731925014454234*^9, 3.7323538834548874`*^9, 3.7325242219748135`*^9, 
   3.7326104707591586`*^9, 3.7328548237423525`*^9, 3.732858686647619*^9, 
   3.732941508020496*^9, 3.733045146737355*^9, 3.733566219687055*^9, 
   3.7456657179477253`*^9, 3.745824552688678*^9, 3.745831677222546*^9, 
   3.745833552631424*^9, 3.7458529643520355`*^9, 3.7459046913626175`*^9, 
   3.7459050294268007`*^9, 3.7459155148105907`*^9, 3.746184838286575*^9, 
   3.7462531731789336`*^9, 3.746262809601081*^9, 3.7464208398256807`*^9, 
   3.7464278408298693`*^9, 3.748448676741956*^9, 3.748450259259445*^9, 
   3.758368648310441*^9, 3.7583725705295773`*^9, 3.7584546115868006`*^9, 
   3.7606001772652707`*^9, {3.7606007283280087`*^9, 3.7606007357032375`*^9}, 
   3.760866452936864*^9},ExpressionUUID->"bc7610a8-1943-4242-b49e-\
a04c39baab75"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en10", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"energcond", "[", 
     RowBox[{"[", "1", "]"}], "]"}], "-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"energcond", "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", "zeroorder"}], ")"}]}], "/.", 
   "a2H"}]}]], "Input",
 CellChangeTimes->{{3.7282161794306803`*^9, 3.7282161850099125`*^9}, {
   3.7282311665084667`*^9, 3.7282311958939333`*^9}, {3.728233266678986*^9, 
   3.7282332668416047`*^9}, {3.748450269886175*^9, 3.7484502707698727`*^9}, 
   3.748451009248801*^9},ExpressionUUID->"e5473dbb-c442-4565-b33c-\
71ddc811ed2c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]Pm", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Delta]\[Rho]m", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]], "-", 
  FractionBox[
   RowBox[{
    RowBox[{"w", "[", "t", "]"}], " ", 
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]], "-", 
  RowBox[{
   SuperscriptBox["\[Delta]\[Rho]m", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"w", "[", "t", "]"}], " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7282161803104095`*^9, 3.728216186494257*^9}, 
   3.7282311366219163`*^9, {3.7282311696424875`*^9, 3.728231196271249*^9}, 
   3.728231472224601*^9, 3.72823321917756*^9, 3.7282332672255545`*^9, 
   3.7282401957524695`*^9, 3.7282807586878166`*^9, 3.7282968615635023`*^9, 
   3.7288933426105194`*^9, 3.7319071341971426`*^9, 3.731919883917266*^9, 
   3.7319250144698024`*^9, 3.7323538834709363`*^9, 3.732524221996954*^9, 
   3.7326104707801943`*^9, 3.7328548237579727`*^9, 3.7328586866632457`*^9, 
   3.732941513757288*^9, 3.733045146755517*^9, 3.7335662197026978`*^9, 
   3.74566571800776*^9, 3.7458245527578707`*^9, 3.7458316772888203`*^9, 
   3.7458335526873617`*^9, 3.7458529643685055`*^9, 3.7459046914564824`*^9, 
   3.7459050294966116`*^9, 3.7459155148574896`*^9, 3.746184838346408*^9, 
   3.746253173234974*^9, 3.7462628096807775`*^9, 3.7464208398954268`*^9, 
   3.7464278408898287`*^9, 3.748448681608074*^9, {3.7484502638604717`*^9, 
   3.748450271876639*^9}, 3.748451009862173*^9, 3.758368651700549*^9, 
   3.7583725740851364`*^9, 3.7584546129273205`*^9, 3.7606001804995484`*^9, 
   3.7606007376335087`*^9, 
   3.760866454274187*^9},ExpressionUUID->"140b56ba-9d7f-4385-b5d4-\
02243a6d9511"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "\[Theta]", "]"}]], "Input",
 CellChangeTimes->{{3.748451095130921*^9, 
  3.748451097254135*^9}},ExpressionUUID->"4d419e30-6319-44d8-ad7d-\
f3c083976373"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"\[Delta]", "'"}], "[", "t", "]"}], "->", 
         RowBox[{"D", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"\[Delta]\[Rho]m", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
            RowBox[{"\[Rho]m", "[", "t", "]"}]], ",", "t"}], "]"}]}], "/.", 
        "cons0"}], "/.", 
       RowBox[{
        RowBox[{"Solve", "[", 
         RowBox[{
          RowBox[{"en10", "\[Equal]", "0"}], ",", 
          RowBox[{
           SuperscriptBox["\[Delta]\[Rho]m", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}]}], "/.", "a2H"}], "/.", 
     RowBox[{
      RowBox[{"\[Delta]Pm", "[", 
       RowBox[{"\[Eta]", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
      "0"}]}], "/.", 
    RowBox[{
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
     RowBox[{
      RowBox[{"\[Delta]", "[", "a", "]"}], "*", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.72823133576729*^9, 3.7282313508437486`*^9}, {
   3.7282313921395187`*^9, 3.728231399579141*^9}, {3.7282315176878395`*^9, 
   3.7282315512694097`*^9}, {3.7282315973091087`*^9, 3.728231653765546*^9}, 
   3.728231692653243*^9, {3.7282332407501764`*^9, 3.7282332476861534`*^9}, {
   3.728233380790492*^9, 3.728233385274924*^9}, {3.7484486893098097`*^9, 
   3.7484487105403423`*^9}, {3.7484502902639656`*^9, 
   3.7484502910988207`*^9}, {3.7484503299137435`*^9, 3.748450363539217*^9}, {
   3.7484509030201435`*^9, 3.748450903283244*^9}, {3.7484510114532037`*^9, 
   3.7484510120066547`*^9}, {3.7484510884971995`*^9, 3.748451132769088*^9}, {
   3.758368666740664*^9, 3.7583686885808764`*^9}, {3.7583690523209357`*^9, 
   3.7583690626307425`*^9}, {3.7606001897706447`*^9, 3.7606002399648256`*^9}, 
   3.760600647613491*^9},ExpressionUUID->"44e3df39-c4e2-4310-93d0-\
afb9f18e9b75"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Delta]", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{"w", "[", "t", "]"}], " ", 
    RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
   FractionBox[
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
    RowBox[{"a", "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"w", "[", "t", "]"}], " ", 
     RowBox[{"\[Theta]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{"a", "[", "t", "]"}]], "-", 
   FractionBox[
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{"\[Rho]m", "[", "t", "]"}]], "-", 
   RowBox[{"3", " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"w", "[", "t", "]"}], " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7484487049021187`*^9, 3.748448711139358*^9}, {
   3.7484502851951084`*^9, 3.7484502915744123`*^9}, {3.7484503309912715`*^9, 
   3.748450364036272*^9}, {3.7484509076123123`*^9, 3.748450931233122*^9}, 
   3.7484510126316986`*^9, {3.7484510916663895`*^9, 3.7484511346686535`*^9}, 
   3.758368689180854*^9, {3.7583690557707744`*^9, 3.7583690660413494`*^9}, 
   3.7583704975667853`*^9, 3.758372577265245*^9, 3.758454619907262*^9, {
   3.760600222766105*^9, 3.7606002406354456`*^9}, 3.7606003432792273`*^9, 
   3.7606007413212185`*^9, 
   3.760866469445074*^9},ExpressionUUID->"78e4256e-ff1d-45a9-b69a-\
666438f77e9b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"FullSimplify", "[", 
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                FractionBox["1", 
                 RowBox[{"\[Rho]m", "[", "t", "]"}]], 
                RowBox[{"Div", "[", 
                 RowBox[{
                  RowBox[{"energcond", "[", 
                   RowBox[{"[", 
                    RowBox[{"2", ";;", "4"}], "]"}], "]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}], "/.", 
               "cons0"}], "/.", "a2H"}], "/.", 
             RowBox[{
              SuperscriptBox["kx", "2"], "\[Rule]", 
              RowBox[{
               RowBox[{"k", "^", "2"}], "-", 
               RowBox[{"(", 
                RowBox[{
                 SuperscriptBox["ky", "2"], "+", 
                 SuperscriptBox["kz", "2"]}], ")"}]}]}]}], "//", "Expand"}], "//",
            "FullSimplify"}], "//", "ApproxFullSimplify"}], "]"}], "/.", 
        RowBox[{
         RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"w", "[", "t", "]"}], " ", 
          RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "/.", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", 
          RowBox[{
           RowBox[{"w", "[", "t", "]"}], " ", 
           RowBox[{"\[Rho]m", "[", "t", "]"}]}]}], ",", "t"}], "]"}]}], "/.", 
      "cons0"}], "/.", "a2H"}], "//", "FullSimplify"}], "//", 
   "ApproxFullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.748448738847443*^9, 3.748448771422245*^9}, {
   3.7484504047129393`*^9, 3.748450512121004*^9}, {3.7484505538839693`*^9, 
   3.748450664501816*^9}, {3.7484507037962103`*^9, 3.7484507411906157`*^9}, {
   3.7484507990595417`*^9, 3.7484508351490135`*^9}, {3.7484508950548325`*^9, 
   3.7484508953083677`*^9}, {3.7484509403623676`*^9, 
   3.7484509420490603`*^9}, {3.75836869920118*^9, 3.7583687224810524`*^9}, {
   3.760600260672521*^9, 3.7606002978704615`*^9}, {3.760600337733412*^9, 
   3.7606003399979057`*^9}, 
   3.7606007493366547`*^9},ExpressionUUID->"1bb348bf-518d-43d0-98f2-\
6b31b015bfde"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Theta]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"w", "[", "t", "]"}], " ", 
   RowBox[{"\[Theta]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"w", "[", "t", "]"}], "2"], " ", 
   RowBox[{"\[Theta]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[Delta]Pm", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"\[Rho]m", "[", "t", "]"}]], "+", 
  RowBox[{
   SuperscriptBox["k", "2"], " ", 
   RowBox[{"\[Sigma]m", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["k", "2"], " ", 
   RowBox[{"w", "[", "t", "]"}], " ", 
   RowBox[{"\[Sigma]m", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["k", "2"], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["k", "2"], " ", 
   RowBox[{"w", "[", "t", "]"}], " ", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{"\[Theta]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
   RowBox[{
    SuperscriptBox["w", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
  RowBox[{
   RowBox[{"a", "[", "t", "]"}], " ", 
   RowBox[{"w", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Theta]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7484487409543014`*^9, 3.7484487720015774`*^9}, 
   3.748450379366459*^9, {3.7484504146984982`*^9, 3.7484505129233294`*^9}, {
   3.7484505555694733`*^9, 3.7484506140534315`*^9}, {3.7484506550440855`*^9, 
   3.7484506664834356`*^9}, {3.7484507057766104`*^9, 3.74845074241886*^9}, {
   3.7484508074754305`*^9, 3.7484508360018215`*^9}, 3.7484509433693905`*^9, 
   3.7484511428503437`*^9, 3.758368724120596*^9, 3.7583690715908422`*^9, 
   3.758370499721654*^9, 3.7583725898800826`*^9, 3.7584546314818997`*^9, 
   3.7606002741896906`*^9, 3.760600307951826*^9, 3.7606003498407583`*^9, 
   3.760600752414132*^9, 
   3.760866473714175*^9},ExpressionUUID->"6364c7e6-a506-4330-92dc-\
925c705ecc7c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "\[Theta]", "]"}]], "Input",
 CellChangeTimes->{{3.760600302807495*^9, 
  3.7606003049002304`*^9}},ExpressionUUID->"a318c582-5499-4200-92e2-\
ca27057048e8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Theta]", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  FractionBox[
   RowBox[{"Vm", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
   RowBox[{"1", "+", 
    RowBox[{"w", "[", "t", "]"}]}]]}]], "Input",
 CellChangeTimes->{{3.758368731300889*^9, 3.758368741681011*^9}, {
   3.7583704850662403`*^9, 3.7583705362922735`*^9}, 3.758370584112078*^9, 
   3.7606002807834196`*^9, 
   3.760600362063244*^9},ExpressionUUID->"3a6835de-efe9-4894-9918-\
441e4d7c52cf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en21", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{"en2", "\[Equal]", "0"}], ",", 
         RowBox[{
          SuperscriptBox["Vm", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{"\[Delta]\[Rho]m", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
       RowBox[{
        RowBox[{"\[Delta]", "[", "a", "]"}], "*", 
        RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "/.", "a2H"}], "//", 
    "FullSimplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.728231876134303*^9, 3.7282318961833067`*^9}, {
   3.728280766673312*^9, 3.728280784504643*^9}, {3.7484506735125136`*^9, 
   3.74845068461707*^9}, {3.7484509599177313`*^9, 3.7484509719935627`*^9}, {
   3.7484510478632927`*^9, 3.7484510761241283`*^9}, {3.758368747370846*^9, 
   3.7583687729508533`*^9}, 3.7583690815911274`*^9, {3.758370523161984*^9, 
   3.758370524631854*^9}},ExpressionUUID->"a01e3453-510c-4ed8-a46d-\
d30ac04ab233"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["Vm", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"H", "[", "t", "]"}]}], " ", 
     RowBox[{"Vm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"Vm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"w", "[", "t", "]"}]}], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[Delta]Pm", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "-", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[Sigma]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]], "+", 
    FractionBox[
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"w", "[", "t", "]"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"a", "[", "t", "]"}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7606002860446253`*^9, 3.760600311513712*^9}, {
   3.760600354210046*^9, 3.7606003638305426`*^9}, 3.7606007568636465`*^9, 
   3.760866476546919*^9},ExpressionUUID->"c792f0fd-e4be-4238-ab74-\
9e1cd0e085ae"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en1", "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.760600397018748*^9, 
  3.760600406313961*^9}},ExpressionUUID->"273a57fc-901f-437e-8330-\
c8b11666e3d2"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["\[Delta]", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
  RowBox[{
   RowBox[{"-", 
    FractionBox[
     RowBox[{"Vm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
     RowBox[{"a", "[", "t", "]"}]]}], "+", 
   RowBox[{
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"w", "[", "t", "]"}], " ", 
       RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"\[Delta]Pm", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[Rho]m", "[", "t", "]"}]]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"w", "[", "t", "]"}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}]], "Output",
 CellChangeTimes->{{3.7606003976996546`*^9, 3.7606004066332703`*^9}, 
   3.7606007594139657`*^9},ExpressionUUID->"3296dc00-9d42-4bda-bba5-\
b6f9e6d9adcf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"en21", "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.7606004127652636`*^9, 
  3.7606004142588153`*^9}},ExpressionUUID->"0c1a1dc3-7d89-474d-9fe3-\
ea5015cd3775"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["Vm", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"\[Delta]Pm", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{"Vm", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"w", "[", "t", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"w", "[", "t", "]"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"\[Sigma]m", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
            RowBox[{"\[CapitalPsi]", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], 
        ")"}]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7606004146546774`*^9, 
  3.7606007608361187`*^9},ExpressionUUID->"bb69c7dc-446b-42d3-926e-\
ff3b3c566b71"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"continuity", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Delta]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "==", 
            RowBox[{
             RowBox[{"-", 
              FractionBox[
               RowBox[{"Vm", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
               RowBox[{"a", "[", "t", "]"}]]}], "+", 
             RowBox[{
              RowBox[{"H", "[", "t", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"3", " ", 
                 RowBox[{"w", "[", "t", "]"}], " ", 
                 RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
                FractionBox[
                 RowBox[{"3", " ", 
                  RowBox[{"\[Delta]Pm", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
                 RowBox[{"\[Rho]m", "[", "t", "]"}]]}], ")"}]}], "-", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"w", "[", "t", "]"}]}], ")"}], " ", 
              RowBox[{
               SuperscriptBox["\[CapitalPhi]", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], ",", 
           
           RowBox[{
            RowBox[{
             SuperscriptBox["Vm", 
              TagBox[
               RowBox[{"(", 
                RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
               Derivative],
              MultilineFunction->None], "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "==", 
            RowBox[{
             FractionBox["1", 
              RowBox[{
               RowBox[{"a", "[", "t", "]"}], " ", 
               RowBox[{"\[Rho]m", "[", "t", "]"}]}]], 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SuperscriptBox["k", "2"], " ", 
                RowBox[{"\[Delta]Pm", "[", 
                 RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
               RowBox[{
                RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"a", "[", "t", "]"}], " ", 
                   RowBox[{"H", "[", "t", "]"}], " ", 
                   RowBox[{"Vm", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "1"}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"w", "[", "t", "]"}]}]}], ")"}]}], "-", 
                  RowBox[{
                   SuperscriptBox["k", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    RowBox[{"w", "[", "t", "]"}]}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"\[Sigma]m", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
                    RowBox[{"\[CapitalPsi]", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}]}], "}"}], "/.", 
         RowBox[{
          RowBox[{
           SuperscriptBox["\[Delta]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
          RowBox[{"a", " ", 
           RowBox[{"H", "[", "a", "]"}], " ", 
           RowBox[{
            RowBox[{"\[Delta]", "'"}], "[", "a", "]"}]}]}]}], "/.", 
        RowBox[{
         RowBox[{"Vm", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         RowBox[{"Vm", "[", "a", "]"}]}]}], "/.", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CapitalPhi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
        RowBox[{"a", " ", 
         RowBox[{"H", "[", "a", "]"}], 
         RowBox[{
          RowBox[{"\[CapitalPhi]", "'"}], "[", "a", "]"}]}]}]}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["Vm", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{"a", " ", 
        RowBox[{"H", "[", "a", "]"}], 
        RowBox[{
         RowBox[{"Vm", "'"}], "[", "a", "]"}]}]}]}], "/.", 
     RowBox[{
      RowBox[{"Vm", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
      RowBox[{"Vm", "[", "a", "]"}]}]}], "/.", 
    RowBox[{
     RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
   RowBox[{
    RowBox[{"a", "[", "t", "]"}], "\[Rule]", "a"}]}]}]], "Input",
 CellChangeTimes->{{3.758368783070638*^9, 3.7583688268538136`*^9}, {
   3.7583688609410086`*^9, 3.758368940550932*^9}, {3.7583690915410757`*^9, 
   3.7583690995407987`*^9}, {3.758369171413519*^9, 3.7583691729830084`*^9}, {
   3.758372622905011*^9, 3.758372630447587*^9}, {3.75845466300731*^9, 
   3.758454674387332*^9}, 3.7584547574771404`*^9, {3.7606005012985573`*^9, 
   3.760600560655792*^9}, {3.760600772071515*^9, 
   3.760600780340576*^9}},ExpressionUUID->"3e3ec6bb-7306-4ebb-b239-\
55698102d9e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Delta]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Vm", "[", "a", "]"}], "a"]}], "+", 
     RowBox[{
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", 
         RowBox[{"w", "[", "t", "]"}], " ", 
         RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
        FractionBox[
         RowBox[{"3", " ", 
          RowBox[{"\[Delta]Pm", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
         RowBox[{"\[Rho]m", "[", "t", "]"}]]}], ")"}]}], "-", 
     RowBox[{"3", " ", "a", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        RowBox[{"w", "[", "t", "]"}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["\[CapitalPhi]", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["Vm", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"a", " ", 
       RowBox[{"\[Rho]m", "[", "t", "]"}]}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[Delta]Pm", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"\[Rho]m", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"a", " ", 
           RowBox[{"H", "[", "a", "]"}], " ", 
           RowBox[{"Vm", "[", "a", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"w", "[", "t", "]"}]}]}], ")"}]}], "-", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"w", "[", "t", "]"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Sigma]m", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
             RowBox[{"\[CapitalPsi]", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}],
          ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.758368783885403*^9, 3.7583687909806795`*^9}, 
   3.7583688287509136`*^9, {3.758368900590768*^9, 3.758368941082923*^9}, 
   3.758369103246123*^9, 3.758369174070913*^9, 3.758370590641879*^9, {
   3.758372612258262*^9, 3.7583726325751753`*^9}, 3.758454675687373*^9, 
   3.7584547582370973`*^9, 3.76060053088521*^9, 3.7606005616405225`*^9, 
   3.7606007821895266`*^9, 
   3.76086650333919*^9},ExpressionUUID->"dcb5e295-2143-45f1-baa5-\
62f362c283bf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{"continuity", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Delta]", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}], ",", 
      RowBox[{
       SuperscriptBox["Vm", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}], "}"}]}], "]"}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.758454682687379*^9, 3.7584546910273*^9}, {
  3.7606005804045815`*^9, 3.7606006043385715`*^9}, {3.7606008720749464`*^9, 
  3.760600878342743*^9}},ExpressionUUID->"93a37b69-7ee0-4b3f-8670-\
4768b3190636"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Delta]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Vm", "[", "a", "]"}], 
        RowBox[{
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"H", "[", "a", "]"}]}]]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"w", "[", "t", "]"}], " ", 
        RowBox[{"\[Delta]", "[", "a", "]"}]}], "a"], "-", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"\[Delta]Pm", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"a", " ", 
        RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
      RowBox[{"3", " ", 
       RowBox[{
        SuperscriptBox["\[CapitalPhi]", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"w", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[CapitalPhi]", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SuperscriptBox["Vm", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Vm", "[", "a", "]"}], "a"]}], "+", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"Vm", "[", "a", "]"}], " ", 
        RowBox[{"w", "[", "t", "]"}]}], "a"], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[Delta]Pm", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}], " ", 
        RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}]}]], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"w", "[", "t", "]"}], " ", 
        RowBox[{"\[Sigma]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}]}]], "+", 
      FractionBox[
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"w", "[", "t", "]"}], " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{
        SuperscriptBox["a", "2"], " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}]}]}], "}"}], "}"}]], "Output",
 CellChangeTimes->{{3.758454688027293*^9, 3.7584546913919706`*^9}, 
   3.758454760176964*^9, {3.7606005455190697`*^9, 3.7606006046531415`*^9}, 
   3.760600784617871*^9, 
   3.760866506057181*^9},ExpressionUUID->"9e8af5c1-3c62-4797-9421-\
84337ef829cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"continuity", "/.", 
      RowBox[{
       RowBox[{"\[Sigma]m", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", 
     RowBox[{
      RowBox[{"\[Delta]Pm", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}]}],
     "/.", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
     RowBox[{"-", 
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], "/.", 
   RowBox[{
    RowBox[{"w", "[", "t", "]"}], "\[Rule]", "0"}]}], "//", 
  "Expand"}]], "Input",
 CellChangeTimes->{{3.7606008849455943`*^9, 3.7606009169258785`*^9}, {
  3.7608665139670997`*^9, 
  3.7608665151467857`*^9}},ExpressionUUID->"ace3177f-e80f-4168-932c-\
e96b546240d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Delta]", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"Vm", "[", "a", "]"}], "a"]}], "-", 
     RowBox[{"3", " ", "a", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[CapitalPhi]", "\[Prime]",
        MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
   RowBox[{
    RowBox[{"a", " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["Vm", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"H", "[", "a", "]"}]}], " ", 
      RowBox[{"Vm", "[", "a", "]"}]}], "-", 
     FractionBox[
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "a"]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.760600895764333*^9, 3.7606009173514943`*^9}, {
  3.7608665114093294`*^9, 
  3.760866515616828*^9}},ExpressionUUID->"027efd87-701f-4a09-9249-\
05624ab9a21b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.728128098322069*^9, 
  3.7281281014358377`*^9}},ExpressionUUID->"ece5c0eb-8d03-409a-8c01-\
de15284b987c"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"cont", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"Vm", "[", "a", "]"}], "a"]}], "-", 
       RowBox[{"3", " ", "a", " ", 
        RowBox[{"H", "[", "a", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CapitalPhi]", "\[Prime]",
          MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{
        SuperscriptBox["Vm", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"H", "[", "a", "]"}]}], " ", 
        RowBox[{"Vm", "[", "a", "]"}]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "a"]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7583692541510625`*^9, 3.758369256005806*^9}, {
   3.758369353881259*^9, 3.7583693562432537`*^9}, 3.758369395441146*^9, 
   3.7583726621051807`*^9, 
   3.758454768677308*^9},ExpressionUUID->"9ba8081f-b2af-4ceb-98e5-\
a845d76949b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"finalsol", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"cont", ",", "eq231"}], "}"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"\[Theta]", "[", "a", "]"}], "\[Rule]", 
        RowBox[{"Vm", "[", "a", "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Delta]", "'"}], "[", "a", "]"}], ",", 
        RowBox[{
         RowBox[{"Vm", "'"}], "[", "a", "]"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalPhi]", "'"}], "[", "a", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]X", "'"}], "[", "a", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7583692948408756`*^9, 3.7583693650009313`*^9}, {
  3.7583693995611124`*^9, 
  3.7583694214713326`*^9}},ExpressionUUID->"96b2e506-5ca4-4d3d-8ca9-\
f045ee3e3f0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Delta]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", 
          RowBox[{"Vm", "[", "a", "]"}]}], 
         SuperscriptBox["a", "2"]], "+", 
        RowBox[{"\[Delta]X", "[", "a", "]"}]}], 
       RowBox[{"2", " ", 
        RowBox[{"H", "[", "a", "]"}]}]]}], "+", 
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "a", "]"}], " ", 
      RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
     FractionBox[
      RowBox[{"9", " ", "a", " ", 
       RowBox[{"Vm", "[", "a", "]"}], " ", 
       RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox["k", "2"]}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["Vm", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"Vm", "[", "a", "]"}]}], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], 
        RowBox[{"H", "[", "a", "]"}]]}], 
      SuperscriptBox["a", "2"]]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{
     FractionBox["1", "6"], " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{"\[Delta]X", "[", "a", "]"}], 
        RowBox[{"H", "[", "a", "]"}]], "-", 
       RowBox[{"6", " ", 
        RowBox[{"H", "[", "a", "]"}], " ", 
        RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
       FractionBox[
        RowBox[{"9", " ", "a", " ", 
         RowBox[{"Vm", "[", "a", "]"}], " ", 
         RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], 
        SuperscriptBox["k", "2"]]}], ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Delta]X", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"H", "[", "a", "]"}], 
        RowBox[{"1", "+", 
         FractionBox["2", 
          RowBox[{
           RowBox[{"-", "1"}], "+", 
           RowBox[{"2", " ", "n"}]}]]}]], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"1", "+", 
             RowBox[{"6", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
            RowBox[{
             SuperscriptBox["k", "2"], " ", 
             RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}], ")"}]}], "+", 
         RowBox[{"9", " ", 
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox["2", 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "+", 
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"8", " ", "n"}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox["\[CapitalOmega]\[CapitalLambda]", "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"2", "+", 
             RowBox[{"8", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"a", " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"4", " ", "n"}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["n", "2"]}]}], ")"}], " ", 
             RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
            RowBox[{"4", " ", 
             SuperscriptBox["k", "2"], " ", "n", " ", 
             RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
            RowBox[{"6", " ", 
             SuperscriptBox["a", "2"], " ", "n", " ", 
             RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
             RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"3", " ", 
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", 
            RowBox[{"2", " ", "n"}]}], ")"}], " ", 
          "\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"2", "+", 
             RowBox[{"4", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             RowBox[{"Vm", "[", "a", "]"}], " ", 
             RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["k", "2"], " ", 
             RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
             RowBox[{
              SuperscriptBox["H", "\[Prime]",
               MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "n"}]}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["k", "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", 
               RowBox[{"2", " ", "n"}]}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["k", "2"], " ", 
                RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
               RowBox[{
                SuperscriptBox["a", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", 
                    RowBox[{"4", " ", "n"}]}], ")"}], " ", 
                   RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
                  RowBox[{"3", " ", 
                   RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
                   RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]}], ")"}]}]}],
               ")"}]}], "+", 
            RowBox[{"18", " ", 
             SuperscriptBox["a", "4"], " ", "n", " ", 
             RowBox[{"Vm", "[", "a", "]"}], " ", 
             RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], " ", 
             RowBox[{
              SuperscriptBox["H", "\[Prime]",
               MultilineFunction->None], "[", "a", "]"}]}]}], ")"}]}]}], 
        ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["a", "3"], " ", 
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         RowBox[{"2", " ", "n"}], "+", 
         RowBox[{"\[CapitalOmega]\[CapitalLambda]", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], 
           FractionBox[
            RowBox[{"4", " ", "n"}], 
            RowBox[{"1", "-", 
             RowBox[{"2", " ", "n"}]}]]]}]}], ")"}]}], ")"}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7583693135407443`*^9, 3.7583693681807165`*^9}, {
   3.7583694041709466`*^9, 3.7583694247013845`*^9}, 3.7583726720597544`*^9, 
   3.758454777157007*^9, 
   3.7608665393267007`*^9},ExpressionUUID->"3f414684-7a1a-41ca-b0ff-\
12f6bb96b2ca"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{"finalsol", "[", 
     RowBox[{"[", 
      RowBox[{"4", ",", "2"}], "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"n", ",", "\[Infinity]", ",", "0"}], "}"}]}], "]"}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.758370376565792*^9, 
  3.758370438514192*^9}},ExpressionUUID->"40ed720c-d4ea-4453-be4d-\
161aaff86c73"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "a"]}], "-", 
      FractionBox[
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}], 
       RowBox[{"H", "[", "a", "]"}]]}], ")"}]}], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "n"], "]"}], "1"],
    SeriesData[$CellContext`n, 
     DirectedInfinity[1], {}, 0, 1, 1],
    Editable->False]}],
  SeriesData[$CellContext`n, 
   DirectedInfinity[
   1], {$CellContext`\[Delta]X[$CellContext`a] ((-2)/$CellContext`a - \
$CellContext`H[$CellContext`a]^(-1) 
     Derivative[1][$CellContext`H][$CellContext`a])}, 0, 1, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.7583703834915085`*^9, 3.7583704389367275`*^9}, 
   3.7583726862650228`*^9, 
   3.7584547820091467`*^9},ExpressionUUID->"1a8af52c-d7eb-460e-9d02-\
7f5dbd31c6d1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"back", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"2", "/", "3"}], "H1"}], "/.", "sola"}], "/.", 
      RowBox[{"H0", "\[Rule]", "1"}]}], "/.", 
     RowBox[{
      RowBox[{"H2", "[", "a", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"H", "[", "a", "]"}], "^", "2"}]}]}], "//", "PowerExpand"}], "//",
    "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7583695362113647`*^9, 
  3.758369550911329*^9}},ExpressionUUID->"31054880-d78e-4cd8-95d1-\
a0243b9a4c3d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
  RowBox[{"\[CapitalOmega]\[CapitalLambda]", " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "a", "]"}], 
    FractionBox["2", 
     RowBox[{"1", "-", 
      RowBox[{"2", " ", "n"}]}]]]}], "+", 
  RowBox[{"\[CapitalOmega]m", "[", "a", "]"}]}]], "Output",
 CellChangeTimes->{{3.758369537841196*^9, 3.7583695516612864`*^9}, 
   3.758372687965129*^9},ExpressionUUID->"b1ef866c-e129-43f4-bbb3-\
cded1c552b06"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solHp", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"back", ",", "a"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"H", "'"}], "[", "a", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.758369556596341*^9, 
  3.758369605143573*^9}},ExpressionUUID->"2a4cf517-0c4d-486e-9725-\
e3605bc20f5c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       RowBox[{"2", " ", "n"}]}], ")"}], " ", 
     RowBox[{"H", "[", "a", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[CapitalOmega]m", "\[Prime]",
       MultilineFunction->None], "[", "a", "]"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        RowBox[{"4", " ", "n"}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], "2"]}], "+", 
     RowBox[{"2", " ", "\[CapitalOmega]\[CapitalLambda]", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "a", "]"}], 
       FractionBox["2", 
        RowBox[{"1", "-", 
         RowBox[{"2", " ", "n"}]}]]]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7583695856712084`*^9, 3.7583696055613317`*^9}, 
   3.7583726888651805`*^9},ExpressionUUID->"831223cf-66f4-4873-a51f-\
086487159b47"]
}, {2}]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",ExpressionUUID->"dcdf91fd-de9f-4238-ada6-21b3a8d65e01"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Designer", " ", "model", " ", "perturbations"}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.757919363943246*^9, 3.7579193687991076`*^9}, 
   3.7579244512066727`*^9, {3.7590422262930684`*^9, 3.7590422327130666`*^9}, {
   3.7590588733360367`*^9, 3.759058877475889*^9}, 
   3.7614747486537757`*^9},ExpressionUUID->"1c3aa5db-ffa6-44b0-8928-\
c404f9742765"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesDES", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"G3", "[", "x", "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7590447110040674`*^9, 3.7590447265947676`*^9}, 
   3.7615699924328113`*^9},ExpressionUUID->"ff67a10b-71fd-414c-95c1-\
f8b580f2c863"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesGR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}]], "Input",ExpressionUUID->"960ce0bc-caac-4ae9-9041-be20ab7b6796"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"soldx", "=", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{"dX", "\[Equal]", 
      RowBox[{"\[Delta]X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7579179554840155`*^9, 3.7579180115651007`*^9}, {
  3.758355025257509*^9, 3.758355025507535*^9}, {3.758363224552236*^9, 
  3.7583632281896715`*^9}},ExpressionUUID->"2416670a-2971-42a2-b209-\
3c155877263c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"-", 
      RowBox[{"\[Delta]X", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], " ", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
    SuperscriptBox[
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "2"]]}], "}"}]], "Output",
 CellChangeTimes->{3.758354189661841*^9, 3.758355026241912*^9, 
  3.7583632645536985`*^9, 3.758372471387169*^9, 3.7584545303267717`*^9, 
  3.7590423708931313`*^9, 3.759045394314475*^9, 3.7590606805258045`*^9, 
  3.759061198255582*^9, 
  3.7615700136696615`*^9},ExpressionUUID->"e4c5d72e-cb0e-4422-9705-\
b8923c4098dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Use", " ", "that", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"\[Delta]X", "'"}], "[", "t", "]"}], "~", "0"}], " ", "to", " ",
     "eliminate", " ", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "'"}], "[", "t", "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"solps", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"dX", ",", "t"}], "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       SuperscriptBox["\[CapitalPsi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7579200296408415`*^9, 3.757920063710582*^9}, {
  3.757920614887021*^9, 
  3.7579206373067665`*^9}},ExpressionUUID->"dffaf6ee-9f2f-4a3b-b422-\
f779dacc2d2f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[CapitalPsi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]\[Phi]", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.758354190864962*^9, 3.758355030587587*^9, 
  3.7583632680597258`*^9, 3.7583724724802*^9, 3.7584545312317944`*^9, 
  3.7590423738368587`*^9, 3.75904539956488*^9, 3.759060681940538*^9, 
  3.759061199470009*^9, 
  3.7615700164294567`*^9},ExpressionUUID->"b107eca7-fc85-4977-beb4-\
cc9184f17601"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"sdx0", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"dX", "\[Equal]", 
       RowBox[{"\[Delta]X", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sdx1", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"dX", ",", "t"}], "]"}], "\[Equal]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Delta]X", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", "t"}], 
        "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sdx2", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"D", "[", 
        RowBox[{"dX", ",", "t", ",", "t"}], "]"}], "\[Equal]", 
       RowBox[{"D", "[", 
        RowBox[{
         RowBox[{"\[Delta]X", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", "t", ",", 
         "t"}], "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7579224074331045`*^9, 3.757922407701745*^9}, {
  3.758363236159485*^9, 3.7583632620993247`*^9}, {3.7583643543598747`*^9, 
  3.7583643558447037`*^9}, {3.7590423880529985`*^9, 
  3.7590423884086666`*^9}},ExpressionUUID->"d6860546-bbc3-489e-a0be-\
b80247fdda42"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"2", "Eqsij"}], "\[Equal]", "0"}], "/.", "rulesDES"}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"pots", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
        RowBox[{"-", 
         RowBox[{"\[CapitalPhi]", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "n"}], "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"n", ",", "0", ",", "3"}], "}"}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7583647449004154`*^9, 3.7583647678603373`*^9}, {
   3.7584545631571193`*^9, 3.7584545633773355`*^9}, {3.7590424597850523`*^9, 
   3.7590424866328583`*^9}, 
   3.761570028092372*^9},ExpressionUUID->"3f1b1ab3-edcf-4863-86da-\
15de24757c3c"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
   RowBox[{"\[CapitalPsi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "\[Equal]", 
  "0"}]], "Output",
 CellChangeTimes->{{3.7583647461603208`*^9, 3.758364768392604*^9}, 
   3.758372538900096*^9, 3.7584545714319115`*^9, {3.7590424736153364`*^9, 
   3.7590424900450535`*^9}, 3.7590454066943965`*^9, 3.759060686135809*^9, 
   3.7590612021855464`*^9, 
   3.761570028804901*^9},ExpressionUUID->"bd02b6f6-13bd-489c-9575-\
9abed94f1617"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqsall", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Eqs00", "\[Equal]", "0"}], ",", 
            RowBox[{"Eqsii", "\[Equal]", "0"}], ",", 
            RowBox[{"Eqs0i", "\[Equal]", "0"}], ",", 
            RowBox[{"Eqscal", "\[Equal]", "0"}]}], "}"}], "/.", "sdx2"}], "/.",
          "sdx1"}], "/.", "sdx0"}], "/.", "pots"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       SqrtBox[
        RowBox[{"2", "X"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"H", "[", "a", "]"}]}]}], "//", "Expand"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7590438657341065`*^9, 3.7590438827936535`*^9}, {
   3.7590454294845314`*^9, 3.7590454317369823`*^9}, 
   3.75904556697079*^9},ExpressionUUID->"ea3c9d2d-5666-41c4-b6c6-\
c733dd3133b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"solFdf", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"eqsall", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"eqsall", "[", 
         RowBox[{"[", "4", "]"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[CapitalPhi]", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], "]"}],
     "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7583647843803496`*^9, 
  3.75836483605457*^9}},ExpressionUUID->"d3770e3f-13cc-4f13-902e-\
393075244fca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eqs23", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"eqsall", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"eqsall", "[", 
        RowBox[{"[", "3", "]"}], "]"}]}], "}"}], "/.", "solFdf"}], "/.", 
    "rulesDES"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.758365016700528*^9, 3.758365061732859*^9}, {
   3.759042645032979*^9, 3.7590426454330006`*^9}, 
   3.7615701802594633`*^9},ExpressionUUID->"e1ee3db9-77da-4607-a63a-\
48a101a5c784"],

Cell[BoxData[
 RowBox[{
  RowBox[{"eq231", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{"eqs23", "/.", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
                    SqrtBox[
                    RowBox[{"2", 
                    RowBox[{"X", "[", "a", "]"}]}]]}]}], "/.", 
                    RowBox[{
                    RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
                    RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
                   RowBox[{
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
                    RowBox[{"a", " ", 
                    RowBox[{"H", "[", "a", "]"}], " ", 
                    RowBox[{
                    RowBox[{"H", "'"}], "[", "a", "]"}]}]}]}], "/.", 
                  RowBox[{
                   RowBox[{"a", "[", "t", "]"}], "\[Rule]", "a"}]}], "/.", 
                 RowBox[{
                  RowBox[{"\[CapitalPhi]", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
                  RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}], "/.", 
                RowBox[{
                 RowBox[{
                  SuperscriptBox["\[CapitalPhi]", 
                   TagBox[
                    RowBox[{"(", 
                    RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
                    Derivative],
                   MultilineFunction->None], "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                 "\[Rule]", 
                 RowBox[{
                  RowBox[{"\[CapitalPhi]", "'"}], "[", "a", "]"}]}]}], "/.", 
               RowBox[{
                RowBox[{"\[Delta]\[Rho]m", "[", 
                 RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                "\[Rule]", 
                RowBox[{"\[Rho]c", " ", 
                 RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], 
                 RowBox[{"\[Delta]", "[", "a", "]"}]}]}]}], "/.", 
              RowBox[{
               RowBox[{"\[Delta]X", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
               RowBox[{"\[Delta]X", "[", "a", "]"}]}]}], "/.", 
             RowBox[{
              RowBox[{
               SuperscriptBox["\[Delta]X", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
              
              RowBox[{"a", " ", 
               RowBox[{"H", "[", "a", "]"}], " ", 
               RowBox[{
                RowBox[{"\[Delta]X", "'"}], "[", "a", "]"}]}]}]}], "/.", 
            RowBox[{"X", "\[Rule]", 
             RowBox[{"X", "[", "a", "]"}]}]}], "/.", 
           RowBox[{
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
            FractionBox[
             RowBox[{
              RowBox[{"X", "'"}], "[", "a", "]"}], 
             RowBox[{
              RowBox[{"\[Phi]", "'"}], "[", "a", "]"}]]}]}], "/.", 
          RowBox[{
           RowBox[{
            RowBox[{"\[Phi]", "'"}], "[", "a", "]"}], "\[Rule]", 
           SqrtBox[
            FractionBox[
             RowBox[{"2", 
              RowBox[{"X", "[", "a", "]"}]}], 
             RowBox[{
              RowBox[{"a", "^", "2"}], " ", 
              RowBox[{
               RowBox[{"H", "[", "a", "]"}], "^", "2"}]}]]]}]}], "/.", 
         RowBox[{
          RowBox[{"H", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"H", "[", "a", "]"}]}]}], "/.", 
        RowBox[{
         RowBox[{"\[Rho]m", "[", "t", "]"}], "\[Rule]", 
         RowBox[{
          RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], " ", "\[Rho]c"}]}]}], "/.", 
       RowBox[{
        RowBox[{"\[Theta]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "->", 
        RowBox[{"\[Theta]", "[", "a", "]"}]}]}], "/.", 
      RowBox[{"G", "\[Rule]", 
       FractionBox[
        RowBox[{"3", 
         RowBox[{"H0", "^", "2"}]}], 
        RowBox[{"8", " ", "Pi", " ", "\[Rho]c"}]]}]}], "/.", 
     RowBox[{
      RowBox[{"\[CapitalOmega]m", "[", "a", "]"}], "->", 
      RowBox[{"\[CapitalOmega]m0", " ", 
       SuperscriptBox["a", 
        RowBox[{"-", "3"}]]}]}]}], ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.759043919654205*^9, 3.7590439523959956`*^9}, {
  3.7590444073840427`*^9, 3.759044413634388*^9}, {3.759044905226556*^9, 
  3.7590449077241745`*^9}, {3.7590617687557945`*^9, 
  3.7590617751057854`*^9}},ExpressionUUID->"073a34a8-e42d-427c-ba11-\
1b88a8301558"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cont", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Delta]", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox[
         RowBox[{"Vm", "[", "a", "]"}], "a"]}], "-", 
       RowBox[{"3", " ", "a", " ", 
        RowBox[{"H", "[", "a", "]"}], " ", 
        RowBox[{
         SuperscriptBox["\[CapitalPhi]", "\[Prime]",
          MultilineFunction->None], "[", "a", "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{"a", " ", 
       RowBox[{"H", "[", "a", "]"}], " ", 
       RowBox[{
        SuperscriptBox["Vm", "\[Prime]",
         MultilineFunction->None], "[", "a", "]"}]}], "\[Equal]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"H", "[", "a", "]"}]}], " ", 
        RowBox[{"Vm", "[", "a", "]"}]}], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "a"]}]}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7583692541510625`*^9, 3.758369256005806*^9}, {
   3.758369353881259*^9, 3.7583693562432537`*^9}, 3.758369395441146*^9, 
   3.7583726621051807`*^9, 
   3.758454768677308*^9},ExpressionUUID->"0e72f1c8-20c8-4f8e-b144-\
986d7f9f215b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"finalsol", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Flatten", "[", 
        RowBox[{"{", 
         RowBox[{"cont", ",", "eq231"}], "}"}], "]"}], "/.", 
       RowBox[{
        RowBox[{"\[Theta]", "[", "a", "]"}], "\[Rule]", 
        RowBox[{"Vm", "[", "a", "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Delta]", "'"}], "[", "a", "]"}], ",", 
        RowBox[{
         RowBox[{"Vm", "'"}], "[", "a", "]"}], ",", 
        RowBox[{
         RowBox[{"\[CapitalPhi]", "'"}], "[", "a", "]"}], ",", 
        RowBox[{
         RowBox[{"\[Delta]X", "'"}], "[", "a", "]"}]}], "}"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7583692948408756`*^9, 3.7583693650009313`*^9}, {
   3.7583693995611124`*^9, 3.7583694214713326`*^9}, 3.759043688383542*^9, 
   3.759043974566433*^9},ExpressionUUID->"74d82419-f40d-4cfd-aaeb-\
c3a2eed2089c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"finalsol1", "=", 
  RowBox[{
   RowBox[{"finalsol", "/.", "rulesDES"}], "/.", 
   RowBox[{
    RowBox[{"\[Delta]Pm", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
    "0"}]}]}]], "Input",
 CellChangeTimes->{{3.761570156819725*^9, 3.761570159414575*^9}, {
   3.761570233052578*^9, 3.7615702653697786`*^9}, 3.761570554249979*^9, {
   3.7615709335797157`*^9, 
   3.7615709440797424`*^9}},ExpressionUUID->"a9197c37-ab5d-4daf-af6f-\
96e68a8ba51c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Delta]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]]}], "-", 
         RowBox[{"18", " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]]}], "+", 
         RowBox[{"36", " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"]}], "+", 
         RowBox[{"9", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "+", 
         RowBox[{"54", " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"162", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"36", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"36", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"108", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"18", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"48", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "4"], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"36", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"108", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"H", "[", "a", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            RowBox[{"KX", "[", "t", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["k", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SqrtBox[
             RowBox[{"X", "[", "a", "]"}]]}], "+", 
           RowBox[{"18", " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "a", "]"}], "2"], " ", 
            SqrtBox[
             RowBox[{"X", "[", "a", "]"}]]}], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            RowBox[{"KX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], 
             RowBox[{"3", "/", "2"}]]}], "-", 
           RowBox[{"18", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["Vm", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{
       RowBox[{"a", " ", 
        RowBox[{"H", "[", "a", "]"}], " ", 
        RowBox[{"Vm", "[", "a", "]"}]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}], 
      RowBox[{
       SuperscriptBox["a", "2"], " ", 
       RowBox[{"H", "[", "a", "]"}]}]]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]]}], "-", 
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
         RowBox[{"18", " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[CapitalOmega]m0", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
         RowBox[{
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"54", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"16", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"36", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"2", " ", 
         SuperscriptBox["a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            RowBox[{"KX", "[", "t", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["k", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SqrtBox[
             RowBox[{"X", "[", "a", "]"}]]}], "+", 
           RowBox[{"18", " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "a", "]"}], "2"], " ", 
            SqrtBox[
             RowBox[{"X", "[", "a", "]"}]]}], "-", 
           RowBox[{"6", " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            RowBox[{"KX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], 
             RowBox[{"3", "/", "2"}]]}], "-", 
           RowBox[{"18", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      ")"}]}]}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Delta]X", "\[Prime]",
      MultilineFunction->None], "[", "a", "]"}], "\[Rule]", 
    RowBox[{"-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"18", " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]]}], "+", 
         RowBox[{"72", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]]}], "-", 
         RowBox[{"36", " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]]}], "+", 
         RowBox[{"6", " ", 
          SuperscriptBox["H0", "2"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0", 
          " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "+", 
         RowBox[{"24", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0", 
          " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
         RowBox[{"18", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "-", 
         RowBox[{"324", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"18", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"14", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"162", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"648", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"54", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"648", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "4"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"324", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"324", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}]}], "-", 
         RowBox[{"4", " ", "a", " ", 
          SuperscriptBox["k", "4"], " ", "\[Rho]c", " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"16", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["k", "4"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"84", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"8", " ", "a", " ", 
          SuperscriptBox["k", "4"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "+", 
         RowBox[{"288", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"72", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "4"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"216", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"216", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "6"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          SqrtBox[
           FractionBox[
            RowBox[{"X", "[", "a", "]"}], 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"18", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"18", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"Vm", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0", 
          " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["H0", "2"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0", 
          " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"18", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"18", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "\[Rho]c", " ", "\[CapitalOmega]m0",
           " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[Delta]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"3", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"3", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"9", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"2", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"72", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"9", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"432", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"180", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"378", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"4", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"4", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KXXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KXXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3XX", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"24", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XXX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"108", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"18", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"108", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "4"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3XX", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XXX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KXXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"G3XX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"9", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"216", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"G3XXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"9", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"9", "/", "2"}]], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "5"], " ", 
          RowBox[{"\[Delta]X", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"4", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["k", "4"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SqrtBox[
           RowBox[{"X", "[", "a", "]"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"6", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          RowBox[{"X", "[", "a", "]"}], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"4", " ", 
          SqrtBox["2"], " ", "a", " ", 
          SuperscriptBox["k", "4"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"10", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"54", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"3", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"48", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "2"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"6", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"KX", "[", "t", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"4", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"5", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"48", " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "3"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "-", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "3"], " ", 
          SuperscriptBox["k", "2"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"108", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"12", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"7", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"72", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "4"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"216", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "a", "]"}], "2"], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"9", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"36", " ", 
          SqrtBox["2"], " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "3"], " ", 
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{"9", "/", "2"}]], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}], "+", 
         RowBox[{"216", " ", 
          SuperscriptBox["a", "5"], " ", "\[Rho]c", " ", 
          SuperscriptBox[
           RowBox[{"G3X", "[", "t", "]"}], "4"], " ", 
          RowBox[{"H", "[", "a", "]"}], " ", 
          SuperscriptBox[
           RowBox[{"X", "[", "a", "]"}], "5"], " ", 
          RowBox[{"\[CapitalPhi]", "[", "a", "]"}], " ", 
          RowBox[{
           SuperscriptBox["X", "\[Prime]",
            MultilineFunction->None], "[", "a", "]"}]}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["a", "4"], " ", "\[Rho]c", " ", 
         RowBox[{"H", "[", "a", "]"}], " ", 
         SqrtBox[
          RowBox[{"X", "[", "a", "]"}]], " ", 
         SqrtBox[
          FractionBox[
           RowBox[{"X", "[", "a", "]"}], 
           RowBox[{
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "a", "]"}], "2"]}]]], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox["2"], " ", 
            RowBox[{"KX", "[", "t", "]"}]}], "+", 
           RowBox[{"12", " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            SqrtBox[
             RowBox[{"X", "[", "a", "]"}]]}], "+", 
           RowBox[{"2", " ", 
            SqrtBox["2"], " ", 
            RowBox[{"KXX", "[", "t", "]"}], " ", 
            RowBox[{"X", "[", "a", "]"}]}], "+", 
           RowBox[{"12", " ", 
            RowBox[{"G3XX", "[", "t", "]"}], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], 
             RowBox[{"3", "/", "2"}]]}], "+", 
           RowBox[{"6", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox[
             RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], "2"]}]}], ")"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "3"}], " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            RowBox[{"KX", "[", "t", "]"}]}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["k", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SqrtBox[
             RowBox[{"X", "[", "a", "]"}]]}], "-", 
           RowBox[{"18", " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "a", "]"}], "2"], " ", 
            SqrtBox[
             RowBox[{"X", "[", "a", "]"}]]}], "+", 
           RowBox[{"6", " ", 
            SuperscriptBox["a", "2"], " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            RowBox[{"KX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], 
             RowBox[{"3", "/", "2"}]]}], "+", 
           RowBox[{"18", " ", 
            SqrtBox["2"], " ", 
            SuperscriptBox["a", "2"], " ", 
            SuperscriptBox[
             RowBox[{"G3X", "[", "t", "]"}], "2"], " ", 
            RowBox[{"H", "[", "a", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"X", "[", "a", "]"}], "2"]}]}], ")"}]}], ")"}]}], 
      ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7615701514346943`*^9, 3.7615701881241627`*^9}, 
   3.761570262106145*^9, {3.7615705531192822`*^9, 3.761570556229266*^9}, 
   3.761570945879126*^9},ExpressionUUID->"1ea2b04e-88d6-47b9-b7c6-\
305e76511ccc"]
}, Closed]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",ExpressionUUID->"ef08e1c4-b8ff-4b14-a7eb-7e4bb33ab854"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
  "Coefficients", " ", "for", " ", "the", " ", "perturbations", " ", "and", 
   " ", "other", " ", "stuff"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568095987703977`*^9, 3.7568096025405245`*^9}, {
  3.7568096466310263`*^9, 3.756809647990944*^9}, {3.759058881508876*^9, 
  3.7590588884860964`*^9}},ExpressionUUID->"15cc277a-efbf-4f60-85ba-\
0ef8110d09a2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"rulesGR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.7608768223278103`*^9},ExpressionUUID->"55329c2f-7b42-4b33-ac32-\
7900ff4bbb11"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A1", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert001", ",", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516230728106737`*^9, 3.751623106845154*^9}, {
   3.751623179576193*^9, 3.751623207766415*^9}, {3.751623238186195*^9, 
   3.7516232715906186`*^9}, 3.7516244030516586`*^9, 3.7516245231157255`*^9, 
   3.7516247017693205`*^9, 
   3.751631705970668*^9},ExpressionUUID->"1b9f10b8-9885-49ce-9ab1-\
c505241618b8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"12", " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}]}]], "Output",
 CellChangeTimes->{
  3.7516231079960785`*^9, {3.751623179895975*^9, 3.7516232084062967`*^9}, {
   3.7516232441561847`*^9, 3.7516232730561066`*^9}, 3.751624453231707*^9, 
   3.751624523771368*^9, 3.751624703968917*^9, 3.751624938934341*^9, 
   3.751630223750257*^9, 3.7516307122704024`*^9, 3.7516317086904936`*^9, 
   3.753343475244482*^9, 3.7533440825094156`*^9, 3.7561094875210066`*^9, 
   3.760866581261598*^9, 3.7608768329470863`*^9, 3.7610286694419966`*^9, 
   3.763101128705476*^9},ExpressionUUID->"c6c3472b-bd7d-42d2-9449-\
e92ae7e952fa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A2", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert001", ",", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516232496410737`*^9, 3.7516232878063154`*^9}, 
   3.7516244041409254`*^9, 3.751628766927614*^9, 
   3.751631709950754*^9},ExpressionUUID->"1cca30d6-4e8d-4738-944b-\
9f696fdd0ccc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"9", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}]}]], "Output",
 CellChangeTimes->{
  3.7516232891259494`*^9, 3.751624454535583*^9, 3.751624941088229*^9, {
   3.751628750910288*^9, 3.751628767698821*^9}, 3.751630225120273*^9, 
   3.751630713761507*^9, 3.7516317104406652`*^9, 3.7533434772258415`*^9, 
   3.753344086044546*^9, 3.760866582997089*^9, 3.7608768344074335`*^9, 
   3.7610286694635487`*^9, 
   3.7631011287667093`*^9},ExpressionUUID->"41359f22-74e6-4814-9369-\
9754eaf3b9f2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A3", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert001", ",", 
     RowBox[{
      RowBox[{"\[CapitalPhi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
      FractionBox[
       RowBox[{"k", "^", "2"}], 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516233424103518`*^9, 3.7516233450793576`*^9}, 
   3.75162440505136*^9, 3.751628768748782*^9, 3.7516303298103685`*^9, 
   3.7516317120307417`*^9},ExpressionUUID->"3d2deaae-f906-4528-a621-\
29bc11cd9d53"],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"G4", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.7516233890061383`*^9, 3.7516244569415684`*^9, 
  3.751624942329975*^9, 3.7516287710091867`*^9, 3.7516302268000293`*^9, 
  3.7516303309303093`*^9, 3.751630714720291*^9, 3.751631712380433*^9, 
  3.7533434785576386`*^9, 3.7533440912784176`*^9, 3.7608665970572615`*^9, 
  3.7608768352773466`*^9, 3.761028669472187*^9, 
  3.763101128817622*^9},ExpressionUUID->"2994dd15-8f95-47ff-9e0b-\
3af25b36b73d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A4", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert001", ",", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.751623326476153*^9, 3.75162335366673*^9}, 
   3.7516244065254383`*^9, 3.7516287695520086`*^9, 
   3.7516317137752934`*^9},ExpressionUUID->"760f7fd0-03e7-4e11-bd78-\
415b21934b73"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "12"}], " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"12", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"KX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"12", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
  RowBox[{
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "5"]}]}]], "Output",
 CellChangeTimes->{3.7516233910361114`*^9, 3.751624458964467*^9, 
  3.7516249438806334`*^9, 3.7516287702225866`*^9, 3.7516302279231377`*^9, 
  3.7516307160703*^9, 3.7516317142207565`*^9, 3.753343479551214*^9, 
  3.7608665992792645`*^9, 3.760876836792348*^9, 3.7610286694923944`*^9, 
  3.7631011288787966`*^9},ExpressionUUID->"4a797dfa-9614-43f8-88fc-\
e7ec0491cae6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A5", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert001", ",", 
     RowBox[{"\[Chi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.751623329550664*^9, 3.751623331876494*^9}, 
   3.7516233644094725`*^9, 3.751623400586379*^9, {3.7516307215345917`*^9, 
   3.751630725770246*^9}, 
   3.751631715640985*^9},ExpressionUUID->"5c4f6aba-8d9f-4338-b422-\
6e49dae7a9d4"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7516233924707565`*^9, 3.7516234031961718`*^9}, 
   3.7516244609516425`*^9, 3.7516249451848364`*^9, 3.75163022931991*^9, {
   3.7516307177401066`*^9, 3.7516307265504365`*^9}, 3.751631716010607*^9, 
   3.7533440981382008`*^9, 3.7608666230472198`*^9, 3.760876852317669*^9, 
   3.7610286695131006`*^9, 
   3.7631011289396915`*^9},ExpressionUUID->"aad5f392-e3a0-48d7-974d-\
fd03488bf631"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"A6", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert001", ",", 
     RowBox[{
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      FractionBox[
       RowBox[{"k", "^", "2"}], 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.7516233668864655`*^9, {3.751623409287554*^9, 3.7516234095944757`*^9}, 
   3.751624407951528*^9, {3.7516246308195477`*^9, 3.751624635112224*^9}, 
   3.751630362650058*^9, 
   3.7516317180110083`*^9},ExpressionUUID->"7b9a46ff-4cb4-4bff-8493-\
77f4715e7d86"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.751623393636262*^9, 3.7516234103945775`*^9}, 
   3.751624462095383*^9, 3.751624636283343*^9, 3.751624946188076*^9, 
   3.751630230399992*^9, 3.751630363139167*^9, 3.75163072873952*^9, 
   3.7516317183909903`*^9, 3.7533440970511804`*^9, 3.7608666276272073`*^9, 
   3.7608768561872816`*^9, 3.7610286695232553`*^9, 
   3.7631011289906282`*^9},ExpressionUUID->"7eff09b8-084b-4198-9d28-\
b09291f00769"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Mu]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"A6", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"pert001", ",", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.751630402270273*^9, 3.751630456669259*^9}, 
   3.7516305107203355`*^9, 
   3.751631721355186*^9},ExpressionUUID->"70b387e4-cd7f-4c18-9086-\
2682e337e401"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}]}]], "Output",
 CellChangeTimes->{{3.7516303985536413`*^9, 3.7516304039602623`*^9}, 
   3.7516304579000983`*^9, 3.7516305114400826`*^9, 3.7516307304204755`*^9, 
   3.751631721770792*^9, 3.753344102353239*^9, 3.7608666318569193`*^9, 
   3.7608768572636003`*^9, 3.7610286695596385`*^9, 
   3.763101129049402*^9},ExpressionUUID->"ea3f4e29-bbb5-468c-be77-\
5b2369ae88c8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B1", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert221", ",", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516230728106737`*^9, 3.751623106845154*^9}, {
   3.751623179576193*^9, 3.751623207766415*^9}, {3.751623238186195*^9, 
   3.7516232715906186`*^9}, 3.7516244030516586`*^9, 3.7516245231157255`*^9, 
   3.7516247017693205`*^9, {3.7516309580106163`*^9, 3.75163096859461*^9}, {
   3.751631019133599*^9, 3.7516310270104628`*^9}, 3.7516314512403045`*^9, 
   3.7516315191797605`*^9},ExpressionUUID->"6aea6d02-e845-474f-9d18-\
a9c6932fd0c8"],

Cell[BoxData[
 RowBox[{"12", " ", 
  RowBox[{"G4", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.751630962360647*^9, 3.751630969110569*^9}, {
   3.751631020220661*^9, 3.751631027390339*^9}, 3.7516312147403812`*^9, 
   3.7516314520006404`*^9, 3.751631521390806*^9, 3.751631729990692*^9, 
   3.753344109191409*^9, 3.7608667190794325`*^9, 3.760876878907032*^9, 
   3.7610286695739965`*^9, 
   3.7631011291004314`*^9},ExpressionUUID->"76ae1dd9-24c0-4488-986f-\
166c22c77ad3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B2", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert221", ",", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.751630991631916*^9, 3.7516310329605694`*^9}, 
   3.751631453800521*^9, 
   3.7516315239008255`*^9},ExpressionUUID->"dcb43b3e-87bd-4c9b-bd88-\
9151f1176819"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.751631006270524*^9, 3.7516310335704713`*^9}, 
   3.751631216010336*^9, 3.75163145482069*^9, 3.751631524320402*^9, 
   3.7516317439404745`*^9, 3.753344110203475*^9, 3.7608667278491373`*^9, 
   3.7608768797376013`*^9, 3.761028669588332*^9, 
   3.763101129153565*^9},ExpressionUUID->"d8cc0d5a-e2b9-4db6-9151-\
ffddd1e0ed3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B3", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert221", ",", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.751631068444545*^9, {3.7516311052096767`*^9, 3.7516311083106227`*^9}, {
   3.7516314566310205`*^9, 3.751631458920704*^9}, 
   3.751631527330482*^9},ExpressionUUID->"28434785-1467-435a-873d-\
e610f06411b2"],

Cell[BoxData[
 RowBox[{
  RowBox[{"36", " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "+", 
  RowBox[{"12", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.751631109154863*^9, 3.7516312173342094`*^9, 
  3.751631459554386*^9, 3.7516315277948885`*^9, 3.7516317576199217`*^9, 
  3.7533441119701166`*^9, 3.760866738777152*^9, 3.760876880427554*^9, 
  3.761028669604484*^9, 
  3.7631011292047033`*^9},ExpressionUUID->"8ebd78cd-a797-4f24-8138-\
98eeb57f37aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B4", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert221", ",", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.751631071030935*^9, {3.7516311152304296`*^9, 3.7516311175002594`*^9}, 
   3.7516314615005803`*^9, 
   3.7516315301708097`*^9},ExpressionUUID->"1afdfd24-caee-4bbf-a817-\
1177782c61ec"],

Cell[BoxData[
 RowBox[{
  RowBox[{"12", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"12", " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.751631118994369*^9, 3.7516312190905805`*^9, 
  3.7516314620798826`*^9, 3.751631530684927*^9, 3.7516317620649085`*^9, 
  3.7533441153520656`*^9, 3.7608667409219933`*^9, 3.76087688115739*^9, 
  3.7610286696144705`*^9, 
  3.763101129265761*^9},ExpressionUUID->"4e216d51-e8f8-48f7-8365-\
92c6e517ab04"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B5", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert221", ",", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.7516310721237154`*^9, {3.7516311255204515`*^9, 3.7516311289403896`*^9}, 
   3.751631464350797*^9, 
   3.7516315326400824`*^9},ExpressionUUID->"9c9a2ca2-20f3-4f5a-aed6-\
e65a1f8c66a1"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "12"}], " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}]}]], "Output",
 CellChangeTimes->{3.7516311317507296`*^9, 3.75163122028065*^9, 
  3.7516314650299053`*^9, 3.751631533060408*^9, 3.751631898600355*^9, 
  3.7533441532286053`*^9, 3.760866899990532*^9, 3.760876884337559*^9, 
  3.7610286696350284`*^9, 
  3.7631011293168755`*^9},ExpressionUUID->"e4031244-ed2c-4b2d-832b-\
8d8fd8aa308b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B6", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"pert221", "//", "Expand"}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"k", "^", "2"}], 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.7516310751410756`*^9, {3.751631139712812*^9, 3.751631143950319*^9}, {
   3.7516312286809874`*^9, 3.7516312695505424`*^9}, {3.751631387412592*^9, 
   3.751631390570664*^9}, {3.751631466430614*^9, 3.751631501903407*^9}, 
   3.7516315356147375`*^9},ExpressionUUID->"da6e6033-8e99-45c5-9f90-\
12c8900f2d5c"],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"G4", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{
  3.751631146319165*^9, 3.7516312221647725`*^9, {3.751631258880642*^9, 
   3.751631270194564*^9}, 3.7516313271750307`*^9, {3.751631388354276*^9, 
   3.7516313912315454`*^9}, {3.7516314669604983`*^9, 3.751631502240043*^9}, 
   3.7516315360944495`*^9, 3.751631901255665*^9, 3.7533441543840723`*^9, 
   3.760866917546824*^9, 3.7608768851922064`*^9, 3.7610286696452503`*^9, 
   3.7631011293676443`*^9},ExpressionUUID->"1b9c3ef5-da4e-486c-8058-\
8f748ab51b1e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B7", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"pert221", "//", "Expand"}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"k", "^", "2"}], 
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516315590809746`*^9, 
  3.7516315726704903`*^9}},ExpressionUUID->"d335120d-9737-4358-896e-\
8d90ed06f79b"],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"G4\[Phi]", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.7516315744856014`*^9, 3.753344155332987*^9, 
  3.760866921596793*^9, 3.760876886682035*^9, 3.7610286696600513`*^9, 
  3.7631011294187355`*^9},ExpressionUUID->"8d223d20-cab0-4650-b6fd-\
f95d48c3afc3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B8", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{
     RowBox[{"pert221", "//", "Expand"}], ",", 
     FractionBox[
      RowBox[{
       RowBox[{"k", "^", "2"}], 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.7516315601649604`*^9, {3.7516316717707305`*^9, 
   3.7516316726010523`*^9}},ExpressionUUID->"89f95e8f-44bd-4071-8a71-\
b2cf46da89ef"],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"G4", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.751631674355742*^9, 3.7533441832604322`*^9, 
  3.760866932696066*^9, 3.7608768875925674`*^9, 3.761028669675237*^9, 
  3.7631011294676466`*^9},ExpressionUUID->"6e681067-807d-4b84-9cd3-\
bc636ea1198c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[Nu]", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Coefficient", "[", 
       RowBox[{"pert221", ",", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "-", 
      RowBox[{"B7", 
       FractionBox[
        RowBox[{"k", "^", "2"}], 
        RowBox[{
         RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], ")"}], "/", "3"}], "//",
    "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516310851606493`*^9, 3.7516310918503017`*^9}, {
  3.7516316189109235`*^9, 
  3.7516316399805655`*^9}},ExpressionUUID->"3374b9f5-331b-43c9-b8e7-\
7a18d40e7d30"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"K\[Phi]", "[", "t", "]"}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.7516316409408274`*^9, 3.7533441581834927`*^9, 
  3.7608768901171317`*^9, 3.761028669687543*^9, 
  3.763101129530646*^9},ExpressionUUID->"1191b513-503c-4f83-b010-\
07826850f5cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"B9", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"pert221", ",", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "-", 
    RowBox[{"B8", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.7516310784205136`*^9, 3.751631538860444*^9, {3.751631682370325*^9, 
   3.7516316906206665`*^9}},ExpressionUUID->"741d294f-6fd8-4b03-bfe8-\
ae2e7df862d9"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "36"}], " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"24", " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"24", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"12", " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
  RowBox[{"12", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"12", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.7516315393308372`*^9, 3.7516316913206425`*^9, 
  3.751631990009692*^9, 3.7533441833075724`*^9, 3.760867015001747*^9, 
  3.7608768917273436`*^9, 3.761028669705845*^9, 
  3.763101129599643*^9},ExpressionUUID->"9d6e8a7f-86ec-4cbc-bbf4-\
92e8cdd54766"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "use", " ", "background", " ", "to", " ", "eliminate", " ", "G4", " ", 
    "in", " ", "favor", " ", "of", " ", "K"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"B9", "/.", 
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"K", "[", "t", "]"}], "==", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "6"}], " ", 
            RowBox[{"G4", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
           RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
            RowBox[{"Pm", "[", "t", "]"}]}], "-", 
           RowBox[{"4", " ", 
            RowBox[{"G4", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "-", 
           RowBox[{"4", " ", 
            RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
            RowBox[{"H", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
           RowBox[{"2", " ", 
            RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
         RowBox[{"G4", "[", "t", "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "/.", 
     RowBox[{
      RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "//", 
    "FullSimplify"}], "//", "Expand"}]}]], "Input",
 CellChangeTimes->{{3.751632173896593*^9, 3.751632207801143*^9}, {
  3.751632240606471*^9, 3.7516322562694798`*^9}, {3.7517970716756196`*^9, 
  3.7517970720196247`*^9}},ExpressionUUID->"6da3c64f-01d0-4437-b828-\
d3136452c3c9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", 
   RowBox[{"K", "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{
  3.7516321130165806`*^9, {3.7516321831962442`*^9, 3.751632208536445*^9}, 
   3.75334418345092*^9, 3.760867171656787*^9, 3.760876893791992*^9, 
   3.761028669807702*^9, 
   3.763101129774709*^9},ExpressionUUID->"165a9f03-f547-49a5-8b3b-\
05c9a3da5b34"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C1", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert12", ",", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516324566667576`*^9, 
  3.751632467820403*^9}},ExpressionUUID->"eea8011d-0aca-42ad-ab9e-\
735906e1e4fc"],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"G4", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.7516324688391285`*^9, 3.7516325075867767`*^9}, 
   3.7533442207095375`*^9, 3.7608673580283213`*^9, 3.7608769358075128`*^9, 
   3.761028669817832*^9, 
   3.763101129846015*^9},ExpressionUUID->"21771676-57c7-49ca-b06a-\
c69ade2c6e3b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C2", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert12", ",", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516325233566146`*^9, 
  3.751632540006919*^9}},ExpressionUUID->"71c8aa72-7181-4783-b78c-\
5a52f56ea50a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.7516325417308445`*^9, 3.7533442216376576`*^9, 
  3.7608673745486465`*^9, 3.7608769358875265`*^9, 3.7610286698378725`*^9, 
  3.763101129896926*^9},ExpressionUUID->"216a70d0-eea4-4ff4-b651-\
47f088f4c26b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C3", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert12", ",", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516325242865376`*^9, 
  3.7516325531769915`*^9}},ExpressionUUID->"2974ac11-dc3b-466b-b5c0-\
f6add7dd33b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "4"}], " ", 
   RowBox[{"G4", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}]}]], "Output",
 CellChangeTimes->{{3.751632547630678*^9, 3.7516325536365595`*^9}, 
   3.7533442240977955`*^9, 3.7608673919477577`*^9, 3.7608769359371033`*^9, 
   3.7610286698482676`*^9, 
   3.763101129947939*^9},ExpressionUUID->"d3f8d187-ad63-4b4d-ac26-\
829d7b499910"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"C4", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"pert12", ",", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{
  3.7516325252266507`*^9, {3.7516325567264986`*^9, 
   3.7516325587067285`*^9}},ExpressionUUID->"d84cdc90-6acb-4f57-b33a-\
9f8d57c34655"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2"}], " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.751632559544952*^9, 3.7533442270788145`*^9, 
  3.7608674036837626`*^9, 3.760876935982139*^9, 3.7610286698684835`*^9, 
  3.763101129998665*^9},ExpressionUUID->"4615cb07-84b5-4620-bc74-\
3b11981bf6ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D1", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7516332882070484`*^9, 3.7516333226266303`*^9}, 
   3.751633471056735*^9},ExpressionUUID->"f81dae17-a391-4602-b906-\
c520fa1da2fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{{3.7516333022111483`*^9, 3.751633323157475*^9}, 
   3.7516334167710986`*^9, {3.751633471680764*^9, 3.751633498506728*^9}, 
   3.751634184646978*^9, 3.7533442377813063`*^9, 3.760867455438033*^9, 
   3.76086790234781*^9, 3.7608769553993044`*^9, 3.7610286698786993`*^9, 
   3.763101130057813*^9},ExpressionUUID->"e8631eb6-a22a-41fb-af48-\
90dc9061b284"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D2", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     SuperscriptBox["\[Delta]\[Phi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.751633443070608*^9, 3.7516334491273947`*^9}, 
   3.751633480647244*^9, 
   3.7608675373077726`*^9},ExpressionUUID->"7e899087-7108-4230-a9c8-\
feb7e8b40ff6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
  RowBox[{"KX", "[", "t", "]"}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}]}]], "Output",
 CellChangeTimes->{
  3.7516334502069387`*^9, {3.7516334810210924`*^9, 3.7516334997768097`*^9}, 
   3.7516341855673623`*^9, 3.7533442400131454`*^9, 3.7608613700053625`*^9, 
   3.7608674747179313`*^9, 3.7608679035502787`*^9, 3.760876956077237*^9, 
   3.7610286698886204`*^9, 
   3.763101130110941*^9},ExpressionUUID->"4f62bc22-e4d5-4bac-b105-\
89f7f96ebede"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D3", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     SuperscriptBox["\[CapitalPhi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7516336659270926`*^9, 
  3.751633668835512*^9}},ExpressionUUID->"320f6fc2-0f6b-45cb-bd2f-\
11384d3ce693"],

Cell[BoxData[
 RowBox[{
  RowBox[{"24", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"18", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.7516336712815657`*^9, 3.7516341870472937`*^9, 
  3.7533442680999994`*^9, 3.760861373190516*^9, 3.7608679288980403`*^9, 
  3.7608769567723618`*^9, 3.7610286699088306`*^9, 
  3.7631011301721168`*^9},ExpressionUUID->"9b7c7dfe-b1dc-48f7-a2a2-\
21e8a5adef5c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D4", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     SuperscriptBox["\[Delta]\[Phi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.75163368008737*^9, 
  3.7516336865373526`*^9}},ExpressionUUID->"6b6b76ae-8fcb-4c76-81f3-\
377907c85015"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"KX", "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"18", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"9", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{
   RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"4", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"15", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"KXXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"3", " ", 
   RowBox[{"G3XXX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{3.751633687301365*^9, 3.7516341891608477`*^9, 
  3.7608613775555363`*^9, 3.76086793673766*^9, 3.7608769575974393`*^9, 
  3.7610286699291563`*^9, 
  3.7631011302640114`*^9},ExpressionUUID->"c0c8c9f7-86d9-4f3e-b068-\
eb5d9f1a0609"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"D4", "-", 
     RowBox[{"D", "[", 
      RowBox[{"D2", ",", "t"}], "]"}], "-", 
     RowBox[{"3", " ", 
      RowBox[{"H", "[", "t", "]"}], " ", "D2"}]}], "/.", "rules"}], "//", 
   "FullSimplify"}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7516337060973277`*^9, 
  3.751633731411133*^9}},ExpressionUUID->"c3665dfe-9f0a-4bf3-8e18-\
f731c82f91be"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7516337227168827`*^9, 3.7516337328607945`*^9}, 
   3.751634196687529*^9, 3.760861384840661*^9, 3.760867939352793*^9, 
   3.760876959097133*^9, 3.761028669944482*^9, 
   3.76310113031504*^9},ExpressionUUID->"97954254-f2ba-40b3-9ed6-\
17fa4eb8bbc0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D5", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     SuperscriptBox["\[CapitalPsi]", 
      TagBox[
       RowBox[{"(", 
        RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
       Derivative],
      MultilineFunction->None], "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.7516337850371323`*^9, 
  3.7516337925213027`*^9}},ExpressionUUID->"96112f9f-9eed-4b06-87ef-\
0ba5a84d93d3"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "6"}], " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"9", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
  RowBox[{
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}]}]], "Output",
 CellChangeTimes->{3.7516337936215353`*^9, 3.751634197966688*^9, 
  3.7608679485328493`*^9, 3.7608769599273343`*^9, 3.7610286699597635`*^9, 
  3.7631011303759546`*^9},ExpressionUUID->"b82c45f2-dd07-4249-94e2-\
b0eea1457ddf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D7", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.751633811177693*^9, 
  3.751633823306978*^9}},ExpressionUUID->"19b5f357-0c85-4065-98d7-\
311499630e88"],

Cell[BoxData[
 RowBox[{"4", " ", 
  RowBox[{"G4\[Phi]", "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.7516338242769012`*^9, 3.7516339979009933`*^9, 
  3.7516341999470844`*^9, 3.7533443028310227`*^9, 3.7608679809477105`*^9, 
  3.7608769606874104`*^9, 3.761028669970007*^9, 
  3.7631011304246173`*^9},ExpressionUUID->"2cdc0052-a31e-46e6-bcc3-\
fa7f583890eb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D8", "=", 
  RowBox[{
   RowBox[{"Coefficient", "[", 
    RowBox[{"scaleq1", ",", 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "-", 
   RowBox[{"D7", 
    FractionBox[
     RowBox[{"k", "^", "2"}], 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}]}]], "Input",
 CellChangeTimes->{{3.75163382883119*^9, 3.751633848717247*^9}, 
   3.7516339704073267`*^9},ExpressionUUID->"f2cbbc22-cd73-4b77-81a8-\
ea6da620b9a0"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.7516338495862975`*^9, 3.7516339715571012`*^9, 3.751634201541346*^9, {
   3.7533442991213207`*^9, 3.753344304846185*^9}, 3.760867985737962*^9, 
   3.7608769647898054`*^9, 3.761028669990377*^9, 
   3.763101130467407*^9},ExpressionUUID->"2a8dbcb9-bc86-40fc-9952-\
919cc6a754dd"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"D8Matsumoto", "=", 
   RowBox[{
    RowBox[{"9", 
     RowBox[{"H", "[", "t", "]"}], 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], 
      RowBox[{"-", "1"}]], 
     RowBox[{"K", "[", "t", "]"}]}], "+", 
    RowBox[{"3", 
     RowBox[{"K\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "+", 
       RowBox[{"3", 
        RowBox[{"H", "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], 
     RowBox[{"KX", "[", "t", "]"}]}], "-", 
    RowBox[{"3", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
        RowBox[{"KXX", "[", "t", "]"}]}]}], ")"}]}], "+", 
    RowBox[{"3", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"3", 
        RowBox[{"H", "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{"9", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        RowBox[{"H", "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], 
     RowBox[{"G3X", "[", "t", "]"}]}], "+", 
    RowBox[{"3", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], 
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}]}], "+", 
    RowBox[{"3", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "-", 
       RowBox[{"3", 
        RowBox[{"H", "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], 
     RowBox[{"G3X\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{"9", 
     RowBox[{"H", "[", "t", "]"}], 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], 
     RowBox[{"G3XX", "[", "t", "]"}]}], " ", "+", 
    RowBox[{"18", 
     RowBox[{"H", "[", "t", "]"}], 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{"2", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], 
     RowBox[{"G4", "[", "t", "]"}]}], "+", 
    RowBox[{"18", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], 
      RowBox[{"-", "1"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"4", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], 
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}], 
     RowBox[{"G4\[Phi]", "[", "t", "]"}]}], " ", "+", 
    RowBox[{"18", 
     RowBox[{"H", "[", "t", "]"}], 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}]}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7533434949980006`*^9, 3.7533434984586363`*^9}, {
  3.753343559975482*^9, 3.753343571805913*^9}, {3.753343611157347*^9, 
  3.7533436695590305`*^9}},ExpressionUUID->"387d43d9-b88b-42f4-8ecc-\
7b3731209cda"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{" ", 
    RowBox[{"Ruben", " ", "is", " ", 
     RowBox[{"correct", " ", ":"}]}], ")"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"D8Matsumoto", "/.", "solK"}], "/.", "solKf"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.753343674060356*^9, 3.7533436847968545`*^9}, {
  3.753343749172119*^9, 3.7533437510445623`*^9}, {3.7533438033262296`*^9, 
  3.753343804364393*^9}, {3.7533438508400126`*^9, 3.7533438518761673`*^9}, {
  3.753343898101838*^9, 3.753343901282007*^9}, {3.7533439314780893`*^9, 
  3.7533439473239536`*^9}},ExpressionUUID->"d8935064-942a-46f9-8556-\
33eb0dade75d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.7533436804233785`*^9, 3.7533436855245876`*^9}, 
   3.7533437521495123`*^9, 3.753343804966017*^9, {3.7533439018870225`*^9, 
   3.753343949837336*^9}, 3.7608679906578283`*^9, 3.7610286700107837`*^9, 
   3.763101130548665*^9},ExpressionUUID->"b6541701-4f30-43d9-b0a2-\
4ec8516b413c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D9", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.751633811177693*^9, 3.751633823306978*^9}, {
  3.7516339912269726`*^9, 
  3.751633996987045*^9}},ExpressionUUID->"3fa6357c-6c77-4216-9d49-\
8a10b73a4534"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
  RowBox[{"KX", "[", "t", "]"}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7516339946071157`*^9, 3.751633998716834*^9}, 
   3.7516342028770227`*^9, 3.7533439627492085`*^9, 3.753344319323015*^9, {
   3.760867995905156*^9, 3.7608680180328617`*^9}, 3.7608769674072204`*^9, 
   3.761028670030996*^9, 
   3.7631011305995145`*^9},ExpressionUUID->"92d4e16c-ea41-4fb2-ab63-\
392d229c8f88"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"M2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], " ", "D9"}], "-", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"scaleq1", ",", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.7516340041769147`*^9, 
  3.7516340442869635`*^9}},ExpressionUUID->"c71d681d-c668-4f43-8191-\
5a7ec84336dd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "12"}], " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"9", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"KX\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.751634036937149*^9, 3.7516340451908464`*^9}, 
   3.751634206027444*^9, {3.7533443303498063`*^9, 3.753344357113015*^9}, 
   3.7608680102877507`*^9, 3.760876968747339*^9, 3.7610286700512714`*^9, 
   3.763101130689129*^9},ExpressionUUID->"e42518ea-2d3b-4f12-9e01-\
e4be41cbe556"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D10", "=", 
  RowBox[{"Coefficient", "[", 
   RowBox[{"scaleq1", ",", 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.751633811177693*^9, 3.751633823306978*^9}, {
  3.751634057486479*^9, 
  3.751634070767291*^9}},ExpressionUUID->"8197f067-2ff6-4ca5-ad39-\
6774d8f329c3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"2", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}]}]], "Output",
 CellChangeTimes->{3.751634082157097*^9, 3.7516342127274046`*^9, 
  3.7608680368576536`*^9, 3.76087697020022*^9, 3.7610286700644712`*^9, 
  3.7631011308010283`*^9},ExpressionUUID->"57394d1a-9d5d-4f5c-8ddc-\
8232e5822d1f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"D11", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Coefficient", "[", 
     RowBox[{"scaleq1", ",", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "-", 
    RowBox[{"D10", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}]}], "//", 
   "Expand"}]}]], "Input",
 CellChangeTimes->{{3.75163382883119*^9, 3.751633848717247*^9}, 
   3.7516339704073267`*^9, {3.751634059367716*^9, 3.7516341055970907`*^9}, {
   3.760868201167717*^9, 
   3.760868206427706*^9}},ExpressionUUID->"0825f03e-39e2-41bc-8f94-\
3d14a0f8efb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "24"}], " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
  RowBox[{"12", " ", 
   RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"12", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"2", " ", 
   RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"36", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{
   RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"12", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
  RowBox[{"9", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{"H", "[", "t", "]"}], "2"], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
  RowBox[{
   RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "5"]}], "-", 
  RowBox[{"4", " ", 
   RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"2", " ", 
   RowBox[{"KX", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"24", " ", 
   RowBox[{"G3X", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{"6", " ", 
   RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"5", " ", 
   RowBox[{"KXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"24", " ", 
   RowBox[{"G3XX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "-", 
  RowBox[{
   RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   RowBox[{"KXXX", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"G3XXX", "[", "t", "]"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "5"], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.751634083676645*^9, 3.751634105987202*^9}, 
   3.7516342146175237`*^9, 3.7608680428674493`*^9, {3.760868204399997*^9, 
   3.7608682068277187`*^9}, 3.760876971001278*^9, 3.761028670086731*^9, 
   3.7631011309051137`*^9},ExpressionUUID->"93885c06-e22e-443b-ae78-\
cd2f52055c5d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", 
    "\[Mu]"}], "}"}], "/.", "rulesGR"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", "B7", 
    ",", "B8", ",", "B9", ",", "\[Nu]"}], "}"}], "/.", 
  "rulesGR"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"C1", ",", "C2", ",", "C3", ",", "C4"}], "}"}], "/.", 
  "rulesGR"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", "D7", ",", "D8", 
    ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], "}"}], "/.", 
  "rulesGR"}]}], "Input",
 CellChangeTimes->{{3.7608769737271867`*^9, 3.7608770207077456`*^9}, {
  3.7608770641977396`*^9, 
  3.7608770645933256`*^9}},ExpressionUUID->"8b127f08-fdb4-4301-b26b-\
df3ecb505110"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"6", " ", 
    RowBox[{"H", "[", "t", "]"}]}], ",", "0", ",", "2", ",", 
   RowBox[{
    RowBox[{"-", "6"}], " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], ",", "0", ",", "0", ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.760877021317181*^9, 3.760877065377263*^9, 
  3.761028675445874*^9, 
  3.763101130955722*^9},ExpressionUUID->"010d7257-42fe-4268-a0a6-\
c1cc5b4497ef"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"6", ",", "0", ",", 
   RowBox[{"18", " ", 
    RowBox[{"H", "[", "t", "]"}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "6"}], " ", 
    RowBox[{"H", "[", "t", "]"}]}], ",", "2", ",", "0", ",", "2", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "18"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.760877021317181*^9, 3.760877065377263*^9, 
  3.761028675445874*^9, 
  3.763101130976198*^9},ExpressionUUID->"ed07a79c-f4ef-4e51-8ee0-\
b2bc91b93571"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2", ",", "0", ",", 
   RowBox[{
    RowBox[{"-", "2"}], " ", 
    RowBox[{"H", "[", "t", "]"}]}], ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.760877021317181*^9, 3.760877065377263*^9, 
  3.761028675445874*^9, 
  3.7631011309843335`*^9},ExpressionUUID->"b269ac38-5aa7-4dfb-8bbd-\
fa898147c6eb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.760877021317181*^9, 3.760877065377263*^9, 
  3.761028675445874*^9, 
  3.763101130986451*^9},ExpressionUUID->"febf88d8-dcfe-4cef-abe9-\
29c37bebf783"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"{", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]"}],
   "}"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", "B7", ",",
    "B8", ",", "B9", ",", "\[Nu]"}], "}"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"C1", ",", "C2", ",", "C3", ",", "C4"}], 
  "}"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
  "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", "D7", ",", "D8", ",",
    "D9", ",", "D10", ",", "D11", ",", "M2"}], "}"}]}], "Input",
 CellChangeTimes->{{3.7610287424727*^9, 
  3.761028748984979*^9}},ExpressionUUID->"ba9cb4f8-cc7c-442a-8461-\
8893a592b3e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"12", " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
   RowBox[{
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"9", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
   RowBox[{"4", " ", 
    RowBox[{"G4", "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"12", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "5"]}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7610286877480917`*^9, 3.761028854727092*^9, 
  3.763101131088459*^9},ExpressionUUID->"5099c271-5079-400f-8d2b-\
9d6ae0b2ace0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"12", " ", 
    RowBox[{"G4", "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"36", " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "+", 
    RowBox[{"12", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"12", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"12", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
   RowBox[{"4", " ", 
    RowBox[{"G4", "[", "t", "]"}]}], ",", 
   RowBox[{"4", " ", 
    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", 
   RowBox[{"4", " ", 
    RowBox[{"G4", "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "36"}], " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"24", " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"24", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"KX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"12", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"K\[Phi]", "[", "t", "]"}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7610286877480917`*^9, 3.761028854727092*^9, 
  3.7631011311601424`*^9},ExpressionUUID->"d86e187c-8857-4894-b008-\
1706f0986ce1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"4", " ", 
    RowBox[{"G4", "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     RowBox[{"G4", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "2"}], " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7610286877480917`*^9, 3.761028854727092*^9, 
  3.7631011311907487`*^9},ExpressionUUID->"8589602c-5856-4709-81c2-\
7fcb9b6e2ae7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{"KX", "[", "t", "]"}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
   RowBox[{
    RowBox[{"24", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"18", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"KX", "[", "t", "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"18", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"9", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{
     RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"4", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"15", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"KXXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"G3XXX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "6"}], " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"9", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
   RowBox[{"4", " ", 
    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", "0", ",", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{"KX", "[", "t", "]"}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{"2", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "24"}], " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"12", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"36", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"12", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
    RowBox[{"9", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
    RowBox[{
     RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "5"]}], "-", 
    RowBox[{"4", " ", 
     RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"2", " ", 
     RowBox[{"KX", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"24", " ", 
     RowBox[{"G3X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"5", " ", 
     RowBox[{"KXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"24", " ", 
     RowBox[{"G3XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"KXXX", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3XXX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "5"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "12"}], " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"9", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{"H", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["H", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"6", " ", 
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "-", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{
     RowBox[{"KX\[Phi]X", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "+", 
    RowBox[{"3", " ", 
     RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7610286877480917`*^9, 3.761028854727092*^9, 
  3.7631011313931103`*^9},ExpressionUUID->"6c366293-842e-4815-ad5a-\
a067c760b3f9"]
}, Closed]],

Cell[BoxData[
 RowBox[{
  RowBox[{"TmUU", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Raise", "[", 
      RowBox[{"Tmdd", ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "//", 
    "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7516345983974047`*^9, 3.751634691461353*^9}, 
   3.751634935949683*^9},ExpressionUUID->"7eec41ed-f8be-4781-ad81-\
aacf1e19c61e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cons", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"covDiv", "[", 
        RowBox[{"TmUU", ",", 
         RowBox[{"{", "1", "}"}]}], "]"}], "/.", "a2H"}], "/.", 
      RowBox[{
       RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Pm", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}]}], "//", 
    "ApproxFullSimplify"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.751634695197692*^9, 3.7516347098172717`*^9}, {
  3.7516347690981307`*^9, 3.7516347717577624`*^9}, {3.7516348631276083`*^9, 
  3.7516348646178737`*^9}},ExpressionUUID->"efcccf1d-eca2-43bc-917e-\
f94759390949"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"cons", "[", 
   RowBox[{"[", "1", "]"}], "]"}], "/.", "zeroorder"}]], "Input",
 CellChangeTimes->{{3.751634713817301*^9, 3.7516347144150367`*^9}, {
  3.7516347551670513`*^9, 
  3.751634757217559*^9}},ExpressionUUID->"2f433b1a-1b17-4f0e-a3ce-\
29308bad9797"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "3"}], " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{"\[Rho]m", "[", "t", "]"}]}], "-", 
  RowBox[{
   SuperscriptBox["\[Rho]m", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{3.751634789417694*^9, 3.7516348668271866`*^9, 
  3.7516349397921257`*^9, 
  3.763101131547551*^9},ExpressionUUID->"d728c7c7-e96d-4588-ac51-\
d0be55527b6b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Delta]\[Rho]m", "[", 
   RowBox[{"t_", ",", "x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"\[Rho]m", "[", "t", "]"}], 
   RowBox[{"\[Delta]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7516348067973557`*^9, 
  3.7516348226408863`*^9}},ExpressionUUID->"e214592c-7835-4dc6-be0c-\
bda174edfd7c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox[
    RowBox[{"cons", "[", 
     RowBox[{"[", "1", "]"}], "]"}], 
    RowBox[{"\[Rho]m", "[", "t", "]"}]], "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Rho]m", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "//", "Expand"}]], "Input",
 CellChangeTimes->{{3.7516347814978843`*^9, 3.7516347988579206`*^9}, {
  3.7516348391675262`*^9, 
  3.751634839457349*^9}},ExpressionUUID->"e4eeff02-fec4-45f8-ac01-\
95f203e763a0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
    RowBox[{"a", "[", "t", "]"}]]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{"\[Delta]Pm", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"\[Rho]m", "[", "t", "]"}]], "-", 
  RowBox[{
   SuperscriptBox["\[Delta]", 
    TagBox[
     RowBox[{"(", 
      RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
     Derivative],
    MultilineFunction->None], "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "-", 
  RowBox[{"3", " ", 
   RowBox[{
    SuperscriptBox["\[CapitalPhi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7516347797719927`*^9, 3.751634868727584*^9}, 
   3.751634942386897*^9, 
   3.763101131660016*^9},ExpressionUUID->"485dd270-6775-45fc-9198-\
1f39ca71befe"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[ImaginaryI]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"kx", ",", "ky", ",", "kz"}], "}"}], ".", 
     FractionBox[
      RowBox[{"cons", "[", 
       RowBox[{"[", 
        RowBox[{"2", ";;", "4"}], "]"}], "]"}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"\[Rho]m", "[", "t", "]"}]}]]}]}], "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Rho]m", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"-", "3"}], " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]m", "[", "t", "]"}]}]}]}], "//", 
  "ApproxFullSimplify"}]], "Input",
 CellChangeTimes->{
  3.7516348533876967`*^9, {3.751634888207579*^9, 3.7516349081626773`*^9}, {
   3.7516350049473057`*^9, 
   3.751635005247489*^9}},ExpressionUUID->"9ba43a2c-c2b4-4984-8032-\
65c16a2e65c1"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    RowBox[{"H", "[", "t", "]"}], " ", 
    RowBox[{"\[Theta]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{"a", "[", "t", "]"}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[Delta]Pm", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"], " ", 
    RowBox[{"\[Rho]m", "[", "t", "]"}]}]], "-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"\[CapitalPsi]", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox["\[Theta]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
   RowBox[{"a", "[", "t", "]"}]]}]], "Output",
 CellChangeTimes->{{3.751634854677455*^9, 3.7516349089275293`*^9}, 
   3.751634944488626*^9, 3.751635005867427*^9, 
   3.7631011317109985`*^9},ExpressionUUID->"0259a1e3-44c9-4eff-8e1d-\
ee8dfae1088e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568096207008667`*^9, 
  3.756809622471049*^9}},ExpressionUUID->"9fcb005e-19fa-4519-9ffd-\
a9e261ac04c9"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Case", " ", "1", 
    RowBox[{"a", ":", " ", 
     RowBox[{
     "Effective", " ", "fluid", " ", "and", " ", "subhorizon", " ", "for", 
      " ", "KGB"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "strict", " ", "JP", " ", "version", " ", "with", " ", "our", " ", 
     "improvement"}], " ", "//", " ", 
    RowBox[{"gives", " ", "f", 
     RowBox[{"(", "R", ")"}], " ", "limit"}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568075707836485`*^9, 3.7568075757622113`*^9}, {
  3.7568096497511396`*^9, 3.7568096534003925`*^9}, {3.759648846982213*^9, 
  3.7596488495525045`*^9}, {3.7631205055312815`*^9, 3.763120542849162*^9}, {
  3.7631209768868275`*^9, 3.763120983412758*^9}, {3.7631346765629463`*^9, 
  3.763134680842601*^9}, {3.7631903863553553`*^9, 3.763190386691338*^9}, {
  3.7631904861304398`*^9, 3.7631904876473083`*^9}, {3.763462492660866*^9, 
  3.7634624941266003`*^9}},ExpressionUUID->"d321ee18-6627-4990-b2ed-\
415d58916bd6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesKGB0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rulesKGB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "X"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"X", "^", "n"}]}]}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "1"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "->", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "3"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7568081983101892`*^9, 3.756808200860401*^9}, {
   3.756808599964323*^9, 3.756808600859193*^9}, 3.757923942100193*^9, {
   3.759648878369643*^9, 3.759648878635396*^9}, {3.7607934082599554`*^9, 
   3.7607934125992403`*^9}},ExpressionUUID->"0a8e8e8a-3609-45ee-8ce9-\
392e90706df9"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dX0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ".", 
        "gUU", ".", 
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], 
      "-", "X0"}], "/.", "a2H"}], "//", "ApproxFullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"soldf", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"dX0", "\[Equal]", 
       RowBox[{"\[Delta]X", "[", "t", "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    SqrtBox[
     RowBox[{"2", "X"}]]}]}]}]}], "Input",
 CellChangeTimes->{
  3.7561141319764814`*^9, {3.7579239991243944`*^9, 
   3.7579240091742053`*^9}},ExpressionUUID->"fb0665d5-e548-40a8-9f22-\
2224518e4482"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]X", "[", "t", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.757924013239633*^9, 3.7584607175620537`*^9, {3.7595831281019588`*^9, 
   3.759583128801408*^9}, 3.759648882211532*^9, 3.7596621180996127`*^9, 
   3.7607063136389337`*^9, 3.7607064887891293`*^9, 3.760707315914773*^9, 
   3.760793455789051*^9, 3.7608602303957033`*^9, 3.760868850328183*^9, 
   3.760877403457257*^9, 3.760877524047437*^9, 3.7609545191368074`*^9, 
   3.760954565031988*^9, 3.760964283246402*^9, 3.7609651066335964`*^9, 
   3.760966651601708*^9, 3.7610284651348453`*^9, 3.7614714548842196`*^9, 
   3.7614755993269067`*^9, 3.762082048992428*^9, 3.7631009151678376`*^9, 
   3.7631009541881647`*^9, 3.763113583475541*^9, 3.763115144246414*^9, 
   3.7631205210067654`*^9, 3.7631887660704556`*^9, 
   3.763806348461116*^9},ExpressionUUID->"1ff743d9-4ae5-4903-b0e3-\
206ac5047fff"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGRA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"A2", "\[Rule]", "0"}], ",", 
     RowBox[{"A3", "\[Rule]", "2"}], ",", 
     RowBox[{"A4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{"A5", "\[Rule]", "0"}], ",", 
     RowBox[{"A6", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B1", "\[Rule]", "6"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B3", "\[Rule]", 
      RowBox[{"18", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B4", "\[Rule]", "0"}], ",", 
     RowBox[{"B5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B6", "\[Rule]", "2"}], ",", 
     RowBox[{"B7", "\[Rule]", "0"}], ",", 
     RowBox[{"B8", "\[Rule]", "2"}], ",", 
     RowBox[{"B9", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "18"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
     RowBox[{"\[Nu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C1", "\[Rule]", "2"}], ",", 
     RowBox[{"C2", "\[Rule]", "0"}], ",", 
     RowBox[{"C3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"C4", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D1", "\[Rule]", "0"}], ",", 
     RowBox[{"D2", "\[Rule]", "0"}], ",", 
     RowBox[{"D3", "\[Rule]", "0"}], ",", 
     RowBox[{"D4", "\[Rule]", "0"}], ",", 
     RowBox[{"D5", "\[Rule]", "0"}], ",", 
     RowBox[{"D7", "\[Rule]", "0"}], ",", 
     RowBox[{"D8", "\[Rule]", "0"}], ",", 
     RowBox[{"D9", "\[Rule]", "0"}], ",", 
     RowBox[{"D10", "\[Rule]", "0"}], ",", 
     RowBox[{"D11", "\[Rule]", "0"}], ",", 
     RowBox[{"M", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRABCD", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"rulesGRA", ",", "rulesGRB", ",", "rulesGRC", ",", "rulesGRD"}], 
     "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7608774109275446`*^9, 3.760877515997035*^9}, {
   3.760877601947462*^9, 3.760877723817091*^9}, 3.760878178137457*^9, {
   3.760878406236206*^9, 3.7608784114662337`*^9}, {3.760964293131819*^9, 
   3.7609643313744884`*^9}},ExpressionUUID->"59a15c7c-b673-47f0-bca7-\
e20735f997f8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eq00", "=", 
   RowBox[{
    RowBox[{"A1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A3", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A4", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", "\[Mu]"}], ")"}], 
     " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqii", "=", 
   RowBox[{
    RowBox[{"B1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B6", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", 
       RowBox[{"3", "\[Nu]"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B8", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "B9"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eq0i", "=", 
   RowBox[{
    RowBox[{"C1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C3", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C4", " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
     SuperscriptBox["k", "2"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqsc", "=", 
   RowBox[{
    RowBox[{"D1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D8"}], ")"}], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D9", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"M", "^", "2"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D10", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D11"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.760871236957633*^9, 3.760871319127609*^9}, {
   3.7608713554071703`*^9, 3.760871572037525*^9}, 3.760871605627293*^9, 
   3.7608720233417673`*^9, {3.7608770922374477`*^9, 3.76087713384791*^9}, {
   3.7608772688874445`*^9, 3.7608772691494226`*^9}, {3.760877955181913*^9, 
   3.7608781114020014`*^9}, {3.760965230731535*^9, 
   3.7609652310438423`*^9}},ExpressionUUID->"d8f5588e-79a6-4c4a-a671-\
a42b0f8dee32"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs00", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq00", "/.", "rulesGRA"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Eqsii", "/.", "rulesGR"}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{"Eqii", "/.", "rulesGRB"}], ")"}]}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs0i", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq0i", "/.", "rulesGRC"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqscal", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eqsc", "/.", "rulesGRD"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7608777345270576`*^9, 3.760877842347237*^9}, 
   3.7608780039918804`*^9, 3.760878415551169*^9, {3.760878470640115*^9, 
   3.7608785600562253`*^9}},ExpressionUUID->"cc577558-17fd-4425-b12e-\
fe4994fbac7e"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9},ExpressionUUID->"f9d54ede-0fa3-40e8-8368-\
1cf50a03e141"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527086481*^9},ExpressionUUID->"eba28cc7-9f57-4526-91e1-\
f80febcd6bfd"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527096819*^9},ExpressionUUID->"ca48ee8b-857c-4643-8865-\
68184e05449f"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.7631205271018257`*^9},ExpressionUUID->"21830853-86f9-4bc8-bd5d-\
f5f8016dddb7"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"subhorstrict", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", "0"}], ",", 
     RowBox[{"A2", "\[Rule]", "0"}], ",", 
     RowBox[{"A4", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}], ",", 
     RowBox[{"B1", "\[Rule]", "0"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B3", "\[Rule]", "0"}], ",", 
     RowBox[{"B4", "\[Rule]", "0"}], ",", 
     RowBox[{"B5", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Nu]", "\[Rule]", "0"}], ",", 
     RowBox[{"B9", "\[Rule]", "0"}], ",", 
     RowBox[{"D1", "\[Rule]", "0"}], ",", 
     RowBox[{"D2", "\[Rule]", "0"}], ",", 
     RowBox[{"D3", "\[Rule]", "0"}], ",", 
     RowBox[{"D4", "\[Rule]", "0"}], ",", 
     RowBox[{"D5", "\[Rule]", "0"}], ",", 
     RowBox[{"D8", "\[Rule]", "0"}], ",", 
     RowBox[{"D11", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"subhorflex", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A1", "\[Rule]", "0"}], ",", 
       RowBox[{"A2", "\[Rule]", "0"}], ",", 
       RowBox[{"B1", "\[Rule]", "0"}], ",", 
       RowBox[{"B2", "\[Rule]", "0"}], ",", 
       RowBox[{"B3", "\[Rule]", "0"}], ",", 
       RowBox[{"B4", "\[Rule]", "0"}], ",", 
       RowBox[{"B5", "\[Rule]", "0"}], ",", 
       RowBox[{"C1", "\[Rule]", "0"}], ",", 
       RowBox[{"C2", "\[Rule]", "0"}], ",", 
       RowBox[{"D1", "\[Rule]", "0"}], ",", 
       RowBox[{"D2", "\[Rule]", "0"}], ",", 
       RowBox[{"D3", "\[Rule]", "0"}], ",", 
       RowBox[{"D4", "\[Rule]", "0"}], ",", 
       RowBox[{"D5", "\[Rule]", "0"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.763120561226567*^9, 
  3.7631205712068496`*^9}},ExpressionUUID->"fa482608-ba27-4222-9667-\
1f980e0bad31"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "potentials"}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"subhor", "=", "subhorstrict"}], ";", 
    RowBox[{"solgen", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Eq00", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqii", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqsc", "\[Equal]", "0"}]}], "}"}], "/.", "subhor"}], "/.", 
          RowBox[{
           RowBox[{"\[Delta]Pm", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
           "0"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[CapitalPsi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[Delta]\[Phi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"solgen", "//", "TableForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7608716843173847`*^9, 3.760871870449571*^9}, {
  3.7608720053374634`*^9, 3.760872006777376*^9}, {3.760878197051565*^9, 
  3.7608782029572024`*^9}, {3.7608790453577843`*^9, 3.760879045865718*^9}, {
  3.760964405164853*^9, 3.7609645103018255`*^9}, {3.7609652605941057`*^9, 
  3.760965262471862*^9}, {3.760966739353032*^9, 3.760966739932638*^9}, {
  3.7609667897358575`*^9, 3.76096683365308*^9}, {3.7631136147260556`*^9, 
  3.7631136366483927`*^9}, {3.763115156776116*^9, 3.7631151673663273`*^9}, {
  3.7631206809169006`*^9, 
  3.76312070061677*^9}},ExpressionUUID->"9aba5923-e5a3-4039-aad5-\
ee88c3f83d89"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D10"}], "-", 
               RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
             SuperscriptBox["k", "2"]}], "+", 
            RowBox[{"B8", " ", 
             SuperscriptBox["M", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"\[Delta]\[Rho]m", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
             RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
             RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
             RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
           SuperscriptBox["k", "4"]}], "-", 
          RowBox[{"A3", " ", "B8", " ", 
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox["M", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]}]},
     {
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "2"]}], "+", 
           RowBox[{"B6", " ", 
            SuperscriptBox["M", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "4"]}], "-", 
         RowBox[{"A3", " ", "B8", " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox["M", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]},
     {
      RowBox[{
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B6", " ", "D10"}], "-", 
           RowBox[{"B8", " ", "D7"}]}], ")"}], " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "2"]}], "-", 
         RowBox[{"A3", " ", "B8", " ", 
          SuperscriptBox["M", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7608717286971655`*^9, {3.7608718611915445`*^9, 3.760871871352357*^9}, {
   3.7608720076070447`*^9, 3.7608720260271597`*^9}, {3.760878191007273*^9, 
   3.760878204447015*^9}, 3.7608789370907774`*^9, 3.7608790463277893`*^9, 
   3.76095458366181*^9, 3.76096435408368*^9, {3.760964465561962*^9, 
   3.7609645113515034`*^9}, {3.7609652497418423`*^9, 3.7609652635475073`*^9}, 
   3.7609668374928026`*^9, 3.7610285102695513`*^9, 3.7614714737442923`*^9, 
   3.7614756089571514`*^9, 3.7620820882657003`*^9, 3.7631009673786554`*^9, {
   3.7631136325212173`*^9, 3.763113637630972*^9}, 3.763115176536146*^9, 
   3.7631205783068843`*^9, 3.7631207044668016`*^9, 3.763188777265856*^9, {
   3.763806358679181*^9, 
   3.76380636413758*^9}},ExpressionUUID->"d19ccb55-26d1-4bf3-9d73-\
f4b92184cbf1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Eta]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Eta]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206084091463`*^9, 3.763120641589445*^9}, {
  3.7631207138169174`*^9, 
  3.763120728343577*^9}},ExpressionUUID->"5adbfb43-e90c-4d79-953c-\
29dd788097d0"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "B6"}], "+", "B8", "+", 
   FractionBox[
    RowBox[{"B7", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B6", " ", "D10"}], "-", 
       RowBox[{"B8", " ", "D7"}]}], ")"}], " ", 
     SuperscriptBox["k", "2"]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B7", " ", "D10"}], "-", 
        RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{"B8", " ", 
      SuperscriptBox["M", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}], "B8"]], "Output",
 CellChangeTimes->{{3.763120609582012*^9, 3.7631206420367975`*^9}, 
   3.7631887797164497`*^9},ExpressionUUID->"fb97d20e-1ac2-4a10-a478-\
5e15bd29c87c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Gamma]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Gamma]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206180173826`*^9, 3.7631206194184933`*^9}, {
  3.763120722997031*^9, 
  3.763120733766609*^9}},ExpressionUUID->"1a4c5904-b40d-4212-b233-\
4c93fe6be1db"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D10"}], "-", 
      RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B8", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{3.763120619816679*^9, 
  3.763188780778008*^9},ExpressionUUID->"63b1ceb5-b4a7-4dea-a96c-\
20de677b66ea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", 
    RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff"}], " ", "*)"}],
   " ", "\[IndentingNewLine]", 
  RowBox[{"Geff", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"k", "^", "2"}], 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]], 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], " ", "G", " ", "\[Pi]", " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], "/.", 
     RowBox[{"solgen", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763120736546857*^9, 
  3.7631207498276453`*^9}},ExpressionUUID->"bde86704-ed30-47cf-8215-\
4bf576204b8d"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B7", " ", "D7"}], "-", 
        RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{"B6", " ", 
      SuperscriptBox["M", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "A6"}], " ", "B6", " ", "D10"}], "+", 
      RowBox[{"A3", " ", "B7", " ", "D10"}], "+", 
      RowBox[{"A6", " ", "B8", " ", "D7"}], "-", 
      RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"A3", " ", "B8", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{3.7631206655067053`*^9, 3.7631207506888466`*^9, 
  3.7631887827794876`*^9},ExpressionUUID->"edb6f536-b16a-4f40-8d3c-\
ccc6a2aabfd9"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Ruben", "'"}], "s", " ", "effective", " ", 
    RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff", " ", "from", 
    " ", "the", " ", "paper"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7631207729569917`*^9, 
  3.7631207857019873`*^9}},ExpressionUUID->"4d31055b-78b4-4f4d-8f3d-\
cd7706b559f0"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GeffRub", "=", 
   FractionBox[
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B6", " ", "D9"}], "-", 
          RowBox[{"B7", "^", "2"}]}], ")"}], 
        FractionBox[
         SuperscriptBox["k", "2"], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"B6", " ", 
        SuperscriptBox["M", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A6", "^", "2"}], " ", "B6"}], "+", 
        RowBox[{
         RowBox[{"B6", "^", "2"}], "D9"}], "-", 
        RowBox[{"2", "A6", " ", "B7", " ", "B6"}]}], ")"}], 
      FractionBox[
       SuperscriptBox["k", "2"], 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
     RowBox[{
      RowBox[{"B6", "^", "2"}], " ", 
      RowBox[{"M", "^", "2"}]}]}]]}], ";"}]], "Input",ExpressionUUID->\
"588d976a-f329-4051-89b1-8f0209893500"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "f", 
    RowBox[{"(", "R", ")"}], " ", "limit"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fRlimit", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "2"}], 
         RowBox[{"\[Phi]", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], 
       ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "Rr"}], "2"]}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "1"}], 
         RowBox[{"2", " ", "fRR"}]]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fRextra", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["M", "2"], "\[Rule]", 
        FractionBox["1", 
         RowBox[{"2", " ", "fRR"}]]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fR", "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fRR", "\[Rule]", 
        RowBox[{"m", " ", "F"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"F", "'"}], "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "->", 
        RowBox[{
         RowBox[{"F", "''"}], "[", "t", "]"}]}]}], "}"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.763120798989036*^9, 3.7631208072669797`*^9}, {
  3.7631211354571056`*^9, 
  3.7631211447892885`*^9}},ExpressionUUID->"fecf1826-7bbb-4fde-a549-\
394f7f44670f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Eliminate", " ", "\[Delta]\[Phi]", " ", "and", " ", 
    RowBox[{"it", "'"}], "s", " ", "derivatives", " ", "to", " ", "improve", 
    " ", "accuracy"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"soldfn", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"Eqsij", "\[Equal]", "0"}], ",", 
             RowBox[{"\[Delta]\[Phi]", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
           "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", "2"}], "}"}]}], "]"}], "/.", "rules"}], 
     "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.763120836316975*^9, 
  3.7631208630569916`*^9}},ExpressionUUID->"34a1aab4-4b10-4126-b9d3-\
d90ac3d19d04"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "quantities"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"soldPDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Eqii", "-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
                   RowBox[{"\[Delta]PDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+",
                   "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", 
              "0"}], ",", 
             RowBox[{"\[Delta]PDE", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
           "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/.", "soldfn"}], "/.", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f_", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
          "0"}]}], "/.", "horizon1"}], "/.", "solgen"}], "//", 
      "FullSimplify"}]}], ";", 
    RowBox[{"soldDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Eq00", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
                  RowBox[{"\[Delta]\[Rho]DE", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
                 "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{"\[Delta]\[Rho]DE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", "soldfn"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"solVDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Eq0i", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox[
                  RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
                   RowBox[{"a", "[", "t", "]"}], 
                   RowBox[{"VDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
                   RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
                  SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", 
                "rulesGRC"}], ")"}]}], "\[Equal]", "0"}], ",", 
            RowBox[{"VDE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", "soldfn"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.76312089191674*^9, 
  3.763120918757121*^9}},ExpressionUUID->"ce31f429-87f9-4fde-be38-\
bf20a4f68602"],

Cell[CellGroupData[{

Cell[BoxData[{"soldPDE", "\[IndentingNewLine]", "soldDE", \
"\[IndentingNewLine]", "solVDE"}], "Input",
 CellChangeTimes->{{3.7638063906022067`*^9, 
  3.763806397502124*^9}},ExpressionUUID->"b79edb46-4a2e-43d2-9974-\
3922c307faf3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D10"}], "-", 
              RowBox[{"B7", " ", "D7"}], "+", 
              RowBox[{"B6", " ", "D9"}], "-", 
              RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
            SuperscriptBox["M", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
         RowBox[{"G4", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", 
               SuperscriptBox["k", "2"]}], "+", 
              RowBox[{"3", " ", "\[Nu]", " ", 
               SuperscriptBox[
                RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"2", " ", "B2", " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "2"], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B4", " ", 
               RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}], "+", 
              RowBox[{"B2", " ", 
               RowBox[{
                SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
          ")"}]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B2", " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "B7"}], " ", "D10"}], "+", 
                 RowBox[{"B7", " ", "D7"}], "-", 
                 RowBox[{"B6", " ", "D9"}], "+", 
                 RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
               SuperscriptBox["k", "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"B6", "-", "B8"}], ")"}], " ", 
               SuperscriptBox["M", "2"], " ", 
               SuperscriptBox[
                RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"-", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "2"}], "+", "B6"}], ")"}]}], " ", "B7", " ", 
                  "D10"}], "+", 
                 RowBox[{"B7", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "2"}], "+", "B8"}], ")"}], " ", "D7"}], "+", 
                 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{"B6", "-", "B8"}], ")"}], " ", "D9"}]}], ")"}], 
               " ", 
               SuperscriptBox["k", "4"]}], "+", 
              RowBox[{
               SuperscriptBox["M", "2"], " ", 
               SuperscriptBox[
                RowBox[{"a", "[", "t", "]"}], "4"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"B6", " ", "B9"}], "-", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"B6", "-", "B8"}], ")"}], " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"B4", " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"B2", " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
                ")"}]}], "+", 
              RowBox[{
               SuperscriptBox["k", "2"], " ", 
               SuperscriptBox[
                RowBox[{"a", "[", "t", "]"}], "2"], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"B7", " ", "B9", " ", "D7"}], "-", 
                 RowBox[{"B6", " ", "B9", " ", "D9"}], "+", 
                 RowBox[{"2", " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
                  SuperscriptBox["M", "2"]}], "+", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"B7", " ", 
                    RowBox[{"(", 
                    RowBox[{"D10", "-", "D7"}], ")"}]}], "+", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"B6", "-", "B8"}], ")"}], " ", "D9"}]}], ")"}], 
                  " ", 
                  RowBox[{"(", 
                   RowBox[{
                    RowBox[{"B4", " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"B2", " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
                ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"3", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
           RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
           RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
           RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "2"]}], "-", 
        RowBox[{"A3", " ", "B8", " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "3"]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.763806398157359*^9},ExpressionUUID->"f19f9b9f-512f-4870-82e6-\
30d99c218a3c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"\[Delta]\[Rho]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D10"}], "-", 
                RowBox[{"B7", " ", "D7"}], "+", 
                RowBox[{"B6", " ", "D9"}], "-", 
                RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
              SuperscriptBox["k", "2"]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
              SuperscriptBox["M", "2"], " ", 
              SuperscriptBox[
               RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{"G4", "[", "t", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"A6", " ", 
                 SuperscriptBox["k", "2"]}], "-", 
                RowBox[{"\[Mu]", " ", 
                 SuperscriptBox[
                  RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
              RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
             RowBox[{"A2", " ", 
              SuperscriptBox[
               RowBox[{"a", "[", "t", "]"}], "2"], " ", 
              RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
              RowBox[{
               SuperscriptBox["\[Phi]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "A3"}], ")"}]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D10"}], "-", 
                RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
              SuperscriptBox["k", "4"]}], "+", 
             RowBox[{
              SuperscriptBox["M", "2"], " ", 
              SuperscriptBox[
               RowBox[{"a", "[", "t", "]"}], "4"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B6", " ", 
                 RowBox[{"(", 
                  RowBox[{"A4", "+", 
                   RowBox[{"6", " ", 
                    SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}], "+", 
                RowBox[{"A2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
                 RowBox[{
                  SuperscriptBox["\[Phi]", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
             "+", 
             RowBox[{
              SuperscriptBox["k", "2"], " ", 
              SuperscriptBox[
               RowBox[{"a", "[", "t", "]"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"A4", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"B7", " ", "D7"}], "-", 
                   RowBox[{"B6", " ", "D9"}]}], ")"}]}], "-", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "B8", " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{"6", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"B7", " ", "D7"}], "-", 
                   RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
                 SuperscriptBox[
                  RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
                RowBox[{"A2", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"B7", " ", "D10"}], "-", 
                   RowBox[{"B7", " ", "D7"}], "+", 
                   RowBox[{"B6", " ", "D9"}], "-", 
                   RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
                 RowBox[{
                  SuperscriptBox["\[Phi]", "\[Prime]",
                   MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
             RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
             RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
             RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
           SuperscriptBox["k", "2"]}], "-", 
          RowBox[{"A3", " ", "B8", " ", 
           SuperscriptBox["M", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.763806398204254*^9},ExpressionUUID->"e09dbf10-dd85-40f3-806b-\
332bcde5a902"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox[
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"B7", " ", "D7"}], "-", 
                 RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
               SuperscriptBox["k", "2"]}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"], " ", 
               SuperscriptBox[
                RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{"C3", "+", 
              RowBox[{"2", " ", 
               RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
           RowBox[{"C2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"B7", " ", "D10"}], "-", 
                 RowBox[{"B7", " ", "D7"}], "+", 
                 RowBox[{"B6", " ", "D9"}], "-", 
                 RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
               SuperscriptBox["k", "2"]}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
               SuperscriptBox["M", "2"], " ", 
               SuperscriptBox[
                RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D10"}], "-", 
              RowBox[{"B7", " ", "D7"}], "+", 
              RowBox[{"B6", " ", "D9"}], "-", 
              RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
            SuperscriptBox["M", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
         RowBox[{"G4", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C4", " ", 
            RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
           RowBox[{"C2", " ", 
            RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
       ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
           RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
           RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
           RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "2"]}], "-", 
        RowBox[{"A3", " ", "B8", " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Rho]DE", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7638063982420244`*^9},ExpressionUUID->"4a7c6962-8faf-494f-9aec-\
d54232a018a2"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"The", " ", "KGB", " ", "limit"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631209397866125`*^9, 3.7631209459418736`*^9}, {
  3.763121010101895*^9, 
  3.7631210112500215`*^9}},ExpressionUUID->"3597df15-eff2-4ed4-aa43-\
908191e11351"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"solgen", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "/.", "subhor"}], "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7609546600619273`*^9, 3.760954664466791*^9}, {
   3.760966857372764*^9, 3.760966857623056*^9}, 
   3.763115173256571*^9},ExpressionUUID->"a52a72e8-2345-4318-a838-\
50c617e16530"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Delta]\[Phi]", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{"A6", "-", "B7"}], ")"}], " ", "G", " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"], " ", 
    RowBox[{"\[Delta]\[Rho]m", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["A6", "2"], "-", 
       RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
       RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "2"]}], "-", 
    RowBox[{"B6", " ", 
     SuperscriptBox["M", "2"], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]], "Output",
 CellChangeTimes->{{3.7609644972316685`*^9, 3.76096452140153*^9}, 
   3.760965267881686*^9, 3.760966858712723*^9, 3.761028528340328*^9, 
   3.7614714740090947`*^9, 3.7631009778543415`*^9, 3.7631136442211275`*^9, 
   3.7631151783760886`*^9, 
   3.763121017667138*^9},ExpressionUUID->"65179dca-abf8-48dd-be85-\
b9482c89b4b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608721634777718`*^9, 3.760872183439308*^9}, 
   3.7608722185270576`*^9, {3.760872271117173*^9, 3.7608722728772163`*^9}, {
   3.7608725066403027`*^9, 3.7608725068252964`*^9}, {3.7608782109070044`*^9, 
   3.7608782132468443`*^9}, {3.760954695182067*^9, 3.76095471970185*^9}, 
   3.760954754834016*^9, {3.7609668631930323`*^9, 3.7609668717226267`*^9}, 
   3.763115174916142*^9, {3.763121025736691*^9, 
   3.7631210366271324`*^9}},ExpressionUUID->"71fa9df2-df24-457f-8f6e-\
efa40bc2756c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"A6", "-", "B7"}], ")"}], " ", "B7", " ", 
   SuperscriptBox["k", "2"]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{
  3.7608782163370647`*^9, 3.760878939305962*^9, {3.7609546827516994`*^9, 
   3.760954720461788*^9}, 3.760954755682119*^9, 3.760964524526888*^9, 
   3.7609652695817666`*^9, {3.7609668643429146`*^9, 3.760966873672986*^9}, 
   3.7610285303769536`*^9, 3.7631009799055977`*^9, 3.763113646616123*^9, 
   3.7631151797660885`*^9, {3.7631210199111567`*^9, 
   3.7631210374269714`*^9}},ExpressionUUID->"1d1584d0-67c5-4999-a7b2-\
3a131219a69a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.760872517388804*^9, 3.7608725507370615`*^9}, {
   3.7608782231496954`*^9, 3.7608782248921795`*^9}, {3.7609547620619287`*^9, 
   3.7609547725885253`*^9}, 3.760966876112828*^9, 3.76311518170636*^9, 
   3.763121039861877*^9},ExpressionUUID->"824c1965-b819-4529-9e50-\
524bb6a2027b"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["B7", "2"], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{{3.760872520881508*^9, 3.760872551269845*^9}, 
   3.760878225431428*^9, {3.760954741811887*^9, 3.760954772871746*^9}, 
   3.760964526241928*^9, 3.76096527069625*^9, 3.760966876882693*^9, 
   3.7610285314106803`*^9, 3.763100981323767*^9, 3.7631136477479143`*^9, 
   3.7631151824566355`*^9, 
   3.7631210407768707`*^9},ExpressionUUID->"ae9dbcc5-f203-4855-bd49-\
677cbe93a20b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Geff", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608720490497875`*^9, 3.7608720761673555`*^9}, 
   3.7608782283273168`*^9, 3.7609547823420057`*^9, {3.7609668940274115`*^9, 
   3.760966914512579*^9}, {3.7631136608859067`*^9, 3.763113661376213*^9}, 
   3.7631210448890667`*^9},ExpressionUUID->"a8ed7200-ff66-4301-96fd-\
d1b5092e622d"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["B7", "2"], "-", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}], 
   RowBox[{"B6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["A6", "2"], "-", 
         RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "2"]}], "-", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.7608720496015744`*^9, 3.760872081867358*^9}, 
   3.7608782296972866`*^9, {3.7609547767217216`*^9, 3.7609547830420494`*^9}, 
   3.760964530741832*^9, 3.7609652723740387`*^9, {3.760966906382824*^9, 
   3.760966916062399*^9}, 3.761028535682231*^9, 3.761471479878995*^9, 
   3.7620820962753325`*^9, 3.763100984211653*^9, {3.7631136524657965`*^9, 
   3.76311366215584*^9}, 3.763115187816374*^9, 
   3.763121046146944*^9},ExpressionUUID->"68481cc0-1225-4ea2-8d43-\
28961e092bea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"solVDE", "/.", 
           RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
        RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
       RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
    RowBox[{"M", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7614715093614264`*^9, 3.761471529839512*^9}, 
   3.761471622774027*^9, 
   3.7631210561473184`*^9},ExpressionUUID->"fe77d9ab-e42a-4b0f-b8d3-\
8ad954a5c16d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"D9", " ", 
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"C3", "+", 
        RowBox[{"2", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["A6", "2"], "+", 
        RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
      RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614715103143363`*^9, 3.761471530249116*^9}, 
   3.7614716234468727`*^9, 3.761475623436673*^9, 3.762082247279933*^9, 
   3.7631137789961405`*^9, 3.763115417160034*^9, 3.7631210570470114`*^9, 
   3.7631888644762216`*^9},ExpressionUUID->"79783f72-2567-46ef-8373-\
e064c7df2fee"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"solVDE", "/.", 
          RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
        RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
       RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.760967170912757*^9, 3.7609671756729927`*^9}, {
   3.7609672170710683`*^9, 3.760967268572739*^9}, {3.7609673456627393`*^9, 
   3.760967355482613*^9}, 
   3.763121079797018*^9},ExpressionUUID->"4ef50966-613d-48a2-ad6b-\
8f4576a33b8b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "D9"}], " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox["M", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"C3", "+", 
       RowBox[{"2", " ", 
        RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["A6", "2"], "+", 
          RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
        SuperscriptBox["k", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7609672099178877`*^9, 3.760967270222868*^9}, {
   3.7609673521427126`*^9, 3.7609673562526836`*^9}, 3.76102860194715*^9, 
   3.7614756243818407`*^9, 3.763113782415992*^9, 3.7631154205899687`*^9, 
   3.7631210871609144`*^9, 
   3.763188865936119*^9},ExpressionUUID->"e50f0abb-8a75-49fb-a3ad-\
620f388ca136"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"soldPDE", "/.", 
            RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
           RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
        RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
     RowBox[{"B6", "\[Rule]", "2"}]}], "/.", 
    RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"M", "\[Rule]", "0"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", "subhor"}]}], "Input",
 CellChangeTimes->{{3.760967419262813*^9, 3.7609674497562037`*^9}, {
  3.760967526613056*^9, 3.7609675736426086`*^9}, {3.7609676630048027`*^9, 
  3.7609676646630898`*^9}, {3.7609677596250677`*^9, 3.7609677612924557`*^9}, {
  3.763121100677089*^9, 
  3.763121112486868*^9}},ExpressionUUID->"b2ce507d-0029-4272-9a49-\
abb7e7e3fa25"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B9", " ", "D9", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["A6", "2"], "+", 
        RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
      SuperscriptBox["k", "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 
   3.7631888673707104`*^9},ExpressionUUID->"821de013-5677-457a-801c-\
590e2bd90a6f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 
   3.7631888673807936`*^9},ExpressionUUID->"d9ed9a9c-b426-489d-a3f4-\
129c90f33cb8"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.763115082136239*^9, 
  3.7631151022566075`*^9}},ExpressionUUID->"1abd80d6-4bca-4d11-9aa3-\
6e8d8279b5d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Coefficients", " ", "//", " ", 
   RowBox[{"run", " ", "this"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.76311405695595*^9, 3.7631140621959715`*^9}, {
  3.763114114611548*^9, 
  3.7631141167663727`*^9}},ExpressionUUID->"1c542e02-0b9d-4a4b-ae08-\
4aebc7493bc1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", 
     "\[Mu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}]}], ",", "0", ",", 
     
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", "B7", 
     ",", "B8", ",", "B9", ",", "\[Nu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"36", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "36"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"C1", ",", "C2", ",", "C3", ",", "C4"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", "D7", ",", "D8", 
     ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"5", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7610287424727*^9, 3.761028748984979*^9}, {
  3.7631140663258605`*^9, 
  3.763114090298678*^9}},ExpressionUUID->"211ff481-f835-4412-a9a6-\
b517851c99d4"],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631140943260336`*^9, 
  3.763114096275912*^9}},ExpressionUUID->"97540c34-6949-46fb-bceb-\
6b18bbdcff20"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Geff", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7631211585671844`*^9, 
  3.7631211623070984`*^9}},ExpressionUUID->"63af097e-ac04-4c1e-a636-\
eb7446313c61"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m"}], "+", 
   RowBox[{"F", "[", "t", "]"}]}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m", " ", 
    RowBox[{"F", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{"F", "[", "t", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{
  3.7631211630169344`*^9},ExpressionUUID->"7cc5ac73-c1b7-4351-9043-\
42eee343fb55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GeffRub", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.763101809150457*^9, 3.7631018648961973`*^9}, {
   3.763101905329755*^9, 3.763101962609453*^9}, {3.7631020677421107`*^9, 
   3.763102068004221*^9}, 3.763113690547677*^9, 3.763113734057954*^9, 
   3.7631143547364793`*^9, {3.7631154529200172`*^9, 
   3.763115454515036*^9}},ExpressionUUID->"8ca5a54a-9b0a-41c4-a0f0-\
9aa6160e1071"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m"}], "+", 
   RowBox[{"F", "[", "t", "]"}]}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m", " ", 
    RowBox[{"F", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{"F", "[", "t", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.7631018109898095`*^9, 3.7631018662119465`*^9}, 
   3.763101919909732*^9, {3.7631019566797557`*^9, 3.7631019631693273`*^9}, 
   3.7631020722108507`*^9, 3.763102140246998*^9, 3.763113735270893*^9, 
   3.7631141615961914`*^9, {3.7631143508882236`*^9, 3.7631143783025227`*^9}, 
   3.7631151078864684`*^9, {3.7631154501800623`*^9, 3.7631154551422105`*^9}, 
   3.7631164377034683`*^9, 
   3.763121152956889*^9},ExpressionUUID->"9a5b63bd-069c-423a-9637-\
1c89f579482e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "expressions"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"They", " ", "agree", " ", "with", " ", "our", " ", "f", 
    RowBox[{"(", "R", ")"}], " ", "effective", " ", "paper"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldPDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"solVDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763114134611041*^9, 3.7631142372359266`*^9}, 
   3.763114314426009*^9, {3.7631143821659684`*^9, 3.7631143908180556`*^9}, {
   3.763115503160205*^9, 3.763115504292551*^9}, {3.7631164227035484`*^9, 
   3.763116429662382*^9}, {3.763116539281295*^9, 3.7631165461681833`*^9}, {
   3.7631211692867537`*^9, 
   3.763121212807345*^9}},ExpressionUUID->"7cd30665-483b-4bc7-b055-\
f8f5cca0197f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "FR", " ", 
        SuperscriptBox["k", "4"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"F", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 
   3.763121216856928*^9}},ExpressionUUID->"223dc905-1cd6-465e-a7e5-\
989d6041c246"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"F", "[", "t", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{
     RowBox[{"F", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 
   3.763121216877079*^9}},ExpressionUUID->"50f327d1-28c1-4c93-b8e3-\
f2a92afe7b0a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["F", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"F", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 
   3.7631212168967094`*^9}},ExpressionUUID->"5f31641f-aea6-4876-a169-\
339e30a6162d"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",ExpressionUUID->"106c6e54-700b-46f4-9ccf-34e19dfcedce"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Sound", " ", "speed", " ", "in", " ", "rest", " ", 
   RowBox[{"frame", "?"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7614725513993692`*^9, 
  3.761472564159005*^9}},ExpressionUUID->"86776efa-5583-4171-8704-\
5d2568aa556f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Eq0i", "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
            RowBox[{"a", "[", "t", "]"}], 
            RowBox[{"VDE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
            RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
           SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", "rulesGRC"}], 
        ")"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"VDE", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "/.", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f_", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.7631158554198527`*^9, 3.7631158618197684`*^9}, 
   3.7631159267299547`*^9},ExpressionUUID->"c8987e81-cb9d-4cf6-ba16-\
d1a3a75b72dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C4", " ", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"C3", " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.76147188603936*^9, 3.7631138043759212`*^9, 3.763115541862115*^9, 
   3.7631155897951345`*^9, {3.763115859190098*^9, 3.7631158626502314`*^9}, 
   3.7631159277401032`*^9, 
   3.7631212287267866`*^9},ExpressionUUID->"30c79800-d9c9-4532-b6cf-\
e7bf6927ad2f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"C4", " ", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"C3", " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7614718970391417`*^9, 3.761471924311453*^9}, {
  3.7614720011495757`*^9, 
  3.7614720080296535`*^9}},ExpressionUUID->"de8bcfc2-893c-45aa-a6d4-\
0d19c1f473d0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C3", "+", 
        RowBox[{"2", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "C4"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761471915188919*^9, 3.761471924789179*^9}, 
   3.7614720087042613`*^9, 3.7631138067557783`*^9, 3.763115549539934*^9, 
   3.7631155921021914`*^9, 3.763115870524472*^9, 3.763115933960049*^9, 
   3.7631212305267663`*^9},ExpressionUUID->"eeaded28-97f6-494e-ab2c-\
96de1a8aa318"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Eqsij", "\[Equal]", "0"}], ",", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", "solres1"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.761471953831363*^9, 
  3.761472050359288*^9}},ExpressionUUID->"969f5107-0f82-47a2-b969-\
751c92a0c880"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C4"}], " ", 
        RowBox[{"G4", "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{"C4", " ", 
     RowBox[{"G4", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.761471970979189*^9, 3.761472050833968*^9}, 
   3.7631138094659233`*^9, 3.7631155517814865`*^9, 3.763115593649844*^9, 
   3.763115872872836*^9, 3.763115935665164*^9, 
   3.763121238506923*^9},ExpressionUUID->"99a7d096-d4ee-40c8-b9c9-\
464696ca9421"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eq00", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]\[Rho]DE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], ",", 
         RowBox[{"\[Delta]\[Rho]DE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.761471944799088*^9, {3.7614720568094683`*^9, 3.7614720965613728`*^9}, {
   3.7631158760098076`*^9, 3.763115877810362*^9}, 
   3.7631159378905425`*^9},ExpressionUUID->"f21192aa-20e3-47bd-961d-\
79b2bdc7ed52"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"8", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"G4", "[", "t", "]"}]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", 
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"C3", "+", 
           RowBox[{"2", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["k", "2"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"A6", " ", "C3"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "C4"}], "+", 
              RowBox[{"2", " ", "A6", " ", 
               RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"A4", " ", "C4"}], "+", 
              RowBox[{"C3", " ", "\[Mu]"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Mu]", "+", 
                 RowBox[{"3", " ", "C4", " ", 
                  RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7614719460993567`*^9, 3.7614720657493687`*^9, 
  3.7614720971790533`*^9, 3.76311381721595*^9, 3.7631155563017883`*^9, 
  3.763115596749812*^9, 3.763115879100114*^9, 3.7631159390147943`*^9, 
  3.763121241389372*^9},ExpressionUUID->"e1ff2c4b-e32f-4844-8c2a-\
ae226b2e4110"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eqii", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]PDE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", "0"}], 
         ",", 
         RowBox[{"\[Delta]PDE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.76147208348938*^9, 3.7614721029591475`*^9}, {
   3.7631158900225515`*^9, 3.7631158918101482`*^9}, 
   3.763115941560336*^9},ExpressionUUID->"be8f026a-90ee-4c54-9f71-\
5000c1b45522"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"24", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"G4", "[", "t", "]"}]}]], 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "B6"}], ")"}], " ", 
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["k", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B7", " ", "C3"}], "+", 
             RowBox[{"B6", " ", "C4"}], "-", 
             RowBox[{"B8", " ", "C4"}], "+", 
             RowBox[{"2", " ", "B7", " ", 
              RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B9", " ", "C4"}], "-", 
             RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
             RowBox[{"6", " ", 
              RowBox[{"H", "[", "t", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[Nu]", "-", 
                RowBox[{"3", " ", "C4", " ", 
                 RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
             RowBox[{"12", " ", "C4", " ", 
              RowBox[{
               SuperscriptBox["H", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761472078879323*^9, 3.7614721041992617`*^9}, 
   3.7631138199222736`*^9, 3.7631155701724977`*^9, 3.7631156120123816`*^9, 
   3.7631158934720345`*^9, 3.763115942599981*^9, 
   3.763121255126955*^9},ExpressionUUID->"8f202013-99a6-4b50-bda8-\
fe7f00bf60d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"In", " ", "the", " ", "rest"}], "-", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{"\[Delta]PDE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
              RowBox[{"\[Delta]\[Rho]DE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", 
             "solres4"}], "/.", "solres3"}], "/.", 
           RowBox[{"B6", "\[Rule]", 
            RowBox[{"4", " ", 
             RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"B8", "\[Rule]", 
           RowBox[{"4", " ", 
            RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"A3", "\[Rule]", 
          RowBox[{"4", 
           RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
         RowBox[{"1", "/", "2"}]}]}], "/.", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f_", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}]}],
     "//", "FullSimplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"cs2", "->", "%"}], "/.", 
            RowBox[{"C3", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "3"}], " ", 
               RowBox[{"G3X", "[", "t", "]"}]}], "-", 
              RowBox[{"4", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"G4", "[", "t", "]"}]}]}]}]}], "/.", 
           RowBox[{"A6", "\[Rule]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "2"}]}], " ", 
             RowBox[{"G3X", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"C4", "->", 
           RowBox[{
            RowBox[{
             RowBox[{"KX", "[", "t", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"G3X", "[", "t", "]"}], " ", 
             RowBox[{"H", "[", "t", "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Phi]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
         RowBox[{"B9", "->", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "18"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
           RowBox[{"12", " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "-", 
           RowBox[{"3", " ", 
            RowBox[{"KX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"12", " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"G3XX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
        RowBox[{"\[Nu]", "->", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
       RowBox[{"A4", "->", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"12", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "5"]}]}]}]}], "/.", 
      RowBox[{"\[Mu]", "->", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614721200917377`*^9, 3.7614721486394243`*^9}, {
   3.7614721804992604`*^9, 3.7614721918691998`*^9}, {3.7614722326390114`*^9, 
   3.7614722779989214`*^9}, {3.761472312289319*^9, 3.7614723190388966`*^9}, {
   3.7614723515292892`*^9, 3.761472368269771*^9}, {3.7614724032092724`*^9, 
   3.7614724857990074`*^9}, {3.7614727130217075`*^9, 
   3.7614727147291737`*^9}, {3.7614727687391253`*^9, 
   3.7614727795990305`*^9}, {3.7614728256989756`*^9, 3.761472830231369*^9}, {
   3.7614728609892225`*^9, 3.7614728632111177`*^9}, {3.761472893969224*^9, 
   3.761473009929489*^9}, {3.761473708378744*^9, 3.7614737373417807`*^9}, {
   3.7631158210000095`*^9, 3.7631158360302916`*^9}, 3.763115945350172*^9, {
   3.763121298017347*^9, 
   3.7631213054969654`*^9}},ExpressionUUID->"dff278fa-d72c-4a00-af7f-\
63aa4a278cf4"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"B9", " ", "C4"}], "-", 
     RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
     RowBox[{"6", " ", 
      RowBox[{"H", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Nu]", "-", 
        RowBox[{"3", " ", "C4", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "C4", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"3", " ", "A6", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"C3", "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A4", " ", "C4"}], "+", 
      RowBox[{"C3", " ", "\[Mu]"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", 
         RowBox[{"3", " ", "C4", " ", 
          RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 
   3.7631213071168237`*^9}},ExpressionUUID->"41e5579d-7086-412a-84e8-\
04d5d0ea1d56"],

Cell[BoxData[
 RowBox[{"cs2", "\[Rule]", "1"}]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 
   3.763121307127221*^9}},ExpressionUUID->"bea580ef-42de-42dd-8b92-\
ee5735f843db"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"In", " ", "a", " ", "general", " ", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"cs2gen", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Delta]PDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                    RowBox[{"\[Delta]\[Rho]DE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.",
                     "soldDE"}], "/.", "soldPDE"}], "/.", 
                    RowBox[{"B6", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B8", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"A3", "\[Rule]", 
                    RowBox[{"4", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B7", "\[Rule]", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["f_", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                    "\[Rule]", "0"}]}], "/.", 
                    RowBox[{"C3", "\[Rule]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}]}], "/.", 
                    RowBox[{"A6", "\[Rule]", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                   RowBox[{"C4", "->", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                  RowBox[{"B9", "->", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "36"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
                 RowBox[{"\[Nu]", "->", 
                  RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
                RowBox[{"A4", "->", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", 
                   SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KXX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}]}]}]}], "/.", 
               RowBox[{"\[Mu]", "->", 
                RowBox[{"-", 
                 RowBox[{"K\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
              RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
             RowBox[{"D7", "\[Rule]", "0"}]}], "/.", 
            RowBox[{"M", "\[Rule]", 
             SqrtBox["M2"]}]}], "/.", 
           RowBox[{"M2", "\[Rule]", 
            RowBox[{"-", 
             RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"D9", "\[Rule]", 
           RowBox[{"-", 
            RowBox[{"KX", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"D11", "\[Rule]", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"KXXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
         RowBox[{
          RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
        "}"}]}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614756379174366`*^9, 3.76147568953691*^9}, {
   3.7614757263370914`*^9, 3.761475958304971*^9}, {3.761476048957116*^9, 
   3.7614760632469234`*^9}, {3.7614763452470846`*^9, 3.76147636870883*^9}, {
   3.7614764569268293`*^9, 3.761476458271467*^9}, {3.76147656326256*^9, 
   3.761476564859185*^9}, {3.7614766282267957`*^9, 3.761476692631748*^9}, {
   3.7614767336265616`*^9, 3.7614767480766664`*^9}, {3.761476783486722*^9, 
   3.7614768313469687`*^9}, {3.7614771328169327`*^9, 3.761477133236987*^9}, 
   3.761477402776991*^9, 3.763115827884598*^9, 3.763115912365671*^9, 
   3.7631159501848774`*^9, {3.763116027695698*^9, 3.763116052252181*^9}, {
   3.763121309557479*^9, 
   3.7631213164173107`*^9}},ExpressionUUID->"32e7236f-1d94-4fce-98c8-\
44331bf2727e"],

Cell[BoxData[
 RowBox[{"1", "-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"K", "[", "t", "]"}]}], 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.7614756472519145`*^9, 3.7614756926065903`*^9}, {
   3.761475740091787*^9, 3.7614758147669015`*^9}, 3.7614758539493217`*^9, {
   3.761475937031951*^9, 3.761475959253948*^9}, 3.761476065157156*^9, {
   3.7614763470866065`*^9, 3.761476353997134*^9}, {3.7614764480070596`*^9, 
   3.7614764599522624`*^9}, 3.761476565546674*^9, {3.76147664327186*^9, 
   3.761476670421854*^9}, {3.76147680656666*^9, 3.7614768317975225`*^9}, 
   3.7614771353316383`*^9, 3.7614774065766478`*^9, 3.763113840095704*^9, 
   3.763115624425024*^9, 3.7631158300199695`*^9, 3.763115913200203*^9, 
   3.7631159516602564`*^9, {3.7631160308620434`*^9, 3.7631160400904016`*^9}, 
   3.763121284941904*^9, 
   3.7631213192667665`*^9},ExpressionUUID->"a3aae09a-baa8-43b2-b8e2-\
5112b67f74b2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"V", "[", "\[Phi]_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"m", "^", "2"}], " ", 
   RowBox[{"\[Phi]", "^", "2"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cs2gen", "/.", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"X0", "+", 
       RowBox[{"V", "[", 
        RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}]}], "/.", 
    RowBox[{
     RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"V", "'"}], "[", 
      RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "/.", 
   RowBox[{
    RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"V", "''"}], "[", 
     RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", "m\[Phi]", " ", "\[Phi]"}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Infinity]", ",", "4"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614774489467955`*^9, 3.7614779250165815`*^9}, {
  3.761477977411518*^9, 3.7614779948497677`*^9}, {3.7631139412058153`*^9, 
  3.763113942055827*^9}, {3.7631213526017084`*^9, 
  3.763121388307263*^9}},ExpressionUUID->"f1f9f936-62c1-4117-93ad-\
55903c7628de"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["m", "2"], " ", 
    SuperscriptBox[
     RowBox[{"\[Phi]", "[", "t", "]"}], "2"]}], 
   SuperscriptBox[
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "2"]]}]], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 
   3.763121388956871*^9}},ExpressionUUID->"6838de36-edc8-4b29-b5cc-\
eee96c3ff9a6"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["m", "2"], " ", 
    SuperscriptBox[
     RowBox[{"\[Phi]", "[", "t", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["m\[Phi]", "2"], " ", 
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    SuperscriptBox["\[Phi]", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 
   3.7631213889726915`*^9}},ExpressionUUID->"d4a62007-2393-4192-b5d2-\
ea734403d4a4"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["m", "2"], " ", 
    SuperscriptBox[
     RowBox[{"\[Phi]", "[", "t", "]"}], "2"]}], 
   RowBox[{
    SuperscriptBox["m\[Phi]", "2"], " ", 
    SuperscriptBox["\[Epsilon]", "2"], " ", 
    SuperscriptBox["\[Phi]", "2"]}]]}]], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 
   3.76312138897676*^9}},ExpressionUUID->"d7029043-d9e9-4710-99b2-\
d10390a32905"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"eq11", "/.", "zeroorder"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"1", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}],
    "/.", 
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
  RowBox[{
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
   "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"H", "'"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614770642968874`*^9, 
  3.761477126561428*^9}},ExpressionUUID->"6be7b7a4-f9db-4297-980a-\
fe706a9170ca"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "2"], "+", 
  FractionBox[
   RowBox[{"K", "[", "t", "]"}], "2"], "+", 
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 
   3.7631213941771016`*^9},ExpressionUUID->"96cd8cee-b69e-4294-bde1-\
0461c3c1c7f2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 
   3.763121394197058*^9},ExpressionUUID->"febf90a1-dd6f-4efd-99d7-\
541627d944ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"scaleq", "/.", "zeroorder"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614759946317997`*^9, 3.761476039417528*^9}, {
  3.7614773827764387`*^9, 
  3.761477393256817*^9}},ExpressionUUID->"2a50a35d-708a-4b8a-a51e-\
b0be5699a0d4"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270069256`*^9},ExpressionUUID->"315ecd1f-a1d9-474c-ab8b-\
487a481f6d34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270269775`*^9},ExpressionUUID->"285ffa8a-59c9-4011-b413-\
0077d3ddc4dc"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",ExpressionUUID->"2985d3ab-6579-4fff-ade3-ece69136b7df"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Case", " ", "1", 
    RowBox[{"b", ":", " ", 
     RowBox[{
     "Effective", " ", "fluid", " ", "and", " ", "subhorizon", " ", "for", 
      " ", "KGB"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "strict", " ", "JP", " ", "version", " ", "without", " ", "our", " ", 
     "improvement"}], " ", "//", " ", 
    RowBox[{"best", " ", "for", " ", "KGB", " ", "numerics", " ", 
     RowBox[{"(", 
      RowBox[{"no", " ", "anisotropic", " ", "stress"}], ")"}]}]}]}], " ", 
  "*)"}]], "Input",
 CellChangeTimes->{{3.7568075707836485`*^9, 3.7568075757622113`*^9}, {
   3.7568096497511396`*^9, 3.7568096534003925`*^9}, {3.759648846982213*^9, 
   3.7596488495525045`*^9}, {3.7631205055312815`*^9, 3.763120542849162*^9}, {
   3.7631209768868275`*^9, 3.763120983412758*^9}, {3.7631214134797087`*^9, 
   3.7631214136679688`*^9}, {3.7631900651562133`*^9, 3.763190083266192*^9}, 
   3.763190392821602*^9, {3.7634624903308573`*^9, 
   3.763462495530807*^9}},ExpressionUUID->"a80d0dd5-6809-4a15-8fc3-\
6c079ce758c5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesKGB0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rulesKGB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "X"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"X", "^", "n"}]}]}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "1"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "->", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "3"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7568081983101892`*^9, 3.756808200860401*^9}, {
   3.756808599964323*^9, 3.756808600859193*^9}, 3.757923942100193*^9, {
   3.759648878369643*^9, 3.759648878635396*^9}, {3.7607934082599554`*^9, 
   3.7607934125992403`*^9}},ExpressionUUID->"5fcf443e-f7ce-45e3-a92f-\
cd9248f3d26a"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dX0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ".", 
        "gUU", ".", 
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], 
      "-", "X0"}], "/.", "a2H"}], "//", "ApproxFullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"soldf", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"dX0", "\[Equal]", 
       RowBox[{"\[Delta]X", "[", "t", "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    SqrtBox[
     RowBox[{"2", "X"}]]}]}]}]}], "Input",
 CellChangeTimes->{
  3.7561141319764814`*^9, {3.7579239991243944`*^9, 
   3.7579240091742053`*^9}},ExpressionUUID->"35370ff0-d491-4e66-9ff0-\
b5d683522163"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]X", "[", "t", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.757924013239633*^9, 3.7584607175620537`*^9, {3.7595831281019588`*^9, 
   3.759583128801408*^9}, 3.759648882211532*^9, 3.7596621180996127`*^9, 
   3.7607063136389337`*^9, 3.7607064887891293`*^9, 3.760707315914773*^9, 
   3.760793455789051*^9, 3.7608602303957033`*^9, 3.760868850328183*^9, 
   3.760877403457257*^9, 3.760877524047437*^9, 3.7609545191368074`*^9, 
   3.760954565031988*^9, 3.760964283246402*^9, 3.7609651066335964`*^9, 
   3.760966651601708*^9, 3.7610284651348453`*^9, 3.7614714548842196`*^9, 
   3.7614755993269067`*^9, 3.762082048992428*^9, 3.7631009151678376`*^9, 
   3.7631009541881647`*^9, 3.763113583475541*^9, 3.763115144246414*^9, 
   3.7631205210067654`*^9, 3.7631214432868347`*^9, 3.763121745526952*^9, 
   3.763189196445918*^9, 
   3.7634625165665894`*^9},ExpressionUUID->"c009682f-3a7d-4b31-b007-\
baadc8501f8b"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGRA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"A2", "\[Rule]", "0"}], ",", 
     RowBox[{"A3", "\[Rule]", "2"}], ",", 
     RowBox[{"A4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{"A5", "\[Rule]", "0"}], ",", 
     RowBox[{"A6", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B1", "\[Rule]", "6"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B3", "\[Rule]", 
      RowBox[{"18", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B4", "\[Rule]", "0"}], ",", 
     RowBox[{"B5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B6", "\[Rule]", "2"}], ",", 
     RowBox[{"B7", "\[Rule]", "0"}], ",", 
     RowBox[{"B8", "\[Rule]", "2"}], ",", 
     RowBox[{"B9", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "18"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
     RowBox[{"\[Nu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C1", "\[Rule]", "2"}], ",", 
     RowBox[{"C2", "\[Rule]", "0"}], ",", 
     RowBox[{"C3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"C4", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D1", "\[Rule]", "0"}], ",", 
     RowBox[{"D2", "\[Rule]", "0"}], ",", 
     RowBox[{"D3", "\[Rule]", "0"}], ",", 
     RowBox[{"D4", "\[Rule]", "0"}], ",", 
     RowBox[{"D5", "\[Rule]", "0"}], ",", 
     RowBox[{"D7", "\[Rule]", "0"}], ",", 
     RowBox[{"D8", "\[Rule]", "0"}], ",", 
     RowBox[{"D9", "\[Rule]", "0"}], ",", 
     RowBox[{"D10", "\[Rule]", "0"}], ",", 
     RowBox[{"D11", "\[Rule]", "0"}], ",", 
     RowBox[{"M", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRABCD", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"rulesGRA", ",", "rulesGRB", ",", "rulesGRC", ",", "rulesGRD"}], 
     "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7608774109275446`*^9, 3.760877515997035*^9}, {
   3.760877601947462*^9, 3.760877723817091*^9}, 3.760878178137457*^9, {
   3.760878406236206*^9, 3.7608784114662337`*^9}, {3.760964293131819*^9, 
   3.7609643313744884`*^9}},ExpressionUUID->"cd36303b-9ab1-404a-9517-\
0d5792a72f92"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eq00", "=", 
   RowBox[{
    RowBox[{"A1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A3", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A4", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", "\[Mu]"}], ")"}], 
     " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqii", "=", 
   RowBox[{
    RowBox[{"B1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B6", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", 
       RowBox[{"3", "\[Nu]"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B8", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "B9"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eq0i", "=", 
   RowBox[{
    RowBox[{"C1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C3", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C4", " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
     SuperscriptBox["k", "2"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqsc", "=", 
   RowBox[{
    RowBox[{"D1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D8"}], ")"}], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D9", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"M", "^", "2"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D10", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D11"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.760871236957633*^9, 3.760871319127609*^9}, {
   3.7608713554071703`*^9, 3.760871572037525*^9}, 3.760871605627293*^9, 
   3.7608720233417673`*^9, {3.7608770922374477`*^9, 3.76087713384791*^9}, {
   3.7608772688874445`*^9, 3.7608772691494226`*^9}, {3.760877955181913*^9, 
   3.7608781114020014`*^9}, {3.760965230731535*^9, 
   3.7609652310438423`*^9}},ExpressionUUID->"6dcc9c25-12a2-4a34-b868-\
8f83db149292"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs00", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq00", "/.", "rulesGRA"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Eqsii", "/.", "rulesGR"}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{"Eqii", "/.", "rulesGRB"}], ")"}]}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs0i", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq0i", "/.", "rulesGRC"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqscal", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eqsc", "/.", "rulesGRD"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7608777345270576`*^9, 3.760877842347237*^9}, 
   3.7608780039918804`*^9, 3.760878415551169*^9, {3.760878470640115*^9, 
   3.7608785600562253`*^9}},ExpressionUUID->"ff499ebf-ed9c-47ec-b502-\
8254558e7e04"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631214450271034`*^9, 3.7631892024959545`*^9, 
   3.763462522100881*^9},ExpressionUUID->"48a0fcc7-e168-4573-a51f-\
bc9e60dcb928"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631214450271034`*^9, 3.7631892024959545`*^9, 
   3.763462522110647*^9},ExpressionUUID->"e97f18c2-6950-423f-8c23-\
cdfb029ac3ce"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631214450271034`*^9, 3.7631892024959545`*^9, 
   3.763462522110647*^9},ExpressionUUID->"d12166ca-248e-4288-9e8a-\
4ed2496bb5cb"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631214450271034`*^9, 3.7631892024959545`*^9, 
   3.763462522120551*^9},ExpressionUUID->"75415a6e-d0fa-41ec-b2e0-\
0d6eab722562"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"subhorstrict", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", "0"}], ",", 
     RowBox[{"A2", "\[Rule]", "0"}], ",", 
     RowBox[{"A4", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}], ",", 
     RowBox[{"B1", "\[Rule]", "0"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B3", "\[Rule]", "0"}], ",", 
     RowBox[{"B4", "\[Rule]", "0"}], ",", 
     RowBox[{"B5", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Nu]", "\[Rule]", "0"}], ",", 
     RowBox[{"B9", "\[Rule]", "0"}], ",", 
     RowBox[{"D1", "\[Rule]", "0"}], ",", 
     RowBox[{"D2", "\[Rule]", "0"}], ",", 
     RowBox[{"D3", "\[Rule]", "0"}], ",", 
     RowBox[{"D4", "\[Rule]", "0"}], ",", 
     RowBox[{"D5", "\[Rule]", "0"}], ",", 
     RowBox[{"D8", "\[Rule]", "0"}], ",", 
     RowBox[{"D11", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"subhorflex", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A1", "\[Rule]", "0"}], ",", 
       RowBox[{"A2", "\[Rule]", "0"}], ",", 
       RowBox[{"B1", "\[Rule]", "0"}], ",", 
       RowBox[{"B2", "\[Rule]", "0"}], ",", 
       RowBox[{"B3", "\[Rule]", "0"}], ",", 
       RowBox[{"B4", "\[Rule]", "0"}], ",", 
       RowBox[{"B5", "\[Rule]", "0"}], ",", 
       RowBox[{"C1", "\[Rule]", "0"}], ",", 
       RowBox[{"C2", "\[Rule]", "0"}], ",", 
       RowBox[{"D1", "\[Rule]", "0"}], ",", 
       RowBox[{"D2", "\[Rule]", "0"}], ",", 
       RowBox[{"D3", "\[Rule]", "0"}], ",", 
       RowBox[{"D4", "\[Rule]", "0"}], ",", 
       RowBox[{"D5", "\[Rule]", "0"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "*)"}]}]}], "Input",
 CellChangeTimes->{{3.763120561226567*^9, 
  3.7631205712068496`*^9}},ExpressionUUID->"7c24fb2b-3f5e-4355-8afe-\
5af0fa6b4619"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "potentials"}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"subhor", "=", "subhorstrict"}], ";", 
    RowBox[{"solgen", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Eq00", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqii", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqsc", "\[Equal]", "0"}]}], "}"}], "/.", "subhor"}], "/.", 
          RowBox[{
           RowBox[{"\[Delta]Pm", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
           "0"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[CapitalPsi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[Delta]\[Phi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"solgen", "//", "TableForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7608716843173847`*^9, 3.760871870449571*^9}, {
  3.7608720053374634`*^9, 3.760872006777376*^9}, {3.760878197051565*^9, 
  3.7608782029572024`*^9}, {3.7608790453577843`*^9, 3.760879045865718*^9}, {
  3.760964405164853*^9, 3.7609645103018255`*^9}, {3.7609652605941057`*^9, 
  3.760965262471862*^9}, {3.760966739353032*^9, 3.760966739932638*^9}, {
  3.7609667897358575`*^9, 3.76096683365308*^9}, {3.7631136147260556`*^9, 
  3.7631136366483927`*^9}, {3.763115156776116*^9, 3.7631151673663273`*^9}, {
  3.7631206809169006`*^9, 
  3.76312070061677*^9}},ExpressionUUID->"ce3d0924-4d1f-483f-b5a1-\
182dae9bac25"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D10"}], "-", 
               RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
             SuperscriptBox["k", "2"]}], "+", 
            RowBox[{"B8", " ", 
             SuperscriptBox["M", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"\[Delta]\[Rho]m", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
             RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
             RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
             RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
           SuperscriptBox["k", "4"]}], "-", 
          RowBox[{"A3", " ", "B8", " ", 
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox["M", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]}]},
     {
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "2"]}], "+", 
           RowBox[{"B6", " ", 
            SuperscriptBox["M", "2"], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "4"]}], "-", 
         RowBox[{"A3", " ", "B8", " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox["M", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]},
     {
      RowBox[{
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B6", " ", "D10"}], "-", 
           RowBox[{"B8", " ", "D7"}]}], ")"}], " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "2"]}], "-", 
         RowBox[{"A3", " ", "B8", " ", 
          SuperscriptBox["M", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7608717286971655`*^9, {3.7608718611915445`*^9, 3.760871871352357*^9}, {
   3.7608720076070447`*^9, 3.7608720260271597`*^9}, {3.760878191007273*^9, 
   3.760878204447015*^9}, 3.7608789370907774`*^9, 3.7608790463277893`*^9, 
   3.76095458366181*^9, 3.76096435408368*^9, {3.760964465561962*^9, 
   3.7609645113515034`*^9}, {3.7609652497418423`*^9, 3.7609652635475073`*^9}, 
   3.7609668374928026`*^9, 3.7610285102695513`*^9, 3.7614714737442923`*^9, 
   3.7614756089571514`*^9, 3.7620820882657003`*^9, 3.7631009673786554`*^9, {
   3.7631136325212173`*^9, 3.763113637630972*^9}, 3.763115176536146*^9, 
   3.7631205783068843`*^9, 3.7631207044668016`*^9, 3.763121457952054*^9, 
   3.7631217465669727`*^9, 3.7631892076272335`*^9, 
   3.7634625258810897`*^9},ExpressionUUID->"f6d66079-01ba-43a2-86dc-\
1e5c426a0a34"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Eta]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Eta]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206084091463`*^9, 3.763120641589445*^9}, {
  3.7631207138169174`*^9, 
  3.763120728343577*^9}},ExpressionUUID->"87255e27-8585-46ec-96ea-\
0ccdaf7f196e"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"-", "B6"}], "+", "B8", "+", 
   FractionBox[
    RowBox[{"B7", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B6", " ", "D10"}], "-", 
       RowBox[{"B8", " ", "D7"}]}], ")"}], " ", 
     SuperscriptBox["k", "2"]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B7", " ", "D10"}], "-", 
        RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{"B8", " ", 
      SuperscriptBox["M", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}], "B8"]], "Output",
 CellChangeTimes->{{3.763120609582012*^9, 3.7631206420367975`*^9}, 
   3.763121460636836*^9, 3.7631217485169353`*^9, 3.7631892104861794`*^9, 
   3.7634625283007545`*^9},ExpressionUUID->"5d7d2498-079d-4f75-9e46-\
31175a9a9875"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Gamma]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Gamma]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206180173826`*^9, 3.7631206194184933`*^9}, {
  3.763120722997031*^9, 
  3.763120733766609*^9}},ExpressionUUID->"c7057730-a00f-4768-9d5c-\
9f798a2f05ee"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D10"}], "-", 
      RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B8", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{3.763120619816679*^9, 3.7631214612471075`*^9, 
  3.7631217490821233`*^9, 3.763189211357095*^9, 
  3.7634625289009905`*^9},ExpressionUUID->"d986218f-2a85-4942-b8fd-\
fe470b29e9fc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", 
    RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff"}], " ", "*)"}],
   " ", "\[IndentingNewLine]", 
  RowBox[{"Geff", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"k", "^", "2"}], 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]], 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], " ", "G", " ", "\[Pi]", " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], "/.", 
     RowBox[{"solgen", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763120736546857*^9, 
  3.7631207498276453`*^9}},ExpressionUUID->"ff353a56-bea6-4cac-98d5-\
a7d36795375c"],

Cell[BoxData[
 FractionBox[
  RowBox[{"2", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B7", " ", "D7"}], "-", 
        RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
      SuperscriptBox["k", "2"]}], "+", 
     RowBox[{"B6", " ", 
      SuperscriptBox["M", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "A6"}], " ", "B6", " ", "D10"}], "+", 
      RowBox[{"A3", " ", "B7", " ", "D10"}], "+", 
      RowBox[{"A6", " ", "B8", " ", "D7"}], "-", 
      RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"A3", " ", "B8", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{3.7631206655067053`*^9, 3.7631207506888466`*^9, 
  3.763121462958994*^9, 3.763121750926945*^9, 3.763189213435964*^9, 
  3.7634625306852956`*^9},ExpressionUUID->"fade02e1-e32f-449c-b9ab-\
28080a207e13"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Ruben", "'"}], "s", " ", "effective", " ", 
    RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff", " ", "from", 
    " ", "the", " ", "paper"}], " ", "*)"}]}]], "Input",
 CellChangeTimes->{{3.7631207729569917`*^9, 
  3.7631207857019873`*^9}},ExpressionUUID->"4192a6d8-dc89-40e1-be86-\
dfeb80aff403"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GeffRub", "=", 
   FractionBox[
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B6", " ", "D9"}], "-", 
          RowBox[{"B7", "^", "2"}]}], ")"}], 
        FractionBox[
         SuperscriptBox["k", "2"], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"B6", " ", 
        SuperscriptBox["M", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A6", "^", "2"}], " ", "B6"}], "+", 
        RowBox[{
         RowBox[{"B6", "^", "2"}], "D9"}], "-", 
        RowBox[{"2", "A6", " ", "B7", " ", "B6"}]}], ")"}], 
      FractionBox[
       SuperscriptBox["k", "2"], 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
     RowBox[{
      RowBox[{"B6", "^", "2"}], " ", 
      RowBox[{"M", "^", "2"}]}]}]]}], ";"}]], "Input",ExpressionUUID->\
"a1054115-ee2c-4602-9853-dd74e324feff"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "f", 
    RowBox[{"(", "R", ")"}], " ", "limit"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fRlimit", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "2"}], 
         RowBox[{"\[Phi]", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], 
       ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "Rr"}], "2"]}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "1"}], 
         RowBox[{"2", " ", "fRR"}]]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fRextra", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["M", "2"], "\[Rule]", 
        FractionBox["1", 
         RowBox[{"2", " ", "fRR"}]]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fR", "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fRR", "\[Rule]", 
        RowBox[{"m", " ", "F"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"F", "'"}], "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "->", 
        RowBox[{
         RowBox[{"F", "''"}], "[", "t", "]"}]}]}], "}"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.763120798989036*^9, 3.7631208072669797`*^9}, {
  3.7631211354571056`*^9, 
  3.7631211447892885`*^9}},ExpressionUUID->"54c1e476-552c-4b0d-b32b-\
40923fe9f84e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Eliminate", " ", "\[Delta]\[Phi]", " ", "and", " ", 
    RowBox[{"it", "'"}], "s", " ", "derivatives", " ", "to", " ", "improve", 
    " ", "accuracy"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"soldfn", "=", 
     RowBox[{"Flatten", "[", 
      RowBox[{
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"D", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Solve", "[", 
             RowBox[{
              RowBox[{"Eqsij", "\[Equal]", "0"}], ",", 
              RowBox[{"\[Delta]\[Phi]", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
            "[", 
            RowBox[{"[", "1", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "n"}], "}"}]}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"n", ",", "0", ",", "2"}], "}"}]}], "]"}], "/.", "rules"}], 
      "]"}]}], ";"}], "*)"}]}]], "Input",
 CellChangeTimes->{{3.763120836316975*^9, 3.7631208630569916`*^9}, {
  3.7631214800571146`*^9, 
  3.763121482257925*^9}},ExpressionUUID->"adade131-4d7f-4f79-8b47-\
caaa70441fcb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "quantities"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"soldPDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Eqii", "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
                 RowBox[{"\[Delta]PDE", "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
                "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", "0"}], 
           ",", 
           RowBox[{"\[Delta]PDE", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
         
         RowBox[{"[", "1", "]"}], "]"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], ";", 
    RowBox[{"soldDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Eq00", "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
                 RowBox[{"\[Delta]\[Rho]DE", "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
                "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{"\[Delta]\[Rho]DE", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
         
         RowBox[{"[", "1", "]"}], "]"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"solVDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Eq0i", "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox[
                 RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
                  RowBox[{"a", "[", "t", "]"}], 
                  RowBox[{"VDE", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
                  RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
                 SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", "rulesGRC"}],
               ")"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{"VDE", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
         
         RowBox[{"[", "1", "]"}], "]"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.76312089191674*^9, 3.763120918757121*^9}, {
  3.763121475107342*^9, 3.76312149122225*^9}, {3.7631215729669237`*^9, 
  3.763121582577254*^9}, {3.7631216842571115`*^9, 
  3.7631216875870333`*^9}},ExpressionUUID->"17fee81d-5e7f-4f6e-8a68-\
7f36950253bb"],

Cell[CellGroupData[{

Cell[BoxData[{"soldPDE", "\[IndentingNewLine]", "soldDE", \
"\[IndentingNewLine]", "solVDE"}], "Input",
 CellChangeTimes->{{3.763462651800935*^9, 
  3.7634626563331933`*^9}},ExpressionUUID->"527da952-e60c-4e5d-a639-\
e33488d102e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B7", " ", 
            RowBox[{"(", 
             RowBox[{"D10", "-", "D7"}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"B6", "-", "B8"}], ")"}], " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "4"]}], "+", 
        RowBox[{"B6", " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{"B9", "+", 
           RowBox[{"18", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"12", " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B7", " ", "B9", " ", "D7"}], "-", 
           RowBox[{"B6", " ", "B9", " ", "D9"}], "-", 
           RowBox[{"2", " ", "B6", " ", 
            SuperscriptBox["M", "2"]}], "+", 
           RowBox[{"2", " ", "B8", " ", 
            SuperscriptBox["M", "2"]}], "+", 
           RowBox[{"3", " ", "B6", " ", "D10", " ", "\[Nu]"}], "-", 
           RowBox[{"3", " ", "B8", " ", "D7", " ", "\[Nu]"}], "+", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"3", " ", 
               SuperscriptBox[
                RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
              RowBox[{"2", " ", 
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
         RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
         RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
         RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "4"]}], "-", 
      RowBox[{"3", " ", "A3", " ", "B8", " ", 
       SuperscriptBox["k", "2"], " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7634626149810963`*^9, 
  3.7634626575145283`*^9},ExpressionUUID->"0b7c3677-9f53-49a1-8a93-\
87b5cbbf0532"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A6", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B6", " ", "D10"}], "-", 
                RowBox[{"B8", " ", "D7"}]}], ")"}]}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D10"}], "-", 
                RowBox[{"B8", " ", "D9"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox["k", "4"]}], "+", 
          RowBox[{"B6", " ", 
           SuperscriptBox["M", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "4"], " ", 
           RowBox[{"(", 
            RowBox[{"A4", "+", 
             RowBox[{"6", " ", 
              SuperscriptBox[
               RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A4", " ", "B7", " ", "D7"}], "-", 
             RowBox[{"A4", " ", "B6", " ", "D9"}], "-", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "B8", " ", 
              SuperscriptBox["M", "2"]}], "-", 
             RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "+", 
             RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
             RowBox[{"6", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D7"}], "-", 
                RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}]}], ")"}], " ", 
        
        RowBox[{"\[Delta]\[Rho]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
           RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
           RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
           RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "4"]}], "-", 
        RowBox[{"A3", " ", "B8", " ", 
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7634626149810963`*^9, 
  3.763462657541112*^9},ExpressionUUID->"d0aba220-ba73-4afb-8dfa-\
6b674a6b131c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B6", " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"C3", "+", 
           RowBox[{"2", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B6", " ", "C4", " ", "D10"}], "+", 
           RowBox[{"B7", " ", "C3", " ", "D7"}], "-", 
           RowBox[{"B8", " ", "C4", " ", "D7"}], "-", 
           RowBox[{"B6", " ", "C3", " ", "D9"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
           RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
           RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
           RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "2"]}], "-", 
        RowBox[{"A3", " ", "B8", " ", 
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
      RowBox[{"\[Rho]DE", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.7634626149810963`*^9, 
  3.763462657573415*^9},ExpressionUUID->"48446737-cbb0-481d-98eb-\
ec1dbf679f42"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"The", " ", "KGB", " ", "limit"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631209397866125`*^9, 3.7631209459418736`*^9}, {
  3.763121010101895*^9, 
  3.7631210112500215`*^9}},ExpressionUUID->"0d2a6eac-64ff-4648-a2b8-\
4f2e1cd723aa"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"solgen", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "/.", "subhor"}], "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7609546600619273`*^9, 3.760954664466791*^9}, {
   3.760966857372764*^9, 3.760966857623056*^9}, 
   3.763115173256571*^9},ExpressionUUID->"e6fc97c9-ddb4-448a-b0a2-\
ee7bb1047adb"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Delta]\[Phi]", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
  FractionBox[
   RowBox[{"8", " ", 
    RowBox[{"(", 
     RowBox[{"A6", "-", "B7"}], ")"}], " ", "G", " ", "\[Pi]", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"], " ", 
    RowBox[{"\[Delta]\[Rho]m", "[", 
     RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["A6", "2"], "-", 
       RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
       RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "2"]}], "-", 
    RowBox[{"B6", " ", 
     SuperscriptBox["M", "2"], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}]}]]}]], "Output",
 CellChangeTimes->{{3.7609644972316685`*^9, 3.76096452140153*^9}, 
   3.760965267881686*^9, 3.760966858712723*^9, 3.761028528340328*^9, 
   3.7614714740090947`*^9, 3.7631009778543415`*^9, 3.7631136442211275`*^9, 
   3.7631151783760886`*^9, 3.763121017667138*^9, 3.7631214974667664`*^9, 
   3.7631216081170287`*^9, 3.763121696749097*^9, 
   3.7631217590393353`*^9},ExpressionUUID->"122429d9-a8c3-4131-86ed-\
fac46c51d4cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608721634777718`*^9, 3.760872183439308*^9}, 
   3.7608722185270576`*^9, {3.760872271117173*^9, 3.7608722728772163`*^9}, {
   3.7608725066403027`*^9, 3.7608725068252964`*^9}, {3.7608782109070044`*^9, 
   3.7608782132468443`*^9}, {3.760954695182067*^9, 3.76095471970185*^9}, 
   3.760954754834016*^9, {3.7609668631930323`*^9, 3.7609668717226267`*^9}, 
   3.763115174916142*^9, {3.763121025736691*^9, 
   3.7631210366271324`*^9}},ExpressionUUID->"8b75dc96-fdd3-44cb-9210-\
3086c53536a3"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"(", 
    RowBox[{"A6", "-", "B7"}], ")"}], " ", "B7", " ", 
   SuperscriptBox["k", "2"]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{
  3.7608782163370647`*^9, 3.760878939305962*^9, {3.7609546827516994`*^9, 
   3.760954720461788*^9}, 3.760954755682119*^9, 3.760964524526888*^9, 
   3.7609652695817666`*^9, {3.7609668643429146`*^9, 3.760966873672986*^9}, 
   3.7610285303769536`*^9, 3.7631009799055977`*^9, 3.763113646616123*^9, 
   3.7631151797660885`*^9, {3.7631210199111567`*^9, 3.7631210374269714`*^9}, 
   3.763121498646746*^9, 3.7631216976168623`*^9, 
   3.763121760587738*^9},ExpressionUUID->"3aef0aa5-79a7-4e83-845d-\
91ce196f702e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.760872517388804*^9, 3.7608725507370615`*^9}, {
   3.7608782231496954`*^9, 3.7608782248921795`*^9}, {3.7609547620619287`*^9, 
   3.7609547725885253`*^9}, 3.760966876112828*^9, 3.76311518170636*^9, 
   3.763121039861877*^9},ExpressionUUID->"47a87269-0f17-49d5-8d4e-\
e6b54ff9319f"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["B7", "2"], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "2"]}], "+", 
   RowBox[{"B6", " ", 
    SuperscriptBox["M", "2"], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}]}]]], "Output",
 CellChangeTimes->{{3.760872520881508*^9, 3.760872551269845*^9}, 
   3.760878225431428*^9, {3.760954741811887*^9, 3.760954772871746*^9}, 
   3.760964526241928*^9, 3.76096527069625*^9, 3.760966876882693*^9, 
   3.7610285314106803`*^9, 3.763100981323767*^9, 3.7631136477479143`*^9, 
   3.7631151824566355`*^9, 3.7631210407768707`*^9, 3.7631215002068796`*^9, 
   3.7631216983470616`*^9, 
   3.7631217613892765`*^9},ExpressionUUID->"24408644-450b-46a5-be52-\
cdf48aec7b95"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Geff", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608720490497875`*^9, 3.7608720761673555`*^9}, 
   3.7608782283273168`*^9, 3.7609547823420057`*^9, {3.7609668940274115`*^9, 
   3.760966914512579*^9}, {3.7631136608859067`*^9, 3.763113661376213*^9}, 
   3.7631210448890667`*^9},ExpressionUUID->"3e73b880-2ad7-48ce-ae18-\
5aad5861c78e"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{"2", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["B7", "2"], "-", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "2"]}], "+", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}], 
   RowBox[{"B6", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["A6", "2"], "-", 
         RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "2"]}], "-", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}]]}]], "Output",
 CellChangeTimes->{{3.7608720496015744`*^9, 3.760872081867358*^9}, 
   3.7608782296972866`*^9, {3.7609547767217216`*^9, 3.7609547830420494`*^9}, 
   3.760964530741832*^9, 3.7609652723740387`*^9, {3.760966906382824*^9, 
   3.760966916062399*^9}, 3.761028535682231*^9, 3.761471479878995*^9, 
   3.7620820962753325`*^9, 3.763100984211653*^9, {3.7631136524657965`*^9, 
   3.76311366215584*^9}, 3.763115187816374*^9, 3.763121046146944*^9, 
   3.763121500871705*^9, 3.763121699606865*^9, 
   3.7631217629894433`*^9},ExpressionUUID->"d5294322-f32a-4d16-ae66-\
ad18f617b88e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"solVDE", "/.", 
           RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
        RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
       RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
    RowBox[{"M", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7614715093614264`*^9, 3.761471529839512*^9}, 
   3.761471622774027*^9, 
   3.7631210561473184`*^9},ExpressionUUID->"7562f6d4-9b2e-44de-9254-\
c1983aae02c0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", "C4"}], "-", 
       RowBox[{"C3", " ", "D9"}], "-", 
       RowBox[{"2", " ", "D9", " ", 
        RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["A6", "2"], "+", 
       RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614715103143363`*^9, 3.761471530249116*^9}, 
   3.7614716234468727`*^9, 3.761475623436673*^9, 3.762082247279933*^9, 
   3.7631137789961405`*^9, 3.763115417160034*^9, 3.7631210570470114`*^9, 
   3.763121502476925*^9, 3.7631217012169733`*^9, 
   3.7631217670768547`*^9},ExpressionUUID->"ea088ca4-2447-45e1-a7f9-\
c15a1bb97547"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"solVDE", "/.", 
          RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
        RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
       RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.760967170912757*^9, 3.7609671756729927`*^9}, {
   3.7609672170710683`*^9, 3.760967268572739*^9}, {3.7609673456627393`*^9, 
   3.760967355482613*^9}, 
   3.763121079797018*^9},ExpressionUUID->"9caa4441-a8e5-4b82-bcd6-\
2ccefa5da8e0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["M", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A6", " ", "C4"}], "-", 
          RowBox[{"C3", " ", "D9"}], "-", 
          RowBox[{"2", " ", "D9", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["A6", "2"], "+", 
          RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
        SuperscriptBox["k", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7609672099178877`*^9, 3.760967270222868*^9}, {
   3.7609673521427126`*^9, 3.7609673562526836`*^9}, 3.76102860194715*^9, 
   3.7614756243818407`*^9, 3.763113782415992*^9, 3.7631154205899687`*^9, 
   3.7631210871609144`*^9, 3.7631215052018366`*^9, 3.7631217030569925`*^9, 
   3.763121768036989*^9},ExpressionUUID->"b781742b-f1b7-4b39-b03e-\
8bd9189c9c5b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"soldPDE", "/.", 
            RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
           RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
        RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
     RowBox[{"B6", "\[Rule]", "2"}]}], "/.", 
    RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"M", "\[Rule]", "0"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", "subhor"}]}], "Input",
 CellChangeTimes->{{3.760967419262813*^9, 3.7609674497562037`*^9}, {
  3.760967526613056*^9, 3.7609675736426086`*^9}, {3.7609676630048027`*^9, 
  3.7609676646630898`*^9}, {3.7609677596250677`*^9, 3.7609677612924557`*^9}, {
  3.763121100677089*^9, 
  3.763121112486868*^9}},ExpressionUUID->"62402534-2d06-42b7-a65e-\
42bae8dffed0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"D9", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"B9", "+", 
        RowBox[{"18", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["A6", "2"], "+", 
        RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
      SuperscriptBox["k", "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 3.7631215074472547`*^9, 
   3.7631217042121444`*^9, 
   3.7631217689321938`*^9},ExpressionUUID->"b423ca47-9345-42a7-b879-\
83a700490080"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"D9", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"18", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{"12", " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["A6", "2"], "+", 
        RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
      SuperscriptBox["k", "2"]}]]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 3.7631215074472547`*^9, 
   3.7631217042121444`*^9, 
   3.763121768956915*^9},ExpressionUUID->"9512d4ba-fd71-4beb-a1a9-\
b1107d2c0cbf"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.763115082136239*^9, 
  3.7631151022566075`*^9}},ExpressionUUID->"03d98672-c666-4425-bbe8-\
5b394771c571"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Coefficients", " ", "//", " ", 
   RowBox[{"run", " ", "this"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.76311405695595*^9, 3.7631140621959715`*^9}, {
  3.763114114611548*^9, 
  3.7631141167663727`*^9}},ExpressionUUID->"2bba5c1e-59aa-4369-b837-\
f7e46132ee60"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", 
     "\[Mu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}]}], ",", "0", ",", 
     
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", "B7", 
     ",", "B8", ",", "B9", ",", "\[Nu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"36", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "36"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"C1", ",", "C2", ",", "C3", ",", "C4"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", "D7", ",", "D8", 
     ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"5", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7610287424727*^9, 3.761028748984979*^9}, {
  3.7631140663258605`*^9, 
  3.763114090298678*^9}},ExpressionUUID->"4d89da9a-2461-4599-9089-\
da5c95279364"],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631140943260336`*^9, 
  3.763114096275912*^9}},ExpressionUUID->"0d3935a7-4c95-46c7-b7e2-\
938e774517ca"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Geff", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7631211585671844`*^9, 
  3.7631211623070984`*^9}},ExpressionUUID->"1881ee72-8fca-44f9-9ba4-\
876119725e6c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m"}], "+", 
   RowBox[{"F", "[", "t", "]"}]}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m", " ", 
    RowBox[{"F", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{"F", "[", "t", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{3.7631211630169344`*^9, 3.763121513977105*^9, 
  3.763121624941717*^9, 
  3.763121789917158*^9},ExpressionUUID->"0f6c8c7a-a913-4b99-846b-\
4c274ba18256"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GeffRub", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.763101809150457*^9, 3.7631018648961973`*^9}, {
   3.763101905329755*^9, 3.763101962609453*^9}, {3.7631020677421107`*^9, 
   3.763102068004221*^9}, 3.763113690547677*^9, 3.763113734057954*^9, 
   3.7631143547364793`*^9, {3.7631154529200172`*^9, 
   3.763115454515036*^9}},ExpressionUUID->"836e41ea-29df-417f-83ed-\
1ea9a3b1a86c"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m"}], "+", 
   RowBox[{"F", "[", "t", "]"}]}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m", " ", 
    RowBox[{"F", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{"F", "[", "t", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.7631018109898095`*^9, 3.7631018662119465`*^9}, 
   3.763101919909732*^9, {3.7631019566797557`*^9, 3.7631019631693273`*^9}, 
   3.7631020722108507`*^9, 3.763102140246998*^9, 3.763113735270893*^9, 
   3.7631141615961914`*^9, {3.7631143508882236`*^9, 3.7631143783025227`*^9}, 
   3.7631151078864684`*^9, {3.7631154501800623`*^9, 3.7631154551422105`*^9}, 
   3.7631164377034683`*^9, 3.763121152956889*^9, 3.763121515996849*^9, 
   3.7631216258470902`*^9, 
   3.763121791636891*^9},ExpressionUUID->"0974b278-7904-4b27-95e2-\
df20b1eb9333"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "expressions"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"They", " ", "agree", " ", "with", " ", "our", " ", "f", 
    RowBox[{"(", "R", ")"}], " ", "effective", " ", "paper"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldPDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"solVDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763114134611041*^9, 3.7631142372359266`*^9}, 
   3.763114314426009*^9, {3.7631143821659684`*^9, 3.7631143908180556`*^9}, {
   3.763115503160205*^9, 3.763115504292551*^9}, {3.7631164227035484`*^9, 
   3.763116429662382*^9}, {3.763116539281295*^9, 3.7631165461681833`*^9}, {
   3.7631211692867537`*^9, 3.763121212807345*^9}, {3.763121548978108*^9, 
   3.7631215621472015`*^9}},ExpressionUUID->"fdfb3727-1f9e-42ff-943c-\
010b6fa8a38c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "FR", " ", 
        SuperscriptBox["k", "4"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"4", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"3", " ", 
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"F", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 3.763121521797028*^9, 
   3.763121555631837*^9, {3.7631216191706915`*^9, 3.7631216283272123`*^9}, 
   3.763121794892276*^9},ExpressionUUID->"a7a11fed-c81e-430e-a24c-\
9f0354b2c3a0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "-", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"F", "[", "t", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{
     RowBox[{"F", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 3.763121521797028*^9, 
   3.763121555631837*^9, {3.7631216191706915`*^9, 3.7631216283272123`*^9}, 
   3.763121794911976*^9},ExpressionUUID->"43c4348c-15d0-4766-a496-\
7b93398f16bd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["F", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"F", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", "FR", " ", 
        SuperscriptBox["k", "2"]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 3.763121521797028*^9, 
   3.763121555631837*^9, {3.7631216191706915`*^9, 3.7631216283272123`*^9}, 
   3.763121794951954*^9},ExpressionUUID->"236b97ae-f1b2-42e7-a12a-\
0ad487df8600"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.763462348923543*^9, 
  3.7634623498506904`*^9}},ExpressionUUID->"4f997098-7bc8-4e81-ab10-\
f4d92a63c515"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",ExpressionUUID->"8aa1c025-d825-450e-9e33-6e94e03866d6"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Sound", " ", "speed", " ", "in", " ", "rest", " ", 
   RowBox[{"frame", "?"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7614725513993692`*^9, 
  3.761472564159005*^9}},ExpressionUUID->"715a5fe4-ca63-4f1c-9b76-\
5826a1c7cbb4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Eq0i", "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
            RowBox[{"a", "[", "t", "]"}], 
            RowBox[{"VDE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
            RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
           SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", "rulesGRC"}], 
        ")"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"VDE", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "/.", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f_", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.7631158554198527`*^9, 3.7631158618197684`*^9}, 
   3.7631159267299547`*^9},ExpressionUUID->"d3cf2da3-38f9-460b-8400-\
c2a2e9ecac19"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C4", " ", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"C3", " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.76147188603936*^9, 3.7631138043759212`*^9, 3.763115541862115*^9, 
   3.7631155897951345`*^9, {3.763115859190098*^9, 3.7631158626502314`*^9}, 
   3.7631159277401032`*^9, 3.7631212287267866`*^9, 
   3.7631218001469655`*^9},ExpressionUUID->"07512fde-7457-40d7-9d62-\
dd30fc0fbc79"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"C4", " ", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"C3", " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7614718970391417`*^9, 3.761471924311453*^9}, {
  3.7614720011495757`*^9, 
  3.7614720080296535`*^9}},ExpressionUUID->"1940d0ac-c3b3-43e2-afcf-\
3f618302d17b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C3", "+", 
        RowBox[{"2", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "C4"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761471915188919*^9, 3.761471924789179*^9}, 
   3.7614720087042613`*^9, 3.7631138067557783`*^9, 3.763115549539934*^9, 
   3.7631155921021914`*^9, 3.763115870524472*^9, 3.763115933960049*^9, 
   3.7631212305267663`*^9, 
   3.7631218016372533`*^9},ExpressionUUID->"ed2e452b-e4cc-4575-940b-\
297609c26770"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Eqsij", "\[Equal]", "0"}], ",", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", "solres1"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.761471953831363*^9, 
  3.761472050359288*^9}},ExpressionUUID->"ad893a2e-dade-44d8-ab38-\
1e3d19913e34"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C4"}], " ", 
        RowBox[{"G4", "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{"C4", " ", 
     RowBox[{"G4", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.761471970979189*^9, 3.761472050833968*^9}, 
   3.7631138094659233`*^9, 3.7631155517814865`*^9, 3.763115593649844*^9, 
   3.763115872872836*^9, 3.763115935665164*^9, 3.763121238506923*^9, 
   3.763121803727137*^9},ExpressionUUID->"4f775161-aa2e-46d3-80cc-\
9da373498870"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eq00", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]\[Rho]DE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], ",", 
         RowBox[{"\[Delta]\[Rho]DE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.761471944799088*^9, {3.7614720568094683`*^9, 3.7614720965613728`*^9}, {
   3.7631158760098076`*^9, 3.763115877810362*^9}, 
   3.7631159378905425`*^9},ExpressionUUID->"f9407807-2ed4-4ad6-93b3-\
ec6f36d44e66"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"8", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"G4", "[", "t", "]"}]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", 
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"C3", "+", 
           RowBox[{"2", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["k", "2"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"A6", " ", "C3"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "C4"}], "+", 
              RowBox[{"2", " ", "A6", " ", 
               RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"A4", " ", "C4"}], "+", 
              RowBox[{"C3", " ", "\[Mu]"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Mu]", "+", 
                 RowBox[{"3", " ", "C4", " ", 
                  RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7614719460993567`*^9, 3.7614720657493687`*^9, 
  3.7614720971790533`*^9, 3.76311381721595*^9, 3.7631155563017883`*^9, 
  3.763115596749812*^9, 3.763115879100114*^9, 3.7631159390147943`*^9, 
  3.763121241389372*^9, 
  3.76312180592728*^9},ExpressionUUID->"565a4f37-26ec-4014-a70b-bda52b0222e9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eqii", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]PDE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", "0"}], 
         ",", 
         RowBox[{"\[Delta]PDE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.76147208348938*^9, 3.7614721029591475`*^9}, {
   3.7631158900225515`*^9, 3.7631158918101482`*^9}, 
   3.763115941560336*^9},ExpressionUUID->"34dfd719-f8d5-4c88-a77b-\
a0d5a8463686"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"24", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"G4", "[", "t", "]"}]}]], 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "B6"}], ")"}], " ", 
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["k", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B7", " ", "C3"}], "+", 
             RowBox[{"B6", " ", "C4"}], "-", 
             RowBox[{"B8", " ", "C4"}], "+", 
             RowBox[{"2", " ", "B7", " ", 
              RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B9", " ", "C4"}], "-", 
             RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
             RowBox[{"6", " ", 
              RowBox[{"H", "[", "t", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[Nu]", "-", 
                RowBox[{"3", " ", "C4", " ", 
                 RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
             RowBox[{"12", " ", "C4", " ", 
              RowBox[{
               SuperscriptBox["H", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761472078879323*^9, 3.7614721041992617`*^9}, 
   3.7631138199222736`*^9, 3.7631155701724977`*^9, 3.7631156120123816`*^9, 
   3.7631158934720345`*^9, 3.763115942599981*^9, 3.763121255126955*^9, 
   3.7631218084369545`*^9},ExpressionUUID->"dbd528bf-f22a-4de9-a42e-\
e5e064fbb5e3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"In", " ", "the", " ", "rest"}], "-", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{"\[Delta]PDE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
              RowBox[{"\[Delta]\[Rho]DE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", 
             "solres4"}], "/.", "solres3"}], "/.", 
           RowBox[{"B6", "\[Rule]", 
            RowBox[{"4", " ", 
             RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"B8", "\[Rule]", 
           RowBox[{"4", " ", 
            RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"A3", "\[Rule]", 
          RowBox[{"4", 
           RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
         RowBox[{"1", "/", "2"}]}]}], "/.", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["f_", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", "0"}]}],
     "//", "FullSimplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"cs2", "->", "%"}], "/.", 
            RowBox[{"C3", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "3"}], " ", 
               RowBox[{"G3X", "[", "t", "]"}]}], "-", 
              RowBox[{"4", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"G4", "[", "t", "]"}]}]}]}]}], "/.", 
           RowBox[{"A6", "\[Rule]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "2"}]}], " ", 
             RowBox[{"G3X", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"C4", "->", 
           RowBox[{
            RowBox[{
             RowBox[{"KX", "[", "t", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"G3X", "[", "t", "]"}], " ", 
             RowBox[{"H", "[", "t", "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Phi]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
         RowBox[{"B9", "->", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "18"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
           RowBox[{"12", " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "-", 
           RowBox[{"3", " ", 
            RowBox[{"KX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"12", " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"G3XX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
        RowBox[{"\[Nu]", "->", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
       RowBox[{"A4", "->", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"12", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "5"]}]}]}]}], "/.", 
      RowBox[{"\[Mu]", "->", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614721200917377`*^9, 3.7614721486394243`*^9}, {
   3.7614721804992604`*^9, 3.7614721918691998`*^9}, {3.7614722326390114`*^9, 
   3.7614722779989214`*^9}, {3.761472312289319*^9, 3.7614723190388966`*^9}, {
   3.7614723515292892`*^9, 3.761472368269771*^9}, {3.7614724032092724`*^9, 
   3.7614724857990074`*^9}, {3.7614727130217075`*^9, 
   3.7614727147291737`*^9}, {3.7614727687391253`*^9, 
   3.7614727795990305`*^9}, {3.7614728256989756`*^9, 3.761472830231369*^9}, {
   3.7614728609892225`*^9, 3.7614728632111177`*^9}, {3.761472893969224*^9, 
   3.761473009929489*^9}, {3.761473708378744*^9, 3.7614737373417807`*^9}, {
   3.7631158210000095`*^9, 3.7631158360302916`*^9}, 3.763115945350172*^9, {
   3.763121298017347*^9, 
   3.7631213054969654`*^9}},ExpressionUUID->"5a869a4c-5acb-4efa-b2ba-\
e4fd22e1e7ee"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"B9", " ", "C4"}], "-", 
     RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
     RowBox[{"6", " ", 
      RowBox[{"H", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Nu]", "-", 
        RowBox[{"3", " ", "C4", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "C4", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"3", " ", "A6", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"C3", "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A4", " ", "C4"}], "+", 
      RowBox[{"C3", " ", "\[Mu]"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", 
         RowBox[{"3", " ", "C4", " ", 
          RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 3.7631213071168237`*^9}, 
   3.7631218112219596`*^9},ExpressionUUID->"7e956214-ba78-404a-b061-\
789caeb4ec4d"],

Cell[BoxData[
 RowBox[{"cs2", "\[Rule]", "1"}]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 3.7631213071168237`*^9}, 
   3.7631218112292647`*^9},ExpressionUUID->"aaf0ccf5-1c4a-41e1-8f25-\
0b874c5e77a9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"In", " ", "a", " ", "general", " ", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"cs2gen", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Delta]PDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                    RowBox[{"\[Delta]\[Rho]DE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.",
                     "soldDE"}], "/.", "soldPDE"}], "/.", 
                    RowBox[{"B6", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B8", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"A3", "\[Rule]", 
                    RowBox[{"4", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B7", "\[Rule]", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}]}], "/.", 
                    RowBox[{
                    RowBox[{
                    SuperscriptBox["f_", 
                    TagBox[
                    RowBox[{"(", 
                    RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
                    Derivative],
                    MultilineFunction->None], "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                    "\[Rule]", "0"}]}], "/.", 
                    RowBox[{"C3", "\[Rule]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}]}], "/.", 
                    RowBox[{"A6", "\[Rule]", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                   RowBox[{"C4", "->", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                  RowBox[{"B9", "->", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "36"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
                 RowBox[{"\[Nu]", "->", 
                  RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
                RowBox[{"A4", "->", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", 
                   SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KXX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}]}]}]}], "/.", 
               RowBox[{"\[Mu]", "->", 
                RowBox[{"-", 
                 RowBox[{"K\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
              RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
             RowBox[{"D7", "\[Rule]", "0"}]}], "/.", 
            RowBox[{"M", "\[Rule]", 
             SqrtBox["M2"]}]}], "/.", 
           RowBox[{"M2", "\[Rule]", 
            RowBox[{"-", 
             RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"D9", "\[Rule]", 
           RowBox[{"-", 
            RowBox[{"KX", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"D11", "\[Rule]", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"KXXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
         RowBox[{
          RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
        "}"}]}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614756379174366`*^9, 3.76147568953691*^9}, {
   3.7614757263370914`*^9, 3.761475958304971*^9}, {3.761476048957116*^9, 
   3.7614760632469234`*^9}, {3.7614763452470846`*^9, 3.76147636870883*^9}, {
   3.7614764569268293`*^9, 3.761476458271467*^9}, {3.76147656326256*^9, 
   3.761476564859185*^9}, {3.7614766282267957`*^9, 3.761476692631748*^9}, {
   3.7614767336265616`*^9, 3.7614767480766664`*^9}, {3.761476783486722*^9, 
   3.7614768313469687`*^9}, {3.7614771328169327`*^9, 3.761477133236987*^9}, 
   3.761477402776991*^9, 3.763115827884598*^9, 3.763115912365671*^9, 
   3.7631159501848774`*^9, {3.763116027695698*^9, 3.763116052252181*^9}, {
   3.763121309557479*^9, 
   3.7631213164173107`*^9}},ExpressionUUID->"b6e20ce3-1167-4442-8d91-\
fa94be544aac"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.7614756472519145`*^9, 3.7614756926065903`*^9}, {
   3.761475740091787*^9, 3.7614758147669015`*^9}, 3.7614758539493217`*^9, {
   3.761475937031951*^9, 3.761475959253948*^9}, 3.761476065157156*^9, {
   3.7614763470866065`*^9, 3.761476353997134*^9}, {3.7614764480070596`*^9, 
   3.7614764599522624`*^9}, 3.761476565546674*^9, {3.76147664327186*^9, 
   3.761476670421854*^9}, {3.76147680656666*^9, 3.7614768317975225`*^9}, 
   3.7614771353316383`*^9, 3.7614774065766478`*^9, 3.763113840095704*^9, 
   3.763115624425024*^9, 3.7631158300199695`*^9, 3.763115913200203*^9, 
   3.7631159516602564`*^9, {3.7631160308620434`*^9, 3.7631160400904016`*^9}, 
   3.763121284941904*^9, 3.7631213192667665`*^9, 
   3.763121814972086*^9},ExpressionUUID->"9787ef98-1322-4ace-b5bd-\
224d3e1f6065"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"V", "[", "\[Phi]_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"m", "^", "2"}], " ", 
   RowBox[{"\[Phi]", "^", "2"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"cs2gen", "/.", 
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"X0", "+", 
       RowBox[{"V", "[", 
        RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}]}], "/.", 
    RowBox[{
     RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"V", "'"}], "[", 
      RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "/.", 
   RowBox[{
    RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"V", "''"}], "[", 
     RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"%", "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    RowBox[{"\[Epsilon]", " ", "m\[Phi]", " ", "\[Phi]"}]}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{"%", ",", 
   RowBox[{"{", 
    RowBox[{"k", ",", "\[Infinity]", ",", "4"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614774489467955`*^9, 3.7614779250165815`*^9}, {
  3.761477977411518*^9, 3.7614779948497677`*^9}, {3.7631139412058153`*^9, 
  3.763113942055827*^9}, {3.7631213526017084`*^9, 
  3.763121388307263*^9}},ExpressionUUID->"18fe73ec-25e7-4bf6-b45a-\
c4f76186742d"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 3.763121388956871*^9}, 
   3.763121821242169*^9},ExpressionUUID->"5d5bdf1f-c1fd-4dc0-a30b-\
060fe50ef7e6"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 3.763121388956871*^9}, 
   3.7631218212518415`*^9},ExpressionUUID->"d68711c6-2582-406e-aedb-\
460ad219b164"],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 3.763121388956871*^9}, 
   3.7631218212569637`*^9},ExpressionUUID->"2f973cae-367f-42e2-9680-\
c464ff2bc2bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"eq11", "/.", "zeroorder"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"1", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}],
    "/.", 
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
  RowBox[{
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
   "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"H", "'"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614770642968874`*^9, 
  3.761477126561428*^9}},ExpressionUUID->"d3fe69ce-3028-49b4-b32a-\
1a62ff0a5f62"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "2"], "+", 
  FractionBox[
   RowBox[{"K", "[", "t", "]"}], "2"], "+", 
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 3.7631213941771016`*^9, 
   3.763121824727173*^9},ExpressionUUID->"4674c9a1-40c4-4df4-8dc0-\
953a006d54f0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 3.7631213941771016`*^9, 
   3.763121824737344*^9},ExpressionUUID->"c30d2568-693d-4b3a-bdc9-\
b13ef6cf8125"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"scaleq", "/.", "zeroorder"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614759946317997`*^9, 3.761476039417528*^9}, {
  3.7614773827764387`*^9, 
  3.761477393256817*^9}},ExpressionUUID->"462fa6b9-2ccc-4fd6-ba43-\
2a6e4c61cb29"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270069256`*^9, 
   3.763121826917076*^9},ExpressionUUID->"64abe947-bdad-48a3-a839-\
11aa197a48d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270069256`*^9, 
   3.763121826932227*^9},ExpressionUUID->"78727c3f-1a19-4d46-82d5-\
b16349f257d4"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",ExpressionUUID->"2eddc90d-027e-428e-9eec-74b8d1204f8f"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Case", " ", "2", 
    RowBox[{"a", ":", " ", 
     RowBox[{
     "Effective", " ", "fluid", " ", "and", " ", "subhorizon", " ", "for", 
      " ", "KGB"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
    "flex", " ", "ES", " ", "version", " ", "with", " ", "our", " ", 
     "improvement"}], " ", "//", " ", 
    RowBox[{"better", " ", 
     RowBox[{"numerics", "?"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568075707836485`*^9, 3.7568075757622113`*^9}, {
   3.7568096497511396`*^9, 3.7568096534003925`*^9}, {3.759648846982213*^9, 
   3.7596488495525045`*^9}, {3.7631205055312815`*^9, 3.763120542849162*^9}, {
   3.7631209768868275`*^9, 3.763120983412758*^9}, {3.7631218607374253`*^9, 
   3.7631218643292313`*^9}, 3.763190390739437*^9, {3.7634558067399745`*^9, 
   3.7634558099803934`*^9}, {3.763462497371116*^9, 
   3.7634625005008593`*^9}},ExpressionUUID->"3b6742c7-8ed0-4b2f-85aa-\
abda3c8e9eb6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesKGB0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rulesKGB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "X"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"X", "^", "n"}]}]}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "1"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "->", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "3"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7568081983101892`*^9, 3.756808200860401*^9}, {
   3.756808599964323*^9, 3.756808600859193*^9}, 3.757923942100193*^9, {
   3.759648878369643*^9, 3.759648878635396*^9}, {3.7607934082599554`*^9, 
   3.7607934125992403`*^9}},ExpressionUUID->"1df053ca-ef77-4cd1-9561-\
72b021abb044"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dX0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ".", 
        "gUU", ".", 
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], 
      "-", "X0"}], "/.", "a2H"}], "//", "ApproxFullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"soldf", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"dX0", "\[Equal]", 
       RowBox[{"\[Delta]X", "[", "t", "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    SqrtBox[
     RowBox[{"2", "X"}]]}]}]}]}], "Input",
 CellChangeTimes->{
  3.7561141319764814`*^9, {3.7579239991243944`*^9, 
   3.7579240091742053`*^9}},ExpressionUUID->"13c1978d-4cf4-41d6-b29c-\
e2d00e33748b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]X", "[", "t", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.757924013239633*^9, 3.7584607175620537`*^9, {3.7595831281019588`*^9, 
   3.759583128801408*^9}, 3.759648882211532*^9, 3.7596621180996127`*^9, 
   3.7607063136389337`*^9, 3.7607064887891293`*^9, 3.760707315914773*^9, 
   3.760793455789051*^9, 3.7608602303957033`*^9, 3.760868850328183*^9, 
   3.760877403457257*^9, 3.760877524047437*^9, 3.7609545191368074`*^9, 
   3.760954565031988*^9, 3.760964283246402*^9, 3.7609651066335964`*^9, 
   3.760966651601708*^9, 3.7610284651348453`*^9, 3.7614714548842196`*^9, 
   3.7614755993269067`*^9, 3.762082048992428*^9, 3.7631009151678376`*^9, 
   3.7631009541881647`*^9, 3.763113583475541*^9, 3.763115144246414*^9, 
   3.7631205210067654`*^9, 3.7631218959471636`*^9, 3.7631339782618136`*^9, 
   3.7631344806359425`*^9},ExpressionUUID->"de66c80d-85a9-4c29-b0f4-\
1febec68ec64"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGRA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"A2", "\[Rule]", "0"}], ",", 
     RowBox[{"A3", "\[Rule]", "2"}], ",", 
     RowBox[{"A4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{"A5", "\[Rule]", "0"}], ",", 
     RowBox[{"A6", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B1", "\[Rule]", "6"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B3", "\[Rule]", 
      RowBox[{"18", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B4", "\[Rule]", "0"}], ",", 
     RowBox[{"B5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B6", "\[Rule]", "2"}], ",", 
     RowBox[{"B7", "\[Rule]", "0"}], ",", 
     RowBox[{"B8", "\[Rule]", "2"}], ",", 
     RowBox[{"B9", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "18"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
     RowBox[{"\[Nu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C1", "\[Rule]", "2"}], ",", 
     RowBox[{"C2", "\[Rule]", "0"}], ",", 
     RowBox[{"C3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"C4", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D1", "\[Rule]", "0"}], ",", 
     RowBox[{"D2", "\[Rule]", "0"}], ",", 
     RowBox[{"D3", "\[Rule]", "0"}], ",", 
     RowBox[{"D4", "\[Rule]", "0"}], ",", 
     RowBox[{"D5", "\[Rule]", "0"}], ",", 
     RowBox[{"D7", "\[Rule]", "0"}], ",", 
     RowBox[{"D8", "\[Rule]", "0"}], ",", 
     RowBox[{"D9", "\[Rule]", "0"}], ",", 
     RowBox[{"D10", "\[Rule]", "0"}], ",", 
     RowBox[{"D11", "\[Rule]", "0"}], ",", 
     RowBox[{"M", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRABCD", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"rulesGRA", ",", "rulesGRB", ",", "rulesGRC", ",", "rulesGRD"}], 
     "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7608774109275446`*^9, 3.760877515997035*^9}, {
   3.760877601947462*^9, 3.760877723817091*^9}, 3.760878178137457*^9, {
   3.760878406236206*^9, 3.7608784114662337`*^9}, {3.760964293131819*^9, 
   3.7609643313744884`*^9}},ExpressionUUID->"68f6549f-4509-4e36-b900-\
4f0cc0e98df4"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eq00", "=", 
   RowBox[{
    RowBox[{"A1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A3", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A4", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", "\[Mu]"}], ")"}], 
     " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqii", "=", 
   RowBox[{
    RowBox[{"B1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B6", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", 
       RowBox[{"3", "\[Nu]"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B8", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "B9"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eq0i", "=", 
   RowBox[{
    RowBox[{"C1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C3", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C4", " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
     SuperscriptBox["k", "2"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqsc", "=", 
   RowBox[{
    RowBox[{"D1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D8"}], ")"}], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D9", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"M", "^", "2"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D10", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D11"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.760871236957633*^9, 3.760871319127609*^9}, {
   3.7608713554071703`*^9, 3.760871572037525*^9}, 3.760871605627293*^9, 
   3.7608720233417673`*^9, {3.7608770922374477`*^9, 3.76087713384791*^9}, {
   3.7608772688874445`*^9, 3.7608772691494226`*^9}, {3.760877955181913*^9, 
   3.7608781114020014`*^9}, {3.760965230731535*^9, 
   3.7609652310438423`*^9}},ExpressionUUID->"4535e837-f4cc-48e6-81a8-\
a8fd75041a50"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs00", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq00", "/.", "rulesGRA"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Eqsii", "/.", "rulesGR"}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{"Eqii", "/.", "rulesGRB"}], ")"}]}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs0i", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq0i", "/.", "rulesGRC"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqscal", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eqsc", "/.", "rulesGRD"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7608777345270576`*^9, 3.760877842347237*^9}, 
   3.7608780039918804`*^9, 3.760878415551169*^9, {3.760878470640115*^9, 
   3.7608785600562253`*^9}},ExpressionUUID->"ba98ff57-4ec1-4074-9f55-\
e6753b0a2f49"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 
   3.763134485172575*^9},ExpressionUUID->"b7e4db5c-ec2e-4807-8a8d-\
ac0be6f8f4f9"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 
   3.763134485184766*^9},ExpressionUUID->"0ad7521c-454c-4e17-87cd-\
f0a26c296d74"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 
   3.763134485184766*^9},ExpressionUUID->"3e5fe15c-c963-432f-b76a-\
c589297743dd"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 
   3.7631344851928596`*^9},ExpressionUUID->"a7c86fa4-97a6-4e3a-97cb-\
d44e070f2ef1"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"subhorstrict", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A1", "\[Rule]", "0"}], ",", 
       RowBox[{"A2", "\[Rule]", "0"}], ",", 
       RowBox[{"A4", "\[Rule]", "0"}], ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0"}], ",", 
       RowBox[{"B1", "\[Rule]", "0"}], ",", 
       RowBox[{"B2", "\[Rule]", "0"}], ",", 
       RowBox[{"B3", "\[Rule]", "0"}], ",", 
       RowBox[{"B4", "\[Rule]", "0"}], ",", 
       RowBox[{"B5", "\[Rule]", "0"}], ",", 
       RowBox[{"\[Nu]", "\[Rule]", "0"}], ",", 
       RowBox[{"B9", "\[Rule]", "0"}], ",", 
       RowBox[{"D1", "\[Rule]", "0"}], ",", 
       RowBox[{"D2", "\[Rule]", "0"}], ",", 
       RowBox[{"D3", "\[Rule]", "0"}], ",", 
       RowBox[{"D4", "\[Rule]", "0"}], ",", 
       RowBox[{"D5", "\[Rule]", "0"}], ",", 
       RowBox[{"D8", "\[Rule]", "0"}], ",", 
       RowBox[{"D11", "\[Rule]", "0"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"subhorflex", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A1", "\[Rule]", "0"}], ",", 
      RowBox[{"A2", "\[Rule]", "0"}], ",", 
      RowBox[{"B1", "\[Rule]", "0"}], ",", 
      RowBox[{"B2", "\[Rule]", "0"}], ",", 
      RowBox[{"B3", "\[Rule]", "0"}], ",", 
      RowBox[{"B4", "\[Rule]", "0"}], ",", 
      RowBox[{"B5", "\[Rule]", "0"}], ",", 
      RowBox[{"C1", "\[Rule]", "0"}], ",", 
      RowBox[{"C2", "\[Rule]", "0"}], ",", 
      RowBox[{"D1", "\[Rule]", "0"}], ",", 
      RowBox[{"D2", "\[Rule]", "0"}], ",", 
      RowBox[{"D3", "\[Rule]", "0"}], ",", 
      RowBox[{"D4", "\[Rule]", "0"}], ",", 
      RowBox[{"D5", "\[Rule]", "0"}]}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.763120561226567*^9, 3.7631205712068496`*^9}, {
  3.76312193474724*^9, 
  3.763121943447171*^9}},ExpressionUUID->"1ea54654-f6a8-4934-8f2c-\
61508972cf82"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "potentials"}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"subhor", "=", "subhorflex"}], ";", 
    RowBox[{"solgen", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Eq00", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqii", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqsc", "\[Equal]", "0"}]}], "}"}], "/.", "subhor"}], "/.", 
          RowBox[{
           RowBox[{"\[Delta]Pm", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
           "0"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[CapitalPsi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[Delta]\[Phi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"solgen", "//", "TableForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7608716843173847`*^9, 3.760871870449571*^9}, {
   3.7608720053374634`*^9, 3.760872006777376*^9}, {3.760878197051565*^9, 
   3.7608782029572024`*^9}, {3.7608790453577843`*^9, 3.760879045865718*^9}, {
   3.760964405164853*^9, 3.7609645103018255`*^9}, {3.7609652605941057`*^9, 
   3.760965262471862*^9}, {3.760966739353032*^9, 3.760966739932638*^9}, {
   3.7609667897358575`*^9, 3.76096683365308*^9}, {3.7631136147260556`*^9, 
   3.7631136366483927`*^9}, {3.763115156776116*^9, 3.7631151673663273`*^9}, {
   3.7631206809169006`*^9, 3.76312070061677*^9}, 
   3.763121946937045*^9},ExpressionUUID->"ea9f8a0b-6818-49df-98a8-\
4bba87022ebd"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D10"}], "-", 
              RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "4"]}], "+", 
           RowBox[{
            SuperscriptBox["k", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D11"}], "-", 
              RowBox[{"B9", " ", "D9"}], "+", 
              RowBox[{"B8", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B9", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A6"}], " ", "B6", " ", "D10"}], "+", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "+", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "-", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "6"]}], "+", 
         RowBox[{
          SuperscriptBox["k", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
            RowBox[{"A6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D11"}], "+", 
               RowBox[{"B9", " ", "D7"}], "+", 
               RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
            RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
            RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
            RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
            RowBox[{"A3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D11"}], "-", 
               RowBox[{"B9", " ", "D9"}], "+", 
               RowBox[{"B8", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
            RowBox[{"A3", " ", "B9", " ", 
             SuperscriptBox["M", "2"]}], "+", 
            RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "-", 
            RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "-", 
            RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "+", 
            RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "-", 
            RowBox[{"A4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D8"}], "+", 
               RowBox[{"B6", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "4"]}], "-", 
         RowBox[{"D8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B9", " ", "\[Mu]"}], "+", 
            RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "6"]}]}]]}]},
     {
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "4"]}], "+", 
           RowBox[{
            SuperscriptBox["k", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D8"}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "6"]}], "-", 
         RowBox[{
          SuperscriptBox["k", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
            RowBox[{"A6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D11"}], "+", 
               RowBox[{"B9", " ", "D7"}], "+", 
               RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
            RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
            RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
            RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
            RowBox[{"A3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D11"}], "-", 
               RowBox[{"B9", " ", "D9"}], "+", 
               RowBox[{"B8", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "-", 
            RowBox[{"A3", " ", "B9", " ", 
             SuperscriptBox["M", "2"]}], "-", 
            RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
            RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "+", 
            RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "-", 
            RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "+", 
            RowBox[{"A4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D8"}], "+", 
               RowBox[{"B6", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
         RowBox[{"D8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B9", " ", "\[Mu]"}], "+", 
            RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "6"]}]}]]}]},
     {
      RowBox[{
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D10"}], "+", 
               RowBox[{"B8", " ", "D7"}]}], ")"}], " ", 
             SuperscriptBox["k", "4"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D11"}], "+", 
               RowBox[{"B9", " ", "D7"}], "+", 
               RowBox[{"B8", " ", "D8"}]}], ")"}], " ", 
             SuperscriptBox["k", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
            RowBox[{"B9", " ", "D8", " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
          RowBox[{"\[Delta]\[Rho]m", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
             RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
             RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
             RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
           SuperscriptBox["k", "6"]}], "-", 
          RowBox[{
           SuperscriptBox["k", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
             RowBox[{"A6", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "B6"}], " ", "D11"}], "+", 
                RowBox[{"B9", " ", "D7"}], "+", 
                RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
             RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
             RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
             RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
             RowBox[{"A3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D11"}], "-", 
                RowBox[{"B9", " ", "D9"}], "+", 
                RowBox[{"B8", " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
           " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "-", 
             RowBox[{"A3", " ", "B9", " ", 
              SuperscriptBox["M", "2"]}], "-", 
             RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
             RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "+", 
             RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "-", 
             RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "+", 
             RowBox[{"A4", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D8"}], "+", 
                RowBox[{"B6", " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
           " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
          RowBox[{"D8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B9", " ", "\[Mu]"}], "+", 
             RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "6"]}]}]]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7608717286971655`*^9, {3.7608718611915445`*^9, 3.760871871352357*^9}, {
   3.7608720076070447`*^9, 3.7608720260271597`*^9}, {3.760878191007273*^9, 
   3.760878204447015*^9}, 3.7608789370907774`*^9, 3.7608790463277893`*^9, 
   3.76095458366181*^9, 3.76096435408368*^9, {3.760964465561962*^9, 
   3.7609645113515034`*^9}, {3.7609652497418423`*^9, 3.7609652635475073`*^9}, 
   3.7609668374928026`*^9, 3.7610285102695513`*^9, 3.7614714737442923`*^9, 
   3.7614756089571514`*^9, 3.7620820882657003`*^9, 3.7631009673786554`*^9, {
   3.7631136325212173`*^9, 3.763113637630972*^9}, 3.763115176536146*^9, 
   3.7631205783068843`*^9, 3.7631207044668016`*^9, 3.7631219047171373`*^9, 
   3.7631219519168615`*^9, 3.7631339902792006`*^9, 
   3.763134491785532*^9},ExpressionUUID->"8cc8bab0-80cf-4b2e-a689-\
f9e545969e68"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Eta]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Eta]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206084091463`*^9, 3.763120641589445*^9}, {
  3.7631207138169174`*^9, 
  3.763120728343577*^9}},ExpressionUUID->"f965612a-ab56-4346-96f7-\
d245e4474a4b"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", 
       RowBox[{"(", 
        RowBox[{"D10", "-", "D7"}], ")"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"B6", "-", "B8"}], ")"}], " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", 
       RowBox[{"(", 
        RowBox[{"D11", "-", "D8"}], ")"}]}], "-", 
      RowBox[{"B9", " ", "D9"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"D10", "-", "D7"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"D11", "-", "D8"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D10"}], "-", 
      RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D11"}], "-", 
      RowBox[{"B9", " ", "D9"}], "+", 
      RowBox[{"B8", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}]]], "Output",
 CellChangeTimes->{{3.763120609582012*^9, 3.7631206420367975`*^9}, 
   3.763121923241412*^9, 3.763121955227069*^9, 
   3.76313449224269*^9},ExpressionUUID->"3b83d721-2a7f-4552-8210-\
2cbda89cefae"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Gamma]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Gamma]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206180173826`*^9, 3.7631206194184933`*^9}, {
  3.763120722997031*^9, 
  3.763120733766609*^9}},ExpressionUUID->"e70b37e6-820b-4271-8de0-\
95a67cfccc89"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D10"}], "-", 
      RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D11"}], "-", 
      RowBox[{"B9", " ", "D9"}], "+", 
      RowBox[{"B8", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D8"}], "+", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}]]], "Output",
 CellChangeTimes->{3.763120619816679*^9, 3.763121924921926*^9, 
  3.763121957747242*^9, 
  3.7631344930682316`*^9},ExpressionUUID->"5203fe39-8170-4220-96e3-\
4cab9d842998"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", 
    RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff"}], " ", "*)"}],
   " ", "\[IndentingNewLine]", 
  RowBox[{"Geff", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"k", "^", "2"}], 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]], 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], " ", "G", " ", "\[Pi]", " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], "/.", 
     RowBox[{"solgen", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763120736546857*^9, 
  3.7631207498276453`*^9}},ExpressionUUID->"953e392b-8e8a-405f-b4b3-\
54b77372172c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B7", " ", "D7"}], "-", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B7", " ", "D8"}], "+", 
         RowBox[{"B6", " ", 
          SuperscriptBox["M", "2"]}], "+", 
         RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "A6"}], " ", "B6", " ", "D10"}], "+", 
       RowBox[{"A3", " ", "B7", " ", "D10"}], "+", 
       RowBox[{"A6", " ", "B8", " ", "D7"}], "-", 
       RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
       RowBox[{"A6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "B6"}], " ", "D11"}], "+", 
          RowBox[{"B9", " ", "D7"}], "+", 
          RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
       RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
       RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
       RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
       RowBox[{"A3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B7", " ", "D11"}], "-", 
          RowBox[{"B9", " ", "D9"}], "+", 
          RowBox[{"B8", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
       RowBox[{"A3", " ", "B9", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "-", 
       RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "-", 
       RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "-", 
       RowBox[{"A4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B7", " ", "D8"}], "+", 
          RowBox[{"B6", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}], "-", 
    RowBox[{"D8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B9", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7631206655067053`*^9, 3.7631207506888466`*^9, 
  3.76312192631944*^9, 3.763121960336917*^9, 
  3.7631344953209963`*^9},ExpressionUUID->"1f1d7751-0cfe-4a55-900e-\
3ca471bbb00c"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Ruben", "'"}], "s", " ", "effective", " ", 
   RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff", " ", "from", 
   " ", "the", " ", "paper"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631207729569917`*^9, 3.7631207857019873`*^9}, 
   3.763121965797014*^9},ExpressionUUID->"2527de26-1d6f-426f-bc22-\
ab5f543ee511"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GeffRub", "=", 
   FractionBox[
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B6", " ", "D9"}], "-", 
          RowBox[{"B7", "^", "2"}]}], ")"}], 
        FractionBox[
         SuperscriptBox["k", "2"], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"B6", " ", 
        SuperscriptBox["M", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A6", "^", "2"}], " ", "B6"}], "+", 
        RowBox[{
         RowBox[{"B6", "^", "2"}], "D9"}], "-", 
        RowBox[{"2", "A6", " ", "B7", " ", "B6"}]}], ")"}], 
      FractionBox[
       SuperscriptBox["k", "2"], 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
     RowBox[{
      RowBox[{"B6", "^", "2"}], " ", 
      RowBox[{"M", "^", "2"}]}]}]]}], ";"}]], "Input",ExpressionUUID->\
"2514a609-4573-45c2-9147-a12fe146bf3f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "f", 
    RowBox[{"(", "R", ")"}], " ", "limit"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fRlimit", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "2"}], 
         RowBox[{"\[Phi]", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], 
       ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "Rr"}], "2"]}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "1"}], 
         RowBox[{"2", " ", "fRR"}]]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fRextra", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["M", "2"], "\[Rule]", 
        FractionBox["1", 
         RowBox[{"2", " ", "fRR"}]]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fR", "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fRR", "\[Rule]", 
        RowBox[{"m", " ", "F"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"F", "'"}], "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "->", 
        RowBox[{
         RowBox[{"F", "''"}], "[", "t", "]"}]}]}], "}"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.763120798989036*^9, 3.7631208072669797`*^9}, {
  3.7631211354571056`*^9, 
  3.7631211447892885`*^9}},ExpressionUUID->"1be3489b-5bf0-4792-bf07-\
94cc7980c5db"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Eliminate", " ", "\[Delta]\[Phi]", " ", "and", " ", 
    RowBox[{"it", "'"}], "s", " ", "derivatives", " ", "to", " ", "improve", 
    " ", "accuracy"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"soldfn", "=", 
    RowBox[{"Flatten", "[", 
     RowBox[{
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"D", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{"Eqsij", "\[Equal]", "0"}], ",", 
             RowBox[{"\[Delta]\[Phi]", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
           "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"t", ",", "n"}], "}"}]}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"n", ",", "0", ",", "2"}], "}"}]}], "]"}], "/.", "rules"}], 
     "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.763120836316975*^9, 
  3.7631208630569916`*^9}},ExpressionUUID->"452f122d-fbfe-4943-8919-\
17744873e469"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "quantities"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"soldPDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Eqii", "-", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{
                  RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
                   RowBox[{"\[Delta]PDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+",
                   "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", 
              "0"}], ",", 
             RowBox[{"\[Delta]PDE", "[", 
              RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], 
           "[", 
           RowBox[{"[", "1", "]"}], "]"}], "/.", "soldfn"}], "/.", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f_", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
          "0"}]}], "/.", "horizon1"}], "/.", "solgen"}], "//", 
      "FullSimplify"}]}], ";", 
    RowBox[{"soldDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Eq00", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
                  RowBox[{"\[Delta]\[Rho]DE", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
                 "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{"\[Delta]\[Rho]DE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", "soldfn"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"solVDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Eq0i", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 FractionBox[
                  RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
                   RowBox[{"a", "[", "t", "]"}], 
                   RowBox[{"VDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
                   RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
                  SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", 
                "rulesGRC"}], ")"}]}], "\[Equal]", "0"}], ",", 
            RowBox[{"VDE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", "soldfn"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.76312089191674*^9, 3.763120918757121*^9}, {
  3.7631341074602857`*^9, 3.76313411217957*^9}, {3.763134400368019*^9, 
  3.7631344032729635`*^9}},ExpressionUUID->"99e3b531-add1-437d-a90a-\
4555f7aafd49"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"The", " ", "KGB", " ", "limit"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631209397866125`*^9, 3.7631209459418736`*^9}, {
  3.763121010101895*^9, 
  3.7631210112500215`*^9}},ExpressionUUID->"14ad0a32-e8bd-49da-82b5-\
28e85c643575"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"solgen", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "/.", "subhor"}], "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7609546600619273`*^9, 3.760954664466791*^9}, {
   3.760966857372764*^9, 3.760966857623056*^9}, 
   3.763115173256571*^9},ExpressionUUID->"cf61a379-2655-4ec4-905b-\
caa8f910b475"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Delta]\[Phi]", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B6", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "A6"}], "+", "B7"}], ")"}], " ", 
          SuperscriptBox["k", "4"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B7", " ", "B9"}], "+", 
            RowBox[{"B6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D11"}], "+", "D8"}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"B9", " ", "D8", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
       RowBox[{"\[Delta]\[Rho]m", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B6", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["A6", "2"], "-", 
          RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
          RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
        SuperscriptBox["k", "6"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A4", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["B7", "2"], "-", 
             RowBox[{"B6", " ", "D9"}]}], ")"}]}], "+", 
          RowBox[{"B6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "B7"}], " ", "D11"}], "+", 
             RowBox[{"B9", " ", "D9"}], "-", 
             RowBox[{"B6", " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{"B7", " ", "\[Mu]"}]}], ")"}]}], "-", 
          RowBox[{"A6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B7", " ", "B9"}], "+", 
             RowBox[{"B6", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D11"}], "+", "D8", "+", "\[Mu]", "+", 
                RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}]}], ")"}], 
        " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "+", 
          RowBox[{"A4", " ", "B6", " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"B6", " ", "B9", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"B7", " ", "B9", " ", "\[Mu]"}], "-", 
          RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
          RowBox[{"B6", " ", "D8", " ", "\[Mu]"}], "-", 
          RowBox[{"3", " ", "B6", " ", "D11", " ", "\[Nu]"}], "+", 
          RowBox[{"A4", " ", "B7", " ", 
           RowBox[{"(", 
            RowBox[{"D8", "+", 
             RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
       RowBox[{"D8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B9", " ", "\[Mu]"}], "+", 
          RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}], ")"}]}]}]], "Output",\

 CellChangeTimes->{{3.7609644972316685`*^9, 3.76096452140153*^9}, 
   3.760965267881686*^9, 3.760966858712723*^9, 3.761028528340328*^9, 
   3.7614714740090947`*^9, 3.7631009778543415`*^9, 3.7631136442211275`*^9, 
   3.7631151783760886`*^9, 3.763121017667138*^9, 3.763122005608285*^9, 
   3.763134542914866*^9},ExpressionUUID->"61e3ee29-59e2-453f-8e15-\
a130d951082c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608721634777718`*^9, 3.760872183439308*^9}, 
   3.7608722185270576`*^9, {3.760872271117173*^9, 3.7608722728772163`*^9}, {
   3.7608725066403027`*^9, 3.7608725068252964`*^9}, {3.7608782109070044`*^9, 
   3.7608782132468443`*^9}, {3.760954695182067*^9, 3.76095471970185*^9}, 
   3.760954754834016*^9, {3.7609668631930323`*^9, 3.7609668717226267`*^9}, 
   3.763115174916142*^9, {3.763121025736691*^9, 
   3.7631210366271324`*^9}},ExpressionUUID->"5844e075-faf3-4a25-a278-\
e9812e5d9829"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"A6", "-", "B7"}], ")"}], " ", "B7", " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "B9"}], " ", "D9"}], "+", 
      RowBox[{"B7", " ", 
       RowBox[{"(", 
        RowBox[{"D11", "-", "D8", "-", 
         RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}], "+", 
      RowBox[{"3", " ", "A6", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"D11", "-", "D8"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D11"}], "-", 
      RowBox[{"B9", " ", "D9"}], "+", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "A6", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}]]], "Output",
 CellChangeTimes->{
  3.7608782163370647`*^9, 3.760878939305962*^9, {3.7609546827516994`*^9, 
   3.760954720461788*^9}, 3.760954755682119*^9, 3.760964524526888*^9, 
   3.7609652695817666`*^9, {3.7609668643429146`*^9, 3.760966873672986*^9}, 
   3.7610285303769536`*^9, 3.7631009799055977`*^9, 3.763113646616123*^9, 
   3.7631151797660885`*^9, {3.7631210199111567`*^9, 3.7631210374269714`*^9}, 
   3.7631220058768663`*^9, 
   3.763134543160547*^9},ExpressionUUID->"27413244-3642-44c5-a91a-\
449396d799c9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.760872517388804*^9, 3.7608725507370615`*^9}, {
   3.7608782231496954`*^9, 3.7608782248921795`*^9}, {3.7609547620619287`*^9, 
   3.7609547725885253`*^9}, 3.760966876112828*^9, 3.76311518170636*^9, 
   3.763121039861877*^9},ExpressionUUID->"ed6e86d5-3825-48c1-9a1b-\
875673faa803"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D11"}], "-", 
      RowBox[{"B9", " ", "D9"}], "+", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "A6", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["B7", "2"], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"B7", " ", 
       RowBox[{"(", 
        RowBox[{"D8", "+", 
         RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}]]], "Output",
 CellChangeTimes->{{3.760872520881508*^9, 3.760872551269845*^9}, 
   3.760878225431428*^9, {3.760954741811887*^9, 3.760954772871746*^9}, 
   3.760964526241928*^9, 3.76096527069625*^9, 3.760966876882693*^9, 
   3.7610285314106803`*^9, 3.763100981323767*^9, 3.7631136477479143`*^9, 
   3.7631151824566355`*^9, 3.7631210407768707`*^9, 3.7631220060269938`*^9, 
   3.7631345432404466`*^9},ExpressionUUID->"e068f215-9fc2-440b-937b-\
02e33cc6d0fd"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Geff", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608720490497875`*^9, 3.7608720761673555`*^9}, 
   3.7608782283273168`*^9, 3.7609547823420057`*^9, {3.7609668940274115`*^9, 
   3.760966914512579*^9}, {3.7631136608859067`*^9, 3.763113661376213*^9}, 
   3.7631210448890667`*^9},ExpressionUUID->"0392ce72-2094-4459-9d69-\
0c9f1fc09ebd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["B7", "2"], "-", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B6", " ", 
          SuperscriptBox["M", "2"]}], "+", 
         RowBox[{"B7", " ", 
          RowBox[{"(", 
           RowBox[{"D8", "+", 
            RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "B6"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["A6", "2"], "-", 
       RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
       RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", "B7", " ", "B9"}], "+", 
       RowBox[{"A4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["B7", "2"]}], "+", 
          RowBox[{"B6", " ", "D9"}]}], ")"}]}], "+", 
       RowBox[{"B6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "B9"}], " ", "D9"}], "+", 
          RowBox[{"B6", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"B7", " ", 
           RowBox[{"(", 
            RowBox[{"D11", "-", "\[Mu]"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"A6", " ", "B6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "D11"}], "+", "D8", "+", "\[Mu]", "+", 
          RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
       RowBox[{"B6", " ", "B9", " ", 
        SuperscriptBox["M", "2"]}], "-", 
       RowBox[{"B7", " ", "B9", " ", "\[Mu]"}], "+", 
       RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "-", 
       RowBox[{"B6", " ", "D8", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "B6", " ", "D11", " ", "\[Nu]"}], "-", 
       RowBox[{"A4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B6", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"B7", " ", 
           RowBox[{"(", 
            RowBox[{"D8", "+", 
             RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}], "-", 
    RowBox[{"D8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B9", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.7608720496015744`*^9, 3.760872081867358*^9}, 
   3.7608782296972866`*^9, {3.7609547767217216`*^9, 3.7609547830420494`*^9}, 
   3.760964530741832*^9, 3.7609652723740387`*^9, {3.760966906382824*^9, 
   3.760966916062399*^9}, 3.761028535682231*^9, 3.761471479878995*^9, 
   3.7620820962753325`*^9, 3.763100984211653*^9, {3.7631136524657965`*^9, 
   3.76311366215584*^9}, 3.763115187816374*^9, 3.763121046146944*^9, 
   3.763122007246956*^9, 
   3.763134544854813*^9},ExpressionUUID->"3bfb029c-4bed-4d3a-87f4-\
2624349aad4c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"solVDE", "/.", 
           RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
        RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
       RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
    RowBox[{"M", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7614715093614264`*^9, 3.761471529839512*^9}, 
   3.761471622774027*^9, 3.7631210561473184`*^9, {3.763122085747472*^9, 
   3.7631221019373255`*^9}},ExpressionUUID->"6d240573-f5a0-4cc3-864e-\
9d13fd12482c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{"D9", " ", 
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"B9", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"C4", " ", 
           RowBox[{"G4", "[", "t", "]"}], " ", 
           RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "+", 
          RowBox[{"C2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox[
              RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], "-", 
             RowBox[{
              RowBox[{"G4", "[", "t", "]"}], " ", 
              RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
      ")"}]}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["A6", "2"], "+", 
          RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
        SuperscriptBox["k", "4"]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A6", " ", 
           RowBox[{"(", 
            RowBox[{"D11", "-", "D8"}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", "D9"}]}], ")"}], 
        " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"A6", " ", "B9", " ", "D8", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614715103143363`*^9, 3.761471530249116*^9}, 
   3.7614716234468727`*^9, 3.761475623436673*^9, 3.762082247279933*^9, 
   3.7631137789961405`*^9, 3.763115417160034*^9, 3.7631210570470114`*^9, 
   3.763122019117032*^9, {3.76312209051744*^9, 3.763122103024601*^9}, 
   3.7631345452307105`*^9},ExpressionUUID->"6cd3c66b-04de-4f2e-ad9b-\
4e4161a6a8a6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"solVDE", "/.", 
          RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
        RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
       RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.760967170912757*^9, 3.7609671756729927`*^9}, {
   3.7609672170710683`*^9, 3.760967268572739*^9}, {3.7609673456627393`*^9, 
   3.760967355482613*^9}, 
   3.763121079797018*^9},ExpressionUUID->"e11a459b-8e3d-4372-9bd4-\
82262c230d03"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "D9"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{"C3", "+", 
           RowBox[{"2", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{"B9", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C4", " ", 
            RowBox[{"G4", "[", "t", "]"}], " ", 
            RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "+", 
           RowBox[{"C2", " ", 
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], "-", 
              RowBox[{
               RowBox[{"G4", "[", "t", "]"}], " ", 
               RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}]}]}], ")"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
       ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["A6", "2"], "+", 
           RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", 
            RowBox[{"(", 
             RowBox[{"D11", "-", "D8"}], ")"}]}], "-", 
           RowBox[{"A4", " ", "D9"}], "+", 
           RowBox[{"B9", " ", "D9"}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["M", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", 
            SuperscriptBox["M", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Rho]DE", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7609672099178877`*^9, 3.760967270222868*^9}, {
   3.7609673521427126`*^9, 3.7609673562526836`*^9}, 3.76102860194715*^9, 
   3.7614756243818407`*^9, 3.763113782415992*^9, 3.7631154205899687`*^9, 
   3.7631210871609144`*^9, 3.7631221130673704`*^9, 
   3.7631345456979804`*^9},ExpressionUUID->"df2436ec-a885-4af6-90e5-\
a20c5707d776"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"soldPDE", "/.", 
            RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
           RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
        RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
     RowBox[{"B6", "\[Rule]", "2"}]}], "/.", 
    RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"M", "\[Rule]", "0"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", "subhor"}]}], "Input",
 CellChangeTimes->{{3.760967419262813*^9, 3.7609674497562037`*^9}, {
  3.760967526613056*^9, 3.7609675736426086`*^9}, {3.7609676630048027`*^9, 
  3.7609676646630898`*^9}, {3.7609677596250677`*^9, 3.7609677612924557`*^9}, {
  3.763121100677089*^9, 
  3.763121112486868*^9}},ExpressionUUID->"3715e23a-59c1-41d5-a4d4-\
af81ea9d1269"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"B9", " ", "D9", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"B2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "2"], " ", 
         RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
        RowBox[{"2", " ", "B2", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"G4", "[", "t", "]"}], " ", 
         SuperscriptBox[
          RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "2"], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"G4", "[", "t", "]"}], " ", 
         RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B4", " ", 
            RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{"B2", " ", 
            RowBox[{
             SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], "-", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", 
            SuperscriptBox["k", "2"]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B4", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}], "+", 
              RowBox[{"B2", " ", 
               RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"6", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["A6", "2"], "+", 
           RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "D11"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", "D9"}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
      SuperscriptBox[
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "3"]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 3.763122115661138*^9, 
   3.763134546033098*^9},ExpressionUUID->"9ac215c1-7af3-40ca-969d-\
7220aca83078"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B9", " ", "D9", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["A6", "2"], "+", 
           RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "D11"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", "D9"}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 3.763122115661138*^9, 
   3.7631345460439477`*^9},ExpressionUUID->"2cc1097d-0c60-479a-9f35-\
acfdd0367f20"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.763115082136239*^9, 
  3.7631151022566075`*^9}},ExpressionUUID->"90aa5eee-1d8a-4f2a-9686-\
346e3ee97194"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Coefficients", " ", "//", " ", 
   RowBox[{"run", " ", "this"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.76311405695595*^9, 3.7631140621959715`*^9}, {
  3.763114114611548*^9, 
  3.7631141167663727`*^9}},ExpressionUUID->"cd2f591a-edd4-4804-9396-\
80b9f5279a22"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", 
     "\[Mu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}]}], ",", "0", ",", 
     
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", "B7", 
     ",", "B8", ",", "B9", ",", "\[Nu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"36", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "36"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"C1", ",", "C2", ",", "C3", ",", "C4"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", "D7", ",", "D8", 
     ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"5", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7610287424727*^9, 3.761028748984979*^9}, {
  3.7631140663258605`*^9, 
  3.763114090298678*^9}},ExpressionUUID->"9d09c3e2-5112-4b17-822c-\
e591f7727538"],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631140943260336`*^9, 
  3.763114096275912*^9}},ExpressionUUID->"9c30b70a-1285-4bbf-9ab8-\
1fa799e0413e"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Geff", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{"Rr", "\[Rule]", "0"}], ",", 
      RowBox[{"fRR", "\[Rule]", "FR"}], ",", 
      RowBox[{
       RowBox[{"F", "[", "t", "]"}], "\[Rule]", "F"}]}], "}"}]}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7631211585671844`*^9, 3.7631211623070984`*^9}, {
  3.763122148417503*^9, 
  3.763122169989927*^9}},ExpressionUUID->"ff728b24-3b00-42cf-8761-\
655108d67a34"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", "2"],
    "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "4"], " ", "m"}]}], 
  RowBox[{
   RowBox[{
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
        "2"], " ", "m"}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
        "2"], " ", "m"}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}]]], "Output",
 CellChangeTimes->{
  3.7631211630169344`*^9, {3.7631221233171396`*^9, 3.7631221709372015`*^9}, 
   3.7631345518872576`*^9},ExpressionUUID->"360cb171-2571-4f90-8b6f-\
0c83c348ab40"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GeffRub", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.763101809150457*^9, 3.7631018648961973`*^9}, {
   3.763101905329755*^9, 3.763101962609453*^9}, {3.7631020677421107`*^9, 
   3.763102068004221*^9}, 3.763113690547677*^9, 3.763113734057954*^9, 
   3.7631143547364793`*^9, {3.7631154529200172`*^9, 
   3.763115454515036*^9}},ExpressionUUID->"1ad193fd-bc60-4d5e-88f8-\
a97591b879d0"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m"}], "+", 
   RowBox[{"F", "[", "t", "]"}]}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m", " ", 
    RowBox[{"F", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{"F", "[", "t", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.7631018109898095`*^9, 3.7631018662119465`*^9}, 
   3.763101919909732*^9, {3.7631019566797557`*^9, 3.7631019631693273`*^9}, 
   3.7631020722108507`*^9, 3.763102140246998*^9, 3.763113735270893*^9, 
   3.7631141615961914`*^9, {3.7631143508882236`*^9, 3.7631143783025227`*^9}, 
   3.7631151078864684`*^9, {3.7631154501800623`*^9, 3.7631154551422105`*^9}, 
   3.7631164377034683`*^9, 3.763121152956889*^9, 3.7631221353275175`*^9, 
   3.763134559392063*^9},ExpressionUUID->"e1679e84-64db-478b-9c93-\
b2e0b6c12f2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "expressions"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "They", " ", "do", " ", "not", " ", "agree", " ", "with", " ", "our", " ", 
    "f", 
    RowBox[{"(", "R", ")"}], " ", "effective", " ", "paper"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldPDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"solVDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763114134611041*^9, 3.7631142372359266`*^9}, 
   3.763114314426009*^9, {3.7631143821659684`*^9, 3.7631143908180556`*^9}, {
   3.763115503160205*^9, 3.763115504292551*^9}, {3.7631164227035484`*^9, 
   3.763116429662382*^9}, {3.763116539281295*^9, 3.7631165461681833`*^9}, {
   3.7631211692867537`*^9, 3.763121212807345*^9}, {3.7631345631767197`*^9, 
   3.763134564076066*^9}},ExpressionUUID->"e27303e9-3738-4176-acc6-\
36f39bbe1544"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "FR", " ", 
        SuperscriptBox["k", "6"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"F", "[", "t", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["F", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"6", " ", 
      SuperscriptBox["k", "4"], " ", 
      RowBox[{"F", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 3.7631221899372272`*^9, 
   3.7631345670643315`*^9},ExpressionUUID->"859d81ee-903c-4cf7-a095-\
7950fe754a1f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "FR", " ", 
        SuperscriptBox["k", "4"]}], "-", 
       RowBox[{"6", " ", "FR", " ", 
        SuperscriptBox["k", "4"], " ", 
        RowBox[{"F", "[", "t", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"F", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"F", "[", "t", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"F", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"F", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 3.7631221899372272`*^9, 
   3.7631345672247467`*^9},ExpressionUUID->"bfa62020-a1d6-464f-9bec-\
89979d887823"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["F", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "FR", " ", 
        SuperscriptBox["k", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"F", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 3.7631221899372272`*^9, 
   3.763134567325906*^9},ExpressionUUID->"6df6433a-f1ca-4408-9db7-\
7456bd58b002"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",ExpressionUUID->"5d4fe59d-d493-4ab1-99d1-a809c4c7f4dc"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Sound", " ", "speed", " ", "in", " ", "rest", " ", 
   RowBox[{"frame", "?"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7614725513993692`*^9, 
  3.761472564159005*^9}},ExpressionUUID->"3a354455-7ae9-4a27-b55c-\
9b5094582f95"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Eq0i", "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
            RowBox[{"a", "[", "t", "]"}], 
            RowBox[{"VDE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
            RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
           SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", "rulesGRC"}], 
        ")"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"VDE", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "/.", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f_", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.7631158554198527`*^9, 3.7631158618197684`*^9}, 
   3.7631159267299547`*^9},ExpressionUUID->"a1042f49-5b6c-45c8-9d2e-\
d96c39ac1206"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C4", " ", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"C3", " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.76147188603936*^9, 3.7631138043759212`*^9, 3.763115541862115*^9, 
   3.7631155897951345`*^9, {3.763115859190098*^9, 3.7631158626502314`*^9}, 
   3.7631159277401032`*^9, 3.7631212287267866`*^9, 3.7631222006817904`*^9, 
   3.7631345716947403`*^9},ExpressionUUID->"efe709e2-c9f3-4106-876c-\
6e6b43db37ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"C4", " ", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"C3", " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7614718970391417`*^9, 3.761471924311453*^9}, {
  3.7614720011495757`*^9, 
  3.7614720080296535`*^9}},ExpressionUUID->"30435000-20eb-4d18-b23c-\
6176a42a8153"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C3", "+", 
        RowBox[{"2", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "C4"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761471915188919*^9, 3.761471924789179*^9}, 
   3.7614720087042613`*^9, 3.7631138067557783`*^9, 3.763115549539934*^9, 
   3.7631155921021914`*^9, 3.763115870524472*^9, 3.763115933960049*^9, 
   3.7631212305267663`*^9, 3.7631222038875384`*^9, 3.763134007571133*^9, 
   3.7631345734110546`*^9},ExpressionUUID->"ce342065-001f-4877-83db-\
ed947c121ce5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Eqsij", "\[Equal]", "0"}], ",", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", "solres1"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.761471953831363*^9, 
  3.761472050359288*^9}},ExpressionUUID->"f7ac7a96-7196-4312-9578-\
ddbd1fd1966b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C4"}], " ", 
        RowBox[{"G4", "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{"C4", " ", 
     RowBox[{"G4", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.761471970979189*^9, 3.761472050833968*^9}, 
   3.7631138094659233`*^9, 3.7631155517814865`*^9, 3.763115593649844*^9, 
   3.763115872872836*^9, 3.763115935665164*^9, 3.763121238506923*^9, 
   3.763122205057131*^9, 3.763134009187193*^9, 
   3.763134574640809*^9},ExpressionUUID->"11380286-d8df-4ded-85f9-\
9d9e83ac7283"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eq00", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]\[Rho]DE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], ",", 
         RowBox[{"\[Delta]\[Rho]DE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.761471944799088*^9, {3.7614720568094683`*^9, 3.7614720965613728`*^9}, {
   3.7631158760098076`*^9, 3.763115877810362*^9}, 
   3.7631159378905425`*^9},ExpressionUUID->"53bca740-71c2-4b6a-9bed-\
ad9f4f012176"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"8", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"G4", "[", "t", "]"}]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", 
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"C3", "+", 
           RowBox[{"2", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["k", "2"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"A6", " ", "C3"}], "+", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "C4"}], "+", 
              RowBox[{"2", " ", "A6", " ", 
               RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"A4", " ", "C4"}], "+", 
              RowBox[{"C3", " ", "\[Mu]"}], "+", 
              RowBox[{"2", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Mu]", "+", 
                 RowBox[{"3", " ", "C4", " ", 
                  RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7614719460993567`*^9, 3.7614720657493687`*^9, 
  3.7614720971790533`*^9, 3.76311381721595*^9, 3.7631155563017883`*^9, 
  3.763115596749812*^9, 3.763115879100114*^9, 3.7631159390147943`*^9, 
  3.763121241389372*^9, 3.7631222073864717`*^9, 3.7631340114093285`*^9, 
  3.763134575916328*^9},ExpressionUUID->"77ef84f7-89f7-414e-8a68-\
a0d3cf358f48"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eqii", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]PDE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", "0"}], 
         ",", 
         RowBox[{"\[Delta]PDE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.76147208348938*^9, 3.7614721029591475`*^9}, {
   3.7631158900225515`*^9, 3.7631158918101482`*^9}, 
   3.763115941560336*^9},ExpressionUUID->"afa19171-1b49-4051-9ac1-\
0cd7294bb20a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", 
     RowBox[{"24", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"G4", "[", "t", "]"}]}]], 
    RowBox[{
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "B6"}], ")"}], " ", 
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["k", "2"]}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B7", " ", "C3"}], "+", 
             RowBox[{"B6", " ", "C4"}], "-", 
             RowBox[{"B8", " ", "C4"}], "+", 
             RowBox[{"2", " ", "B7", " ", 
              RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B9", " ", "C4"}], "-", 
             RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
             RowBox[{"6", " ", 
              RowBox[{"H", "[", "t", "]"}], " ", 
              RowBox[{"(", 
               RowBox[{"\[Nu]", "-", 
                RowBox[{"3", " ", "C4", " ", 
                 RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
             RowBox[{"12", " ", "C4", " ", 
              RowBox[{
               SuperscriptBox["H", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
         ")"}]}]}], ")"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761472078879323*^9, 3.7614721041992617`*^9}, 
   3.7631138199222736`*^9, 3.7631155701724977`*^9, 3.7631156120123816`*^9, 
   3.7631158934720345`*^9, 3.763115942599981*^9, 3.763121255126955*^9, 
   3.763122209486991*^9, 3.763134013940463*^9, 
   3.7631345778300047`*^9},ExpressionUUID->"b0cb9dab-9738-4d1d-8b88-\
8ceedf8be126"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"In", " ", "the", " ", "rest"}], "-", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{"\[Delta]PDE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
              RowBox[{"\[Delta]\[Rho]DE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", 
             "solres4"}], "/.", "solres3"}], "/.", 
           RowBox[{"B6", "\[Rule]", 
            RowBox[{"4", " ", 
             RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"B8", "\[Rule]", 
           RowBox[{"4", " ", 
            RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"A3", "\[Rule]", 
          RowBox[{"4", 
           RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
         RowBox[{"1", "/", "2"}]}]}], "/.", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", "subhorflex"}], "//", 
    "FullSimplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"cs2", "->", "%"}], "/.", 
            RowBox[{"C3", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "3"}], " ", 
               RowBox[{"G3X", "[", "t", "]"}]}], "-", 
              RowBox[{"4", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"G4", "[", "t", "]"}]}]}]}]}], "/.", 
           RowBox[{"A6", "\[Rule]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "2"}]}], " ", 
             RowBox[{"G3X", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"C4", "->", 
           RowBox[{
            RowBox[{
             RowBox[{"KX", "[", "t", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"G3X", "[", "t", "]"}], " ", 
             RowBox[{"H", "[", "t", "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Phi]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
         RowBox[{"B9", "->", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "18"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
           RowBox[{"12", " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "-", 
           RowBox[{"3", " ", 
            RowBox[{"KX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"12", " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"G3XX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
        RowBox[{"\[Nu]", "->", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
       RowBox[{"A4", "->", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"12", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "5"]}]}]}]}], "/.", 
      RowBox[{"\[Mu]", "->", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614721200917377`*^9, 3.7614721486394243`*^9}, {
   3.7614721804992604`*^9, 3.7614721918691998`*^9}, {3.7614722326390114`*^9, 
   3.7614722779989214`*^9}, {3.761472312289319*^9, 3.7614723190388966`*^9}, {
   3.7614723515292892`*^9, 3.761472368269771*^9}, {3.7614724032092724`*^9, 
   3.7614724857990074`*^9}, {3.7614727130217075`*^9, 
   3.7614727147291737`*^9}, {3.7614727687391253`*^9, 
   3.7614727795990305`*^9}, {3.7614728256989756`*^9, 3.761472830231369*^9}, {
   3.7614728609892225`*^9, 3.7614728632111177`*^9}, {3.761472893969224*^9, 
   3.761473009929489*^9}, {3.761473708378744*^9, 3.7614737373417807`*^9}, {
   3.7631158210000095`*^9, 3.7631158360302916`*^9}, 3.763115945350172*^9, {
   3.763121298017347*^9, 3.7631213054969654`*^9}, 
   3.7631340406792617`*^9},ExpressionUUID->"634ae0ca-89c3-43db-8f1e-\
a68085a8e624"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"B9", " ", "C4"}], "-", 
     RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
     RowBox[{"6", " ", 
      RowBox[{"H", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Nu]", "-", 
        RowBox[{"3", " ", "C4", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "C4", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"3", " ", "A6", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"C3", "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A4", " ", "C4"}], "+", 
      RowBox[{"C3", " ", "\[Mu]"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", 
         RowBox[{"3", " ", "C4", " ", 
          RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 3.7631213071168237`*^9}, 3.7631222121070485`*^9, 
   3.76313404212954*^9, 3.763134130547038*^9, 
   3.763134580227434*^9},ExpressionUUID->"2f41bbe1-1f3d-4ab7-aa09-\
6d99eeaaf9b5"],

Cell[BoxData[
 RowBox[{"cs2", "\[Rule]", "1"}]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 3.7631213071168237`*^9}, 3.7631222121070485`*^9, 
   3.76313404212954*^9, 3.763134130547038*^9, 
   3.763134580227434*^9},ExpressionUUID->"550bf943-78a6-4e73-b139-\
ce38dde5d6ba"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"In", " ", "a", " ", "general", " ", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"cs2gen", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Delta]PDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                    RowBox[{"\[Delta]\[Rho]DE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.",
                     "soldDE"}], "/.", "soldPDE"}], "/.", 
                    RowBox[{"B6", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B8", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"A3", "\[Rule]", 
                    RowBox[{"4", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B7", "\[Rule]", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}]}], "/.", 
                    "subhorflex"}], "/.", 
                    RowBox[{"B4", "->", 
                    RowBox[{
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
                    RowBox[{"A2", "\[Rule]", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"9", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
                    RowBox[{
                    RowBox[{"KXX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}]}]}]}], "/.", 
                    RowBox[{"B2", "->", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                    RowBox[{"C3", "\[Rule]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}]}], "/.", 
                    RowBox[{"A6", "\[Rule]", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                   RowBox[{"C4", "->", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                  RowBox[{"B9", "->", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "36"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
                 RowBox[{"\[Nu]", "->", 
                  RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
                RowBox[{"A4", "->", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", 
                   SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KXX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}]}]}]}], "/.", 
               RowBox[{"\[Mu]", "->", 
                RowBox[{"-", 
                 RowBox[{"K\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
              RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
             RowBox[{"D7", "\[Rule]", "0"}]}], "/.", 
            RowBox[{"M", "\[Rule]", 
             SqrtBox["M2"]}]}], "/.", 
           RowBox[{"M2", "\[Rule]", 
            RowBox[{"-", 
             RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"D9", "\[Rule]", 
           RowBox[{"-", 
            RowBox[{"KX", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"D11", "\[Rule]", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"KXXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
         RowBox[{
          RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}]}], 
        "}"}]}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614756379174366`*^9, 3.76147568953691*^9}, {
   3.7614757263370914`*^9, 3.761475958304971*^9}, {3.761476048957116*^9, 
   3.7614760632469234`*^9}, {3.7614763452470846`*^9, 3.76147636870883*^9}, {
   3.7614764569268293`*^9, 3.761476458271467*^9}, {3.76147656326256*^9, 
   3.761476564859185*^9}, {3.7614766282267957`*^9, 3.761476692631748*^9}, {
   3.7614767336265616`*^9, 3.7614767480766664`*^9}, {3.761476783486722*^9, 
   3.7614768313469687`*^9}, {3.7614771328169327`*^9, 3.761477133236987*^9}, 
   3.761477402776991*^9, 3.763115827884598*^9, 3.763115912365671*^9, 
   3.7631159501848774`*^9, {3.763116027695698*^9, 3.763116052252181*^9}, {
   3.763121309557479*^9, 3.7631213164173107`*^9}, {3.7631223630075283`*^9, 
   3.7631223779171925`*^9}, {3.7631224589874425`*^9, 
   3.7631224928674297`*^9}, {3.7631225348072133`*^9, 3.763122576617199*^9}, {
   3.763134026578411*^9, 
   3.7631340342870765`*^9}},ExpressionUUID->"a64dedc4-b2f7-411e-908d-\
5f360f297845"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0\\\"]\\) \
encountered.\"",2,177,3,27888442674803138787,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.763134583153101*^9},ExpressionUUID->"c77c6190-3112-4bb3-9e4e-\
5cafed64374e"],

Cell[BoxData[
 TemplateBox[{
  "Power","infy",
   "\"Infinite expression \\!\\(\\*FractionBox[\\\"1\\\", \\\"0\\\"]\\) \
encountered.\"",2,177,4,27888442674803138787,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.763134583173428*^9},ExpressionUUID->"f2b45787-9f89-48fc-aa5d-\
501d5943ab69"],

Cell[BoxData[
 TemplateBox[{
  "Infinity","indet",
   "\"Indeterminate expression \\!\\(\\*RowBox[{\\\"0\\\", \\\" \\\", \
\\\"ComplexInfinity\\\", \\\" \\\", \\\"ComplexInfinity\\\"}]\\) encountered.\
\"",2,177,5,27888442674803138787,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.763134583183957*^9},ExpressionUUID->"1f36eccd-c677-41ef-962d-\
d48b38249cb4"],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{{3.7614756472519145`*^9, 3.7614756926065903`*^9}, {
   3.761475740091787*^9, 3.7614758147669015`*^9}, 3.7614758539493217`*^9, {
   3.761475937031951*^9, 3.761475959253948*^9}, 3.761476065157156*^9, {
   3.7614763470866065`*^9, 3.761476353997134*^9}, {3.7614764480070596`*^9, 
   3.7614764599522624`*^9}, 3.761476565546674*^9, {3.76147664327186*^9, 
   3.761476670421854*^9}, {3.76147680656666*^9, 3.7614768317975225`*^9}, 
   3.7614771353316383`*^9, 3.7614774065766478`*^9, 3.763113840095704*^9, 
   3.763115624425024*^9, 3.7631158300199695`*^9, 3.763115913200203*^9, 
   3.7631159516602564`*^9, {3.7631160308620434`*^9, 3.7631160400904016`*^9}, 
   3.763121284941904*^9, 3.7631213192667665`*^9, 3.763122215632853*^9, {
   3.763122357757098*^9, 3.763122385437146*^9}, {3.7631224721660748`*^9, 
   3.7631224992970867`*^9}, {3.7631225726990604`*^9, 3.7631225847820225`*^9}, 
   3.763134045829632*^9, 3.763134133446569*^9, 
   3.7631345831939898`*^9},ExpressionUUID->"15cfd52f-8cb9-4b99-9b30-\
5ecd185920dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"V", "[", "\[Phi]_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"m", "^", "2"}], " ", 
   RowBox[{"\[Phi]", "^", "2"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"cs2gen1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cs2gen", "/.", 
      RowBox[{
       RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"X0", "+", 
        RowBox[{"V", "[", 
         RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}]}], "/.", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"V", "'"}], "[", 
       RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "/.", 
    RowBox[{
     RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"V", "''"}], "[", 
      RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"cs2gen1", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     RowBox[{"\[Epsilon]", " ", "m", " ", 
      RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614774489467955`*^9, 3.7614779250165815`*^9}, {
   3.761477977411518*^9, 3.7614779948497677`*^9}, {3.7631139412058153`*^9, 
   3.763113942055827*^9}, {3.7631213526017084`*^9, 3.763121388307263*^9}, 
   3.7631341570756016`*^9, {3.763134285909507*^9, 
   3.7631343174318323`*^9}},ExpressionUUID->"d03c6bb7-e7b1-4698-ac34-\
113a56710d4b"],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 3.763121388956871*^9}, 
   3.763134149772596*^9, {3.7631342800674496`*^9, 3.763134318352883*^9}, 
   3.7631346001085825`*^9},ExpressionUUID->"ebc269c0-dc9c-47d2-8e05-\
0a34a6d79c14"],

Cell[BoxData["Indeterminate"], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 3.763121388956871*^9}, 
   3.763134149772596*^9, {3.7631342800674496`*^9, 3.763134318352883*^9}, 
   3.7631346001085825`*^9},ExpressionUUID->"0eb6d65b-418a-44a4-884a-\
74bbf2e31961"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"eq11", "/.", "zeroorder"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"1", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}],
    "/.", 
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
  RowBox[{
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
   "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"H", "'"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614770642968874`*^9, 
  3.761477126561428*^9}},ExpressionUUID->"bc95e162-0905-41fe-80b9-\
53954fd19a0f"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "2"], "+", 
  FractionBox[
   RowBox[{"K", "[", "t", "]"}], "2"], "+", 
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 3.7631213941771016`*^9, 
   3.7631346020489607`*^9},ExpressionUUID->"48548839-d421-4818-a504-\
34ac87e3d723"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 3.7631213941771016`*^9, 
   3.7631346020588694`*^9},ExpressionUUID->"62686fc1-19a6-486c-ae48-\
eb48820622e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"scaleq", "/.", "zeroorder"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614759946317997`*^9, 3.761476039417528*^9}, {
  3.7614773827764387`*^9, 
  3.761477393256817*^9}},ExpressionUUID->"b1980540-806e-40ed-951e-\
9368fcf9f44e"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270069256`*^9, 
   3.7631346038979735`*^9},ExpressionUUID->"2796a41d-da21-429b-ab2a-\
9f650a98ccb0"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270069256`*^9, 
   3.7631346039004946`*^9},ExpressionUUID->"da2efa14-d1b2-4fb4-b44f-\
663bd7643f3e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",ExpressionUUID->"025ae85d-1f78-449e-843b-bb713f05e0a1"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Case", " ", "2", 
    RowBox[{"b", ":", " ", 
     RowBox[{
     "Effective", " ", "fluid", " ", "and", " ", "subhorizon", " ", "for", 
      " ", "KGB"}]}]}], ",", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "flex", " ", "ES", " ", "version", " ", "without", " ", "our", " ", 
      "improvement"}], " ", "//", " ", 
     RowBox[{"gives", " ", "cs2", " ", "limit"}]}], " ", "//", " ", 
    RowBox[{"better", " ", 
     RowBox[{"numerics", "?"}]}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7568075707836485`*^9, 3.7568075757622113`*^9}, {
   3.7568096497511396`*^9, 3.7568096534003925`*^9}, {3.759648846982213*^9, 
   3.7596488495525045`*^9}, {3.7631205055312815`*^9, 3.763120542849162*^9}, {
   3.7631209768868275`*^9, 3.763120983412758*^9}, {3.7631218607374253`*^9, 
   3.7631218643292313`*^9}, {3.7631343875119905`*^9, 3.763134387684534*^9}, {
   3.7631346846494837`*^9, 3.7631346929404383`*^9}, 3.7631903898780704`*^9, {
   3.7634558326135645`*^9, 3.763455832845481*^9}, {3.763462501961097*^9, 
   3.7634625051932697`*^9}},ExpressionUUID->"a3544c8f-5d05-4199-a2b2-\
2f64468af5f5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGR", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["G3", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesKGB0", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rulesKGB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "X"}]}], ",", 
     RowBox[{
      RowBox[{"KX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"-", "1"}]}], ",", 
     RowBox[{
      RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"\[Alpha]", " ", 
       RowBox[{"X", "^", "n"}]}]}], ",", 
     RowBox[{
      RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "1"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XX", "[", "t", "]"}], "->", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "2"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"D", "[", 
       RowBox[{
        RowBox[{"\[Alpha]", " ", 
         SuperscriptBox["X", "n"]}], ",", 
        RowBox[{"{", 
         RowBox[{"X", ",", "3"}], "}"}]}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     
     RowBox[{
      RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
      RowBox[{"1", "/", "2"}]}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
     RowBox[{
      RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
    "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7568081983101892`*^9, 3.756808200860401*^9}, {
   3.756808599964323*^9, 3.756808600859193*^9}, 3.757923942100193*^9, {
   3.759648878369643*^9, 3.759648878635396*^9}, {3.7607934082599554`*^9, 
   3.7607934125992403`*^9}},ExpressionUUID->"9c195fc2-879d-41b1-8142-\
fec56106d04f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"dX0", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], 
       RowBox[{
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], ".", 
        "gUU", ".", 
        RowBox[{"covD", "[", 
         RowBox[{
          RowBox[{"\[Phi]", "[", "t", "]"}], "+", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}]}]}], 
      "-", "X0"}], "/.", "a2H"}], "//", "ApproxFullSimplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"soldf", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{"dX0", "\[Equal]", 
       RowBox[{"\[Delta]X", "[", "t", "]"}]}], ",", 
      RowBox[{
       SuperscriptBox["\[Delta]\[Phi]", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "/.", 
   RowBox[{
    RowBox[{
     SuperscriptBox["\[Phi]", "\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
    SqrtBox[
     RowBox[{"2", "X"}]]}]}]}]}], "Input",
 CellChangeTimes->{
  3.7561141319764814`*^9, {3.7579239991243944`*^9, 
   3.7579240091742053`*^9}},ExpressionUUID->"796863b7-8173-4ed7-9819-\
19d6b9c7a40a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Delta]\[Phi]", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]X", "[", "t", "]"}], "+", 
     RowBox[{"2", " ", "X", " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
    RowBox[{
     SqrtBox["2"], " ", 
     SqrtBox["X"]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.757924013239633*^9, 3.7584607175620537`*^9, {3.7595831281019588`*^9, 
   3.759583128801408*^9}, 3.759648882211532*^9, 3.7596621180996127`*^9, 
   3.7607063136389337`*^9, 3.7607064887891293`*^9, 3.760707315914773*^9, 
   3.760793455789051*^9, 3.7608602303957033`*^9, 3.760868850328183*^9, 
   3.760877403457257*^9, 3.760877524047437*^9, 3.7609545191368074`*^9, 
   3.760954565031988*^9, 3.760964283246402*^9, 3.7609651066335964`*^9, 
   3.760966651601708*^9, 3.7610284651348453`*^9, 3.7614714548842196`*^9, 
   3.7614755993269067`*^9, 3.762082048992428*^9, 3.7631009151678376`*^9, 
   3.7631009541881647`*^9, 3.763113583475541*^9, 3.763115144246414*^9, 
   3.7631205210067654`*^9, 3.7631218959471636`*^9, 3.7631339782618136`*^9, 
   3.7634619196693935`*^9, 
   3.763463099601515*^9},ExpressionUUID->"2b9ebad2-9744-4e08-a97f-\
babfa29b0a1a"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulesGRA", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"A1", "\[Rule]", " ", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"A2", "\[Rule]", "0"}], ",", 
     RowBox[{"A3", "\[Rule]", "2"}], ",", 
     RowBox[{"A4", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{"A5", "\[Rule]", "0"}], ",", 
     RowBox[{"A6", "\[Rule]", "0"}], ",", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRB", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"B1", "\[Rule]", "6"}], ",", 
     RowBox[{"B2", "\[Rule]", "0"}], ",", 
     RowBox[{"B3", "\[Rule]", 
      RowBox[{"18", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B4", "\[Rule]", "0"}], ",", 
     RowBox[{"B5", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"B6", "\[Rule]", "2"}], ",", 
     RowBox[{"B7", "\[Rule]", "0"}], ",", 
     RowBox[{"B8", "\[Rule]", "2"}], ",", 
     RowBox[{"B9", "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "18"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
       RowBox[{"12", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}]}], ",", 
     RowBox[{"\[Nu]", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRC", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"C1", "\[Rule]", "2"}], ",", 
     RowBox[{"C2", "\[Rule]", "0"}], ",", 
     RowBox[{"C3", "\[Rule]", 
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ",", 
     RowBox[{"C4", "\[Rule]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRD", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"D1", "\[Rule]", "0"}], ",", 
     RowBox[{"D2", "\[Rule]", "0"}], ",", 
     RowBox[{"D3", "\[Rule]", "0"}], ",", 
     RowBox[{"D4", "\[Rule]", "0"}], ",", 
     RowBox[{"D5", "\[Rule]", "0"}], ",", 
     RowBox[{"D7", "\[Rule]", "0"}], ",", 
     RowBox[{"D8", "\[Rule]", "0"}], ",", 
     RowBox[{"D9", "\[Rule]", "0"}], ",", 
     RowBox[{"D10", "\[Rule]", "0"}], ",", 
     RowBox[{"D11", "\[Rule]", "0"}], ",", 
     RowBox[{"M", "\[Rule]", "0"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulesGRABCD", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"{", 
     RowBox[{"rulesGRA", ",", "rulesGRB", ",", "rulesGRC", ",", "rulesGRD"}], 
     "}"}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.7608774109275446`*^9, 3.760877515997035*^9}, {
   3.760877601947462*^9, 3.760877723817091*^9}, 3.760878178137457*^9, {
   3.760878406236206*^9, 3.7608784114662337`*^9}, {3.760964293131819*^9, 
   3.7609643313744884`*^9}},ExpressionUUID->"7156a42e-736b-44f9-8551-\
16f61393e602"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Eq00", "=", 
   RowBox[{
    RowBox[{"A1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A3", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"A4", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", "\[Mu]"}], ")"}], 
     " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "-", 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqii", "=", 
   RowBox[{
    RowBox[{"B1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"B6", " ", 
     FractionBox[
      RowBox[{"k", "^", "2"}], 
      RowBox[{
       RowBox[{"a", "[", "t", "]"}], "^", "2"}]], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", 
       RowBox[{"3", "\[Nu]"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B8", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "B9"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"\[Delta]Pm", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eq0i", "=", 
   RowBox[{
    RowBox[{"C1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C3", " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"C4", " ", 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    FractionBox[
     RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"\[Theta]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"\[Rho]m", "[", "t", "]"}]}], 
     SuperscriptBox["k", "2"]]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Eqsc", "=", 
   RowBox[{
    RowBox[{"D1", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D2", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"2", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D3", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPhi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D4", " ", 
     RowBox[{
      SuperscriptBox["\[Delta]\[Phi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{"D5", " ", 
     RowBox[{
      SuperscriptBox["\[CapitalPsi]", 
       TagBox[
        RowBox[{"(", 
         RowBox[{"1", ",", "0", ",", "0", ",", "0"}], ")"}],
        Derivative],
       MultilineFunction->None], "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D7", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D8"}], ")"}], 
     RowBox[{"\[CapitalPhi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D9", " ", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"M", "^", "2"}]}], ")"}], 
     RowBox[{"\[Delta]\[Phi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"D10", 
        FractionBox[
         RowBox[{"k", "^", "2"}], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "+", "D11"}], ")"}], 
     " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.760871236957633*^9, 3.760871319127609*^9}, {
   3.7608713554071703`*^9, 3.760871572037525*^9}, 3.760871605627293*^9, 
   3.7608720233417673`*^9, {3.7608770922374477`*^9, 3.76087713384791*^9}, {
   3.7608772688874445`*^9, 3.7608772691494226`*^9}, {3.760877955181913*^9, 
   3.7608781114020014`*^9}, {3.760965230731535*^9, 
   3.7609652310438423`*^9}},ExpressionUUID->"9b0136ab-e18e-4024-a18c-\
8fb57d69da62"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs00", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq00", "/.", "rulesGRA"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{"Eqsii", "/.", "rulesGR"}], ")"}], "-", 
   RowBox[{"(", 
    RowBox[{"Eqii", "/.", "rulesGRB"}], ")"}]}], "//", 
  "Expand"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqs0i", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eq0i", "/.", "rulesGRC"}], ")"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Eqscal", "/.", "rulesGR"}], ")"}], "-", 
  RowBox[{"(", 
   RowBox[{"Eqsc", "/.", "rulesGRD"}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.7608777345270576`*^9, 3.760877842347237*^9}, 
   3.7608780039918804`*^9, 3.760878415551169*^9, {3.760878470640115*^9, 
   3.7608785600562253`*^9}},ExpressionUUID->"e8183c40-4844-41fa-be4e-\
dd2b289c2390"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 3.763461922460208*^9, 
   3.763463104121669*^9},ExpressionUUID->"121e73dc-33ad-474c-9a62-\
a68ef110339a"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 3.763461922460208*^9, 
   3.763463104131546*^9},ExpressionUUID->"72e8d2be-805d-4506-a1ae-\
c60fd51c5be6"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 3.763461922460208*^9, 
   3.76346310414176*^9},ExpressionUUID->"9850fba4-3ace-4840-b418-\
8db554206d4d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.760877738282347*^9, 3.7608777427694855`*^9}, {
   3.760877779187274*^9, 3.760877843539316*^9}, 3.760878004647311*^9, 
   3.760878117127223*^9, 3.760878419576108*^9, 3.7608784806658454`*^9, {
   3.7608785153579445`*^9, 3.760878560428297*^9}, 3.7609545760619636`*^9, 
   3.7609643508416996`*^9, 3.7609652469545546`*^9, 3.7609666823840647`*^9, 
   3.7610284735339766`*^9, 3.761471459849162*^9, 3.7631151515412407`*^9, 
   3.763120527078928*^9, 3.7631219007222595`*^9, 3.763461922460208*^9, 
   3.76346310414176*^9},ExpressionUUID->"b881f904-6c68-47b7-874e-\
9dc4daf7121e"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"subhorstrict", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"A1", "\[Rule]", "0"}], ",", 
       RowBox[{"A2", "\[Rule]", "0"}], ",", 
       RowBox[{"A4", "\[Rule]", "0"}], ",", 
       RowBox[{"\[Mu]", "\[Rule]", "0"}], ",", 
       RowBox[{"B1", "\[Rule]", "0"}], ",", 
       RowBox[{"B2", "\[Rule]", "0"}], ",", 
       RowBox[{"B3", "\[Rule]", "0"}], ",", 
       RowBox[{"B4", "\[Rule]", "0"}], ",", 
       RowBox[{"B5", "\[Rule]", "0"}], ",", 
       RowBox[{"\[Nu]", "\[Rule]", "0"}], ",", 
       RowBox[{"B9", "\[Rule]", "0"}], ",", 
       RowBox[{"D1", "\[Rule]", "0"}], ",", 
       RowBox[{"D2", "\[Rule]", "0"}], ",", 
       RowBox[{"D3", "\[Rule]", "0"}], ",", 
       RowBox[{"D4", "\[Rule]", "0"}], ",", 
       RowBox[{"D5", "\[Rule]", "0"}], ",", 
       RowBox[{"D8", "\[Rule]", "0"}], ",", 
       RowBox[{"D11", "\[Rule]", "0"}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"subhorflex", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"A1", "\[Rule]", "0"}], ",", 
      RowBox[{"A2", "\[Rule]", "0"}], ",", 
      RowBox[{"B1", "\[Rule]", "0"}], ",", 
      RowBox[{"B2", "\[Rule]", "0"}], ",", 
      RowBox[{"B3", "\[Rule]", "0"}], ",", 
      RowBox[{"B4", "\[Rule]", "0"}], ",", 
      RowBox[{"B5", "\[Rule]", "0"}], ",", 
      RowBox[{"C1", "\[Rule]", "0"}], ",", 
      RowBox[{"C2", "\[Rule]", "0"}], ",", 
      RowBox[{"D1", "\[Rule]", "0"}], ",", 
      RowBox[{"D2", "\[Rule]", "0"}], ",", 
      RowBox[{"D3", "\[Rule]", "0"}], ",", 
      RowBox[{"D4", "\[Rule]", "0"}], ",", 
      RowBox[{"D5", "\[Rule]", "0"}]}], "}"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.763120561226567*^9, 3.7631205712068496`*^9}, {
  3.76312193474724*^9, 
  3.763121943447171*^9}},ExpressionUUID->"66c93d6d-b5f1-4eb9-b1b0-\
1330f0b6f36b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "potentials"}], " ", "*)"}], " ", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"subhor", "=", "subhorflex"}], ";", 
    RowBox[{"solgen", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Eq00", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqii", "\[Equal]", "0"}], ",", 
             RowBox[{"Eqsc", "\[Equal]", "0"}]}], "}"}], "/.", "subhor"}], "/.", 
          RowBox[{
           RowBox[{"\[Delta]Pm", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
           "0"}]}], ",", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"\[CapitalPhi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[CapitalPsi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"\[Delta]\[Phi]", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "}"}]}], 
        "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"solgen", "//", "TableForm"}]}]}]], "Input",
 CellChangeTimes->{{3.7608716843173847`*^9, 3.760871870449571*^9}, {
   3.7608720053374634`*^9, 3.760872006777376*^9}, {3.760878197051565*^9, 
   3.7608782029572024`*^9}, {3.7608790453577843`*^9, 3.760879045865718*^9}, {
   3.760964405164853*^9, 3.7609645103018255`*^9}, {3.7609652605941057`*^9, 
   3.760965262471862*^9}, {3.760966739353032*^9, 3.760966739932638*^9}, {
   3.7609667897358575`*^9, 3.76096683365308*^9}, {3.7631136147260556`*^9, 
   3.7631136366483927`*^9}, {3.763115156776116*^9, 3.7631151673663273`*^9}, {
   3.7631206809169006`*^9, 3.76312070061677*^9}, 
   3.763121946937045*^9},ExpressionUUID->"c55e8c8d-6f09-40b6-a46e-\
dc517bcfe094"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      RowBox[{
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D10"}], "-", 
              RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "4"]}], "+", 
           RowBox[{
            SuperscriptBox["k", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D11"}], "-", 
              RowBox[{"B9", " ", "D9"}], "+", 
              RowBox[{"B8", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B9", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A6"}], " ", "B6", " ", "D10"}], "+", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "+", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "-", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "6"]}], "+", 
         RowBox[{
          SuperscriptBox["k", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
            RowBox[{"A6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D11"}], "+", 
               RowBox[{"B9", " ", "D7"}], "+", 
               RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
            RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
            RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
            RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
            RowBox[{"A3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D11"}], "-", 
               RowBox[{"B9", " ", "D9"}], "+", 
               RowBox[{"B8", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
            RowBox[{"A3", " ", "B9", " ", 
             SuperscriptBox["M", "2"]}], "+", 
            RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "-", 
            RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "-", 
            RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "+", 
            RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "-", 
            RowBox[{"A4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D8"}], "+", 
               RowBox[{"B6", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "4"]}], "-", 
         RowBox[{"D8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B9", " ", "\[Mu]"}], "+", 
            RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "6"]}]}]]}]},
     {
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       FractionBox[
        RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox["k", "4"]}], "+", 
           RowBox[{
            SuperscriptBox["k", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D8"}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
            RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
            RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
            RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
          SuperscriptBox["k", "6"]}], "-", 
         RowBox[{
          SuperscriptBox["k", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
            RowBox[{"A6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D11"}], "+", 
               RowBox[{"B9", " ", "D7"}], "+", 
               RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
            RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
            RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
            RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
            RowBox[{"A3", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D11"}], "-", 
               RowBox[{"B9", " ", "D9"}], "+", 
               RowBox[{"B8", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          SuperscriptBox["k", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "-", 
            RowBox[{"A3", " ", "B9", " ", 
             SuperscriptBox["M", "2"]}], "-", 
            RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
            RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "+", 
            RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "-", 
            RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "+", 
            RowBox[{"A4", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"B7", " ", "D8"}], "+", 
               RowBox[{"B6", " ", 
                SuperscriptBox["M", "2"]}], "+", 
               RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
          " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
         RowBox[{"D8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B9", " ", "\[Mu]"}], "+", 
            RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "6"]}]}]]}]},
     {
      RowBox[{
       RowBox[{"\[Delta]\[Phi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       RowBox[{"-", 
        FractionBox[
         RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D10"}], "+", 
               RowBox[{"B8", " ", "D7"}]}], ")"}], " ", 
             SuperscriptBox["k", "4"]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "B6"}], " ", "D11"}], "+", 
               RowBox[{"B9", " ", "D7"}], "+", 
               RowBox[{"B8", " ", "D8"}]}], ")"}], " ", 
             SuperscriptBox["k", "2"], " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
            RowBox[{"B9", " ", "D8", " ", 
             SuperscriptBox[
              RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
          RowBox[{"\[Delta]\[Rho]m", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
             RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
             RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
             RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
           SuperscriptBox["k", "6"]}], "-", 
          RowBox[{
           SuperscriptBox["k", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
             RowBox[{"A6", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "B6"}], " ", "D11"}], "+", 
                RowBox[{"B9", " ", "D7"}], "+", 
                RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
             RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
             RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
             RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
             RowBox[{"A3", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D11"}], "-", 
                RowBox[{"B9", " ", "D9"}], "+", 
                RowBox[{"B8", " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
           " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["k", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "-", 
             RowBox[{"A3", " ", "B9", " ", 
              SuperscriptBox["M", "2"]}], "-", 
             RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
             RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "+", 
             RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "-", 
             RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "+", 
             RowBox[{"A4", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"B7", " ", "D8"}], "+", 
                RowBox[{"B6", " ", 
                 SuperscriptBox["M", "2"]}], "+", 
                RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
           " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
          RowBox[{"D8", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B9", " ", "\[Mu]"}], "+", 
             RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "6"]}]}]]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.5599999999999999]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Column],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.7608717286971655`*^9, {3.7608718611915445`*^9, 3.760871871352357*^9}, {
   3.7608720076070447`*^9, 3.7608720260271597`*^9}, {3.760878191007273*^9, 
   3.760878204447015*^9}, 3.7608789370907774`*^9, 3.7608790463277893`*^9, 
   3.76095458366181*^9, 3.76096435408368*^9, {3.760964465561962*^9, 
   3.7609645113515034`*^9}, {3.7609652497418423`*^9, 3.7609652635475073`*^9}, 
   3.7609668374928026`*^9, 3.7610285102695513`*^9, 3.7614714737442923`*^9, 
   3.7614756089571514`*^9, 3.7620820882657003`*^9, 3.7631009673786554`*^9, {
   3.7631136325212173`*^9, 3.763113637630972*^9}, 3.763115176536146*^9, 
   3.7631205783068843`*^9, 3.7631207044668016`*^9, 3.7631219047171373`*^9, 
   3.7631219519168615`*^9, 3.7631339902792006`*^9, 3.7634619294444056`*^9, 
   3.7634631103266735`*^9},ExpressionUUID->"9f60be9d-8d27-4b04-9c1b-\
cefdd4eeec96"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Eta]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Eta]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "+", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206084091463`*^9, 3.763120641589445*^9}, {
  3.7631207138169174`*^9, 
  3.763120728343577*^9}},ExpressionUUID->"f0bfdaa2-75f5-43ce-85b8-\
f605725949ca"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", 
        RowBox[{"(", 
         RowBox[{"D10", "-", "D7"}], ")"}]}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"B6", "-", "B8"}], ")"}], " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", 
        RowBox[{"(", 
         RowBox[{"D11", "-", "D8"}], ")"}]}], "-", 
       RowBox[{"B9", " ", "D9"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"D10", "-", "D7"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B9", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{"D11", "-", "D8"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", "D10"}], "-", 
       RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", "D11"}], "-", 
       RowBox[{"B9", " ", "D9"}], "+", 
       RowBox[{"B8", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B9", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.763120609582012*^9, 3.7631206420367975`*^9}, 
   3.763121923241412*^9, 3.763121955227069*^9, 
   3.7634619312495165`*^9},ExpressionUUID->"86b2e462-861a-4c91-9720-\
8dfc34061c86"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "anisotropic", " ", "stress", " ", "\[Gamma]", " ", "param"}], 
   " ", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{"\[Gamma]", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"-", 
        RowBox[{"\[CapitalPhi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", "solgen"}],
      "/.", "subhor"}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7631206180173826`*^9, 3.7631206194184933`*^9}, {
  3.763120722997031*^9, 
  3.763120733766609*^9}},ExpressionUUID->"fb817054-3698-4086-8843-\
6661905e0465"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", "D10"}], "-", 
       RowBox[{"B8", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", "D11"}], "-", 
       RowBox[{"B9", " ", "D9"}], "+", 
       RowBox[{"B8", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B9", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", "D7"}], "-", 
       RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "4"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B7", " ", "D8"}], "+", 
       RowBox[{"B6", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.763120619816679*^9, 3.763121924921926*^9, 
  3.763121957747242*^9, 
  3.7634619332445765`*^9},ExpressionUUID->"c1a36df4-726c-446e-9ffe-\
eb55bba934e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", 
    RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff"}], " ", "*)"}],
   " ", "\[IndentingNewLine]", 
  RowBox[{"Geff", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      FractionBox[
       RowBox[{"k", "^", "2"}], 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]], 
      RowBox[{
       RowBox[{"\[CapitalPsi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "4"}], " ", "G", " ", "\[Pi]", " ", 
         RowBox[{"\[Delta]\[Rho]m", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}]}]}], "/.", 
     RowBox[{"solgen", "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "//", "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763120736546857*^9, 
  3.7631207498276453`*^9}},ExpressionUUID->"7561a743-0cf6-479a-8eeb-\
536010748098"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B7", " ", "D7"}], "-", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B7", " ", "D8"}], "+", 
         RowBox[{"B6", " ", 
          SuperscriptBox["M", "2"]}], "+", 
         RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "A6"}], " ", "B6", " ", "D10"}], "+", 
       RowBox[{"A3", " ", "B7", " ", "D10"}], "+", 
       RowBox[{"A6", " ", "B8", " ", "D7"}], "-", 
       RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
       RowBox[{"A6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "B6"}], " ", "D11"}], "+", 
          RowBox[{"B9", " ", "D7"}], "+", 
          RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
       RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
       RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
       RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
       RowBox[{"A3", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B7", " ", "D11"}], "-", 
          RowBox[{"B9", " ", "D9"}], "+", 
          RowBox[{"B8", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
       RowBox[{"A3", " ", "B9", " ", 
        SuperscriptBox["M", "2"]}], "+", 
       RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "-", 
       RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "-", 
       RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "-", 
       RowBox[{"A4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B7", " ", "D8"}], "+", 
          RowBox[{"B6", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}], "-", 
    RowBox[{"D8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B9", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.7631206655067053`*^9, 3.7631207506888466`*^9, 
  3.76312192631944*^9, 3.763121960336917*^9, 3.763461935329827*^9, 
  3.7634631154413896`*^9},ExpressionUUID->"2fc7b7a1-a104-477f-ae5a-\
c2dcca6a370f"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"Ruben", "'"}], "s", " ", "effective", " ", 
   RowBox[{"Newton", "'"}], "s", " ", "constant", " ", "Geff", " ", "from", 
   " ", "the", " ", "paper"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631207729569917`*^9, 3.7631207857019873`*^9}, 
   3.763121965797014*^9},ExpressionUUID->"f08af11e-0e4d-482d-8865-\
45a5731d5ba9"],

Cell[BoxData[
 RowBox[{
  RowBox[{"GeffRub", "=", 
   FractionBox[
    RowBox[{"2", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B6", " ", "D9"}], "-", 
          RowBox[{"B7", "^", "2"}]}], ")"}], 
        FractionBox[
         SuperscriptBox["k", "2"], 
         RowBox[{
          RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
       RowBox[{"B6", " ", 
        SuperscriptBox["M", "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"A6", "^", "2"}], " ", "B6"}], "+", 
        RowBox[{
         RowBox[{"B6", "^", "2"}], "D9"}], "-", 
        RowBox[{"2", "A6", " ", "B7", " ", "B6"}]}], ")"}], 
      FractionBox[
       SuperscriptBox["k", "2"], 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "2"}]]}], "-", 
     RowBox[{
      RowBox[{"B6", "^", "2"}], " ", 
      RowBox[{"M", "^", "2"}]}]}]]}], ";"}]], "Input",ExpressionUUID->\
"38a602f5-7ce5-4099-ac1e-21cb99e1c27c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "f", 
    RowBox[{"(", "R", ")"}], " ", "limit"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"fRlimit", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"1", "/", "2"}], 
         RowBox[{"\[Phi]", "[", "t", "]"}]}]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox["1", "2"]}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], 
       ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "Rr"}], "2"]}], ",", 
       RowBox[{
        RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
        FractionBox[
         RowBox[{"-", "1"}], 
         RowBox[{"2", " ", "fRR"}]]}]}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"fRextra", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SuperscriptBox["M", "2"], "\[Rule]", 
        FractionBox["1", 
         RowBox[{"2", " ", "fRR"}]]}], ",", 
       RowBox[{
        RowBox[{"\[Phi]", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fR", "\[Rule]", 
        RowBox[{"F", "[", "t", "]"}]}], ",", 
       RowBox[{"fRR", "\[Rule]", 
        RowBox[{"m", " ", "F"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
        RowBox[{
         RowBox[{"F", "'"}], "[", "t", "]"}]}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "->", 
        RowBox[{
         RowBox[{"F", "''"}], "[", "t", "]"}]}]}], "}"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.763120798989036*^9, 3.7631208072669797`*^9}, {
  3.7631211354571056`*^9, 
  3.7631211447892885`*^9}},ExpressionUUID->"e6950db8-d6b4-45c8-bc4f-\
b142907a2ea6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "quantities"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"soldPDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Solve", "[", 
           RowBox[{
            RowBox[{
             RowBox[{"Eqii", "-", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
                  RowBox[{"\[Delta]PDE", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
                 "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", "0"}], 
            ",", 
            RowBox[{"\[Delta]PDE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}], "/.", 
         RowBox[{
          RowBox[{
           SuperscriptBox["f_", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
          "0"}]}], "/.", "horizon1"}], "/.", "solgen"}], "//", 
      "FullSimplify"}]}], ";", 
    RowBox[{"soldDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Eq00", "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
                 RowBox[{"\[Delta]\[Rho]DE", "[", 
                  RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
                "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{"\[Delta]\[Rho]DE", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
         
         RowBox[{"[", "1", "]"}], "]"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"solVDE", "=", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Solve", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Eq0i", "-", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                FractionBox[
                 RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
                  RowBox[{"a", "[", "t", "]"}], 
                  RowBox[{"VDE", "[", 
                   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
                  RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
                 SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", "rulesGRC"}],
               ")"}]}], "\[Equal]", "0"}], ",", 
           RowBox[{"VDE", "[", 
            RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
         
         RowBox[{"[", "1", "]"}], "]"}], "/.", 
        RowBox[{
         RowBox[{
          SuperscriptBox["f_", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
         "0"}]}], "/.", "solgen"}], "//", "FullSimplify"}]}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.76312089191674*^9, 3.763120918757121*^9}, {
  3.7631341074602857`*^9, 
  3.76313411217957*^9}},ExpressionUUID->"7c789d8a-f7d1-4ddb-9af0-\
125d5f4d938e"],

Cell[CellGroupData[{

Cell[BoxData[{"soldPDE", "\[IndentingNewLine]", "soldDE", \
"\[IndentingNewLine]", "solVDE"}], "Input",
 CellChangeTimes->{{3.7634631569220657`*^9, 
  3.763463162331869*^9}},ExpressionUUID->"c8e2da02-dec7-4746-b2e4-\
9dc0b1ce6335"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B7", " ", 
            RowBox[{"(", 
             RowBox[{"D10", "-", "D7"}], ")"}]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"B6", "-", "B8"}], ")"}], " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "4"]}], "+", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B7", " ", 
            RowBox[{"(", 
             RowBox[{"D11", "-", "D8"}], ")"}]}], "-", 
           RowBox[{"B9", " ", "D9"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "B6"}], "+", "B8"}], ")"}], " ", 
            SuperscriptBox["M", "2"]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{"D10", "-", "D7"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
         
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B9", " ", 
            SuperscriptBox["M", "2"]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{"D11", "-", "D8"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
         
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
           RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
           RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
           RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["k", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
           RowBox[{"A6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "B6"}], " ", "D11"}], "+", 
              RowBox[{"B9", " ", "D7"}], "+", 
              RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
           RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
           RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
           RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
           RowBox[{"A3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D11"}], "-", 
              RowBox[{"B9", " ", "D9"}], "+", 
              RowBox[{"B8", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "-", 
           RowBox[{"A3", " ", "B9", " ", 
            SuperscriptBox["M", "2"]}], "-", 
           RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
           RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "+", 
           RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "-", 
           RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "+", 
           RowBox[{"A4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D8"}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
        RowBox[{"D8", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B9", " ", "\[Mu]"}], "+", 
           RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7634631633717055`*^9},ExpressionUUID->"ced5e4c0-8502-4b64-856d-\
c8832f918f45"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B6", " ", "D10"}], "-", 
              RowBox[{"B8", " ", "D7"}]}], ")"}]}], "-", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D10"}], "-", 
              RowBox[{"B8", " ", "D9"}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox["k", "6"]}], "+", 
        RowBox[{
         SuperscriptBox["k", "4"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B6", " ", "D11"}], "+", 
           RowBox[{"2", " ", "B7", " ", "D11"}], "-", 
           RowBox[{"A3", " ", "B7", " ", "D11"}], "+", 
           RowBox[{"A4", " ", "B7", " ", "D7"}], "-", 
           RowBox[{"A6", " ", "B9", " ", "D7"}], "-", 
           RowBox[{"A6", " ", "B8", " ", "D8"}], "-", 
           RowBox[{"A4", " ", "B6", " ", "D9"}], "-", 
           RowBox[{"2", " ", "B9", " ", "D9"}], "+", 
           RowBox[{"A3", " ", "B9", " ", "D9"}], "+", 
           RowBox[{"2", " ", "B8", " ", 
            SuperscriptBox["M", "2"]}], "-", 
           RowBox[{"A3", " ", "B8", " ", 
            SuperscriptBox["M", "2"]}], "-", 
           RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "+", 
           RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "-", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "D10", " ", 
            "\[Nu]"}], "+", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}], "+", 
        RowBox[{"D8", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "6"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B9", " ", "\[Mu]"}], "+", 
           RowBox[{"3", " ", "A4", " ", "\[Nu]"}], "+", 
           RowBox[{"18", " ", "\[Nu]", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "+", 
           RowBox[{"2", " ", "B9", " ", 
            SuperscriptBox["M", "2"]}], "-", 
           RowBox[{"A3", " ", "B9", " ", 
            SuperscriptBox["M", "2"]}], "-", 
           RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
           RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "+", 
           RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "-", 
           RowBox[{"3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "D11", " ", 
            "\[Nu]"}], "+", 
           RowBox[{"A4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D8"}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}], "+", 
           RowBox[{"6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D8"}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "A6"}], " ", "B6", " ", "D10"}], "+", 
         RowBox[{"A3", " ", "B7", " ", "D10"}], "+", 
         RowBox[{"A6", " ", "B8", " ", "D7"}], "-", 
         RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "6"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
         RowBox[{"A6", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "B6"}], " ", "D11"}], "+", 
            RowBox[{"B9", " ", "D7"}], "+", 
            RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
         RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
         RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
         RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
         RowBox[{"A3", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B7", " ", "D11"}], "-", 
            RowBox[{"B9", " ", "D9"}], "+", 
            RowBox[{"B8", " ", 
             SuperscriptBox["M", "2"]}], "+", 
            RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
       
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
         RowBox[{"A3", " ", "B9", " ", 
          SuperscriptBox["M", "2"]}], "+", 
         RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "-", 
         RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "-", 
         RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "+", 
         RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "-", 
         RowBox[{"A4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B7", " ", "D8"}], "+", 
            RowBox[{"B6", " ", 
             SuperscriptBox["M", "2"]}], "+", 
            RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"D8", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B9", " ", "\[Mu]"}], "+", 
         RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.7634631634416904`*^9},ExpressionUUID->"c76efe31-1fed-4df9-bf5e-\
5e171f8bc140"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         SuperscriptBox["k", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B6", " ", "C4", " ", "D10"}], "+", 
           RowBox[{"B7", " ", "C3", " ", "D7"}], "-", 
           RowBox[{"B8", " ", "C4", " ", "D7"}], "-", 
           RowBox[{"B6", " ", "C3", " ", "D9"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D7"}], "-", 
              RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{"D8", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "B9"}], " ", "C4"}], "+", 
           RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "+", 
           RowBox[{"6", " ", "\[Nu]", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B6", " ", "C4", " ", "D11"}], "-", 
           RowBox[{"B9", " ", "C4", " ", "D7"}], "+", 
           RowBox[{"B7", " ", "C3", " ", "D8"}], "-", 
           RowBox[{"B8", " ", "C4", " ", "D8"}], "+", 
           RowBox[{"B6", " ", "C3", " ", 
            SuperscriptBox["M", "2"]}], "+", 
           RowBox[{"3", " ", "C3", " ", "D7", " ", "\[Nu]"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D8"}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}], " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B6", " ", "D10"}], "-", 
           RowBox[{"A3", " ", "B7", " ", "D10"}], "-", 
           RowBox[{"A6", " ", "B8", " ", "D7"}], "+", 
           RowBox[{"A3", " ", "B8", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "6"]}], "-", 
        RowBox[{
         SuperscriptBox["k", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "A4"}], " ", "B7", " ", "D7"}], "+", 
           RowBox[{"A6", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "B6"}], " ", "D11"}], "+", 
              RowBox[{"B9", " ", "D7"}], "+", 
              RowBox[{"B8", " ", "D8"}]}], ")"}]}], "+", 
           RowBox[{"A4", " ", "B6", " ", "D9"}], "+", 
           RowBox[{"B6", " ", "D10", " ", "\[Mu]"}], "-", 
           RowBox[{"B8", " ", "D7", " ", "\[Mu]"}], "+", 
           RowBox[{"A3", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D11"}], "-", 
              RowBox[{"B9", " ", "D9"}], "+", 
              RowBox[{"B8", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D10", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
        RowBox[{
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "-", 
           RowBox[{"A3", " ", "B9", " ", 
            SuperscriptBox["M", "2"]}], "-", 
           RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
           RowBox[{"B9", " ", "D7", " ", "\[Mu]"}], "+", 
           RowBox[{"B8", " ", "D8", " ", "\[Mu]"}], "-", 
           RowBox[{"3", " ", "A3", " ", "D11", " ", "\[Nu]"}], "+", 
           RowBox[{"A4", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "D8"}], "+", 
              RowBox[{"B6", " ", 
               SuperscriptBox["M", "2"]}], "+", 
              RowBox[{"3", " ", "D7", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
        RowBox[{"D8", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"B9", " ", "\[Mu]"}], "+", 
           RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}], " ", 
      RowBox[{"\[Rho]DE", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.763463163501403*^9},ExpressionUUID->"44c71284-0c3e-473c-aaf3-\
603719f9c178"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"The", " ", "KGB", " ", "limit"}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631209397866125`*^9, 3.7631209459418736`*^9}, {
  3.763121010101895*^9, 
  3.7631210112500215`*^9}},ExpressionUUID->"78644633-6d5f-4c37-ad69-\
07d97b537043"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"solgen", "[", 
        RowBox[{"[", "3", "]"}], "]"}], "/.", "subhor"}], "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7609546600619273`*^9, 3.760954664466791*^9}, {
   3.760966857372764*^9, 3.760966857623056*^9}, 
   3.763115173256571*^9},ExpressionUUID->"bdbf1f23-c3f6-4b43-8dec-\
8d9a9ecd1857"],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Delta]\[Phi]", "[", 
   RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
  RowBox[{"-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B6", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "A6"}], "+", "B7"}], ")"}], " ", 
          SuperscriptBox["k", "4"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"B7", " ", "B9"}], "+", 
            RowBox[{"B6", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "D11"}], "+", "D8"}], ")"}]}]}], ")"}], " ", 
          SuperscriptBox["k", "2"], " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"B9", " ", "D8", " ", 
          SuperscriptBox[
           RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
       RowBox[{"\[Delta]\[Rho]m", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B6", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["A6", "2"], "-", 
          RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
          RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
        SuperscriptBox["k", "6"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"A4", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["B7", "2"], "-", 
             RowBox[{"B6", " ", "D9"}]}], ")"}]}], "+", 
          RowBox[{"B6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "B7"}], " ", "D11"}], "+", 
             RowBox[{"B9", " ", "D9"}], "-", 
             RowBox[{"B6", " ", 
              SuperscriptBox["M", "2"]}], "+", 
             RowBox[{"B7", " ", "\[Mu]"}]}], ")"}]}], "-", 
          RowBox[{"A6", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"B7", " ", "B9"}], "+", 
             RowBox[{"B6", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "D11"}], "+", "D8", "+", "\[Mu]", "+", 
                RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}]}], ")"}], 
        " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "A6"}], " ", "B9", " ", "D8"}], "+", 
          RowBox[{"A4", " ", "B6", " ", 
           SuperscriptBox["M", "2"]}], "-", 
          RowBox[{"B6", " ", "B9", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"B7", " ", "B9", " ", "\[Mu]"}], "-", 
          RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "+", 
          RowBox[{"B6", " ", "D8", " ", "\[Mu]"}], "-", 
          RowBox[{"3", " ", "B6", " ", "D11", " ", "\[Nu]"}], "+", 
          RowBox[{"A4", " ", "B7", " ", 
           RowBox[{"(", 
            RowBox[{"D8", "+", 
             RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
       RowBox[{"D8", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B9", " ", "\[Mu]"}], "+", 
          RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}], ")"}]}]}]], "Output",\

 CellChangeTimes->{{3.7609644972316685`*^9, 3.76096452140153*^9}, 
   3.760965267881686*^9, 3.760966858712723*^9, 3.761028528340328*^9, 
   3.7614714740090947`*^9, 3.7631009778543415`*^9, 3.7631136442211275`*^9, 
   3.7631151783760886`*^9, 3.763121017667138*^9, 3.763122005608285*^9, 
   3.763463216311497*^9},ExpressionUUID->"352142e8-44f6-4335-aaa9-\
2ca174bc18ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Eta]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608721634777718`*^9, 3.760872183439308*^9}, 
   3.7608722185270576`*^9, {3.760872271117173*^9, 3.7608722728772163`*^9}, {
   3.7608725066403027`*^9, 3.7608725068252964`*^9}, {3.7608782109070044`*^9, 
   3.7608782132468443`*^9}, {3.760954695182067*^9, 3.76095471970185*^9}, 
   3.760954754834016*^9, {3.7609668631930323`*^9, 3.7609668717226267`*^9}, 
   3.763115174916142*^9, {3.763121025736691*^9, 
   3.7631210366271324`*^9}},ExpressionUUID->"0de46f77-83b4-416e-bc02-\
c0f9b4a9ea82"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{"A6", "-", "B7"}], ")"}], " ", "B7", " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "B9"}], " ", "D9"}], "+", 
      RowBox[{"B7", " ", 
       RowBox[{"(", 
        RowBox[{"D11", "-", "D8", "-", 
         RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}], "+", 
      RowBox[{"3", " ", "A6", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"D11", "-", "D8"}], ")"}], " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D11"}], "-", 
      RowBox[{"B9", " ", "D9"}], "+", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "A6", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}]]], "Output",
 CellChangeTimes->{
  3.7608782163370647`*^9, 3.760878939305962*^9, {3.7609546827516994`*^9, 
   3.760954720461788*^9}, 3.760954755682119*^9, 3.760964524526888*^9, 
   3.7609652695817666`*^9, {3.7609668643429146`*^9, 3.760966873672986*^9}, 
   3.7610285303769536`*^9, 3.7631009799055977`*^9, 3.763113646616123*^9, 
   3.7631151797660885`*^9, {3.7631210199111567`*^9, 3.7631210374269714`*^9}, 
   3.7631220058768663`*^9},ExpressionUUID->"2eb27883-4cdd-4926-8c39-\
fcbeae8c5390"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"\[Gamma]", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "Simplify"}]], "Input",
 CellChangeTimes->{{3.760872517388804*^9, 3.7608725507370615`*^9}, {
   3.7608782231496954`*^9, 3.7608782248921795`*^9}, {3.7609547620619287`*^9, 
   3.7609547725885253`*^9}, 3.760966876112828*^9, 3.76311518170636*^9, 
   3.763121039861877*^9},ExpressionUUID->"d00f3770-1860-4f01-a04f-\
060487e11c19"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A6", " ", "B7"}], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B7", " ", "D11"}], "-", 
      RowBox[{"B9", " ", "D9"}], "+", 
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "A6", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B9", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"3", " ", "D11", " ", "\[Nu]"}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}], 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["B7", "2"], "-", 
      RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
    SuperscriptBox["k", "4"]}], "+", 
   RowBox[{
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"B6", " ", 
       SuperscriptBox["M", "2"]}], "+", 
      RowBox[{"B7", " ", 
       RowBox[{"(", 
        RowBox[{"D8", "+", 
         RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
   RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "4"]}]}]]], "Output",
 CellChangeTimes->{{3.760872520881508*^9, 3.760872551269845*^9}, 
   3.760878225431428*^9, {3.760954741811887*^9, 3.760954772871746*^9}, 
   3.760964526241928*^9, 3.76096527069625*^9, 3.760966876882693*^9, 
   3.7610285314106803`*^9, 3.763100981323767*^9, 3.7631136477479143`*^9, 
   3.7631151824566355`*^9, 3.7631210407768707`*^9, 
   3.7631220060269938`*^9},ExpressionUUID->"ac0263b1-17e6-4d14-b785-\
52be25a1800d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Geff", "/.", 
      RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
     RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
    RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
   RowBox[{"D10", "\[Rule]", "A6"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7608720490497875`*^9, 3.7608720761673555`*^9}, 
   3.7608782283273168`*^9, 3.7609547823420057`*^9, {3.7609668940274115`*^9, 
   3.760966914512579*^9}, {3.7631136608859067`*^9, 3.763113661376213*^9}, 
   3.7631210448890667`*^9},ExpressionUUID->"49825ab2-abd6-43c1-8ed9-\
257cc3b9c3b6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"2", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["B7", "2"], "-", 
         RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
       SuperscriptBox["k", "4"]}], "+", 
      RowBox[{
       SuperscriptBox["k", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"B6", " ", 
          SuperscriptBox["M", "2"]}], "+", 
         RowBox[{"B7", " ", 
          RowBox[{"(", 
           RowBox[{"D8", "+", 
            RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", "D8", " ", "\[Nu]", " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}]}], ")"}], "/", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     RowBox[{"-", "B6"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["A6", "2"], "-", 
       RowBox[{"2", " ", "A6", " ", "B7"}], "+", 
       RowBox[{"B6", " ", "D9"}]}], ")"}], " ", 
     SuperscriptBox["k", "6"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "4"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", "B7", " ", "B9"}], "+", 
       RowBox[{"A4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["B7", "2"]}], "+", 
          RowBox[{"B6", " ", "D9"}]}], ")"}]}], "+", 
       RowBox[{"B6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "B9"}], " ", "D9"}], "+", 
          RowBox[{"B6", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"B7", " ", 
           RowBox[{"(", 
            RowBox[{"D11", "-", "\[Mu]"}], ")"}]}]}], ")"}]}], "+", 
       RowBox[{"A6", " ", "B6", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "D11"}], "+", "D8", "+", "\[Mu]", "+", 
          RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
       RowBox[{"B6", " ", "B9", " ", 
        SuperscriptBox["M", "2"]}], "-", 
       RowBox[{"B7", " ", "B9", " ", "\[Mu]"}], "+", 
       RowBox[{"B6", " ", "D11", " ", "\[Mu]"}], "-", 
       RowBox[{"B6", " ", "D8", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "B6", " ", "D11", " ", "\[Nu]"}], "-", 
       RowBox[{"A4", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"B6", " ", 
           SuperscriptBox["M", "2"]}], "+", 
          RowBox[{"B7", " ", 
           RowBox[{"(", 
            RowBox[{"D8", "+", 
             RowBox[{"3", " ", "\[Nu]"}]}], ")"}]}]}], ")"}]}]}], ")"}], " ", 
     
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "4"]}], "-", 
    RowBox[{"D8", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"B9", " ", "\[Mu]"}], "+", 
       RowBox[{"3", " ", "A4", " ", "\[Nu]"}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "6"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.7608720496015744`*^9, 3.760872081867358*^9}, 
   3.7608782296972866`*^9, {3.7609547767217216`*^9, 3.7609547830420494`*^9}, 
   3.760964530741832*^9, 3.7609652723740387`*^9, {3.760966906382824*^9, 
   3.760966916062399*^9}, 3.761028535682231*^9, 3.761471479878995*^9, 
   3.7620820962753325`*^9, 3.763100984211653*^9, {3.7631136524657965`*^9, 
   3.76311366215584*^9}, 3.763115187816374*^9, 3.763121046146944*^9, 
   3.763122007246956*^9},ExpressionUUID->"efecb2bb-75ff-4b23-8a1a-\
8314cfc79ce1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"solVDE", "/.", 
           RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
        RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
       RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
    RowBox[{"M", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7614715093614264`*^9, 3.761471529839512*^9}, 
   3.761471622774027*^9, 3.7631210561473184`*^9, {3.763122085747472*^9, 
   3.7631221019373255`*^9}},ExpressionUUID->"a442f620-3ed4-4591-b0c1-\
d46f98e9e261"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "C4", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "D11"}], "+", "D8"}], ")"}], " ", 
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
          RowBox[{"B9", " ", "C4", " ", "D8", " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["k", "4"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "A6"}], " ", "C4"}], "+", 
             RowBox[{"C3", " ", "D9"}], "+", 
             RowBox[{"2", " ", "D9", " ", 
              RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{"\[Delta]\[Rho]m", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["A6", "2"], "+", 
             RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
           SuperscriptBox["k", "4"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"A6", " ", 
              RowBox[{"(", 
               RowBox[{"D11", "-", "D8"}], ")"}]}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", "D9"}]}], ")"}],
            " ", 
           SuperscriptBox["k", "2"], " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"]}], "-", 
          RowBox[{"A6", " ", "B9", " ", "D8", " ", 
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
        RowBox[{"\[Rho]DE", "[", "t", "]"}]}], ")"}]}], ")"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7614715103143363`*^9, 3.761471530249116*^9}, 
   3.7614716234468727`*^9, 3.761475623436673*^9, 3.762082247279933*^9, 
   3.7631137789961405`*^9, 3.763115417160034*^9, 3.7631210570470114`*^9, 
   3.763122019117032*^9, {3.76312209051744*^9, 3.763122103024601*^9}, 
   3.763461951589939*^9, 
   3.7634632212818336`*^9},ExpressionUUID->"f293b16d-4f66-4ec1-9075-\
ac418e33ea55"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"solVDE", "/.", 
          RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
         RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
        RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
       RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
     RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
    RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
   RowBox[{"B6", "\[Rule]", "2"}]}], "//", "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.760967170912757*^9, 3.7609671756729927`*^9}, {
   3.7609672170710683`*^9, 3.760967268572739*^9}, {3.7609673456627393`*^9, 
   3.760967355482613*^9}, 
   3.763121079797018*^9},ExpressionUUID->"f3e4d95c-6ca8-4ec5-b707-\
6551b4a26c0c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "B9"}], " ", "C4", " ", "D8", " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "4"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "C4"}], "-", 
           RowBox[{"C3", " ", "D9"}], "-", 
           RowBox[{"2", " ", "D9", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"C4", " ", "D11"}], "-", 
           RowBox[{"C4", " ", "D8"}], "+", 
           RowBox[{"C3", " ", 
            SuperscriptBox["M", "2"]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["A6", "2"], "+", 
           RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "4"]}], "+", 
        RowBox[{"2", " ", 
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", 
            RowBox[{"(", 
             RowBox[{"D11", "-", "D8"}], ")"}]}], "-", 
           RowBox[{"A4", " ", "D9"}], "+", 
           RowBox[{"B9", " ", "D9"}], "-", 
           RowBox[{"2", " ", 
            SuperscriptBox["M", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "B9", " ", "D8"}], "+", 
           RowBox[{"2", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", 
            SuperscriptBox["M", "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "4"]}]}], ")"}], " ", 
      RowBox[{"\[Rho]DE", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7609672099178877`*^9, 3.760967270222868*^9}, {
   3.7609673521427126`*^9, 3.7609673562526836`*^9}, 3.76102860194715*^9, 
   3.7614756243818407`*^9, 3.763113782415992*^9, 3.7631154205899687`*^9, 
   3.7631210871609144`*^9, 3.7631221130673704`*^9, 
   3.7634622097502174`*^9},ExpressionUUID->"d7d0cddf-06c9-446d-a18d-\
6086e0b82353"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"soldPDE", "/.", 
            RowBox[{"A3", "\[Rule]", "B6"}]}], "/.", 
           RowBox[{"B8", "\[Rule]", "B6"}]}], "/.", 
          RowBox[{"D7", "\[Rule]", "B7"}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "A6"}]}], "/.", 
        RowBox[{"B7", "\[Rule]", "0"}]}], "/.", 
       RowBox[{"\[Mu]", "\[Rule]", "0"}]}], "/.", 
      RowBox[{"\[Nu]", "->", "0"}]}], "/.", 
     RowBox[{"B6", "\[Rule]", "2"}]}], "/.", 
    RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
   RowBox[{"M", "\[Rule]", "0"}]}], "//", 
  "FullSimplify"}], "\[IndentingNewLine]", 
 RowBox[{"%", "/.", "subhor"}]}], "Input",
 CellChangeTimes->{{3.760967419262813*^9, 3.7609674497562037`*^9}, {
  3.760967526613056*^9, 3.7609675736426086`*^9}, {3.7609676630048027`*^9, 
  3.7609676646630898`*^9}, {3.7609677596250677`*^9, 3.7609677612924557`*^9}, {
  3.763121100677089*^9, 
  3.763121112486868*^9}},ExpressionUUID->"e4419570-41ae-41d2-9750-\
4b86389e1720"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B9", " ", "D9", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["A6", "2"], "+", 
           RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "D11"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", "D9"}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 3.763122115661138*^9, 
   3.7634622125203958`*^9},ExpressionUUID->"05bb5126-daf1-4932-bac9-\
9cfc36e6ff45"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{"B9", " ", "D9", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"\[Delta]\[Rho]m", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["A6", "2"], "+", 
           RowBox[{"2", " ", "D9"}]}], ")"}], " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"A6", " ", "D11"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "A4"}], "+", "B9"}], ")"}], " ", "D9"}]}], ")"}], 
         " ", 
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}]}]]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.7609674305149093`*^9, 3.760967450722547*^9}, 
   3.7609674953324614`*^9, {3.760967527962755*^9, 3.760967542187791*^9}, 
   3.760967574662849*^9, 3.7609676663525467`*^9, 3.7609677623576345`*^9, 
   3.7610286085144053`*^9, 3.76311379795105*^9, 3.763115427499794*^9, {
   3.7631211015378103`*^9, 3.7631211131671486`*^9}, 3.763122115661138*^9, 
   3.7634622125451493`*^9},ExpressionUUID->"078d642c-08cb-48ea-92a9-\
0aa728b66c72"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.763115082136239*^9, 
  3.7631151022566075`*^9}},ExpressionUUID->"4febc991-b712-4a8e-aecb-\
b2ba9decba2c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Coefficients", " ", "//", " ", 
   RowBox[{"run", " ", "this"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.76311405695595*^9, 3.7631140621959715`*^9}, {
  3.763114114611548*^9, 
  3.7631141167663727`*^9}},ExpressionUUID->"3eac66de-3e2b-4b56-b1d4-\
9cdc134ae85a"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", 
     "\[Mu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}]}], ",", "0", ",", 
     
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", "B7", 
     ",", "B8", ",", "B9", ",", "\[Nu]"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"12", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"36", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "36"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"K\[Phi]", "[", "t", "]"}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"C1", ",", "C2", ",", "C3", ",", "C4"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"4", " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "4"}], " ", 
       RowBox[{"G4", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", "D7", ",", "D8", 
     ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}]}], ",", 
     RowBox[{
      RowBox[{"24", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"18", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"15", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "6"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}]}], ",", 
     RowBox[{"4", " ", 
      RowBox[{"G4\[Phi]", "[", "t", "]"}]}], ",", "0", ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{"KX", "[", "t", "]"}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{"2", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "24"}], " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"12", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"36", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"12", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{
       RowBox[{"KXX\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"]}], "-", 
      RowBox[{"4", " ", 
       RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"KX", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"5", " ", 
       RowBox[{"KXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"24", " ", 
       RowBox[{"G3XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KXXX", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3XXX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "5"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "12"}], " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"9", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]X\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
      RowBox[{"2", " ", 
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"6", " ", 
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "-", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{
       RowBox[{"KX\[Phi]X", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}], "+", 
      RowBox[{"3", " ", 
       RowBox[{"G3\[Phi]XX", "[", "t", "]"}], " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       SuperscriptBox[
        RowBox[{
         SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.7610287424727*^9, 3.761028748984979*^9}, {
  3.7631140663258605`*^9, 
  3.763114090298678*^9}},ExpressionUUID->"db44289d-58b6-4268-897e-\
586611d1ef40"],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7631140943260336`*^9, 
  3.763114096275912*^9}},ExpressionUUID->"65ac2757-4f75-4fd8-a7eb-\
68abaab30723"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Geff", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{"Rr", "\[Rule]", "0"}], ",", 
      RowBox[{"fRR", "\[Rule]", "FR"}], ",", 
      RowBox[{
       RowBox[{"F", "[", "t", "]"}], "\[Rule]", "F"}]}], "}"}]}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.7631211585671844`*^9, 3.7631211623070984`*^9}, {
  3.763122148417503*^9, 
  3.763122169989927*^9}},ExpressionUUID->"b85cd775-229a-47f4-9940-\
4fa4e37d66fe"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", "2"],
    "+", 
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "4"], " ", "m"}]}], 
  RowBox[{
   RowBox[{
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
        "2"], " ", "m"}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{"1", "+", 
      RowBox[{"2", " ", 
       SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
        "2"], " ", "m"}]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["F", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}]}]}]]], "Output",
 CellChangeTimes->{
  3.7631211630169344`*^9, {3.7631221233171396`*^9, 
   3.7631221709372015`*^9}},ExpressionUUID->"0c81dc14-84ef-467c-812a-\
51c4c0103725"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"GeffRub", "/.", "fRlimit"}], "//.", "fRextra"}], "/.", 
   RowBox[{"k", "\[Rule]", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     "\"\<(\!\(\*FractionBox[\(k\), \(a\)]\))\>\""}]}]}], "//", 
  "FullSimplify"}]], "Input",
 CellChangeTimes->{{3.763101809150457*^9, 3.7631018648961973`*^9}, {
   3.763101905329755*^9, 3.763101962609453*^9}, {3.7631020677421107`*^9, 
   3.763102068004221*^9}, 3.763113690547677*^9, 3.763113734057954*^9, 
   3.7631143547364793`*^9, {3.7631154529200172`*^9, 
   3.763115454515036*^9}},ExpressionUUID->"c0920caf-7e81-484c-b3ad-\
f8642aaf0353"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   RowBox[{"4", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m"}], "+", 
   RowBox[{"F", "[", "t", "]"}]}], 
  RowBox[{
   RowBox[{"3", " ", 
    SuperscriptBox["\<\"(\\!\\(\\*FractionBox[\\(k\\), \\(a\\)]\\))\"\>", 
     "2"], " ", "F", " ", "m", " ", 
    RowBox[{"F", "[", "t", "]"}]}], "+", 
   SuperscriptBox[
    RowBox[{"F", "[", "t", "]"}], "2"]}]]], "Output",
 CellChangeTimes->{{3.7631018109898095`*^9, 3.7631018662119465`*^9}, 
   3.763101919909732*^9, {3.7631019566797557`*^9, 3.7631019631693273`*^9}, 
   3.7631020722108507`*^9, 3.763102140246998*^9, 3.763113735270893*^9, 
   3.7631141615961914`*^9, {3.7631143508882236`*^9, 3.7631143783025227`*^9}, 
   3.7631151078864684`*^9, {3.7631154501800623`*^9, 3.7631154551422105`*^9}, 
   3.7631164377034683`*^9, 3.763121152956889*^9, 
   3.7631221353275175`*^9},ExpressionUUID->"d1cf4057-07fe-4159-856d-\
edda23065321"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "effective", " ", "fluid", " ", "expressions"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"They", " ", "agree", " ", "with", " ", "our", " ", "f", 
    RowBox[{"(", "R", ")"}], " ", "effective", " ", "paper"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldPDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"soldDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", "FullSimplify"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"solVDE", "/.", "fRlimit"}], "/.", "fRextra"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"H", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{"Rr", "\[Rule]", "0"}], ",", 
       RowBox[{"fRR", "\[Rule]", "FR"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.763114134611041*^9, 3.7631142372359266`*^9}, 
   3.763114314426009*^9, {3.7631143821659684`*^9, 3.7631143908180556`*^9}, {
   3.763115503160205*^9, 3.763115504292551*^9}, {3.7631164227035484`*^9, 
   3.763116429662382*^9}, {3.763116539281295*^9, 3.7631165461681833`*^9}, {
   3.7631211692867537`*^9, 
   3.763121212807345*^9}},ExpressionUUID->"dcc95999-6a7b-4dab-b7dd-\
da0a882dbec2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "FR", " ", 
        SuperscriptBox["k", "6"]}], "+", 
       RowBox[{"6", " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"5", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"F", "[", "t", "]"}]}], ")"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "6"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["F", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "t", "]"}], "2"]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"6", " ", 
      SuperscriptBox["k", "4"], " ", 
      RowBox[{"F", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["k", "2"], " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 
   3.7631221899372272`*^9},ExpressionUUID->"f64760d0-1b23-4059-bf91-\
4d5e70fc807d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"4", " ", "FR", " ", 
        SuperscriptBox["k", "4"]}], "-", 
       RowBox[{"6", " ", "FR", " ", 
        SuperscriptBox["k", "4"], " ", 
        RowBox[{"F", "[", "t", "]"}]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          RowBox[{"F", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{"F", "[", "t", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          RowBox[{"F", "[", "t", "]"}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["k", "2"], " ", 
      RowBox[{"F", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"3", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "FR", " ", 
         SuperscriptBox["k", "2"]}], "+", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"a", "[", "t", "]"}], "2"], " ", 
         RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["F", "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 
   3.7631221900822196`*^9},ExpressionUUID->"2b12c7be-9568-4162-8437-\
b7ec122b2cd3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Delta]\[Rho]m", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
     RowBox[{
      SuperscriptBox["F", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", " ", "FR", " ", 
        SuperscriptBox["k", "4"]}], "+", 
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"F", "[", "t", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
    RowBox[{"2", " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        SuperscriptBox["k", "2"], " ", 
        RowBox[{"F", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"F", "[", "t", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "FR", " ", 
           SuperscriptBox["k", "2"]}], "+", 
          RowBox[{
           SuperscriptBox[
            RowBox[{"a", "[", "t", "]"}], "2"], " ", 
           RowBox[{"F", "[", "t", "]"}]}]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["F", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.763114168995981*^9, 3.7631141796959505`*^9}, {
   3.763114221228054*^9, 3.7631142377910814`*^9}, 3.763114299056079*^9, 
   3.7631143917765684`*^9, 3.76311546091193*^9, 3.763115505541252*^9, {
   3.763116432549697*^9, 3.763116439408099*^9}, 3.7631165466850824`*^9, {
   3.7631211879817486`*^9, 3.763121216856928*^9}, 
   3.7631221901920204`*^9},ExpressionUUID->"b70f87a6-7bce-456a-8a9b-\
7a7ee9f923fb"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "A1", ",", "A2", ",", "A3", ",", "A4", ",", "A5", ",", "A6", ",", "\[Mu]", 
   ",", "B1", ",", "B2", ",", "B3", ",", "B4", ",", "B5", ",", "B6", ",", 
   "B7", ",", "B8", ",", "B9", ",", "\[Nu]", ",", "C1", ",", "C2", ",", "C3", 
   ",", "C4", ",", "D1", ",", "D2", ",", "D3", ",", "D4", ",", "D5", ",", 
   "D7", ",", "D8", ",", "D9", ",", "D10", ",", "D11", ",", "M2"}], 
  "]"}]], "Input",ExpressionUUID->"8943e741-a5fb-4da1-843f-8f7098d06821"],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.7634623086906395`*^9, 
  3.763462309970793*^9}},ExpressionUUID->"64138038-4292-4ace-ac0f-\
7da333db98e8"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"Sound", " ", "speed", " ", "in", " ", "rest", " ", 
   RowBox[{"frame", "?"}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7614725513993692`*^9, 
  3.761472564159005*^9}},ExpressionUUID->"3985db62-482e-4a0f-8190-\
f7001f690e05"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Eq0i", "-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          FractionBox[
           RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
            RowBox[{"a", "[", "t", "]"}], 
            RowBox[{"VDE", "[", 
             RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
            RowBox[{"\[Rho]DE", "[", "t", "]"}]}], 
           SuperscriptBox["k", "2"]], "+", "Eq0i"}], "/.", "rulesGRC"}], 
        ")"}]}], "\[Equal]", "0"}], ",", 
     RowBox[{"VDE", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}], "/.", 
  RowBox[{
   RowBox[{
    SuperscriptBox["f_", 
     TagBox[
      RowBox[{"(", 
       RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
      Derivative],
     MultilineFunction->None], "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   "0"}]}]], "Input",
 CellChangeTimes->{{3.7631158554198527`*^9, 3.7631158618197684`*^9}, 
   3.7631159267299547`*^9},ExpressionUUID->"0ae3a27c-369d-4620-9612-\
2408ce7e10b5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"VDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"C4", " ", 
        RowBox[{"\[Delta]\[Phi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"C3", " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
       RowBox[{"2", " ", 
        RowBox[{"H", "[", "t", "]"}], " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}]}], 
    RowBox[{"8", " ", "G", " ", "\[Pi]", " ", 
     RowBox[{"a", "[", "t", "]"}], " ", 
     RowBox[{"\[Rho]DE", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{
  3.76147188603936*^9, 3.7631138043759212`*^9, 3.763115541862115*^9, 
   3.7631155897951345`*^9, {3.763115859190098*^9, 3.7631158626502314`*^9}, 
   3.7631159277401032`*^9, 3.7631212287267866`*^9, 3.7631222006817904`*^9, 
   3.7634622311801667`*^9},ExpressionUUID->"bd5247f0-0a38-42b7-b5f4-\
83429bf81af7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"C4", " ", 
          RowBox[{"\[Delta]\[Phi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"C3", " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          RowBox[{"\[CapitalPsi]", "[", 
           RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], ")"}], 
       "\[Equal]", "0"}], ",", 
      RowBox[{"\[Delta]\[Phi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.7614718970391417`*^9, 3.761471924311453*^9}, {
  3.7614720011495757`*^9, 
  3.7614720080296535`*^9}},ExpressionUUID->"9a3eb415-6af4-4643-ad63-\
6bf2a24ba95c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Phi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{"C3", "+", 
        RowBox[{"2", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}], " ", 
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "C4"]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.761471915188919*^9, 3.761471924789179*^9}, 
   3.7614720087042613`*^9, 3.7631138067557783`*^9, 3.763115549539934*^9, 
   3.7631155921021914`*^9, 3.763115870524472*^9, 3.763115933960049*^9, 
   3.7631212305267663`*^9, 3.7631222038875384`*^9, 3.763134007571133*^9, 
   3.7634622331326857`*^9},ExpressionUUID->"09f35c96-dc47-47b0-8daa-\
a9ceea6b43c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres2", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"Eqsij", "\[Equal]", "0"}], ",", 
       RowBox[{"\[CapitalPhi]", "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "/.", "solres1"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.761471953831363*^9, 
  3.761472050359288*^9}},ExpressionUUID->"444f6932-c49c-437f-ada8-\
916ce9ffcb91"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[CapitalPhi]", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "C4"}], " ", 
        RowBox[{"G4", "[", "t", "]"}]}], "+", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{"C3", "+", 
          RowBox[{"2", " ", 
           RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}], " ", 
     RowBox[{"\[CapitalPsi]", "[", 
      RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], 
    RowBox[{"C4", " ", 
     RowBox[{"G4", "[", "t", "]"}]}]]}], "}"}]], "Output",
 CellChangeTimes->{{3.761471970979189*^9, 3.761472050833968*^9}, 
   3.7631138094659233`*^9, 3.7631155517814865`*^9, 3.763115593649844*^9, 
   3.763115872872836*^9, 3.763115935665164*^9, 3.763121238506923*^9, 
   3.763122205057131*^9, 3.763134009187193*^9, 
   3.763462237805515*^9},ExpressionUUID->"71272e49-92e4-47fd-9a21-\
cef3621a9c0e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres3", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eq00", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"-", "8"}], " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]\[Rho]DE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eq00"}], "/.", "rulesGRA"}], ")"}]}], "\[Equal]", "0"}], ",", 
         RowBox[{"\[Delta]\[Rho]DE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{
  3.761471944799088*^9, {3.7614720568094683`*^9, 3.7614720965613728`*^9}, {
   3.7631158760098076`*^9, 3.763115877810362*^9}, 
   3.7631159378905425`*^9},ExpressionUUID->"a2b7782e-cdc8-45f0-a470-\
3b9845e04312"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]\[Rho]DE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{"-", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", 
           SuperscriptBox["k", "2"], " ", 
           RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"C3", "+", 
             RowBox[{"2", " ", 
              RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
          RowBox[{
           RowBox[{"G4", "[", "t", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["k", "2"]}], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"A6", " ", "C3"}], "+", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "2"}], "+", "A3"}], ")"}], " ", "C4"}], "+", 
                RowBox[{"2", " ", "A6", " ", 
                 RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"a", "[", "t", "]"}], "2"], " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"A4", " ", "C4"}], "+", 
                RowBox[{"C3", " ", "\[Mu]"}], "+", 
                RowBox[{"2", " ", 
                 RowBox[{"H", "[", "t", "]"}], " ", 
                 RowBox[{"(", 
                  RowBox[{"\[Mu]", "+", 
                   RowBox[{"3", " ", "C4", " ", 
                    RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], ")"}], " ", 
        RowBox[{"\[CapitalPsi]", "[", 
         RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], ")"}], "/", 
      RowBox[{"(", 
       RowBox[{"8", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"G4", "[", "t", "]"}]}], ")"}]}], ")"}]}]}], "}"}]], "Output",\

 CellChangeTimes->{3.7614719460993567`*^9, 3.7614720657493687`*^9, 
  3.7614720971790533`*^9, 3.76311381721595*^9, 3.7631155563017883`*^9, 
  3.763115596749812*^9, 3.763115879100114*^9, 3.7631159390147943`*^9, 
  3.763121241389372*^9, 3.7631222073864717`*^9, 3.7631340114093285`*^9, 
  3.7634622405003614`*^9},ExpressionUUID->"8ed259f7-9e52-401c-907e-\
c2609bedf5e6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"solres4", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"Solve", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Eqii", "-", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"24", " ", "G", " ", "\[Pi]", " ", 
               RowBox[{"\[Delta]PDE", "[", 
                RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "+", 
              "Eqii"}], "/.", "rulesGRABCD"}], ")"}]}], "\[Equal]", "0"}], 
         ",", 
         RowBox[{"\[Delta]PDE", "[", 
          RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]}], "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["f_", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"n_", ",", "0", ",", "0", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
       "0"}]}], "/.", "solres1"}], "/.", "solres2"}], "//", 
   "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.76147208348938*^9, 3.7614721029591475`*^9}, {
   3.7631158900225515`*^9, 3.7631158918101482`*^9}, 
   3.763115941560336*^9},ExpressionUUID->"4eade83d-d23e-433e-bfb9-\
325ca2283ead"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Delta]PDE", "[", 
    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"\[CapitalPsi]", "[", 
       RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "2"}], "+", "B6"}], ")"}], " ", 
         SuperscriptBox["k", "2"], " ", 
         RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"C3", "+", 
           RowBox[{"2", " ", 
            RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["k", "2"]}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B7", " ", "C3"}], "+", 
              RowBox[{"B6", " ", "C4"}], "-", 
              RowBox[{"B8", " ", "C4"}], "+", 
              RowBox[{"2", " ", "B7", " ", 
               RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"a", "[", "t", "]"}], "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"B9", " ", "C4"}], "-", 
              RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
              RowBox[{"6", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"(", 
                RowBox[{"\[Nu]", "-", 
                 RowBox[{"3", " ", "C4", " ", 
                  RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
              RowBox[{"12", " ", "C4", " ", 
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}]}], 
          ")"}]}]}], ")"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"24", " ", "C4", " ", "G", " ", "\[Pi]", " ", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "2"], " ", 
      RowBox[{"G4", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761472078879323*^9, 3.7614721041992617`*^9}, 
   3.7631138199222736`*^9, 3.7631155701724977`*^9, 3.7631156120123816`*^9, 
   3.7631158934720345`*^9, 3.763115942599981*^9, 3.763121255126955*^9, 
   3.763122209486991*^9, 3.763134013940463*^9, {3.7634622438505516`*^9, 
   3.763462270550702*^9}},ExpressionUUID->"d7273d6e-2ca8-4121-bb41-\
49abcf876b7a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"In", " ", "the", " ", "rest"}], "-", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             FractionBox[
              RowBox[{"\[Delta]PDE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
              RowBox[{"\[Delta]\[Rho]DE", "[", 
               RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.", 
             "solres4"}], "/.", "solres3"}], "/.", 
           RowBox[{"B6", "\[Rule]", 
            RowBox[{"4", " ", 
             RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"B8", "\[Rule]", 
           RowBox[{"4", " ", 
            RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"A3", "\[Rule]", 
          RowBox[{"4", 
           RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
        RowBox[{
         RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
         RowBox[{"1", "/", "2"}]}]}], "/.", 
       RowBox[{
        RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
      RowBox[{"B7", "\[Rule]", "0"}]}], "/.", "subhorflex"}], "//", 
    "FullSimplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"cs2", "->", "%"}], "/.", 
            RowBox[{"C3", "\[Rule]", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "3"}], " ", 
               RowBox[{"G3X", "[", "t", "]"}]}], "-", 
              RowBox[{"4", " ", 
               RowBox[{"H", "[", "t", "]"}], " ", 
               RowBox[{"G4", "[", "t", "]"}]}]}]}]}], "/.", 
           RowBox[{"A6", "\[Rule]", 
            RowBox[{
             RowBox[{"-", 
              RowBox[{
               RowBox[{
                RowBox[{"\[Phi]", "'"}], "[", "t", "]"}], "^", "2"}]}], " ", 
             RowBox[{"G3X", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"C4", "->", 
           RowBox[{
            RowBox[{
             RowBox[{"KX", "[", "t", "]"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}]}], "+", 
            RowBox[{"3", " ", 
             RowBox[{"G3X", "[", "t", "]"}], " ", 
             RowBox[{"H", "[", "t", "]"}], " ", 
             SuperscriptBox[
              RowBox[{
               SuperscriptBox["\[Phi]", "\[Prime]",
                MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
         RowBox[{"B9", "->", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "18"}], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
           RowBox[{"12", " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "-", 
           RowBox[{"3", " ", 
            RowBox[{"KX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
           RowBox[{"12", " ", 
            RowBox[{"G3X", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}], "+", 
           RowBox[{"3", " ", 
            RowBox[{"G3XX", "[", "t", "]"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["\[Phi]", "\[Prime]",
               MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
        RowBox[{"\[Nu]", "->", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
       RowBox[{"A4", "->", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "6"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
         RowBox[{"12", " ", 
          RowBox[{"G3X", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "4"]}], "+", 
         RowBox[{"3", " ", 
          RowBox[{"G3XX", "[", "t", "]"}], " ", 
          RowBox[{"H", "[", "t", "]"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}], "5"]}]}]}]}], "/.", 
      RowBox[{"\[Mu]", "->", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
        RowBox[{
         RowBox[{"KX\[Phi]", "[", "t", "]"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["\[Phi]", "\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
        RowBox[{"1", "/", "2"}]}], ",", 
       RowBox[{
        RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
       RowBox[{
        RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
       RowBox[{
        RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614721200917377`*^9, 3.7614721486394243`*^9}, {
   3.7614721804992604`*^9, 3.7614721918691998`*^9}, {3.7614722326390114`*^9, 
   3.7614722779989214`*^9}, {3.761472312289319*^9, 3.7614723190388966`*^9}, {
   3.7614723515292892`*^9, 3.761472368269771*^9}, {3.7614724032092724`*^9, 
   3.7614724857990074`*^9}, {3.7614727130217075`*^9, 
   3.7614727147291737`*^9}, {3.7614727687391253`*^9, 
   3.7614727795990305`*^9}, {3.7614728256989756`*^9, 3.761472830231369*^9}, {
   3.7614728609892225`*^9, 3.7614728632111177`*^9}, {3.761472893969224*^9, 
   3.761473009929489*^9}, {3.761473708378744*^9, 3.7614737373417807`*^9}, {
   3.7631158210000095`*^9, 3.7631158360302916`*^9}, 3.763115945350172*^9, {
   3.763121298017347*^9, 3.7631213054969654`*^9}, 
   3.7631340406792617`*^9},ExpressionUUID->"529f2bcd-8a78-4692-bc18-\
0f509a7a0aac"],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"B9", " ", "C4"}], "-", 
     RowBox[{"3", " ", "C3", " ", "\[Nu]"}], "-", 
     RowBox[{"6", " ", 
      RowBox[{"H", "[", "t", "]"}], " ", 
      RowBox[{"(", 
       RowBox[{"\[Nu]", "-", 
        RowBox[{"3", " ", "C4", " ", 
         RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "+", 
     RowBox[{"12", " ", "C4", " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]}]}], ")"}]}], 
  RowBox[{
   RowBox[{"3", " ", "A6", " ", 
    SuperscriptBox["k", "2"], " ", 
    RowBox[{"(", 
     RowBox[{"C3", "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}], "-", 
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"a", "[", "t", "]"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"A4", " ", "C4"}], "+", 
      RowBox[{"C3", " ", "\[Mu]"}], "+", 
      RowBox[{"2", " ", 
       RowBox[{"H", "[", "t", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{"\[Mu]", "+", 
         RowBox[{"3", " ", "C4", " ", 
          RowBox[{"H", "[", "t", "]"}]}]}], ")"}]}]}], ")"}]}]}]]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 3.7631213071168237`*^9}, 3.7631222121070485`*^9, 
   3.76313404212954*^9, 3.763134130547038*^9, 
   3.763462289250354*^9},ExpressionUUID->"07a551da-3099-4d94-aad2-\
6140a4ec824f"],

Cell[BoxData[
 RowBox[{"cs2", "\[Rule]", "1"}]], "Output",
 CellChangeTimes->{{3.7614721310514145`*^9, 3.761472149639283*^9}, 
   3.7614721945290365`*^9, {3.76147223692889*^9, 3.76147227935435*^9}, 
   3.7614723208092365`*^9, {3.7614723555492244`*^9, 3.7614723687693815`*^9}, {
   3.761472423861476*^9, 3.7614724862891035`*^9}, 3.761472716873892*^9, 
   3.761472769649106*^9, 3.7614728326090326`*^9, 3.7614728666187963`*^9, {
   3.7614729023689604`*^9, 3.7614729506991324`*^9}, {3.761472981611308*^9, 
   3.761473011953796*^9}, {3.761473716210994*^9, 3.761473742129*^9}, 
   3.763113823836*^9, 3.7631156157599025`*^9, {3.7631158225034504`*^9, 
   3.763115836705008*^9}, 3.7631158972500267`*^9, 3.763115947390077*^9, {
   3.7631212823868027`*^9, 3.7631213071168237`*^9}, 3.7631222121070485`*^9, 
   3.76313404212954*^9, 3.763134130547038*^9, 
   3.763462289250354*^9},ExpressionUUID->"5e945b86-3c5a-4719-860e-\
4054174a95d0"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"In", " ", "a", " ", "general", " ", "frame"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"cs2gen", "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{
                 RowBox[{
                  RowBox[{
                   RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    FractionBox[
                    RowBox[{"\[Delta]PDE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}], 
                    RowBox[{"\[Delta]\[Rho]DE", "[", 
                    RowBox[{"t", ",", "x", ",", "y", ",", "z"}], "]"}]], "/.",
                     "soldDE"}], "/.", "soldPDE"}], "/.", 
                    RowBox[{"B6", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B8", "\[Rule]", 
                    RowBox[{"4", " ", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"A3", "\[Rule]", 
                    RowBox[{"4", 
                    RowBox[{"G4", "[", "t", "]"}]}]}]}], "/.", 
                    RowBox[{"B7", "\[Rule]", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}]}], "/.", 
                    "subhorflex"}], "/.", 
                    RowBox[{"B4", "->", 
                    RowBox[{
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
                    RowBox[{"A2", "\[Rule]", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"9", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
                    RowBox[{
                    RowBox[{"KXX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}]}]}]}], "/.", 
                    RowBox[{"B2", "->", 
                    RowBox[{
                    RowBox[{"6", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                    RowBox[{"C3", "\[Rule]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "4"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "3"]}]}]}]}], "/.", 
                    RowBox[{"A6", "\[Rule]", 
                    RowBox[{
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                   RowBox[{"C4", "->", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}]}], "-", 
                    RowBox[{"2", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"2", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}]}]}]}], "/.", 
                  RowBox[{"B9", "->", 
                   RowBox[{
                    RowBox[{
                    RowBox[{"-", "36"}], " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["H", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "-", 
                    RowBox[{"24", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{"H", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"6", " ", 
                    RowBox[{"G3\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "-", 
                    RowBox[{"3", " ", 
                    RowBox[{"KX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3\[Phi]X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}], "-", 
                    RowBox[{"12", " ", 
                    RowBox[{"G4\[Phi]", "[", "t", "]"}], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"12", " ", 
                    RowBox[{"G3X", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}], "+", 
                    RowBox[{"3", " ", 
                    RowBox[{"G3XX", "[", "t", "]"}], " ", 
                    SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
                 RowBox[{"\[Nu]", "->", 
                  RowBox[{"K\[Phi]", "[", "t", "]"}]}]}], "/.", 
                RowBox[{"A4", "->", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "6"}], " ", 
                   SuperscriptBox[
                    RowBox[{"H", "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "2"]}], "+", 
                  RowBox[{
                   RowBox[{"KXX", "[", "t", "]"}], " ", 
                   SuperscriptBox[
                    RowBox[{
                    SuperscriptBox["\[Phi]", "\[Prime]",
                    MultilineFunction->None], "[", "t", "]"}], "4"]}]}]}]}], "/.", 
               RowBox[{"\[Mu]", "->", 
                RowBox[{"-", 
                 RowBox[{"K\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
              RowBox[{"D8", "\[Rule]", "0"}]}], "/.", 
             RowBox[{"D7", "\[Rule]", "0"}]}], "/.", 
            RowBox[{"M", "\[Rule]", 
             SqrtBox["M2"]}]}], "/.", 
           RowBox[{"M2", "\[Rule]", 
            RowBox[{"-", 
             RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}]}]}]}], "/.", 
          RowBox[{"D9", "\[Rule]", 
           RowBox[{"-", 
            RowBox[{"KX", "[", "t", "]"}]}]}]}], "/.", 
         RowBox[{"D10", "\[Rule]", "0"}]}], "/.", 
        RowBox[{"D11", "\[Rule]", 
         RowBox[{
          RowBox[{"6", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"3", " ", 
           RowBox[{"H", "[", "t", "]"}], " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "3"]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{"KX", "[", "t", "]"}], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"KXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}], "+", 
          RowBox[{
           RowBox[{"KXXX", "[", "t", "]"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "t", "]"}], "4"], " ", 
           RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
          RowBox[{"1", "/", "2"}]}], ",", 
         RowBox[{
          RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
         RowBox[{
          RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"KXXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
         RowBox[{
          RowBox[{
           SuperscriptBox["G4\[Phi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "t", "]"}], "\[Rule]", "0"}]}], 
        "}"}]}], "/.", 
      RowBox[{
       RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
         MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
       RowBox[{
        RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
        RowBox[{"3", " ", 
         RowBox[{"H", "[", "t", "]"}], " ", 
         RowBox[{
          SuperscriptBox["\[Phi]", "\[Prime]",
           MultilineFunction->None], "[", "t", "]"}]}]}]}]}], "/.", 
     RowBox[{
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          SuperscriptBox[
           RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
         RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}]}], "//", 
    "FullSimplify"}]}]}]], "Input",
 CellChangeTimes->{{3.7614756379174366`*^9, 3.76147568953691*^9}, {
   3.7614757263370914`*^9, 3.761475958304971*^9}, {3.761476048957116*^9, 
   3.7614760632469234`*^9}, {3.7614763452470846`*^9, 3.76147636870883*^9}, {
   3.7614764569268293`*^9, 3.761476458271467*^9}, {3.76147656326256*^9, 
   3.761476564859185*^9}, {3.7614766282267957`*^9, 3.761476692631748*^9}, {
   3.7614767336265616`*^9, 3.7614767480766664`*^9}, {3.761476783486722*^9, 
   3.7614768313469687`*^9}, {3.7614771328169327`*^9, 3.761477133236987*^9}, 
   3.761477402776991*^9, 3.763115827884598*^9, 3.763115912365671*^9, 
   3.7631159501848774`*^9, {3.763116027695698*^9, 3.763116052252181*^9}, {
   3.763121309557479*^9, 3.7631213164173107`*^9}, {3.7631223630075283`*^9, 
   3.7631223779171925`*^9}, {3.7631224589874425`*^9, 
   3.7631224928674297`*^9}, {3.7631225348072133`*^9, 3.763122576617199*^9}, {
   3.763134026578411*^9, 
   3.7631340342870765`*^9}},ExpressionUUID->"0a051423-f6ce-49ed-bd33-\
c926035fbf1b"],

Cell[BoxData[
 RowBox[{"1", "+", 
  FractionBox[
   RowBox[{
    RowBox[{
     RowBox[{"-", "4"}], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"K\[Phi]", "[", "t", "]"}], "2"]}], "-", 
    RowBox[{"2", " ", 
     RowBox[{"K", "[", "t", "]"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}]}]}], ")"}]}]}], 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"K\[Phi]", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"], " ", 
        RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}]]}]], "Output",
 CellChangeTimes->{{3.7614756472519145`*^9, 3.7614756926065903`*^9}, {
   3.761475740091787*^9, 3.7614758147669015`*^9}, 3.7614758539493217`*^9, {
   3.761475937031951*^9, 3.761475959253948*^9}, 3.761476065157156*^9, {
   3.7614763470866065`*^9, 3.761476353997134*^9}, {3.7614764480070596`*^9, 
   3.7614764599522624`*^9}, 3.761476565546674*^9, {3.76147664327186*^9, 
   3.761476670421854*^9}, {3.76147680656666*^9, 3.7614768317975225`*^9}, 
   3.7614771353316383`*^9, 3.7614774065766478`*^9, 3.763113840095704*^9, 
   3.763115624425024*^9, 3.7631158300199695`*^9, 3.763115913200203*^9, 
   3.7631159516602564`*^9, {3.7631160308620434`*^9, 3.7631160400904016`*^9}, 
   3.763121284941904*^9, 3.7631213192667665`*^9, 3.763122215632853*^9, {
   3.763122357757098*^9, 3.763122385437146*^9}, {3.7631224721660748`*^9, 
   3.7631224992970867`*^9}, {3.7631225726990604`*^9, 3.7631225847820225`*^9}, 
   3.763134045829632*^9, 3.763134133446569*^9, 
   3.763462297360429*^9},ExpressionUUID->"288200c8-4441-4895-984d-\
f0d7a16784c1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"V", "[", "\[Phi]_", "]"}], ":=", 
  RowBox[{
   FractionBox["1", "2"], 
   RowBox[{"m", "^", "2"}], " ", 
   RowBox[{"\[Phi]", "^", "2"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"cs2gen1", "=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"cs2gen", "/.", 
      RowBox[{
       RowBox[{"K", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"X0", "+", 
        RowBox[{"V", "[", 
         RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}]}], "/.", 
     RowBox[{
      RowBox[{"K\[Phi]", "[", "t", "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"V", "'"}], "[", 
       RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "/.", 
    RowBox[{
     RowBox[{"K\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"V", "''"}], "[", 
      RowBox[{"\[Phi]", "[", "t", "]"}], "]"}]}]}], "//", 
   "FullSimplify"}]}], "\[IndentingNewLine]", 
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"cs2gen1", "/.", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
     RowBox[{"\[Epsilon]", " ", "m", " ", 
      RowBox[{"\[Phi]", "[", "t", "]"}]}]}]}], ",", 
   RowBox[{"{", 
    RowBox[{"m", ",", "\[Infinity]", ",", "2"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614774489467955`*^9, 3.7614779250165815`*^9}, {
   3.761477977411518*^9, 3.7614779948497677`*^9}, {3.7631139412058153`*^9, 
   3.763113942055827*^9}, {3.7631213526017084`*^9, 3.763121388307263*^9}, 
   3.7631341570756016`*^9, {3.763134285909507*^9, 
   3.7631343174318323`*^9}},ExpressionUUID->"8f29872c-b1af-4225-90dd-\
4a0a71d87241"],

Cell[BoxData[
 RowBox[{"-", 
  FractionBox[
   RowBox[{
    SuperscriptBox["m", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["k", "2"], "+", 
      RowBox[{
       SuperscriptBox["m", "2"], " ", 
       SuperscriptBox[
        RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
    SuperscriptBox[
     RowBox[{"\[Phi]", "[", "t", "]"}], "2"]}], 
   RowBox[{
    RowBox[{"2", " ", 
     SuperscriptBox["m", "4"], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"\[Phi]", "[", "t", "]"}], "2"]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["k", "2"], "-", 
       RowBox[{
        SuperscriptBox["m", "2"], " ", 
        SuperscriptBox[
         RowBox[{"a", "[", "t", "]"}], "2"]}]}], ")"}], " ", 
     SuperscriptBox[
      RowBox[{
       SuperscriptBox["\[Phi]", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}], "2"]}]}]]}]], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 3.763121388956871*^9}, 
   3.763134149772596*^9, {3.7631342800674496`*^9, 3.763134318352883*^9}, 
   3.763462303250451*^9},ExpressionUUID->"8f1e7d5c-17bd-4ad4-9697-\
57308b520436"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox["1", 
    RowBox[{
     RowBox[{"-", "2"}], "+", 
     SuperscriptBox["\[Epsilon]", "2"]}]], "+", 
   FractionBox[
    RowBox[{"2", " ", 
     SuperscriptBox["k", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       SuperscriptBox["\[Epsilon]", "2"]}], ")"}]}], 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", 
        SuperscriptBox["\[Epsilon]", "2"]}], ")"}], "2"], " ", 
     SuperscriptBox[
      RowBox[{"a", "[", "t", "]"}], "2"], " ", 
     SuperscriptBox["m", "2"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", 
      FractionBox["1", "m"], "]"}], "3"],
    SeriesData[$CellContext`m, 
     DirectedInfinity[1], {}, 0, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`m, 
   DirectedInfinity[
   1], {(-2 + $CellContext`\[Epsilon]^2)^(-1), 0, 
    2 $CellContext`k^2 (-2 + $CellContext`\[Epsilon]^2)^(-2) (-1 + \
$CellContext`\[Epsilon]^2) $CellContext`a[$CellContext`t]^(-2)}, 0, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.761477449647174*^9, 3.7614774729815307`*^9}, {
   3.761477504206897*^9, 3.761477514186728*^9}, {3.761477553876737*^9, 
   3.7614775907063975`*^9}, {3.761477621934631*^9, 3.761477905801426*^9}, {
   3.7614779721416283`*^9, 3.761477979161363*^9}, 3.7614780277206855`*^9, 
   3.7631138457460237`*^9, 3.763113943046124*^9, 3.763115706114865*^9, 
   3.7631213225974355`*^9, {3.763121354397581*^9, 3.763121388956871*^9}, 
   3.763134149772596*^9, {3.7631342800674496`*^9, 3.763134318352883*^9}, 
   3.763462303270789*^9},ExpressionUUID->"d8bd3d55-1f01-49bb-8e53-\
9d2cd3fc5bcf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"eq11", "/.", "zeroorder"}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
       RowBox[{"1", "/", "2"}]}], ",", 
      RowBox[{
       RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
      RowBox[{
       RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
      RowBox[{
       RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], "}"}]}],
    "/.", 
   RowBox[{
    RowBox[{"Pm", "[", "t", "]"}], "\[Rule]", "0"}]}], "/.", 
  RowBox[{
   RowBox[{"G4\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", 
   "0"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"H", "'"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614770642968874`*^9, 
  3.761477126561428*^9}},ExpressionUUID->"213e5907-07f5-4ea6-ae27-\
8422cf5eaa89"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox[
     RowBox[{"H", "[", "t", "]"}], "2"]}], "2"], "+", 
  FractionBox[
   RowBox[{"K", "[", "t", "]"}], "2"], "+", 
  RowBox[{
   SuperscriptBox["H", "\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 
   3.7631213941771016`*^9},ExpressionUUID->"90b68619-1a03-4cfe-9769-\
efeeae29b183"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["H", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    FractionBox["1", "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "3"}], " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "t", "]"}], "2"]}], "-", 
      RowBox[{"K", "[", "t", "]"}]}], ")"}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7614770669366693`*^9, 3.7614771269814177`*^9}, 
   3.76311392891586*^9, 3.7631213254393826`*^9, 
   3.763121394197058*^9},ExpressionUUID->"5e4412a8-6d5b-4579-a227-\
b30b96b8f722"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"scaleq", "/.", "zeroorder"}], "/.", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"G4", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"1", "/", "2"}]}], ",", 
    RowBox[{
     RowBox[{"KX", "[", "t", "]"}], "\[Rule]", "1"}], ",", 
    RowBox[{
     RowBox[{"KX\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3XX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"KXX", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]X", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G4\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}], ",", 
    RowBox[{
     RowBox[{"G3\[Phi]\[Phi]", "[", "t", "]"}], "\[Rule]", "0"}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{"%", "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"\[Phi]", "''"}], "[", "t", "]"}]}], "]"}], "[", 
  RowBox[{"[", "1", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7614759946317997`*^9, 3.761476039417528*^9}, {
  3.7614773827764387`*^9, 
  3.761477393256817*^9}},ExpressionUUID->"b00a40b4-57e8-437a-95bc-\
e89c3632e7a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   RowBox[{"K\[Phi]", "[", "t", "]"}]}], "+", 
  RowBox[{"3", " ", 
   RowBox[{"H", "[", "t", "]"}], " ", 
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}]}], "+", 
  RowBox[{
   SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
    MultilineFunction->None], "[", "t", "]"}]}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270069256`*^9},ExpressionUUID->"379e1483-5fa1-4eb6-ad85-\
5a15ae1ce263"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "\[Rule]", 
   RowBox[{
    RowBox[{"K\[Phi]", "[", "t", "]"}], "-", 
    RowBox[{"3", " ", 
     RowBox[{"H", "[", "t", "]"}], " ", 
     RowBox[{
      SuperscriptBox["\[Phi]", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.761475997512003*^9, 3.7614760398071337`*^9}, {
   3.761477390467184*^9, 3.7614773937213845`*^9}, 3.763113931705803*^9, 
   3.7631213270269775`*^9},ExpressionUUID->"92dd6490-afa3-4797-ba3c-\
d53c904ada38"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",ExpressionUUID->"b7e0a758-bffe-4ff5-837e-f8bd504a4f22"]
}, Closed]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{"--", 
   RowBox[{"--", 
    RowBox[{"--", 
     RowBox[{"--", 
      RowBox[{"--", 
       RowBox[{"--", 
        RowBox[{"--", 
         RowBox[{"--", 
          RowBox[{"--", 
           RowBox[{"--", 
            RowBox[{"--", 
             RowBox[{"--", 
              RowBox[{"--", 
               RowBox[{"--", 
                RowBox[{"--", 
                 RowBox[{"--", 
                  RowBox[{"--", 
                   RowBox[{"--", "-"}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}]}], " ",
   "*)"}]], "Input",
 CellChangeTimes->{{3.7514658650834045`*^9, 3.751465866768694*^9}, {
  3.7533443727859783`*^9, 
  3.753344374717942*^9}},ExpressionUUID->"9292f020-ab30-408a-b3bb-\
090259ef4e11"]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", "end", " ", "*)"}]], "Input",
 CellChangeTimes->{{3.7275177697880125`*^9, 
  3.7275177743514357`*^9}},ExpressionUUID->"64af0b94-a472-445b-8855-\
c20200ec1c45"]
}, Open  ]],

Cell["", "Text",
 FontSize->10,
 FontColor->RGBColor[
  0, 0, 1],ExpressionUUID->"7930e970-38f8-4ecb-ae4d-5a27665d1aaa"]
},
CellGrouping->Manual,
WindowSize->{953, 997},
WindowMargins->{{-6, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"11.2 for Microsoft Windows (64-bit) (September 10, 2017)",
StyleDefinitions->"Default.nb",
MacintoshSystemPageSetup -> \
"0040001804P000000aP2I0000003609To`83609T0@00001804P000000aP2I001\n\
0@00I00100000@0200000BL?00400000000000000000051`I6H0I00000000000\n\
00000000000000000000000000000000"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 177, 4, 43, "Input",ExpressionUUID->"46e16825-9137-474e-8a90-926dc5d4657e"],
Cell[CellGroupData[{
Cell[760, 28, 445, 15, 236, "Text",ExpressionUUID->"93712e9f-463d-418a-aa7e-ede3df646b0f"],
Cell[1208, 45, 146, 5, 46, "Text",ExpressionUUID->"5d38bb7e-caba-4a3a-819d-4ab9175b2d11"],
Cell[1357, 52, 1271, 47, 240, "Text",ExpressionUUID->"c55db92e-c919-43f8-8a2b-3ac0cca1e381"]
}, Closed]],
Cell[2643, 102, 966, 32, 58, "Text",ExpressionUUID->"873d17d5-d20d-454f-9abb-c61f78b0b6bd"],
Cell[CellGroupData[{
Cell[3634, 138, 204, 5, 92, "Section",ExpressionUUID->"173c2924-6d97-4a8d-a555-e9aae66fa09a"],
Cell[CellGroupData[{
Cell[3863, 147, 80, 2, 73, "Subsection",ExpressionUUID->"2b324f19-b4f9-480b-a233-3efa58047f54"],
Cell[3946, 151, 870, 23, 196, "Text",ExpressionUUID->"4c8972a6-079f-4079-9879-4b2f18827fb8"],
Cell[4819, 176, 811, 23, 196, "Text",ExpressionUUID->"69fb5a1d-8a3a-460d-9255-7d430e99623f"],
Cell[5633, 201, 1206, 57, 105, "Text",ExpressionUUID->"2c670a48-25e0-4fd7-9369-054957ac0082"]
}, Closed]],
Cell[CellGroupData[{
Cell[6876, 263, 98, 2, 47, "Subsection",ExpressionUUID->"6caee4e7-dbdf-4e38-bac3-2e8699d611ab"],
Cell[6977, 267, 1662, 55, 302, "Text",ExpressionUUID->"5f209b81-a7b6-4560-967c-b30ccadb1815"],
Cell[CellGroupData[{
Cell[8664, 326, 924, 32, 196, "Text",ExpressionUUID->"68bf135f-0e63-4ca9-9f3a-6c16c774fa8f"],
Cell[9591, 360, 209, 8, 0, "Text",ExpressionUUID->"18e13e01-555f-4c6e-91cb-19935052484f"],
Cell[9803, 370, 215, 8, 0, "Text",ExpressionUUID->"47be14e5-260f-41b5-bd36-4ab48f10f48d"],
Cell[10021, 380, 265, 10, 0, "Text",ExpressionUUID->"9f05d15d-1a7e-4ab6-b139-6ec1544670f6"],
Cell[10289, 392, 250, 11, 0, "Text",ExpressionUUID->"3780f30b-e153-437d-89b3-3ed073daf029"],
Cell[10542, 405, 269, 11, 0, "Text",ExpressionUUID->"1b41e437-9be5-455f-bfe6-7014cd463f88"],
Cell[10814, 418, 373, 17, 0, "Text",ExpressionUUID->"9972d9ed-e4c5-4de4-9df0-cbaf8f52e1bf"],
Cell[11190, 437, 507, 24, 0, "Text",ExpressionUUID->"eedf1b2b-5ac2-4884-b9c3-b5aa3ec0ccab"],
Cell[11700, 463, 343, 16, 0, "Text",ExpressionUUID->"2bb2efa8-a043-4f9c-8043-0e2250e5bea7"],
Cell[12046, 481, 217, 8, 0, "Text",ExpressionUUID->"ac57db93-a796-4e9c-8bca-ae7433ded89f"]
}, Closed]],
Cell[12278, 492, 1091, 35, 188, "Text",ExpressionUUID->"e5b3baba-41da-4518-bcf3-2096c7e90d85"],
Cell[13372, 529, 1399, 42, 303, "Text",ExpressionUUID->"0d551833-618c-413f-b08d-64e5e8b7137e"],
Cell[CellGroupData[{
Cell[14796, 575, 110, 2, 150, "Subsubsection",ExpressionUUID->"0e534907-8848-4087-bfa8-a7b970096715"],
Cell[14909, 579, 645, 22, 15, "Text",ExpressionUUID->"a59513f9-7c51-4b43-a546-e76fce43ae08"],
Cell[15557, 603, 467, 20, 9, "Text",ExpressionUUID->"3e4b7901-2c3d-405e-ae78-271120c697a7"],
Cell[16027, 625, 456, 21, 9, "Text",ExpressionUUID->"719c43b6-1ad9-4a4f-845d-c6f829573e51"],
Cell[16486, 648, 568, 23, 15, "Text",ExpressionUUID->"9a81196d-fdbf-46dd-8263-bec2986157c0"],
Cell[17057, 673, 436, 20, 0, "Text",ExpressionUUID->"1d378a62-742f-4d30-b712-622170e94e08"],
Cell[17496, 695, 145, 9, 0, "Text",ExpressionUUID->"932ceba4-13ce-4423-99df-dabfee9f8d76"],
Cell[17644, 706, 581, 25, 0, "Text",ExpressionUUID->"56e76f6b-150d-4644-bc65-3d2eb67e69eb"],
Cell[18228, 733, 1422, 58, 33, "Text",ExpressionUUID->"feb250c6-0dc5-4864-af65-c9721ed52b1a"]
}, Closed]],
Cell[19665, 794, 286, 11, 352, "Text",ExpressionUUID->"4c2f5789-22bd-4eeb-b883-c6b8022c1d81"]
}, Closed]],
Cell[CellGroupData[{
Cell[19988, 810, 116, 2, 47, "Subsection",ExpressionUUID->"68d12292-51e5-4176-a124-fe361bc980eb"],
Cell[20107, 814, 281, 12, 13, "Text",ExpressionUUID->"cb46d9f3-1b39-4412-80a0-4da3d42a81f1"],
Cell[20391, 828, 182, 8, 0, "Text",ExpressionUUID->"3f1b374e-6f88-4b08-92d5-d6fb9cb9e33b"],
Cell[20576, 838, 300, 15, 0, "Text",ExpressionUUID->"39063825-66a8-4f7c-b89d-e35dce99956e"],
Cell[20879, 855, 212, 9, 13, "Text",ExpressionUUID->"0bc7bd6b-01dd-4b4d-8032-8692f1a93dad"],
Cell[21094, 866, 465, 21, 13, "Text",ExpressionUUID->"bc68b52f-2e6d-44eb-a1c7-8e558ad6ad0a"],
Cell[21562, 889, 465, 21, 13, "Text",ExpressionUUID->"b54ebef1-ad6d-4874-ab4c-1bea8720758d"],
Cell[22030, 912, 660, 32, 19, "Text",ExpressionUUID->"071cc2a5-0ff5-4ded-8469-db6a193a7be3"],
Cell[22693, 946, 567, 27, 19, "Text",ExpressionUUID->"eb136a01-5be6-478e-9ec4-0fb532bf3ac5"],
Cell[23263, 975, 309, 15, 13, "Text",ExpressionUUID->"ead68687-1dca-46f1-9cff-56896a36c7fb"],
Cell[23575, 992, 518, 24, 13, "Text",ExpressionUUID->"e83236e5-8e85-4017-88eb-8a07932b83a1"],
Cell[24096, 1018, 1112, 54, 33, "Text",ExpressionUUID->"75baf6eb-3e43-45d1-a60a-d25b66f40262"]
}, Closed]],
Cell[CellGroupData[{
Cell[25245, 1077, 97, 2, 47, "Subsection",ExpressionUUID->"f60eec5e-56ea-4898-918b-1bf4a751fe7f"],
Cell[25345, 1081, 732, 21, 161, "Text",ExpressionUUID->"8ada4136-3fc1-4de6-8fa4-13a13b9a60ae"],
Cell[26080, 1104, 375, 18, 54, "Text",ExpressionUUID->"5fb3fc67-e161-4f42-bc21-919661cb1910"],
Cell[26458, 1124, 246, 13, 54, "Text",ExpressionUUID->"7e360fa6-3f45-4ed2-982d-450fad317033"],
Cell[26707, 1139, 446, 20, 90, "Text",ExpressionUUID->"859dd086-a6a1-4807-9d8c-b736ac2e486a"],
Cell[27156, 1161, 431, 16, 90, "Text",ExpressionUUID->"d3cce596-762f-4f2d-a405-5510deaa6d28"],
Cell[27590, 1179, 616, 24, 125, "Text",ExpressionUUID->"eabf8842-9fd1-4279-ad9a-7a5e0b8626a2"],
Cell[28209, 1205, 1949, 82, 232, "Text",ExpressionUUID->"c1433082-d37f-4f12-b578-4550fe5d0872"],
Cell[30161, 1289, 541, 15, 125, "Text",ExpressionUUID->"2e30bcb5-c96e-49c8-86fe-58c6f57a6e60"],
Cell[30705, 1306, 779, 23, 161, "Text",ExpressionUUID->"3d2fa420-c2f3-4c54-9c44-2bfa509aac53"]
}, Closed]],
Cell[CellGroupData[{
Cell[31521, 1334, 104, 2, 47, "Subsection",ExpressionUUID->"08bf26da-9c5d-441d-a0ac-426b2a1c0aa5"],
Cell[31628, 1338, 128, 4, 54, "Text",ExpressionUUID->"e2e22da1-3418-4930-8e4b-fe0ef75f78ac"],
Cell[CellGroupData[{
Cell[31781, 1346, 921, 34, 125, "Text",ExpressionUUID->"a31f900b-a568-444b-8abd-50aa8869db97"],
Cell[32705, 1382, 406, 21, 59, "Text",ExpressionUUID->"a66f50f2-fe66-4f2d-b228-4ab07e1f8412"],
Cell[33114, 1405, 442, 22, 59, "Text",ExpressionUUID->"b1933f76-e5a6-4d5d-8511-49d0b6b3451b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33593, 1432, 918, 34, 125, "Text",ExpressionUUID->"7820a9a8-932c-47ae-a809-2a828e939880"],
Cell[34514, 1468, 442, 22, 59, "Text",ExpressionUUID->"a1bceec7-a767-4112-91cf-240095778dfc"],
Cell[34959, 1492, 499, 24, 59, "Text",ExpressionUUID->"c3774d73-94cf-4614-8617-3fdd31baf72d"],
Cell[35461, 1518, 450, 24, 54, "Text",ExpressionUUID->"15da7955-0c93-4dac-9fa2-6167e3abbeee"],
Cell[35914, 1544, 474, 20, 90, "Text",ExpressionUUID->"95d3bd87-c09e-4625-b991-983f2c00a476"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36425, 1569, 1322, 52, 161, "Text",ExpressionUUID->"0bf673b3-36cc-4bd2-99a1-a3e5a8171415"],
Cell[37750, 1623, 848, 40, 55, "Text",ExpressionUUID->"c09563a3-175c-44b4-a6c1-03698228b4f1"],
Cell[38601, 1665, 1454, 73, 92, "Text",ExpressionUUID->"7ebdcda5-073b-4da0-9913-eed447bf297b"],
Cell[40058, 1740, 995, 36, 125, "Text",ExpressionUUID->"e9ae95a4-e0e7-4ffb-81ce-3f2d062b2ebe"]
}, Open  ]],
Cell[41068, 1779, 790, 31, 133, "Text",ExpressionUUID->"20aced06-5c1a-4b6d-8c46-5ee843d661b4"],
Cell[41861, 1812, 909, 40, 91, "Text",ExpressionUUID->"a6b7f3a8-ba90-45cf-806d-a5ebc95a9615"],
Cell[CellGroupData[{
Cell[42795, 1856, 682, 24, 125, "Text",ExpressionUUID->"f39e662e-6c23-45cc-b88d-f6b94c24dda1"],
Cell[43480, 1882, 483, 14, 15, "Text",ExpressionUUID->"4ad6d70a-4fd4-4ddb-8ff9-5c9eeb52f2da"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[44012, 1902, 101, 2, 47, "Subsection",ExpressionUUID->"b3fc218f-744e-458a-bd02-e2905241cb99"],
Cell[44116, 1906, 443, 9, 125, "Text",ExpressionUUID->"109c1e99-f680-430d-aafe-974131b206be"],
Cell[CellGroupData[{
Cell[44584, 1919, 260, 13, 61, "Subsubsection",ExpressionUUID->"fbe4dd2f-1b43-4d96-a70f-76b5e61e5e1e"],
Cell[44847, 1934, 732, 26, 161, "Text",ExpressionUUID->"6767cfe3-c5df-4c67-900f-04e51f9788e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45616, 1965, 247, 12, 61, "Subsubsection",ExpressionUUID->"52c7bcf0-749e-442c-898f-4e41fa314e3f"],
Cell[45866, 1979, 623, 21, 33, "Text",ExpressionUUID->"954316ed-4edc-4669-8738-5d1d24aeeee8"]
}, Closed]],
Cell[CellGroupData[{
Cell[46526, 2005, 241, 12, 47, "Subsubsection",ExpressionUUID->"c2df9beb-d144-49db-9e07-c2b52900651f"],
Cell[46770, 2019, 424, 15, 19, "Text",ExpressionUUID->"b1514241-27bd-4859-b52c-f36d2047bf87"]
}, Closed]],
Cell[CellGroupData[{
Cell[47231, 2039, 237, 12, 47, "Subsubsection",ExpressionUUID->"f89da904-0f7e-4a41-beb6-d15a1df443ff"],
Cell[47471, 2053, 441, 15, 19, "Text",ExpressionUUID->"5bf769a5-b844-4106-b65c-6606ba9c063e"]
}, Closed]],
Cell[CellGroupData[{
Cell[47949, 2073, 313, 15, 47, "Subsubsection",ExpressionUUID->"197c7693-d138-480d-815a-20976cc3d5e6"],
Cell[48265, 2090, 412, 19, 0, "Text",ExpressionUUID->"d2a6fd66-b905-490c-a1ca-fbeccb4ed162"]
}, Closed]],
Cell[48692, 2112, 529, 22, 82, "Text",ExpressionUUID->"1da44339-3e30-4371-8e1d-245b4c76493c"]
}, Closed]],
Cell[CellGroupData[{
Cell[49258, 2139, 82, 2, 47, "Subsection",ExpressionUUID->"93f8b4b4-559e-4ec1-861f-3bffe108948b"],
Cell[49343, 2143, 440, 12, 125, "Text",ExpressionUUID->"b1f6a197-ddd7-489d-a998-6a920557c034"]
}, Closed]],
Cell[49798, 2158, 530, 12, 117, "Text",ExpressionUUID->"ce903355-bd00-4c02-8142-530a0607a573"],
Cell[50331, 2172, 743, 29, 90, "Text",ExpressionUUID->"f33c8ce5-d142-4560-abbb-7716c76b7d93"]
}, Closed]],
Cell[51089, 2204, 120, 3, 34, "Text",ExpressionUUID->"b65d8ee8-2f6d-4af3-8212-5637a54f4474"],
Cell[CellGroupData[{
Cell[51234, 2211, 202, 5, 92, "Section",ExpressionUUID->"ee6effb8-abac-448e-8d16-d04c591c5a02"],
Cell[51439, 2218, 180, 4, 43, "Input",ExpressionUUID->"ae28db5a-38c1-48a5-ab27-40648f80d51d"],
Cell[CellGroupData[{
Cell[51644, 2226, 142, 3, 67, "Input",ExpressionUUID->"a99268d3-baa0-4575-a11a-7af576bbc269",
 InitializationCell->True],
Cell[51789, 2231, 5647, 81, 70, "Message",ExpressionUUID->"ba51d72e-fa7a-4324-8140-11465157b4d2"]
}, Open  ]],
Cell[57451, 2315, 536, 16, 161, "Text",ExpressionUUID->"e883cdef-f3f8-443e-b8e4-2d5f2af27028"],
Cell[57990, 2333, 86, 0, 43, "Input",ExpressionUUID->"cc6976d9-2e40-43ea-81fe-f25eb0f7084b"],
Cell[58079, 2335, 485, 16, 90, "Text",ExpressionUUID->"aa546552-0d1c-48ef-ab6b-1d813fda1443"],
Cell[58567, 2353, 297, 8, 90, "Text",ExpressionUUID->"469b5241-371d-4ff1-806b-8b5b94c61778"]
}, Closed]],
Cell[58879, 2364, 120, 3, 34, "Text",ExpressionUUID->"b929167e-301b-47e0-bb06-fd8b7e56756f"],
Cell[CellGroupData[{
Cell[59024, 2371, 512, 17, 122, "Section",ExpressionUUID->"d4db6884-e79e-430e-a3bc-05bcdb8f3307"],
Cell[59539, 2390, 347, 10, 123, "Text",ExpressionUUID->"1ad3e9d8-fdc9-4e75-affe-25f5ad4606e2"],
Cell[59889, 2402, 163, 4, 43, "Input",ExpressionUUID->"be9b65e3-c8b5-4729-8817-5fd99088891e"],
Cell[CellGroupData[{
Cell[60077, 2410, 144, 2, 73, "Subsection",ExpressionUUID->"960d3d59-44b4-4599-a928-fb011bcb1f83"],
Cell[60224, 2414, 161, 5, 9, "Input",ExpressionUUID->"8b295497-70f6-42f8-b3ab-461017426410"],
Cell[60388, 2421, 1040, 34, 19, "Input",ExpressionUUID->"06525bfd-0c76-4938-b208-b2b6e7606d6b"],
Cell[61431, 2457, 83, 2, 9, "Input",ExpressionUUID->"48df3fa8-c74f-4693-8e5c-417967c17e85"],
Cell[CellGroupData[{
Cell[61539, 2463, 90, 2, 9, "Input",ExpressionUUID->"3cede667-5d72-4da7-83cf-93f9f60f6442"],
Cell[61632, 2467, 1089, 33, 42, "Print",ExpressionUUID->"967b9fb1-95e0-43b6-a9bd-0d47bc039fec"],
Cell[62724, 2502, 1194, 35, 15, "Print",ExpressionUUID->"414b52a5-233c-468f-9e15-096e59b156e2"],
Cell[63921, 2539, 1168, 36, 54, "Print",ExpressionUUID->"d802b89c-abf4-4dab-ba7f-92aa330ba722"],
Cell[65092, 2577, 256, 5, 0, "Print",ExpressionUUID->"a4c6cb20-eeb7-429a-b3c8-99f2168ad5ff"],
Cell[65351, 2584, 260, 5, 0, "Print",ExpressionUUID->"2a75d7c0-d982-41b0-bc2c-373da903b349"],
Cell[65614, 2591, 276, 5, 0, "Print",ExpressionUUID->"f1c7dd43-396c-4fcc-a0c1-a0b0f3a99b5e"],
Cell[65893, 2598, 276, 5, 0, "Print",ExpressionUUID->"399b4dde-f94d-4736-8053-31eaa3e9543b"],
Cell[66172, 2605, 260, 5, 0, "Print",ExpressionUUID->"f1217919-a91c-4279-ad30-68a201a7d68c"],
Cell[66435, 2612, 258, 5, 0, "Print",ExpressionUUID->"9507c371-8b97-499d-9335-f21b4aed241d"],
Cell[66696, 2619, 118, 3, 13, "Output",ExpressionUUID->"270f2627-ba6b-4737-b499-68ca07f6d473"],
Cell[66817, 2624, 266, 5, 0, "Print",ExpressionUUID->"5f98bf8a-4444-433b-b1e7-59913c18557b"],
Cell[67086, 2631, 73, 0, 0, "Print",ExpressionUUID->"0a06d03e-3a5b-46e4-a75d-722adbd1340f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67196, 2636, 103, 3, 9, "Input",ExpressionUUID->"cee50043-606f-4cef-be98-86564c267161"],
Cell[67302, 2641, 220, 7, 19, "Output",ExpressionUUID->"0e1d386f-cd2b-43f8-b583-d587da2d021e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67559, 2653, 103, 3, 9, "Input",ExpressionUUID->"201a8a4e-485d-4837-9a27-62a765db8ed1"],
Cell[67665, 2658, 301, 10, 19, "Output",ExpressionUUID->"941a12e2-23c2-4c33-9f6c-b50bbe431607"]
}, Open  ]],
Cell[67981, 2671, 141, 5, 9, "Text",ExpressionUUID->"61febf38-6b9b-43e3-8377-d5999a9ec35e"],
Cell[CellGroupData[{
Cell[68147, 2680, 92, 2, 9, "Input",ExpressionUUID->"50f7b40f-fa5c-4e46-9546-3e0475fba715"],
Cell[68242, 2684, 31, 0, 9, "Output",ExpressionUUID->"01a1b38b-4c34-431f-9635-abe1f16a5a70"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[68322, 2690, 552, 11, 47, "Subsection",ExpressionUUID->"50d1e2f6-1f1e-4769-bffa-d78a2b7aadd5"],
Cell[68877, 2703, 198, 5, 43, "Input",ExpressionUUID->"ded5aabc-ec98-42ac-99ca-ba75c35a7f45"],
Cell[69078, 2710, 408, 8, 43, "Input",ExpressionUUID->"9ea78abd-6108-46b0-b71e-89b9d7124a1a"],
Cell[69489, 2720, 1868, 52, 131, "Input",ExpressionUUID->"eb0b2c78-a54f-49d1-a0f6-31b2f7928f00"],
Cell[71360, 2774, 140, 3, 43, "Input",ExpressionUUID->"e813fbd8-ba0a-4228-b1ba-d61099f9a209"],
Cell[CellGroupData[{
Cell[71525, 2781, 147, 3, 43, "Input",ExpressionUUID->"71405c6e-decf-4357-8f21-213e6f50d774"],
Cell[71675, 2786, 5357, 108, 111, "Print",ExpressionUUID->"ee535809-274b-4970-9fe1-08c012169bf0"],
Cell[77035, 2896, 5095, 101, 89, "Print",ExpressionUUID->"ca0b8047-b369-44b5-892f-840d7a49a263"],
Cell[82133, 2999, 5515, 112, 183, "Print",ExpressionUUID->"e9d5c1f1-f0cf-4e9b-b78a-c4e58c962c53"],
Cell[87651, 3113, 3054, 46, 32, "Print",ExpressionUUID->"283fa127-a14a-499f-9cbb-b840cbe711d4"],
Cell[90708, 3161, 3095, 46, 32, "Print",ExpressionUUID->"26cf1a1a-4f91-4c03-aca6-bf1097050242"],
Cell[93806, 3209, 3108, 46, 32, "Print",ExpressionUUID->"a74234c3-9964-45f5-989c-779caafdedbb"],
Cell[96917, 3257, 3108, 46, 32, "Print",ExpressionUUID->"8ba31a41-a9cf-4474-b706-b81c567ccfd3"],
Cell[100028, 3305, 3064, 46, 32, "Print",ExpressionUUID->"da562ce9-b60a-489c-af2a-fe327bf40a6b"],
Cell[103095, 3353, 3093, 46, 32, "Print",ExpressionUUID->"472b4257-96bf-4360-850e-e7e502567400"],
Cell[106191, 3401, 3099, 46, 32, "Print",ExpressionUUID->"9c06e9d0-3b43-4767-aa5c-42f9ed23292c"],
Cell[109293, 3449, 2907, 41, 32, "Print",ExpressionUUID->"a735375b-6601-43ac-b763-91b9df21bc40"]
}, Open  ]],
Cell[CellGroupData[{
Cell[112237, 3495, 341, 7, 43, "Input",ExpressionUUID->"1c0d27dc-645f-44eb-b78f-414d374b5b66"],
Cell[112581, 3504, 10693, 317, 1091, "Input",ExpressionUUID->"c1ef4baa-5e9a-4f69-bbc7-5922e1993efb"],
Cell[CellGroupData[{
Cell[123299, 3825, 878, 21, 160, "Input",ExpressionUUID->"bd1f1de1-b3a0-4c89-ab1b-5d18f5a990ff"],
Cell[124180, 3848, 2098, 36, 70, "Output",ExpressionUUID->"71a8d887-88ad-4912-8108-c3375c9a5148"],
Cell[126281, 3886, 2096, 36, 70, "Output",ExpressionUUID->"12fb8686-9d0b-4d60-90c7-6661cf9a8647"],
Cell[128380, 3924, 2098, 36, 70, "Output",ExpressionUUID->"f9a3b860-90b2-4feb-a463-ab5994af19f8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130515, 3965, 452, 13, 102, "Input",ExpressionUUID->"42d26ee8-2449-4850-8f12-f2945ae3924b"],
Cell[130970, 3980, 2202, 41, 70, "Output",ExpressionUUID->"a5cc3dc2-de20-4a3d-8833-1f89dbc131de"],
Cell[133175, 4023, 2027, 35, 70, "Output",ExpressionUUID->"70685291-5a2d-412c-bd34-cb9810ca5e39"],
Cell[135205, 4060, 3581, 81, 70, "Output",ExpressionUUID->"0ac012ca-86c8-497a-be2a-cf488456cbce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[138823, 4146, 339, 7, 73, "Input",ExpressionUUID->"01cb8c31-1d2f-4630-a9aa-6bbf134eb797"],
Cell[139165, 4155, 4867, 105, 70, "Print",ExpressionUUID->"e507c56e-25ad-46e6-aef4-885eac9b3455"],
Cell[144035, 4262, 1935, 30, 70, "Print",ExpressionUUID->"bc5fbe84-1c8b-40c8-9951-06a33d6590bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[146007, 4297, 1908, 53, 160, "Input",ExpressionUUID->"eab5c015-1e4a-4b02-aba1-1e3a80689083"],
Cell[147918, 4352, 509, 8, 70, "Output",ExpressionUUID->"f8bbbc8f-1a7f-4456-9324-6dec9e45bfac"],
Cell[148430, 4362, 524, 9, 70, "Output",ExpressionUUID->"96e98809-a839-456f-af81-ebc6ec23ffd5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[148991, 4376, 2558, 61, 409, "Input",ExpressionUUID->"c66f8feb-b80a-4274-bd8d-4d357b56e58e"],
Cell[151552, 4439, 6737, 159, 70, "Output",ExpressionUUID->"985126c7-bb1a-45ea-b75d-30baa1a66675"],
Cell[158292, 4600, 2478, 35, 70, "Output",ExpressionUUID->"6eb91ec1-9e95-4756-9c7f-a29f28365e27"]
}, Open  ]],
Cell[160785, 4638, 2249, 58, 218, "Input",ExpressionUUID->"40897f7c-8c9c-4954-bfea-e0670da49f77"],
Cell[CellGroupData[{
Cell[163059, 4700, 3716, 113, 569, "Input",ExpressionUUID->"11d3145f-840e-4458-ba95-aabc41d721e5"],
Cell[166778, 4815, 2081, 33, 70, "Output",ExpressionUUID->"583dfaf9-3e86-406f-8f10-9395fe0c23d4"],
Cell[168862, 4850, 2166, 36, 70, "Output",ExpressionUUID->"6b1e5775-14f2-49c8-8243-3dcfc754bcd0"],
Cell[171031, 4888, 2208, 38, 70, "Output",ExpressionUUID->"0c5a6da5-60a5-40fe-9e98-0e951580ccf2"],
Cell[173242, 4928, 2051, 32, 70, "Output",ExpressionUUID->"e1ea27f7-9f35-41d6-8d9a-bc99bef9e8b9"],
Cell[175296, 4962, 2271, 39, 70, "Output",ExpressionUUID->"65ae0f94-b21d-484c-8b77-5df7055fbcbd"],
Cell[177570, 5003, 2151, 36, 70, "Output",ExpressionUUID->"42961622-ff19-4fcb-9d65-32a175cc3f49"],
Cell[179724, 5041, 2137, 35, 70, "Output",ExpressionUUID->"dcff1757-d66f-406b-96ed-3923d2a0a002"],
Cell[181864, 5078, 1921, 28, 70, "Output",ExpressionUUID->"cb10c5de-7b75-4673-9eb0-634f293b7012"]
}, Open  ]],
Cell[183800, 5109, 691, 18, 73, "Input",ExpressionUUID->"0e3b9ecc-3482-4d0a-833d-f1e1e642a618"],
Cell[184494, 5129, 4210, 114, 421, "Input",ExpressionUUID->"29c2d53f-5f5d-4df6-8864-f56e538dc447"],
Cell[188707, 5245, 7835, 218, 877, "Input",ExpressionUUID->"58191868-87a6-4184-98cf-7755c3015750"],
Cell[196545, 5465, 4564, 131, 334, "Input",ExpressionUUID->"a0a86744-b7ae-4ae1-8124-f68a66a4e643"],
Cell[201112, 5598, 499, 15, 73, "Input",ExpressionUUID->"08b1fbf1-27b9-487c-9c31-32bd4fc1bb06"],
Cell[201614, 5615, 580, 16, 43, "Input",ExpressionUUID->"bc4a36df-f3dc-4ab4-84a0-d0658a9f76b4"],
Cell[202197, 5633, 1062, 23, 43, "Input",ExpressionUUID->"b221360c-92d5-4177-bfe3-34eb74f0ae79"],
Cell[203262, 5658, 8615, 246, 566, "Input",ExpressionUUID->"3ca70d18-2b39-4a00-ba63-dcb10f18c83a"],
Cell[CellGroupData[{
Cell[211902, 5908, 83, 0, 43, "Input",ExpressionUUID->"66116201-7b3d-4afc-8d54-3e91bfa85b54"],
Cell[211988, 5910, 2612, 49, 70, "Output",ExpressionUUID->"bf8b0f61-98f3-47dd-88ba-2ab4972b5752"]
}, Open  ]],
Cell[214615, 5962, 5556, 160, 228, "Input",ExpressionUUID->"7792188c-1d30-4ca4-a05e-5ae1645766a6"],
Cell[CellGroupData[{
Cell[220196, 6126, 1256, 34, 112, "Input",ExpressionUUID->"8f248569-bc88-4c83-99f4-7af21d3b9264"],
Cell[221455, 6162, 4204, 79, 70, "Output",ExpressionUUID->"3187eb37-2804-4a03-a3ab-6e28663841bf"],
Cell[225662, 6243, 4575, 89, 70, "Output",ExpressionUUID->"3083c499-5790-49d1-b0c2-1add072f5f1d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[230274, 6337, 2901, 83, 167, "Input",ExpressionUUID->"f1fb0577-94f8-4228-a64d-9a493c82b710"],
Cell[233178, 6422, 2970, 46, 70, "Output",ExpressionUUID->"06aab65f-6c71-4e27-b62b-dbde50cf7765"],
Cell[236151, 6470, 3044, 48, 70, "Output",ExpressionUUID->"faf74ffe-a256-42ef-acbf-6453a9e3efe1"],
Cell[239198, 6520, 3109, 49, 70, "Output",ExpressionUUID->"8ff67c02-d731-45c2-a36b-df3926363080"]
}, Open  ]],
Cell[CellGroupData[{
Cell[242344, 6574, 857, 20, 73, "Input",ExpressionUUID->"02811add-c244-4b86-945e-1ca407df69d4"],
Cell[243204, 6596, 5725, 137, 70, "Output",ExpressionUUID->"88b0a64a-8cc0-4b20-8b5d-b979e66f5ff5"]
}, Open  ]],
Cell[248944, 6736, 193, 4, 43, "Input",ExpressionUUID->"1bd2e1b9-81d3-44c0-a041-6cf69ce0e882"]
}, Closed]],
Cell[CellGroupData[{
Cell[249174, 6745, 411, 8, 35, "Input",ExpressionUUID->"242e65f5-2958-4477-b53b-1af1428be6e0"],
Cell[CellGroupData[{
Cell[249610, 6757, 852, 23, 73, "Input",ExpressionUUID->"a08284af-1301-43d7-ae5d-b29a1a1fb80f"],
Cell[250465, 6782, 3610, 75, 70, "Output",ExpressionUUID->"1092175a-7a53-4258-90f0-7a06bdcda028"],
Cell[254078, 6859, 5918, 138, 70, "Output",ExpressionUUID->"67d50a59-8e84-415b-922c-0b0d33496b51"]
}, Open  ]],
Cell[260011, 7000, 901, 27, 73, "Input",ExpressionUUID->"b08acb51-5750-444b-ae36-e6cb1e487561"],
Cell[260915, 7029, 673, 15, 43, "Input",ExpressionUUID->"be2a4911-e1ea-4f0b-b9d1-31a023aac44e"],
Cell[CellGroupData[{
Cell[261613, 7048, 518, 15, 43, "Input",ExpressionUUID->"8e054cb8-4748-4445-a158-c1a8c3b3f1da"],
Cell[262134, 7065, 3517, 69, 70, "Output",ExpressionUUID->"e05570e2-2ab0-4326-8d3d-32217e8a3d84"]
}, Open  ]],
Cell[265666, 7137, 433, 11, 43, "Input",ExpressionUUID->"20a5dd20-6083-492b-8b5d-8e51ef3817d8"],
Cell[266102, 7150, 1161, 27, 180, "Input",ExpressionUUID->"0e0d18eb-7d6e-462e-ae1d-3d3b99c00182"],
Cell[267266, 7179, 789, 25, 115, "Input",ExpressionUUID->"c349af1c-65f8-4821-b8cb-909628591775"],
Cell[268058, 7206, 840, 25, 180, "Input",ExpressionUUID->"02eb31f1-4233-4e1b-b36a-300292cc325d"],
Cell[268901, 7233, 691, 20, 145, "Input",ExpressionUUID->"4e538a46-c04e-4a91-9bda-27425d861be8"],
Cell[269595, 7255, 1135, 33, 160, "Input",ExpressionUUID->"3bbaf24e-7999-44ce-8701-ba6bca517330"],
Cell[270733, 7290, 615, 14, 160, "Input",ExpressionUUID->"1d4a62c5-bf8b-4f3b-ade4-df6b8c572874"],
Cell[271351, 7306, 2616, 67, 189, "Input",ExpressionUUID->"f3fe56ae-1f36-4341-8120-38165c0d1a4a"],
Cell[CellGroupData[{
Cell[273992, 7377, 819, 22, 160, "Input",ExpressionUUID->"dd04cbbe-bf61-48e0-a993-34f0480b8b82"],
Cell[274814, 7401, 2932, 55, 70, "Output",ExpressionUUID->"6c6618f8-0122-424f-b36a-50136ecc6674"],
Cell[277749, 7458, 3993, 89, 70, "Output",ExpressionUUID->"4c7e63ae-454b-4ad8-a6c4-47b21769bc27"],
Cell[281745, 7549, 2236, 34, 70, "Output",ExpressionUUID->"1d8883e1-dbc9-4fe8-afbf-45e55c8db680"],
Cell[283984, 7585, 2761, 50, 70, "Output",ExpressionUUID->"cb1fc7d7-e76b-4586-9447-94631e31dd93"],
Cell[286748, 7637, 2043, 29, 70, "Output",ExpressionUUID->"88940eee-58a7-4a41-8db9-148671e45e27"]
}, Open  ]],
Cell[288806, 7669, 191, 4, 43, "Input",ExpressionUUID->"07d3885c-863a-4fd3-937b-dcc8b179d940"]
}, Closed]],
Cell[CellGroupData[{
Cell[289034, 7678, 397, 9, 35, "Input",ExpressionUUID->"4c09478d-8704-4be7-887d-ed68ae85d345"],
Cell[289434, 7689, 195, 4, 43, "Input",ExpressionUUID->"55bac692-a85d-4424-973f-aa26dae6791b"],
Cell[CellGroupData[{
Cell[289654, 7697, 434, 12, 43, "Input",ExpressionUUID->"d31e3621-baaf-4c39-888a-9ea0128f74b6"],
Cell[290091, 7711, 9261, 248, 320, "Output",ExpressionUUID->"e9bef96c-0e93-44ba-b578-f9c37e0dc961"]
}, Open  ]],
Cell[CellGroupData[{
Cell[299389, 7964, 669, 18, 43, "Input",ExpressionUUID->"fb8bf662-da8a-4ea9-b71e-89398712391b"],
Cell[300061, 7984, 1466, 28, 48, "Output",ExpressionUUID->"74049b8e-9e13-4ba0-8b11-10ef8ce16422"]
}, Open  ]],
Cell[CellGroupData[{
Cell[301564, 8017, 605, 15, 43, "Input",ExpressionUUID->"24784925-2711-447b-bd8e-58aae5c6b51d"],
Cell[302172, 8034, 2960, 69, 130, "Output",ExpressionUUID->"f24b636e-0eff-4380-a928-cc06c49d530f"]
}, Open  ]],
Cell[305147, 8106, 191, 4, 43, "Input",ExpressionUUID->"aae0d7a2-f19e-4979-ad07-34d4a8c90310"],
Cell[305341, 8112, 511, 12, 81, "Input",ExpressionUUID->"49fe1fe4-76e5-439c-a930-1cd41b14574a"],
Cell[CellGroupData[{
Cell[305877, 8128, 2334, 55, 114, "Input",ExpressionUUID->"0e49df56-2086-4124-b342-dc2f7159b5ff"],
Cell[308214, 8185, 1822, 45, 74, "Output",ExpressionUUID->"17a92702-814f-4ef1-9484-a9bffae05a6d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[310073, 8235, 1959, 49, 159, "Input",ExpressionUUID->"aea44dcf-db35-4a99-bb67-4b5f68fe31c6"],
Cell[312035, 8286, 2558, 66, 136, "Output",ExpressionUUID->"490b544f-2cf1-4964-bae7-c274a2a9fccf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[314630, 8357, 2062, 51, 109, "Input",ExpressionUUID->"0e876286-d35d-48e2-b7bd-b5f5df87d91e"],
Cell[316695, 8410, 2908, 63, 78, "Output",ExpressionUUID->"6dad14a5-a663-4ac7-a31e-ee09ccc124e0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[319640, 8478, 6722, 161, 332, "Input",ExpressionUUID->"461d917b-965e-4cf1-9d73-9d2e65537e1c"],
Cell[326365, 8641, 2330, 68, 135, "Output",ExpressionUUID->"ad2ff368-9dca-42df-93af-416006354c6a"],
Cell[CellGroupData[{
Cell[328720, 8713, 514, 15, 43, "Input",ExpressionUUID->"4a79d501-3f45-4a5f-bf92-961b8668f993"],
Cell[329237, 8730, 2510, 72, 137, "Output",ExpressionUUID->"0ee88834-c567-4278-ade1-a643b47a3fb6"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[331796, 8808, 764, 23, 43, "Input",ExpressionUUID->"7697c8c6-efe1-4507-b2c8-89ec929c1312"],
Cell[332563, 8833, 1142, 36, 79, "Output",ExpressionUUID->"3178e101-5f26-4bb1-9e17-e6315d3be0a1"]
}, Open  ]],
Cell[333720, 8872, 191, 4, 43, "Input",ExpressionUUID->"da31141e-3488-477b-9251-872a0e1c693f"]
}, Closed]],
Cell[CellGroupData[{
Cell[333948, 8881, 224, 5, 35, "Input",ExpressionUUID->"0b06cc52-c0b6-4273-8437-ab30654a089f"],
Cell[CellGroupData[{
Cell[334197, 8890, 315, 9, 43, "Input",ExpressionUUID->"8350b594-b769-4719-92dd-ebfe821f5153"],
Cell[334515, 8901, 1472, 40, 102, "Input",ExpressionUUID->"c79398b0-5dc0-4e5c-a7af-4219ecf72ad8"],
Cell[CellGroupData[{
Cell[336012, 8945, 894, 24, 80, "Input",ExpressionUUID->"c6658163-61c5-4f55-800f-25861a9950e7"],
Cell[336909, 8971, 850, 22, 77, "Output",ExpressionUUID->"938313bb-0c37-49e6-a4d9-d6dc2c19820c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[337796, 8998, 570, 17, 77, "Input",ExpressionUUID->"943b22a8-1c12-4c4f-ad17-fa11ed9784cd"],
Cell[338369, 9017, 459, 13, 59, "Output",ExpressionUUID->"21e0b450-0c0b-482f-8432-f29882f161a3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[338865, 9035, 578, 14, 53, "Input",ExpressionUUID->"54bd4f3b-afcc-4803-aa5e-261d182d0930"],
Cell[339446, 9051, 1084, 28, 54, "Output",ExpressionUUID->"b9ba3830-62bb-4a17-9dab-660eaf236bdf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[340567, 9084, 751, 21, 61, "Input",ExpressionUUID->"6e6ff24f-2d70-4161-a528-83b5b20b9dbe"],
Cell[341321, 9107, 381, 10, 78, "Output",ExpressionUUID->"0121869f-ae85-4efb-867a-0bdf65a06537"]
}, Open  ]],
Cell[341717, 9120, 189, 4, 43, "Input",ExpressionUUID->"76bb049b-e58b-4d67-8fdc-2c6f5d15517d"]
}, Closed]],
Cell[CellGroupData[{
Cell[341943, 9129, 339, 9, 35, "Input",ExpressionUUID->"86a27331-cc83-42b0-a7b1-0725c7b397fe"],
Cell[342285, 9140, 243, 5, 43, "Input",ExpressionUUID->"e6334d38-e86e-4eb2-ad03-6f46a4685313"],
Cell[342531, 9147, 1507, 40, 102, "Input",ExpressionUUID->"8c4e10ab-0935-45c8-a629-4c045bfa9c51"],
Cell[CellGroupData[{
Cell[344063, 9191, 1076, 30, 80, "Input",ExpressionUUID->"28836f5b-65e9-43b9-b8b7-bb14f0cf3a98"],
Cell[345142, 9223, 897, 23, 54, "Output",ExpressionUUID->"36722b12-18ee-4e04-8873-90f091065652"]
}, Open  ]],
Cell[CellGroupData[{
Cell[346076, 9251, 1188, 35, 144, "Input",ExpressionUUID->"4ce3bef8-1798-4b16-a5c2-52177610aa0e"],
Cell[347267, 9288, 1441, 38, 54, "Output",ExpressionUUID->"4ada0c8f-b160-44f4-83d9-ac583f2a969d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348745, 9331, 244, 7, 43, "Input",ExpressionUUID->"aa537cb5-94a9-463e-a101-0af08232172a"],
Cell[348992, 9340, 244, 3, 48, "Output",ExpressionUUID->"e4b5c9fb-8904-46ea-8389-ec204c890179"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349273, 9348, 624, 19, 53, "Input",ExpressionUUID->"4906122a-d823-4c6a-afb1-2e3d2ff349f9"],
Cell[349900, 9369, 567, 15, 48, "Output",ExpressionUUID->"b3d8090f-0f34-4ae5-800c-86f78f9802e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350504, 9389, 581, 17, 43, "Input",ExpressionUUID->"b32631c8-aa7c-46bd-9896-ad8f03fc9ba2"],
Cell[351088, 9408, 529, 13, 48, "Output",ExpressionUUID->"14aa4779-81dc-4ae3-bd6b-2eda3bb2ade2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351654, 9426, 675, 20, 43, "Input",ExpressionUUID->"b8eb886f-07fa-4241-b931-946a9252eaff"],
Cell[352332, 9448, 372, 10, 76, "Output",ExpressionUUID->"3885c6ab-8f03-4c96-a916-f1fd1c37006e"]
}, Open  ]],
Cell[352719, 9461, 388, 12, 60, "Input",ExpressionUUID->"1e6aa086-fd80-443a-887c-db08c833b896"],
Cell[CellGroupData[{
Cell[353132, 9477, 1912, 53, 171, "Input",ExpressionUUID->"20ab99e2-671e-4d28-a147-aca3c4d93ad2"],
Cell[355047, 9532, 802, 17, 75, "Output",ExpressionUUID->"ccc82fa2-489e-4272-b760-a51d294d9a98"],
Cell[355852, 9551, 842, 20, 79, "Output",ExpressionUUID->"104d51a7-5904-47c0-ad6e-a34c008607d5"],
Cell[356697, 9573, 964, 23, 73, "Output",ExpressionUUID->"af0bac1a-6502-4522-a801-0b75527f65f6"],
Cell[357664, 9598, 1018, 25, 112, "Output",ExpressionUUID->"1899756b-35ec-4dbe-bbfa-b4e3cf8df725"]
}, Open  ]],
Cell[CellGroupData[{
Cell[358719, 9628, 1166, 30, 122, "Input",ExpressionUUID->"8d138719-d007-4f8e-8d91-ead2a130502f"],
Cell[359888, 9660, 2045, 55, 192, "Output",ExpressionUUID->"db012fed-e14d-495b-91b0-3b70c31280ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361970, 9720, 2692, 77, 236, "Input",ExpressionUUID->"920eaf20-454d-4f5c-980c-5f838f14bdb9"],
Cell[364665, 9799, 715, 19, 111, "Output",ExpressionUUID->"9393fe51-981e-4ef4-accf-8cd19eac3e59"]
}, Open  ]],
Cell[CellGroupData[{
Cell[365417, 9823, 912, 29, 77, "Input",ExpressionUUID->"03a295b5-2e96-41f3-a8e5-eb606c2a7b68"],
Cell[366332, 9854, 561, 14, 76, "Output",ExpressionUUID->"be31b4bc-25f1-4c14-a95a-6d58516f6229"]
}, Open  ]],
Cell[CellGroupData[{
Cell[366930, 9873, 1045, 30, 202, "Input",ExpressionUUID->"ac5464e0-5b26-468c-8ed9-2212994a74cb"],
Cell[367978, 9905, 703, 21, 78, "Output",ExpressionUUID->"e624108e-1b28-45ef-8da0-54224a15a6ef"],
Cell[368684, 9928, 758, 22, 111, "Output",ExpressionUUID->"135f995a-568a-4e22-90b7-ae521eabd908"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369479, 9955, 88, 0, 43, "Input",ExpressionUUID->"5860bcb9-1e6b-475a-bf06-84de3a0dd3ae"],
Cell[369570, 9957, 568, 18, 54, "Output",ExpressionUUID->"a75d6e1f-cc32-4305-99ab-6346315d6672"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370175, 9980, 1729, 47, 201, "Input",ExpressionUUID->"f33dbf31-b448-4aee-8cef-c2f8891ab5a6"],
Cell[371907, 10029, 230, 4, 48, "Output",ExpressionUUID->"76fa8c5a-307e-4e4e-862e-141fa396caf8"]
}, Open  ]],
Cell[372152, 10036, 442, 13, 73, "Input",ExpressionUUID->"6272d345-1256-4a9a-bc15-43d42a9aa0f6"],
Cell[372597, 10051, 4356, 113, 420, "Input",ExpressionUUID->"bd7f5758-f465-4c53-a0b6-bfd2bdd58cbe"],
Cell[CellGroupData[{
Cell[376978, 10168, 231, 5, 43, "Input",ExpressionUUID->"a0592061-584b-4daa-b312-a0331fe15628"],
Cell[377212, 10175, 158, 3, 48, "Output",ExpressionUUID->"8ef7c18e-3b5a-401c-a257-936ab92232fb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[377407, 10183, 449, 14, 77, "Input",ExpressionUUID->"dc932c1a-25b1-4d68-acb8-098cf88d1381"],
Cell[377859, 10199, 410, 11, 76, "Output",ExpressionUUID->"91834e89-358f-4889-ab02-0a186ba1f42d"]
}, Open  ]],
Cell[378284, 10213, 1324, 36, 297, "Input",ExpressionUUID->"6487c740-6cc5-496d-a815-581ad44ce68e"],
Cell[379611, 10251, 189, 4, 43, "Input",ExpressionUUID->"49f0621c-c706-4da3-bd9e-64d6ced51995"]
}, Closed]],
Cell[CellGroupData[{
Cell[379837, 10260, 518, 15, 35, "Input",ExpressionUUID->"f5da5b19-5f0c-42a0-b7e3-5d161febbaa0"],
Cell[380358, 10277, 291, 6, 43, "Input",ExpressionUUID->"1502c4bf-53fb-4642-a362-b2c2d3c41ded"],
Cell[380652, 10285, 1698, 45, 102, "Input",ExpressionUUID->"4b595f11-de2a-47e6-80ed-ffc4269481ef"],
Cell[CellGroupData[{
Cell[382375, 10334, 1103, 30, 144, "Input",ExpressionUUID->"68909456-a3f0-4513-a659-2b394fe59332"],
Cell[383481, 10366, 1284, 32, 70, "Output",ExpressionUUID->"aa251b4a-ba27-46ed-94a2-3fbebf002b60"]
}, Open  ]],
Cell[CellGroupData[{
Cell[384802, 10403, 1214, 36, 144, "Input",ExpressionUUID->"5f61ec90-938d-409c-9954-0a5294582c7a"],
Cell[386019, 10441, 2248, 60, 83, "Output",ExpressionUUID->"6ab42396-35ad-43cf-b577-528e4c4d2b3f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[388304, 10506, 397, 11, 43, "Input",ExpressionUUID->"dd533c9d-df01-4533-952e-8a4debfe5a69"],
Cell[388704, 10519, 2005, 56, 90, "Output",ExpressionUUID->"39955abc-56fe-4407-918b-ed189a2db940"]
}, Open  ]],
Cell[CellGroupData[{
Cell[390746, 10580, 289, 9, 43, "Input",ExpressionUUID->"2940dedf-8d8d-48ef-84c9-caef1a3b83f0"],
Cell[391038, 10591, 387, 6, 48, "Output",ExpressionUUID->"c1e565cb-92d2-44e8-b5de-9506a57ac700"]
}, Open  ]],
Cell[CellGroupData[{
Cell[391462, 10602, 650, 20, 84, "Input",ExpressionUUID->"89b4819f-0875-4d73-8cac-3c84132d0c5e"],
Cell[392115, 10624, 925, 24, 59, "Output",ExpressionUUID->"1f19c8c4-1bdc-4dac-ba1c-b08c72e0f3c7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[393077, 10653, 581, 17, 73, "Input",ExpressionUUID->"412dd077-5431-4a85-9f5b-961eb5284438"],
Cell[393661, 10672, 629, 14, 48, "Output",ExpressionUUID->"925d5056-ce1a-4a2c-beda-5c353af1af9b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[394327, 10691, 675, 20, 43, "Input",ExpressionUUID->"b406ad58-618b-4ef3-9d84-2e9bf73f56e9"],
Cell[395005, 10713, 471, 12, 76, "Output",ExpressionUUID->"71c03766-6393-4592-bbfe-8c1a7df67bfd"]
}, Open  ]],
Cell[395491, 10728, 484, 13, 60, "Input",ExpressionUUID->"5786a6af-1295-4b14-ad20-da22bc739b24"],
Cell[395978, 10743, 644, 20, 53, "Input",ExpressionUUID->"d0b8024b-7e42-46bc-9001-7d43940393f2"],
Cell[CellGroupData[{
Cell[396647, 10767, 532, 15, 45, "Input",ExpressionUUID->"92dbb22e-1199-4a41-a33a-52bd12bfec30"],
Cell[397182, 10784, 838, 23, 87, "Output",ExpressionUUID->"8353a5f9-d677-4241-ab66-a4c5beb72bd4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[398057, 10812, 576, 16, 45, "Input",ExpressionUUID->"4100a43a-fe82-43bd-9aa5-f842a876a94f"],
Cell[398636, 10830, 1046, 29, 87, "Output",ExpressionUUID->"d99f31a7-6bbd-4563-ab67-840ad8b8e446"]
}, Open  ]],
Cell[399697, 10862, 428, 14, 77, "Input",ExpressionUUID->"ae4966ae-ef18-4383-b3ef-41f2581f96f9"],
Cell[CellGroupData[{
Cell[400150, 10880, 453, 12, 43, "Input",ExpressionUUID->"a63bb419-0763-44ff-a3b1-bbde74240136"],
Cell[400606, 10894, 782, 21, 88, "Output",ExpressionUUID->"d5d3e126-eecf-48ae-bb00-c880d08c7563"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401425, 10920, 444, 13, 73, "Input",ExpressionUUID->"6265b5dd-31b0-4fa6-8c20-1e3af2e62944"],
Cell[401872, 10935, 939, 26, 79, "Output",ExpressionUUID->"44810eb2-1082-4798-b460-9ed3be509562"],
Cell[402814, 10963, 848, 22, 54, "Output",ExpressionUUID->"90046e18-890c-411a-9be0-1209b83ca9ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[403699, 10990, 400, 11, 43, "Input",ExpressionUUID->"a8f0bf45-d865-4789-8213-ac520a847f86"],
Cell[404102, 11003, 1647, 46, 160, "Output",ExpressionUUID->"831539e7-b592-40c1-adac-43124c9cef05"]
}, Open  ]],
Cell[CellGroupData[{
Cell[405786, 11054, 354, 9, 73, "Input",ExpressionUUID->"6150d43d-1336-4196-afed-f2f436c69095"],
Cell[406143, 11065, 581, 16, 84, "Output",ExpressionUUID->"3198a932-d1c3-4fc4-a343-429a6ed4f2f0"],
Cell[406727, 11083, 431, 12, 55, "Output",ExpressionUUID->"df4d255e-af8d-4605-94c7-63fbe7ee9504"]
}, Open  ]],
Cell[CellGroupData[{
Cell[407195, 11100, 450, 13, 73, "Input",ExpressionUUID->"56d2a161-dc81-448e-af6d-e3693b0d6e7b"],
Cell[407648, 11115, 2673, 72, 189, "Output",ExpressionUUID->"543d62a0-20b3-4dc1-acd5-e63f9a73b710"]
}, Open  ]],
Cell[410336, 11190, 234, 5, 43, "Input",ExpressionUUID->"ad30f333-6243-4ec1-8e13-3f81f696ba0c"],
Cell[CellGroupData[{
Cell[410595, 11199, 536, 14, 102, "Input",ExpressionUUID->"e0d8e5a8-6125-4132-96e2-d8a4f690696a"],
Cell[411134, 11215, 714, 22, 87, "Output",ExpressionUUID->"d176d246-3c0a-4f7e-9334-3af886ebc7b9"],
Cell[411851, 11239, 765, 23, 114, "Output",ExpressionUUID->"95ba464b-b16d-4b76-96e0-dd79f6a7cd3f"],
Cell[412619, 11264, 398, 11, 50, "Output",ExpressionUUID->"83886450-308d-45b2-a1c7-b05019adcd27"]
}, Open  ]],
Cell[413032, 11278, 189, 5, 43, "Input",ExpressionUUID->"700e9cc3-337f-46a0-a1c5-c5302211ff13"],
Cell[413224, 11285, 1937, 49, 245, "Input",ExpressionUUID->"fb2e2925-f0de-4ddc-b093-195f7cd45d6a"],
Cell[CellGroupData[{
Cell[415186, 11338, 1466, 39, 188, InheritFromParent,ExpressionUUID->"62e3b469-0b80-45fb-a60c-65ccf465bc91"],
Cell[416655, 11379, 953, 30, 89, "Output",ExpressionUUID->"4e73ceda-85a0-407a-a143-5dc921f2d69e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[417645, 11414, 781, 23, 109, "Input",ExpressionUUID->"03ec9911-3546-433e-91e7-ba77b7c2889c"],
Cell[418429, 11439, 610, 19, 84, "Output",ExpressionUUID->"5475c6e3-bc0c-469e-9e19-ddd88f2ec072"]
}, Open  ]],
Cell[CellGroupData[{
Cell[419076, 11463, 451, 13, 43, "Input",ExpressionUUID->"9dd68612-87d7-46bd-9654-9e09f9626529"],
Cell[419530, 11478, 1537, 44, 84, "Output",ExpressionUUID->"3063ecf7-4e51-4c39-a5b0-f068fe229e79"]
}, Open  ]],
Cell[CellGroupData[{
Cell[421104, 11527, 1107, 34, 119, "Input",ExpressionUUID->"2e63370d-830a-4214-a22f-061fa329520c"],
Cell[422214, 11563, 676, 18, 77, "Output",ExpressionUUID->"ddf35fb1-6a52-4eef-948e-43d4d81aa714"],
Cell[422893, 11583, 755, 21, 72, "Output",ExpressionUUID->"5220e12f-7755-4cc4-b7fa-577475b8c086"],
Cell[423651, 11606, 943, 27, 111, "Output",ExpressionUUID->"8f0c327e-7490-4298-aaa1-813184bfd8e0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[424631, 11638, 1315, 37, 224, "Input",ExpressionUUID->"d5ace2c0-84ea-48fa-8102-6b701551f916"],
Cell[425949, 11677, 9062, 194, 347, "Output",ExpressionUUID->"6bc9a8c7-846c-42a5-bbc1-71270eabdbb3"]
}, Open  ]],
Cell[435026, 11874, 1127, 33, 73, "Input",ExpressionUUID->"013883ae-fcb9-4720-8527-49eb83ea18b0"],
Cell[CellGroupData[{
Cell[436178, 11911, 2026, 60, 209, "Input",ExpressionUUID->"f6a5eefd-702a-4b2c-88ff-8abf6645f95c"],
Cell[438207, 11973, 875, 23, 82, "Output",ExpressionUUID->"d66a3154-d59a-46e7-a34a-2b6804920f6f"],
Cell[439085, 11998, 482, 11, 81, "Output",ExpressionUUID->"a964109c-de05-4e89-b3ef-085ece2e87eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439604, 12014, 868, 22, 73, "Input",ExpressionUUID->"9dbd43d1-2f63-4170-bbf0-05bf625e130b"],
Cell[440475, 12038, 1016, 27, 90, "Output",ExpressionUUID->"106156b1-2f89-4cef-9c8b-97e938606fea"],
Cell[441494, 12067, 816, 21, 115, "Output",ExpressionUUID->"7104deb8-3482-4380-b6b7-322c27cdc347"]
}, Open  ]],
Cell[CellGroupData[{
Cell[442347, 12093, 329, 10, 77, "Input",ExpressionUUID->"78526f40-97ad-4ecf-85d2-a8f54fb25ae0"],
Cell[442679, 12105, 1393, 41, 163, "Output",ExpressionUUID->"d05277c8-9778-4a54-88dd-a49ca4ef0ece"]
}, Open  ]],
Cell[CellGroupData[{
Cell[444109, 12151, 1415, 38, 131, "Input",ExpressionUUID->"3b445363-c0b4-4754-bfcf-5718c36dd636"],
Cell[445527, 12191, 1119, 29, 86, "Output",ExpressionUUID->"70be0198-a1a2-4ed8-af84-350ec2275b69"]
}, Open  ]],
Cell[CellGroupData[{
Cell[446683, 12225, 492, 11, 43, "Input",ExpressionUUID->"4555ea88-6909-41a1-815e-b546fa314161"],
Cell[447178, 12238, 1502, 40, 86, "Output",ExpressionUUID->"c9bd996e-9b0a-44dc-acaf-2202f840b0ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[448717, 12283, 524, 16, 100, "Input",ExpressionUUID->"2b16c43f-2305-4796-af95-c3c91f6d242a"],
Cell[449244, 12301, 367, 10, 71, "Output",ExpressionUUID->"97652fbd-522f-4e67-bea1-dfb3f71206e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[449648, 12316, 1462, 36, 83, "Input",ExpressionUUID->"979147a1-f617-430a-8fc6-6d1ff96779da"],
Cell[451113, 12354, 700, 11, 48, "Output",ExpressionUUID->"7e8a3413-b6ab-4756-90e4-ee00f6ca2a02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[451850, 12370, 591, 16, 78, "Input",ExpressionUUID->"4d6bf96e-b112-47b6-8727-f92637c4a160"],
Cell[452444, 12388, 970, 30, 129, "Output",ExpressionUUID->"77f797e4-9121-4058-8649-e1433e963b30"]
}, Open  ]],
Cell[453429, 12421, 208, 5, 43, "Input",ExpressionUUID->"243564ce-a009-49a1-a1b9-9945a99e0051"],
Cell[CellGroupData[{
Cell[453662, 12430, 234, 6, 43, "Input",ExpressionUUID->"19428e88-2400-4b49-8091-fe3daa04d0d4"],
Cell[453899, 12438, 546, 16, 72, "Output",ExpressionUUID->"2f0c1e21-df1d-42e9-a2ed-ea407452179a"]
}, Open  ]],
Cell[454460, 12457, 217, 5, 43, "Input",ExpressionUUID->"82f79fc9-7867-42b1-9f90-0ecaf90147b7"],
Cell[CellGroupData[{
Cell[454702, 12466, 1000, 24, 135, "Input",ExpressionUUID->"02b652a9-43a7-4660-ab5f-e391259dff51"],
Cell[455705, 12492, 704, 19, 87, "Output",ExpressionUUID->"7a066c4f-da8b-4ab4-852a-fd4b68903dcb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[456446, 12516, 451, 12, 73, "Input",ExpressionUUID->"a0a5ede9-0de5-4663-8099-dbdd79d27bfc"],
Cell[456900, 12530, 1076, 34, 84, "Output",ExpressionUUID->"5413458a-f74f-413a-ac43-6db80790403c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[458013, 12569, 717, 22, 101, "Input",ExpressionUUID->"5142d9c7-15e2-4904-9bda-0ae609a97e78"],
Cell[458733, 12593, 602, 18, 78, "Output",ExpressionUUID->"61279f0e-b681-4b64-84a4-38dacf23e86c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[459372, 12616, 1063, 31, 119, "Input",ExpressionUUID->"447c4566-16e7-483b-bc0f-942924f8e894"],
Cell[460438, 12649, 678, 18, 84, "Output",ExpressionUUID->"abc0a9da-94b6-4aba-ab4d-4844bc595536"],
Cell[461119, 12669, 758, 20, 76, "Output",ExpressionUUID->"8376662d-e99f-43ca-8ed4-e24252e9b6f4"],
Cell[461880, 12691, 956, 26, 81, "Output",ExpressionUUID->"2206266f-9d50-4989-b564-47720c419e94"]
}, Open  ]],
Cell[462851, 12720, 368, 9, 43, "Input",ExpressionUUID->"0d7d3c49-1466-40d4-bae9-3ef4f31ae4f8"],
Cell[CellGroupData[{
Cell[463244, 12733, 711, 21, 50, "Input",ExpressionUUID->"5e9e1ba5-829b-47d5-b677-1c15c4fcb835"],
Cell[463958, 12756, 2013, 59, 235, "Output",ExpressionUUID->"fad1bfa4-6861-4abf-9c8d-db3b2d5a8601"]
}, Open  ]],
Cell[CellGroupData[{
Cell[466008, 12820, 1372, 37, 174, "Input",ExpressionUUID->"04df4761-5db2-4287-91cc-e6171c68acfc"],
Cell[467383, 12859, 1103, 31, 113, "Output",ExpressionUUID->"e362ee5d-3882-4d58-b52e-8346eb2c10ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[468523, 12895, 85, 0, 43, "Input",ExpressionUUID->"7ff08513-f4ca-4a7a-b121-cb6230f2228e"],
Cell[468611, 12897, 737, 24, 79, "Output",ExpressionUUID->"c50cd9e7-6763-4fdb-a328-d59c506baaed"]
}, Open  ]],
Cell[469363, 12924, 900, 26, 134, "Input",ExpressionUUID->"5d3c69b7-add6-47b0-9223-9137590deace"],
Cell[470266, 12952, 134, 2, 43, "Input",ExpressionUUID->"858ac8a2-f7e2-46c7-863d-192022d48c8c"],
Cell[CellGroupData[{
Cell[470425, 12958, 1909, 52, 219, "Input",ExpressionUUID->"db8b5c43-727b-463b-a793-74d6ce3398ea"],
Cell[472337, 13012, 1079, 31, 120, "Output",ExpressionUUID->"eb9d3296-6485-412f-9770-b2d1a17d27f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[473453, 13048, 1655, 49, 113, "Input",ExpressionUUID->"7e8fb56d-6f8d-44f7-ae91-54ef3bd72913"],
Cell[475111, 13099, 1704, 47, 92, "Output",ExpressionUUID->"2e5055c7-4275-4e7f-a26c-bf5f3f590b26"],
Cell[476818, 13148, 834, 22, 81, "Output",ExpressionUUID->"b5fb972d-ffe0-45d6-bfec-e7bbae753699"]
}, Open  ]],
Cell[CellGroupData[{
Cell[477689, 13175, 946, 26, 144, "Input",ExpressionUUID->"afdc2ad3-352f-4cb4-901c-5ae5257a2ed4"],
Cell[478638, 13203, 3953, 103, 197, "Output",ExpressionUUID->"b3b10da3-71eb-44b0-86fc-2ea4f25fa505"]
}, Open  ]],
Cell[CellGroupData[{
Cell[482628, 13311, 1192, 36, 117, "Input",ExpressionUUID->"f30bc793-8f83-4320-bcd3-4a610afffd1e"],
Cell[483823, 13349, 1715, 50, 117, "Output",ExpressionUUID->"47477ba9-74f3-4dbe-a3a1-0de4d16dc173"]
}, Open  ]],
Cell[CellGroupData[{
Cell[485575, 13404, 250, 6, 43, "Input",ExpressionUUID->"240af923-08d8-42f2-b13d-db4bad527994"],
Cell[485828, 13412, 994, 29, 78, "Output",ExpressionUUID->"6650dd59-c915-4b9a-a42f-c1604386ad88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[486859, 13446, 861, 24, 83, "Input",ExpressionUUID->"c27c9cc9-754e-4e18-a008-81a223c5322a"],
Cell[487723, 13472, 1096, 30, 78, "Output",ExpressionUUID->"c98a145b-01a4-446d-ba74-248c48bbda89"]
}, Open  ]],
Cell[CellGroupData[{
Cell[488856, 13507, 982, 28, 105, "Input",ExpressionUUID->"a49bb790-9fe8-4dd9-a504-422e0d33478f"],
Cell[489841, 13537, 510, 14, 78, "Output",ExpressionUUID->"082662fa-9b35-459d-a3fb-aee2415dfe5b"]
}, Open  ]],
Cell[490366, 13554, 900, 27, 77, "Input",ExpressionUUID->"b36bd80d-46d0-4ed9-adb4-e79a2ce550a3"],
Cell[CellGroupData[{
Cell[491291, 13585, 1827, 54, 232, "Input",ExpressionUUID->"a0df9969-b14e-453f-b67a-86822d7ad702"],
Cell[493121, 13641, 4180, 121, 235, "Output",ExpressionUUID->"8b5cba03-a4ab-451d-ad2e-f066892891a0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[497338, 13767, 879, 23, 75, "Input",ExpressionUUID->"ff18487f-3b6f-40c8-a8a1-f964d3b14e45"],
Cell[498220, 13792, 2997, 81, 100, "Output",ExpressionUUID->"28ee93e7-463a-4186-8365-0008958b35e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[501254, 13878, 2118, 58, 267, "Input",ExpressionUUID->"d0ece97f-baee-4841-9a2e-13a1821ed10c"],
Cell[503375, 13938, 1048, 33, 103, "Output",ExpressionUUID->"c1b366ec-a81f-4d5a-946d-4c1622c9d977"],
Cell[504426, 13973, 1044, 32, 103, "Output",ExpressionUUID->"041b16a7-a120-4140-a1fe-622ad2709253"]
}, Open  ]],
Cell[505485, 14008, 276, 7, 43, "Input",ExpressionUUID->"bae05997-e4bb-4d13-9f74-087e94c2310c"],
Cell[CellGroupData[{
Cell[505786, 14019, 643, 19, 43, "Input",ExpressionUUID->"c5f9bf19-97a1-4723-bc87-254f81312291"],
Cell[506432, 14040, 2718, 78, 187, "Output",ExpressionUUID->"22a133bc-e31f-40e1-a241-ed16ec2d213e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[509187, 14123, 1603, 42, 153, "Input",ExpressionUUID->"e866959e-05d8-46bf-8026-7bdf80c39371"],
Cell[510793, 14167, 1101, 29, 121, "Output",ExpressionUUID->"af3a26b0-cfd4-4ce9-859d-a9c23d5b542d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[511931, 14201, 377, 10, 43, "Input",ExpressionUUID->"677c8237-cd1b-451b-8bfe-8b1bb62adfa9"],
Cell[512311, 14213, 918, 27, 113, "Output",ExpressionUUID->"112ba199-b6cc-4379-84e4-9ab3fe560e54"]
}, Open  ]],
Cell[513244, 14243, 950, 27, 141, "Input",ExpressionUUID->"c7b3cf21-16d8-4fdf-b65f-4aaf38645949"],
Cell[514197, 14272, 283, 7, 43, "Input",ExpressionUUID->"c8219de5-9523-4137-894c-5b809fd6955d"],
Cell[CellGroupData[{
Cell[514505, 14283, 599, 18, 43, "Input",ExpressionUUID->"08784c06-84eb-4954-9135-5725e2544fb2"],
Cell[515107, 14303, 2506, 69, 189, "Output",ExpressionUUID->"ad0cf556-08fa-41c2-a46a-8b6f1dcefd82"]
}, Open  ]],
Cell[CellGroupData[{
Cell[517650, 14377, 1472, 39, 276, "Input",ExpressionUUID->"e795ea4c-7b44-4d71-83b2-b00dcca41c35"],
Cell[519125, 14418, 914, 26, 89, "Output",ExpressionUUID->"79bbdec6-2237-487c-86c8-54fb0c74c99b"]
}, Open  ]],
Cell[520054, 14447, 189, 4, 43, "Input",ExpressionUUID->"5d9964cb-5d0f-4523-8e9e-83685e135b19"]
}, Closed]],
Cell[CellGroupData[{
Cell[520280, 14456, 612, 16, 35, "Input",ExpressionUUID->"263c1ee1-6cdc-4bcc-b4c1-9dcd897dd939"],
Cell[520895, 14474, 291, 6, 43, "Input",ExpressionUUID->"777a0497-8364-4262-85d6-1622b765f4e3"],
Cell[521189, 14482, 1698, 45, 102, "Input",ExpressionUUID->"8579583d-d98f-46ce-8ac7-d3803b799e41"],
Cell[CellGroupData[{
Cell[522912, 14531, 1103, 30, 144, "Input",ExpressionUUID->"821d790d-77a2-4ffc-b2d1-d294d6b98662"],
Cell[524018, 14563, 1308, 32, 70, "Output",ExpressionUUID->"93c526ef-298b-4507-bc90-15f437bada57"]
}, Open  ]],
Cell[CellGroupData[{
Cell[525363, 14600, 1214, 36, 144, "Input",ExpressionUUID->"4f46c90c-3399-4820-8e7b-1c79faf3fd28"],
Cell[526580, 14638, 2272, 60, 83, "Output",ExpressionUUID->"41c8391e-831b-4455-86ca-45a20d02ed67"]
}, Open  ]],
Cell[CellGroupData[{
Cell[528889, 14703, 397, 11, 43, "Input",ExpressionUUID->"7755da1a-f2fc-4d89-8f5e-75c177d35a80"],
Cell[529289, 14716, 2029, 56, 90, "Output",ExpressionUUID->"11bce863-c380-4089-b8e7-b698bea9dbf7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[531355, 14777, 289, 9, 43, "Input",ExpressionUUID->"7643abec-c08e-4677-b209-21400d8d1cda"],
Cell[531647, 14788, 414, 7, 48, "Output",ExpressionUUID->"201fd865-a774-4872-8b6a-b7d3617fd530"]
}, Open  ]],
Cell[CellGroupData[{
Cell[532098, 14800, 650, 20, 84, "Input",ExpressionUUID->"b7010bda-9cea-4387-bcea-96ce08e6e302"],
Cell[532751, 14822, 949, 24, 59, "Output",ExpressionUUID->"abfdbb7a-b172-44a5-ac5b-dea40acc4728"]
}, Open  ]],
Cell[CellGroupData[{
Cell[533737, 14851, 581, 17, 73, "Input",ExpressionUUID->"22ca6321-bcde-4e4d-9aa0-90d077429efb"],
Cell[534321, 14870, 657, 15, 48, "Output",ExpressionUUID->"8f5b49f1-86a3-4c63-acf6-197bfe3edeed"]
}, Open  ]],
Cell[CellGroupData[{
Cell[535015, 14890, 675, 20, 43, "Input",ExpressionUUID->"3768658a-6cec-4f36-8b42-051f4957f20e"],
Cell[535693, 14912, 493, 12, 76, "Output",ExpressionUUID->"e520d46d-884d-4030-895f-7f739bdf6b23"]
}, Open  ]],
Cell[536201, 14927, 484, 13, 60, "Input",ExpressionUUID->"f5053aa1-846a-41ae-8833-6c014b8255c0"],
Cell[536688, 14942, 644, 20, 53, "Input",ExpressionUUID->"25aafd11-ccf9-4e95-8d13-39251009e39a"],
Cell[CellGroupData[{
Cell[537357, 14966, 532, 15, 45, "Input",ExpressionUUID->"7f6ccc18-63b7-48a6-b7c5-97a787e6990d"],
Cell[537892, 14983, 863, 24, 87, "Output",ExpressionUUID->"f2d6ff26-8155-422b-a24b-b43617604fa3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[538792, 15012, 576, 16, 45, "Input",ExpressionUUID->"5733dac0-4003-4408-a29a-3962dabe1db8"],
Cell[539371, 15030, 1070, 29, 87, "Output",ExpressionUUID->"a4427ff3-6340-4f2a-9ba6-b0cf5e771ce0"]
}, Open  ]],
Cell[540456, 15062, 428, 14, 77, "Input",ExpressionUUID->"65b6094d-b46e-438a-8ce5-31b73c661c85"],
Cell[CellGroupData[{
Cell[540909, 15080, 453, 12, 43, "Input",ExpressionUUID->"81f574e3-ecef-4482-a600-64cddaa66d21"],
Cell[541365, 15094, 810, 22, 88, "Output",ExpressionUUID->"1e6e3f00-ea19-45da-be77-95a36121581b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542212, 15121, 444, 13, 73, "Input",ExpressionUUID->"faaf5c90-ea77-4d25-ad1e-a48ea6df589f"],
Cell[542659, 15136, 967, 27, 79, "Output",ExpressionUUID->"932a6130-5400-451d-a4cd-1412d5956314"],
Cell[543629, 15165, 876, 23, 54, "Output",ExpressionUUID->"a14ef191-16a0-4231-8689-28b8eb724212"]
}, Open  ]],
Cell[CellGroupData[{
Cell[544542, 15193, 286, 8, 43, "Input",ExpressionUUID->"0b7d0eed-e4da-46f7-8ccd-1b0e83a8f7c9"],
Cell[544831, 15203, 400, 10, 65, "Message",ExpressionUUID->"90925043-3f6c-4275-84b9-c82d30110a25"],
Cell[545234, 15215, 333, 11, 69, "Output",ExpressionUUID->"4647f354-5f00-45c6-afc2-ea68d6b5b7b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[545604, 15231, 790, 24, 151, "Input",ExpressionUUID->"ad9483bf-3ac1-4771-b6b6-11006554615f"],
Cell[546397, 15257, 1050, 34, 80, "Output",ExpressionUUID->"cee10d33-98ab-4459-afb5-9299a9ef7a08"],
Cell[547450, 15293, 796, 24, 60, "Output",ExpressionUUID->"84389573-4954-4d54-80eb-e1c9d7ead166"]
}, Open  ]],
Cell[CellGroupData[{
Cell[548283, 15322, 424, 12, 43, "Input",ExpressionUUID->"6e0677a0-2dc7-4ca8-8ae7-51cab8f0e808"],
Cell[548710, 15336, 1361, 42, 99, "Output",ExpressionUUID->"77217442-56d8-4a34-91b7-c4ef1ba4129e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[550108, 15383, 533, 14, 73, "Input",ExpressionUUID->"f1a1e496-83e1-43ac-bf90-eca9796044a4"],
Cell[550644, 15399, 817, 25, 87, "Output",ExpressionUUID->"669b4e49-f412-456d-9f2a-cda16901e4dd"],
Cell[551464, 15426, 899, 27, 87, "Output",ExpressionUUID->"d7b3487e-9c41-4f66-8b2a-37b6d9329011"]
}, Open  ]],
Cell[CellGroupData[{
Cell[552400, 15458, 276, 7, 43, "Input",ExpressionUUID->"8a38e12a-6813-41ea-8082-38df595c3256"],
Cell[552679, 15467, 617, 19, 87, "Output",ExpressionUUID->"b6a31697-5a57-4f56-ab42-5fa7ee976b58"]
}, Open  ]],
Cell[CellGroupData[{
Cell[553333, 15491, 862, 25, 96, "Input",ExpressionUUID->"f5c92ec3-9cd0-4026-bb9f-56884ee31583"],
Cell[554198, 15518, 627, 18, 87, "Output",ExpressionUUID->"fd4fd6ad-64c8-4b6d-adc6-4af5e7ce1995"]
}, Open  ]],
Cell[CellGroupData[{
Cell[554862, 15541, 324, 9, 43, "Input",ExpressionUUID->"63b98ff7-a5bb-47df-9edc-c0ad1291d9c4"],
Cell[555189, 15552, 496, 15, 87, "Output",ExpressionUUID->"1da0c5bc-63ea-4329-b95c-7f2832cebf9d"]
}, Open  ]],
Cell[555700, 15570, 1127, 33, 73, "Input",ExpressionUUID->"aa21fd2a-42a7-4987-bade-1a36d06f7313"],
Cell[CellGroupData[{
Cell[556852, 15607, 2880, 84, 267, "Input",ExpressionUUID->"99d1828d-f656-443b-8739-d324ef19e7bb"],
Cell[559735, 15693, 1246, 35, 102, "Output",ExpressionUUID->"2ab000f7-db1e-42c9-a637-de96893d3bf3"],
Cell[560984, 15730, 762, 18, 90, "Output",ExpressionUUID->"e9f08a8b-2c2b-4d94-831f-b75ba46ee3e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[561783, 15753, 1042, 28, 102, "Input",ExpressionUUID->"f79c4acd-89c8-4d2d-a8c1-eac0a196ad3a"],
Cell[562828, 15783, 778, 21, 79, "Output",ExpressionUUID->"7fa7d1e1-d402-4f1d-b2aa-bfef9607c8a9"],
Cell[563609, 15806, 654, 17, 79, "Output",ExpressionUUID->"318cab7c-d91b-41f6-9e7a-255127535ee2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[564300, 15828, 418, 12, 77, "Input",ExpressionUUID->"79c004b1-9de5-43b8-83ff-05dee41afd07"],
Cell[564721, 15842, 1153, 37, 79, "Output",ExpressionUUID->"6708ea10-49b8-4657-9fb2-1737dcfb22b9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[565911, 15884, 498, 16, 90, "Input",ExpressionUUID->"f4522fe2-06c6-4cff-b2ba-aea2b22b5f68"],
Cell[566412, 15902, 276, 7, 48, "Output",ExpressionUUID->"995d8280-1520-4347-a3fb-1b430d20ac7c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[566725, 15914, 285, 7, 43, "Input",ExpressionUUID->"bc43e2e5-5afc-469c-afee-c504a4763a12"],
Cell[567013, 15923, 665, 20, 82, "Output",ExpressionUUID->"7b660d43-2253-4720-820b-b03bcf99e35c"]
}, Open  ]],
Cell[567693, 15946, 189, 4, 43, "Input",ExpressionUUID->"c699c5ff-382d-4602-b543-2c86af86ff10"]
}, Closed]],
Cell[CellGroupData[{
Cell[567919, 15955, 638, 16, 35, "Input",ExpressionUUID->"ce775d9e-0ce7-4946-b31a-942c460e077c"],
Cell[568560, 15973, 360, 7, 43, "Input",ExpressionUUID->"8d94ac51-7f9d-4620-98d8-0ea167484627"],
Cell[568923, 15982, 1698, 45, 102, "Input",ExpressionUUID->"e2f9b93f-35f5-40cf-80a1-7a754d9eec5e"],
Cell[CellGroupData[{
Cell[570646, 16031, 1103, 30, 80, "Input",ExpressionUUID->"7fc23a12-af78-4689-a4a9-1342924513e5"],
Cell[571752, 16063, 1504, 35, 70, "Output",ExpressionUUID->"cc95b246-1717-4a3f-9282-d86f3732b0ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[573293, 16103, 1214, 36, 144, "Input",ExpressionUUID->"42c46795-e01d-4c43-bd6c-a74812f7e4d5"],
Cell[574510, 16141, 2444, 62, 83, "Output",ExpressionUUID->"79814219-c863-4fdf-b6e5-cd51bd9b43f3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[576991, 16208, 481, 13, 43, "Input",ExpressionUUID->"b1122f7c-db6d-4e33-9cf6-ccfef1a20162"],
Cell[577475, 16223, 2229, 59, 90, "Output",ExpressionUUID->"dbbae6eb-832c-4831-bc14-237d744ac930"]
}, Open  ]],
Cell[CellGroupData[{
Cell[579741, 16287, 289, 9, 43, "Input",ExpressionUUID->"d77a980f-2825-4f81-8856-764d7635a6d2"],
Cell[580033, 16298, 584, 9, 48, "Output",ExpressionUUID->"7167e2d2-d1ec-4169-834f-69c914033813"]
}, Open  ]],
Cell[CellGroupData[{
Cell[580654, 16312, 650, 20, 53, "Input",ExpressionUUID->"82e620b9-a674-40c6-8b3b-ce734c1623ef"],
Cell[581307, 16334, 1117, 27, 59, "Output",ExpressionUUID->"40c98180-f745-4d8d-8b47-ae0406de7f61"]
}, Open  ]],
Cell[CellGroupData[{
Cell[582461, 16366, 581, 17, 43, "Input",ExpressionUUID->"933d0e89-435e-4c65-a9ba-6f7c2812ae6e"],
Cell[583045, 16385, 805, 17, 48, "Output",ExpressionUUID->"3df6507c-7daf-49c5-b604-57f909b30800"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583887, 16407, 675, 20, 43, "Input",ExpressionUUID->"2d904464-68b0-44a7-9f0d-fc48d354af64"],
Cell[584565, 16429, 617, 14, 76, "Output",ExpressionUUID->"7b5355a7-16f2-4b16-810b-d036eaab194a"]
}, Open  ]],
Cell[585197, 16446, 484, 13, 60, "Input",ExpressionUUID->"a426c4b3-fa7e-4a07-95b8-1495d862fcff"],
Cell[585684, 16461, 644, 20, 53, "Input",ExpressionUUID->"45d62a8b-6827-401b-9eea-444aa0755ee9"],
Cell[CellGroupData[{
Cell[586353, 16485, 532, 15, 45, "Input",ExpressionUUID->"59157c93-4757-4616-9b9c-abcadfdaa341"],
Cell[586888, 16502, 1033, 26, 87, "Output",ExpressionUUID->"30000aa3-e6c7-49f4-b7a2-aa5b065a071e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[587958, 16533, 576, 16, 45, "Input",ExpressionUUID->"bc44f4ad-09ad-40f8-859c-e7cd7c14c61f"],
Cell[588537, 16551, 1239, 31, 87, "Output",ExpressionUUID->"6991b267-84cc-4e6d-818e-5f6c64ad9c91"]
}, Open  ]],
Cell[589791, 16585, 428, 14, 77, "Input",ExpressionUUID->"5f443977-0048-4641-b9cd-6375ad5dbd0c"],
Cell[CellGroupData[{
Cell[590244, 16603, 536, 14, 43, "Input",ExpressionUUID->"39fc8bf9-ef2a-4cc6-b90f-a504c17d2df1"],
Cell[590783, 16619, 1058, 26, 88, "Output",ExpressionUUID->"56795774-e090-4c96-9045-7108778f1b80"]
}, Open  ]],
Cell[CellGroupData[{
Cell[591878, 16650, 444, 13, 73, "Input",ExpressionUUID->"ddc399d0-929a-4a40-a244-1a7fab1f013c"],
Cell[592325, 16665, 1182, 30, 76, "Output",ExpressionUUID->"e3834f76-6f4e-4810-ab95-2589b1015621"],
Cell[593510, 16697, 1083, 26, 54, "Output",ExpressionUUID->"011d93df-dc93-4b56-b624-72fc4622ad81"]
}, Open  ]],
Cell[CellGroupData[{
Cell[594630, 16728, 670, 19, 84, "Input",ExpressionUUID->"cb206038-4317-4a10-b20f-0aadeda3f877"],
Cell[595303, 16749, 926, 25, 79, "Output",ExpressionUUID->"0ab5e863-0406-467a-a708-7d25789d915e"],
Cell[596232, 16776, 1005, 28, 79, "Output",ExpressionUUID->"29434768-bbe0-4e31-824e-a13ac42dd4be"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597274, 16809, 987, 28, 102, "Input",ExpressionUUID->"df192910-b439-4888-a3eb-1efe028b914a"],
Cell[598264, 16839, 851, 21, 73, "Output",ExpressionUUID->"fb0f4aa8-51e4-49cc-9823-2a422449b6a4"],
Cell[599118, 16862, 785, 20, 73, "Output",ExpressionUUID->"dd039e9f-fb8e-4837-9343-042652ea5c15"],
Cell[599906, 16884, 650, 16, 72, "Output",ExpressionUUID->"e2e9ddf2-8f73-451d-a44c-3afe48ff9f5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600593, 16905, 8953, 207, 517, "Input",ExpressionUUID->"91157d42-555d-4417-a144-e434dec362ad"],
Cell[609549, 17114, 6616, 178, 237, "Output",ExpressionUUID->"a38e95b1-c340-4675-a12a-8d5cde78f54e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[616202, 17297, 4030, 121, 389, "Input",ExpressionUUID->"1996e739-b68e-4f65-be70-a29dc218055e"],
Cell[620235, 17420, 1002, 30, 82, "Output",ExpressionUUID->"e680d066-dab0-499d-baa2-f4c548fe2221"],
Cell[621240, 17452, 607, 17, 82, "Output",ExpressionUUID->"0033e0e4-4967-451d-a342-094e8afbca80"],
Cell[621850, 17471, 1423, 43, 82, "Output",ExpressionUUID->"25d1b29e-897e-4606-b0ed-6395534a5963"]
}, Open  ]],
Cell[CellGroupData[{
Cell[623310, 17519, 352, 10, 81, "Input",ExpressionUUID->"8a59054b-76bb-4d03-a1ee-39baf27fde1f"],
Cell[623665, 17531, 402, 10, 65, "Message",ExpressionUUID->"7f27ebfc-516c-4009-bb54-1ad1714757f9"],
Cell[624070, 17543, 363, 12, 69, "Output",ExpressionUUID->"21c42717-20ce-4502-a338-7f0671f34307"]
}, Open  ]],
Cell[624448, 17558, 391, 13, 79, "Input",ExpressionUUID->"777d1cca-9020-4420-a818-3ac9a8d7d700"],
Cell[CellGroupData[{
Cell[624864, 17575, 1064, 33, 116, "Input",ExpressionUUID->"6de30c6e-f598-416b-a654-ced41b6dd5b8"],
Cell[625931, 17610, 1005, 32, 79, "Output",ExpressionUUID->"85035bb7-e426-41dd-b691-17a360dff8c8"],
Cell[626939, 17644, 903, 29, 79, "Output",ExpressionUUID->"1b38ed92-64ed-4eab-8220-90949d545a4c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[627879, 17678, 613, 20, 91, "Input",ExpressionUUID->"78a104fc-7713-4e6d-ab16-afa2e8b023cb"],
Cell[628495, 17700, 251, 6, 91, "Output",ExpressionUUID->"296af237-5622-4565-888b-a2953eb942c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[628783, 17711, 409, 12, 91, "Input",ExpressionUUID->"6389bb1d-a829-4854-a4de-1343b8685128"],
Cell[629195, 17725, 209, 6, 91, "Output",ExpressionUUID->"1758362a-842c-40ff-8fe1-8602196e10c3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[629441, 17736, 1135, 35, 105, "Input",ExpressionUUID->"5a5c5c1d-e251-4c1c-bb0d-2fcd9efe4590"],
Cell[630579, 17773, 804, 24, 77, "Output",ExpressionUUID->"2ce542e2-5ba5-4c42-b8fb-8237c37c651b"],
Cell[631386, 17799, 599, 17, 72, "Output",ExpressionUUID->"05ad1cc0-5579-4416-bb2a-03e54d4f62bd"]
}, Open  ]],
Cell[632000, 17819, 189, 4, 43, "Input",ExpressionUUID->"c046dce7-0bf4-4f19-b4b5-9e91befd731a"]
}, Closed]],
Cell[CellGroupData[{
Cell[632226, 17828, 575, 16, 35, "Input",ExpressionUUID->"2e71b9a0-c3cf-4e62-8259-9c3e1528a2d3"],
Cell[632804, 17846, 291, 6, 43, "Input",ExpressionUUID->"9f6f8c4f-7ff2-4799-91ab-5c4a2a14fa79"],
Cell[633098, 17854, 1698, 45, 73, "Input",ExpressionUUID->"18cf4007-8932-4eaa-a685-e103fc274b63"],
Cell[CellGroupData[{
Cell[634821, 17903, 1103, 30, 80, "Input",ExpressionUUID->"98a3facb-150e-4f28-b5c7-244de884f50c"],
Cell[635927, 17935, 1434, 34, 70, "Output",ExpressionUUID->"ce4b3507-7231-407f-9c41-503c61d0bbc1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[637398, 17974, 1214, 36, 80, "Input",ExpressionUUID->"264207c3-f8bb-422c-8ee9-db4ea6f6a764"],
Cell[638615, 18012, 2392, 62, 54, "Output",ExpressionUUID->"0f724e8d-e645-439c-a035-408844c34f56"]
}, Open  ]],
Cell[CellGroupData[{
Cell[641044, 18079, 361, 10, 43, "Input",ExpressionUUID->"ce18cca5-f23c-49aa-8611-806e51be9ab0"],
Cell[641408, 18091, 1928, 55, 90, "Output",ExpressionUUID->"882cd167-9e4f-4a17-a644-f251e5d7a3b4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[643373, 18151, 289, 9, 43, "Input",ExpressionUUID->"88766868-8f33-4556-bbf1-e6420485990f"],
Cell[643665, 18162, 460, 7, 48, "Output",ExpressionUUID->"0abfc230-6131-411b-b68c-321503386152"]
}, Open  ]],
Cell[CellGroupData[{
Cell[644162, 18174, 650, 20, 53, "Input",ExpressionUUID->"6adb290a-78ab-40df-9e02-de881cbb9811"],
Cell[644815, 18196, 997, 25, 59, "Output",ExpressionUUID->"8bba2d6f-993c-4115-9127-f6e5dbc81700"]
}, Open  ]],
Cell[CellGroupData[{
Cell[645849, 18226, 581, 17, 43, "Input",ExpressionUUID->"8c25b43e-11c7-44ef-b634-f6a0aadbc7c6"],
Cell[646433, 18245, 705, 15, 48, "Output",ExpressionUUID->"2609abda-a156-4995-9460-f65b93f570dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[647175, 18265, 675, 20, 43, "Input",ExpressionUUID->"6cbe7ba1-7e29-4057-bb0e-509c79202405"],
Cell[647853, 18287, 545, 13, 76, "Output",ExpressionUUID->"50582299-33f1-4673-a208-65c39aa689c2"]
}, Open  ]],
Cell[648413, 18303, 484, 13, 60, "Input",ExpressionUUID->"9c3f1a57-8d0a-4747-94b5-a264767e68a9"],
Cell[648900, 18318, 644, 20, 53, "Input",ExpressionUUID->"8bcb7f7c-c40c-4a29-906b-0c203284ca71"],
Cell[CellGroupData[{
Cell[649569, 18342, 532, 15, 45, "Input",ExpressionUUID->"1bc4b3a7-831c-459a-a0e2-265e61e0d81c"],
Cell[650104, 18359, 982, 25, 87, "Output",ExpressionUUID->"828b659f-8775-4ece-8471-e329fb48665c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[651123, 18389, 576, 16, 45, "Input",ExpressionUUID->"18c8ff53-cb6f-40ff-a7ca-b3350a576c11"],
Cell[651702, 18407, 1192, 31, 87, "Output",ExpressionUUID->"70f639f9-5dd3-418b-a6bd-ad627f2483bc"]
}, Open  ]],
Cell[652909, 18441, 428, 14, 77, "Input",ExpressionUUID->"67b51265-ae10-4642-9ba0-f280ed1a4f4d"],
Cell[CellGroupData[{
Cell[653362, 18459, 536, 14, 43, "Input",ExpressionUUID->"e9de9094-4763-426c-8ce8-e366505707d9"],
Cell[653901, 18475, 1019, 26, 88, "Output",ExpressionUUID->"1623bc67-fb7a-49ee-b884-fda7bb52a7cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[654957, 18506, 444, 13, 73, "Input",ExpressionUUID->"d49d0c38-528f-45ab-beb0-ea8043cd728e"],
Cell[655404, 18521, 1160, 30, 76, "Output",ExpressionUUID->"a2293bb9-5b7c-4f8b-9c6d-bf1b629a70c5"],
Cell[656567, 18553, 1059, 26, 54, "Output",ExpressionUUID->"b8a27272-fa7c-4b3a-ad20-04cf37da1ea5"]
}, Open  ]],
Cell[657641, 18582, 956, 31, 73, "Input",ExpressionUUID->"3decb33a-38ff-444a-a828-50f21981e6f1"],
Cell[658600, 18615, 7173, 175, 357, "Input",ExpressionUUID->"5a9bd638-0394-4804-89f5-10dd69fe994c"],
Cell[CellGroupData[{
Cell[665798, 18794, 656, 18, 84, "Input",ExpressionUUID->"a21f4925-9de1-4a6c-a3ed-9f5b14327eff"],
Cell[666457, 18814, 902, 25, 79, "Output",ExpressionUUID->"cefb8469-a6af-4c50-b70b-10b76b73b89e"],
Cell[667362, 18841, 983, 28, 79, "Output",ExpressionUUID->"01df3aa1-55d1-476a-9199-49b967278150"]
}, Open  ]],
Cell[668360, 18872, 665, 13, 45, "Input",ExpressionUUID->"a588f749-70bd-4684-89c1-944c9d7296f0"],
Cell[669028, 18887, 775, 16, 82, "Input",ExpressionUUID->"931516f5-b198-464c-8990-1ecfdcdc1531"],
Cell[CellGroupData[{
Cell[669828, 18907, 420, 12, 43, "Input",ExpressionUUID->"bd63c8c2-df38-4a1d-9575-c8a304283b4a"],
Cell[670251, 18921, 1491, 37, 87, "Output",ExpressionUUID->"958dbdf2-65a6-4314-b8d7-9201d56a36e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[671779, 18963, 606, 17, 102, "Input",ExpressionUUID->"5e2936ce-248d-4049-9895-b46585fce1e0"],
Cell[672388, 18982, 1009, 28, 84, "Output",ExpressionUUID->"6b3c6eef-6234-4400-93f3-93bbfca35e59"],
Cell[673400, 19012, 2276, 65, 117, "Output",ExpressionUUID->"bc0fa30d-2fc3-41e1-a077-f0cc0fbf357b"]
}, Open  ]],
Cell[675691, 19080, 1136, 33, 131, "Input",ExpressionUUID->"a8ce2983-9186-4343-a68c-87d64c44f0e1"],
Cell[CellGroupData[{
Cell[676852, 19117, 556, 15, 43, "Input",ExpressionUUID->"afaa9c8c-2714-42ec-b96b-4ebfe083f1bd"],
Cell[677411, 19134, 7277, 185, 470, "Output",ExpressionUUID->"a957330b-820b-41f8-a713-f062f5d45850"]
}, Open  ]],
Cell[CellGroupData[{
Cell[684725, 19324, 277, 7, 43, "Input",ExpressionUUID->"3104a41b-abdb-4daa-a37d-596b38da7622"],
Cell[685005, 19333, 5270, 141, 505, "Output",ExpressionUUID->"48778062-9544-4e1f-ab23-e3f2441efe7d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[690312, 19479, 871, 25, 43, "Input",ExpressionUUID->"88912fa0-7ff9-443b-a8e4-634d7d4f2021"],
Cell[691186, 19506, 226, 5, 49, "Output",ExpressionUUID->"a1236468-d0b5-48cb-983f-4f0e778a3334"]
}, Open  ]],
Cell[691427, 19514, 3632, 112, 288, "Input",ExpressionUUID->"a82054d7-9ae1-4488-85cd-1451127126d1"],
Cell[CellGroupData[{
Cell[695084, 19630, 1657, 44, 78, "Input",ExpressionUUID->"b85e602c-a9d1-4ee7-945d-366a6806597c"],
Cell[696744, 19676, 324, 8, 62, "Message",ExpressionUUID->"3c044a48-1840-44d6-b44b-b73a960f202a"],
Cell[697071, 19686, 357, 9, 64, "Message",ExpressionUUID->"a6e4e1fe-0512-439b-83e7-984b8f12d360"],
Cell[697431, 19697, 337, 9, 68, "Message",ExpressionUUID->"dbda66b0-6894-44bc-adbc-fcf1ac50ff7b"],
Cell[697771, 19708, 400, 9, 35, "Message",ExpressionUUID->"716d89e1-545e-4fba-95f9-4a8cca9f4bac"],
Cell[698174, 19719, 357, 9, 35, "Message",ExpressionUUID->"044c121f-4943-4bb8-9a12-497dcb76d47d"],
Cell[698534, 19730, 391, 9, 35, "Message",ExpressionUUID->"8405b937-6178-4ba8-911e-2fd716e58107"],
Cell[698928, 19741, 405, 9, 35, "Message",ExpressionUUID->"3f1c6d2c-6eac-4037-8f87-6a789ed535d7"],
Cell[699336, 19752, 406, 9, 35, "Message",ExpressionUUID->"31e8e79d-be4c-4595-93a5-838a36e545a5"],
Cell[699745, 19763, 736, 14, 48, "Output",ExpressionUUID->"eb9ffa2f-954f-4255-bc5f-6f533cb48077"]
}, Open  ]],
Cell[CellGroupData[{
Cell[700518, 19782, 1509, 41, 78, "Input",ExpressionUUID->"12079e2c-5e0d-4315-ba17-eafbe7404665"],
Cell[702030, 19825, 335, 9, 68, "Message",ExpressionUUID->"6a106451-1e41-4a4b-a5ad-111d0d9a18ba"],
Cell[702368, 19836, 356, 9, 64, "Message",ExpressionUUID->"5577e8ad-86b1-426b-80a5-2d7b33faa429"],
Cell[702727, 19847, 357, 9, 35, "Message",ExpressionUUID->"e5b2cba4-35ff-4177-9f06-0bc9a7c02197"],
Cell[703087, 19858, 383, 9, 64, "Message",ExpressionUUID->"0e1ce675-e1a4-40bd-83e7-494178419b45"],
Cell[703473, 19869, 400, 9, 35, "Message",ExpressionUUID->"7bc4f3d4-75d5-44b7-a0d8-34fe3ebddb4a"],
Cell[703876, 19880, 403, 9, 35, "Message",ExpressionUUID->"bd7b4587-431f-488d-a17f-ea479b43a4d4"],
Cell[704282, 19891, 1181, 28, 91, "Output",ExpressionUUID->"d451cfb2-c108-4234-b38c-625ffeaeb301"]
}, Open  ]],
Cell[705478, 19922, 189, 4, 43, "Input",ExpressionUUID->"a3e5ba54-be0f-448e-bd84-b06bfad4aab0"]
}, Closed]],
Cell[CellGroupData[{
Cell[705704, 19931, 448, 11, 35, "Input",ExpressionUUID->"8443877a-8614-4d12-aa5b-7efb9d013949"],
Cell[706155, 19944, 291, 6, 43, "Input",ExpressionUUID->"97a7f01a-0fe9-4bf8-885f-77206e44d767"],
Cell[706449, 19952, 1874, 48, 102, "Input",ExpressionUUID->"55d274b2-6a6d-4e00-92c8-e05dccad1348"],
Cell[708326, 20002, 1578, 44, 102, "Input",ExpressionUUID->"83273432-f356-4cdc-8574-fcc6ee2a0859"],
Cell[CellGroupData[{
Cell[709929, 20050, 1103, 30, 80, "Input",ExpressionUUID->"ea2565ce-833c-47c7-9a68-f793cf4a4b9a"],
Cell[711035, 20082, 1211, 30, 70, "Output",ExpressionUUID->"51688221-a275-43e8-8317-66c5e1215b05"]
}, Open  ]],
Cell[CellGroupData[{
Cell[712283, 20117, 1214, 36, 113, "Input",ExpressionUUID->"83595097-9000-475e-a387-15b583d3a642"],
Cell[713500, 20155, 1094, 27, 48, "Output",ExpressionUUID->"94c2953a-f368-4bb7-8e73-34be77861d77"]
}, Open  ]],
Cell[CellGroupData[{
Cell[714631, 20187, 397, 11, 43, "Input",ExpressionUUID->"1505188b-b02f-4519-bf0c-e47f373b39fb"],
Cell[715031, 20200, 338, 8, 35, "Message",ExpressionUUID->"8ce8eef4-ed32-4b65-874b-a47e18103143"],
Cell[715372, 20210, 296, 7, 48, "Output",ExpressionUUID->"eee37f6c-b1ff-40b1-969c-1fcd48231e2b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[715705, 20222, 289, 9, 43, "Input",ExpressionUUID->"6130cc1e-85c6-47a7-8559-cb0605a9facb"],
Cell[715997, 20233, 800, 21, 55, "Output",ExpressionUUID->"42b58f1e-156b-4257-9fd9-6e09440fc45b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[716834, 20259, 650, 20, 53, "Input",ExpressionUUID->"8e5b41be-a492-402d-82cd-c61e0bde53e3"],
Cell[717487, 20281, 449, 9, 48, "Output",ExpressionUUID->"815540cb-ebac-4240-af25-bde57f78ead7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[717973, 20295, 581, 17, 43, "Input",ExpressionUUID->"0d1e5864-47d7-4bff-b135-c914b40f89a2"],
Cell[718557, 20314, 579, 14, 48, "Output",ExpressionUUID->"e13b0584-f429-42fa-8c41-6677aa3a8521"]
}, Open  ]],
Cell[CellGroupData[{
Cell[719173, 20333, 675, 20, 43, "Input",ExpressionUUID->"23e604ef-9f11-49a1-bb90-b6a2510e2a56"],
Cell[719851, 20355, 422, 11, 76, "Output",ExpressionUUID->"c8054526-7b71-4e39-8bb8-4bfc8c94c90a"]
}, Open  ]],
Cell[720288, 20369, 484, 13, 60, "Input",ExpressionUUID->"49ed0338-a2c0-4344-9ba0-7bf7e6c2f7b4"],
Cell[720775, 20384, 783, 23, 49, "Input",ExpressionUUID->"7b9172f7-a6f5-4d8b-b261-dd0be06330f6"],
Cell[CellGroupData[{
Cell[721583, 20411, 763, 22, 45, "Input",ExpressionUUID->"27fd33dd-ed2d-4233-84f4-08c36b2a474f"],
Cell[722349, 20435, 758, 21, 78, "Output",ExpressionUUID->"a8939816-76f2-4aec-9aff-74a2597f7b65"]
}, Open  ]],
Cell[CellGroupData[{
Cell[723144, 20461, 576, 16, 45, "Input",ExpressionUUID->"bc7fd261-d90b-4e9e-a043-8cbf380cf4fe"],
Cell[723723, 20479, 1116, 32, 93, "Output",ExpressionUUID->"9044c2a5-9c4b-45de-ab1f-174b14467b20"]
}, Open  ]],
Cell[724854, 20514, 428, 14, 77, "Input",ExpressionUUID->"e1c641a5-22d4-4afb-bef9-6914c8f9d021"],
Cell[CellGroupData[{
Cell[725307, 20532, 453, 12, 43, "Input",ExpressionUUID->"fba65895-e01f-463f-ad0a-8ae60f3c9f45"],
Cell[725763, 20546, 688, 20, 88, "Output",ExpressionUUID->"e0137029-be31-4e8c-88aa-5cbdea0ebb4b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[726488, 20571, 444, 13, 73, "Input",ExpressionUUID->"748edf63-af89-495c-8dc2-adc79b49f933"],
Cell[726935, 20586, 659, 18, 55, "Output",ExpressionUUID->"bb273b40-a5ec-4c52-a543-37ea84d6f435"],
Cell[727597, 20606, 786, 22, 86, "Output",ExpressionUUID->"eec6eef8-7b10-4e1a-8112-e195ffd8679e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[728420, 20633, 400, 11, 43, "Input",ExpressionUUID->"faf43546-163c-4eb5-a65d-c63ecb827b74"],
Cell[728823, 20646, 1640, 47, 108, "Output",ExpressionUUID->"69e2d52f-6186-4bee-832d-f9b36d440e40"]
}, Open  ]],
Cell[CellGroupData[{
Cell[730500, 20698, 467, 13, 43, "Input",ExpressionUUID->"de6b3bb1-cc65-4468-a51f-7cac8cbe32d9"],
Cell[730970, 20713, 1820, 51, 108, "Output",ExpressionUUID->"b316cb02-fd62-491a-b3a6-5e6864a24a9f"]
}, Open  ]],
Cell[732805, 20767, 276, 7, 43, "Input",ExpressionUUID->"9e1aa4ca-d98c-4537-abcf-99fa8fb63ac4"],
Cell[CellGroupData[{
Cell[733106, 20778, 704, 19, 43, "Input",ExpressionUUID->"39529cfb-e950-45d0-ad17-fb3343960447"],
Cell[733813, 20799, 1926, 53, 108, "Output",ExpressionUUID->"db4ca517-d745-42ca-8ef9-b5177ee1839c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[735776, 20857, 1603, 42, 153, "Input",ExpressionUUID->"e7094d57-1fef-4c4e-b139-814aabdc3c11"],
Cell[737382, 20901, 1101, 29, 76, "Output",ExpressionUUID->"29ea6418-50d5-4d1b-92f8-ba371b1352d9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[738520, 20935, 377, 10, 43, "Input",ExpressionUUID->"6d284f67-7051-40bb-9de5-4bd65bd1cdc8"],
Cell[738900, 20947, 918, 27, 113, "Output",ExpressionUUID->"ed64d883-f2a9-4798-89d7-ee2d0c725448"]
}, Open  ]],
Cell[739833, 20977, 189, 4, 43, "Input",ExpressionUUID->"d3f65622-c89b-41dd-9780-4e1e8ce67607"]
}, Closed]],
Cell[740037, 20984, 191, 4, 35, "Input",ExpressionUUID->"958b6a9f-860e-49bf-89bd-90daa377aa47"]
}, Closed]],
Cell[CellGroupData[{
Cell[740265, 20993, 319, 6, 35, "Input",ExpressionUUID->"ad32ba00-e531-4fbb-8559-e5cba0776777"],
Cell[CellGroupData[{
Cell[740609, 21003, 156, 3, 43, "Input",ExpressionUUID->"42b5791e-44fb-4b41-aa93-a767510d28bc"],
Cell[740768, 21008, 973, 26, 51, "Output",ExpressionUUID->"c3c570ce-f566-45f4-98e8-987000cf58cb"]
}, Open  ]],
Cell[741756, 21037, 1942, 50, 160, "Input",ExpressionUUID->"1dc670ae-962a-4e55-ab3b-371f2f142603"],
Cell[743701, 21089, 3351, 88, 218, "Input",ExpressionUUID->"c8f994ad-b53b-4945-8b39-eff37fc0a007"],
Cell[CellGroupData[{
Cell[747077, 21181, 602, 14, 43, "Input",ExpressionUUID->"050cc75b-86ae-4f95-a429-57df6fbaa5a0"],
Cell[747682, 21197, 1148, 30, 80, "Output",ExpressionUUID->"f09b3434-5c38-4f7a-bdec-f4736eab127a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[748867, 21232, 1027, 30, 79, "Input",ExpressionUUID->"f5b72dfa-9336-43d4-a5a4-6c099e830f29"],
Cell[749897, 21264, 2091, 58, 122, "Output",ExpressionUUID->"74e3cd97-42cc-4cbf-968f-470e160f9f38"]
}, Open  ]],
Cell[752003, 21325, 3214, 93, 265, "Input",ExpressionUUID->"c39cd311-87ec-495a-acfa-0c410e681a02"],
Cell[CellGroupData[{
Cell[755242, 21422, 200, 4, 43, "Input",ExpressionUUID->"eca19379-f815-48f7-9aa4-67cbece8433d"],
Cell[CellGroupData[{
Cell[755467, 21430, 992, 28, 102, "Input",ExpressionUUID->"700c9aa1-9e99-444c-8e30-f52ee858b44d"],
Cell[756462, 21460, 744, 17, 50, "Output",ExpressionUUID->"e19163df-e9b7-43ba-8219-abab5ddd393c"],
Cell[757209, 21479, 894, 23, 75, "Output",ExpressionUUID->"5a19dbeb-a46e-4199-99a4-de053af2c6db"]
}, Open  ]],
Cell[CellGroupData[{
Cell[758140, 21507, 1262, 36, 162, "Input",ExpressionUUID->"5dd1417d-87e0-45d4-ae1d-8ed61bcf2bbc"],
Cell[759405, 21545, 631, 13, 65, "Message",ExpressionUUID->"181c659c-aa76-4457-9f6a-2460f6c107e1"],
Cell[760039, 21560, 1053, 32, 70, "Output",ExpressionUUID->"261d0bfc-ccaa-4d9a-8e65-22f7b22bfb2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[761129, 21597, 819, 22, 112, "Input",ExpressionUUID->"87085f85-2fa6-4168-ac89-0caf5185f3cc"],
Cell[761951, 21621, 1274, 38, 72, "Output",ExpressionUUID->"7b266d69-46fa-461b-8ed4-82a51e35c347"]
}, Open  ]],
Cell[CellGroupData[{
Cell[763262, 21664, 805, 23, 80, "Input",ExpressionUUID->"98c40058-608f-48d2-8d13-3df926b8b7c4"],
Cell[764070, 21689, 1298, 39, 72, "Output",ExpressionUUID->"31c8aaaa-5068-4ac1-87cc-70e4a2900911"]
}, Open  ]],
Cell[CellGroupData[{
Cell[765405, 21733, 1007, 28, 102, "Input",ExpressionUUID->"23d9a407-f784-4d93-bedf-d3158f523994"],
Cell[766415, 21763, 1198, 35, 74, "Output",ExpressionUUID->"202d59e1-dfa3-4fd0-a65b-40be1e91dc7b"],
Cell[767616, 21800, 573, 12, 65, "Message",ExpressionUUID->"bab18367-307c-488f-8a38-c72f6e89ae6b"],
Cell[768192, 21814, 872, 23, 92, "Output",ExpressionUUID->"7c339ac0-5a6b-464f-97a7-423f7123500c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[769101, 21842, 1847, 56, 142, "Input",ExpressionUUID->"f228fdfb-fd2d-4636-bbf7-cc7061c887ca"],
Cell[770951, 21900, 467, 12, 69, "Output",ExpressionUUID->"73c54dba-7927-48f3-bf4f-bcb3230d3e78"]
}, Open  ]],
Cell[CellGroupData[{
Cell[771455, 21917, 546, 16, 73, "Input",ExpressionUUID->"b9ac7706-f997-4b8a-a602-2368a4ec7a13"],
Cell[772004, 21935, 872, 25, 61, "Output",ExpressionUUID->"10a9c323-ed57-4816-bdfd-5a7ef847f93c"],
Cell[772879, 21962, 1132, 31, 70, "Output",ExpressionUUID->"f6529a29-58c9-4735-98c6-9ff4d3cceeb4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[774048, 21998, 331, 9, 73, "Input",ExpressionUUID->"ad007463-a0c0-4406-a082-659d9f24a73d"],
Cell[774382, 22009, 753, 20, 69, "Output",ExpressionUUID->"15e04151-87a0-405d-b1a1-882ead0f2e2a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[775172, 22034, 722, 20, 73, "Input",ExpressionUUID->"6364fc60-e602-4fb1-9ed8-4d6449457f09"],
Cell[775897, 22056, 877, 22, 74, "Output",ExpressionUUID->"0c94fc60-92b6-4a79-9626-93b311234eb0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[776811, 22083, 1392, 43, 171, "Input",ExpressionUUID->"4fad4bda-5257-4ab7-b7eb-d9139343b5d7"],
Cell[778206, 22128, 715, 22, 93, "Output",ExpressionUUID->"d696f5b0-b215-4881-a3e4-ab8b33ce245e"],
Cell[778924, 22152, 920, 26, 86, "Output",ExpressionUUID->"b96404a9-16e8-409c-ac9e-ea4e796a87ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[779881, 22183, 1426, 44, 171, "Input",ExpressionUUID->"8056e4c2-a0ce-4b1d-8cbf-f6fb21b0d732"],
Cell[781310, 22229, 768, 23, 93, "Output",ExpressionUUID->"0be33ee4-d4c8-4bf0-9fef-b7bee5e15610"],
Cell[782081, 22254, 1637, 44, 86, "Output",ExpressionUUID->"d4f7e06b-4a31-4ad3-8ec8-0fa7f8d67239"]
}, Open  ]],
Cell[CellGroupData[{
Cell[783755, 22303, 1924, 59, 156, "Input",ExpressionUUID->"efe09db8-b598-454c-8a5c-1e931341b7df"],
Cell[785682, 22364, 1145, 32, 87, "Output",ExpressionUUID->"dfcf36c1-7146-4923-baa5-0e032c949fa3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[786864, 22401, 934, 28, 95, "Input",ExpressionUUID->"d321cf8e-414d-406c-8312-0da37d22532f"],
Cell[787801, 22431, 1036, 30, 110, "Output",ExpressionUUID->"6653ce58-dc78-4f1b-ad8a-0300201ef802"]
}, Open  ]],
Cell[788852, 22464, 193, 4, 43, "Input",ExpressionUUID->"e0674789-8987-40c3-aedb-9f69d37e85ad"]
}, Open  ]],
Cell[789060, 22471, 316, 9, 47, "Input",ExpressionUUID->"e5061296-b4e1-4961-b831-77a9030f6ba7"],
Cell[CellGroupData[{
Cell[789401, 22484, 393, 13, 73, "Input",ExpressionUUID->"1612bfe4-9f11-4db7-97ae-c11b995d2d33"],
Cell[789797, 22499, 2461, 71, 138, "Output",ExpressionUUID->"8cec0389-08aa-4de9-b826-16cee64e2fd0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[792295, 22575, 981, 23, 73, "Input",ExpressionUUID->"ba3db77d-e958-462a-8a51-d572b8bee448"],
Cell[793279, 22600, 2205, 56, 108, "Output",ExpressionUUID->"9124ffc6-8807-4978-bdbb-5294d2a1e695"]
}, Open  ]],
Cell[CellGroupData[{
Cell[795521, 22661, 535, 16, 73, "Input",ExpressionUUID->"56b95b6a-5223-46ba-a38d-aa215d6e701b"],
Cell[796059, 22679, 3391, 96, 170, "Output",ExpressionUUID->"f830c7ce-bd51-4ef4-b60f-afaccaaf5768"]
}, Open  ]],
Cell[CellGroupData[{
Cell[799487, 22780, 1375, 38, 141, "Input",ExpressionUUID->"21ce6ac3-1454-4b2e-803c-f07042f7dc03"],
Cell[800865, 22820, 1207, 33, 87, "Output",ExpressionUUID->"14ebdf0c-0ffc-449d-bbd8-b24c4cc52f37"],
Cell[802075, 22855, 1415, 34, 78, "Output",ExpressionUUID->"3d05daf5-ac4d-40a1-a56f-68f33fcbb23c"]
}, Open  ]],
Cell[803505, 22892, 314, 9, 47, "Input",ExpressionUUID->"ff4d1809-5d57-4cb5-9ff3-19f9a4e6d48c"],
Cell[CellGroupData[{
Cell[803844, 22905, 533, 17, 43, "Input",ExpressionUUID->"004fab7a-7d4d-4f0d-b5a0-94f10ec011cf"],
Cell[804380, 22924, 1251, 32, 71, "Output",ExpressionUUID->"80150e92-b6f6-4b14-83ee-92d8579a4ea9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[805668, 22961, 506, 15, 43, "Input",ExpressionUUID->"4aa91a47-1bb8-40e4-9719-fd1a2901019f"],
Cell[806177, 22978, 1363, 36, 71, "Output",ExpressionUUID->"f0bf3796-0d4d-4f50-b16d-0094291ccc53"]
}, Open  ]],
Cell[CellGroupData[{
Cell[807577, 23019, 889, 26, 81, "Input",ExpressionUUID->"512e4d9e-67d9-4bb7-a070-ba696bd0b912"],
Cell[808469, 23047, 1259, 36, 104, "Output",ExpressionUUID->"8ea1a833-af79-4931-abd4-370f76d634ee"],
Cell[809731, 23085, 332, 6, 49, "Output",ExpressionUUID->"09f49b7a-904b-4fdd-99bd-195cfeb5b437"]
}, Open  ]],
Cell[810078, 23094, 316, 9, 48, "Input",ExpressionUUID->"4850e69f-4cb7-4bf9-a4f9-4c2979cc3534"],
Cell[810397, 23105, 1427, 39, 111, "Input",ExpressionUUID->"ed60dd4f-42b9-45e1-8401-021aadc769c2"],
Cell[CellGroupData[{
Cell[811849, 23148, 302, 8, 43, "Input",ExpressionUUID->"bcec9317-786e-4bb2-beb4-8e4dc746cfea"],
Cell[812154, 23158, 1739, 48, 117, "Output",ExpressionUUID->"61e9fc01-d5f3-4b6a-9b00-5d9920531027"]
}, Open  ]],
Cell[CellGroupData[{
Cell[813930, 23211, 889, 25, 73, "Input",ExpressionUUID->"de1e8804-8fa2-4ff9-af1d-bb77e2eeb2e0"],
Cell[814822, 23238, 480, 11, 49, "Output",ExpressionUUID->"959e65ff-15d6-44bb-9315-9b715359640f"]
}, Open  ]],
Cell[815317, 23252, 785, 21, 43, "Input",ExpressionUUID->"34991300-e872-43c7-bf34-34fcd8158c97"],
Cell[816105, 23275, 952, 28, 50, "Input",ExpressionUUID->"8e97ca42-bebe-4466-8b05-dfa0470b14e0"],
Cell[817060, 23305, 456, 14, 43, "Input",ExpressionUUID->"b6d48d4a-d6d2-4e4f-931b-26c82c97e95a"],
Cell[817519, 23321, 6022, 144, 451, "Input",ExpressionUUID->"3422f7b9-66ef-46c3-bc48-359b9764fcd7"],
Cell[CellGroupData[{
Cell[823566, 23469, 852, 19, 43, "Input",ExpressionUUID->"7b212192-1267-4972-9bd1-769586b6c98a"],
Cell[824421, 23490, 8617, 228, 330, "Output",ExpressionUUID->"5e3c1a1f-d057-44ff-badc-825e6a13f538"]
}, Open  ]],
Cell[CellGroupData[{
Cell[833075, 23723, 457, 13, 43, "Input",ExpressionUUID->"28213f0a-4fdd-475b-a557-5cc4d7a89741"],
Cell[833535, 23738, 1089, 31, 74, "Output",ExpressionUUID->"fc251dab-c33e-4613-8bbe-d44088db3334"]
}, Open  ]],
Cell[CellGroupData[{
Cell[834661, 23774, 555, 17, 43, "Input",ExpressionUUID->"708976f8-7cb8-48b5-85b8-3f182b15f1dd"],
Cell[835219, 23793, 258, 5, 73, "Input",ExpressionUUID->"53bfd5a7-e913-4426-9b54-98d4bb45f64e"],
Cell[CellGroupData[{
Cell[835502, 23802, 704, 19, 73, "Input",ExpressionUUID->"dbaea814-c3a3-4f34-8a23-77e5bf23d513"],
Cell[836209, 23823, 15209, 392, 1146, "Output",ExpressionUUID->"da0b01ca-284f-4003-be48-17d73f315b00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[851455, 24220, 669, 18, 73, "Input",ExpressionUUID->"facf3541-ddaa-41dd-8af1-4ff51063206e"],
Cell[852127, 24240, 1423, 27, 48, "Output",ExpressionUUID->"bc7610a8-1943-4242-b49e-a04c39baab75"]
}, Open  ]],
Cell[CellGroupData[{
Cell[853587, 24272, 605, 15, 43, "Input",ExpressionUUID->"e5473dbb-c442-4565-b33c-71ddc811ed2c"],
Cell[854195, 24289, 2973, 70, 136, "Output",ExpressionUUID->"140b56ba-9d7f-4385-b5d4-02243a6d9511"]
}, Open  ]],
Cell[857183, 24362, 191, 4, 43, "Input",ExpressionUUID->"4d419e30-6319-44d8-ad7d-f3c083976373"],
Cell[CellGroupData[{
Cell[857399, 24370, 2302, 53, 181, "Input",ExpressionUUID->"44e3df39-c4e2-4310-93d0-afb9f18e9b75"],
Cell[859704, 24425, 2132, 54, 130, "Output",ExpressionUUID->"78e4256e-ff1d-45a9-b69a-666438f77e9b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[861873, 24484, 2332, 58, 298, "Input",ExpressionUUID->"1bb348bf-518d-43d0-98f2-6b31b015bfde"],
Cell[864208, 24544, 3153, 82, 198, "Output",ExpressionUUID->"6364c7e6-a506-4330-92dc-925c705ecc7c"]
}, Open  ]],
Cell[867376, 24629, 193, 4, 43, "Input",ExpressionUUID->"a318c582-5499-4200-92e2-ca27057048e8"],
Cell[867572, 24635, 536, 13, 81, "Input",ExpressionUUID->"3a6835de-efe9-4894-9918-441e4d7c52cf"],
Cell[CellGroupData[{
Cell[868133, 24652, 1317, 32, 109, "Input",ExpressionUUID->"a01e3453-510c-4ed8-a46d-d30ac04ab233"],
Cell[869453, 24686, 2099, 59, 184, "Output",ExpressionUUID->"c792f0fd-e4be-4238-ab74-9e1cd0e085ae"]
}, Open  ]],
Cell[CellGroupData[{
Cell[871589, 24750, 185, 4, 43, "Input",ExpressionUUID->"273a57fc-901f-437e-8330-c8b11666e3d2"],
Cell[871777, 24756, 1266, 37, 130, "Output",ExpressionUUID->"3296dc00-9d42-4bda-bba5-b6f9e6d9adcf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[873080, 24798, 190, 4, 43, "Input",ExpressionUUID->"0c1a1dc3-7d89-474d-9fe3-ea5015cd3775"],
Cell[873273, 24804, 1727, 50, 154, "Output",ExpressionUUID->"bb69c7dc-446b-42d3-926e-ff3b3c566b71"]
}, Open  ]],
Cell[CellGroupData[{
Cell[875037, 24859, 5845, 146, 452, "Input",ExpressionUUID->"3e3ec6bb-7306-4ebb-b239-55698102d9e0"],
Cell[880885, 25007, 2965, 80, 221, "Output",ExpressionUUID->"dcb5e295-2143-45f1-baa5-62f362c283bf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[883887, 25092, 609, 16, 43, "Input",ExpressionUUID->"93a37b69-7ee0-4b3f-8670-4768b3190636"],
Cell[884499, 25110, 3304, 93, 200, "Output",ExpressionUUID->"9e8af5c1-3c62-4797-9421-84337ef829cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[887840, 25208, 903, 26, 73, "Input",ExpressionUUID->"ace3177f-e80f-4168-932c-e96b546240d0"],
Cell[888746, 25236, 1262, 38, 126, "Output",ExpressionUUID->"027efd87-701f-4a09-9249-05624ab9a21b"]
}, Open  ]],
Cell[890023, 25277, 191, 4, 43, "Input",ExpressionUUID->"ece5c0eb-8d03-409a-8c01-de15284b987c"]
}, Closed]],
Cell[890229, 25284, 1393, 40, 141, "Input",ExpressionUUID->"9ba8081f-b2af-4ceb-98e5-a845d76949b1"],
Cell[CellGroupData[{
Cell[891647, 25328, 970, 27, 102, "Input",ExpressionUUID->"96b2e506-5ca4-4d3d-8ca9-f045ee3e3f0c"],
Cell[892620, 25357, 9715, 266, 604, "Output",ExpressionUUID->"3f414684-7a1a-41ca-b0ff-12f6bb96b2ca"]
}, Open  ]],
Cell[CellGroupData[{
Cell[902372, 25628, 408, 12, 43, "Input",ExpressionUUID->"40ed720c-d4ea-4453-be4d-161aaff86c73"],
Cell[902783, 25642, 1019, 30, 74, "Output",ExpressionUUID->"1a8af52c-d7eb-460e-9d02-7f5dbd31c6d1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[903839, 25677, 550, 17, 73, "Input",ExpressionUUID->"31054880-d78e-4cd8-95d1-a0243b9a4c3d"],
Cell[904392, 25696, 511, 14, 60, "Output",ExpressionUUID->"b1ef866c-e129-43f4-bbb3-cded1c552b06"]
}, Open  ]],
Cell[CellGroupData[{
Cell[904940, 25715, 482, 14, 43, "Input",ExpressionUUID->"2a4cf517-0c4d-486e-9725-e3605bc20f5c"],
Cell[905425, 25731, 1063, 32, 87, "Output",ExpressionUUID->"831223cf-66f4-4873-a51f-086487159b47"]
}, {2}]],
Cell[906500, 25766, 118, 1, 43, "Input",ExpressionUUID->"dcdf91fd-de9f-4238-ada6-21b3a8d65e01"]
}, Closed]],
Cell[CellGroupData[{
Cell[906655, 25772, 403, 8, 35, "Input",ExpressionUUID->"1c3aa5db-ffa6-44b0-8928-c404f9742765"],
Cell[907061, 25782, 1923, 49, 102, "Input",ExpressionUUID->"ff67a10b-71fd-414c-95c1-f8b580f2c863"],
Cell[908987, 25833, 2395, 62, 102, "Input",ExpressionUUID->"960ce0bc-caac-4ae9-9041-be20ab7b6796"],
Cell[CellGroupData[{
Cell[911407, 25899, 602, 14, 43, "Input",ExpressionUUID->"2416670a-2971-42a2-b209-3c155877263c"],
Cell[912012, 25915, 1175, 31, 80, "Output",ExpressionUUID->"e4c5d72e-cb0e-4422-9705-b8923c4098dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[913224, 25951, 1027, 30, 79, "Input",ExpressionUUID->"dffaf6ee-9f2f-4a3b-b422-f779dacc2d2f"],
Cell[914254, 25983, 2115, 59, 75, "Output",ExpressionUUID->"b107eca7-fc85-4977-beb4-cc9184f17601"]
}, Open  ]],
Cell[916384, 26045, 2330, 66, 120, "Input",ExpressionUUID->"d6860546-bbc3-489e-a0be-b80247fdda42"],
Cell[CellGroupData[{
Cell[918739, 26115, 966, 26, 73, "Input",ExpressionUUID->"3f1b1ab3-edcf-4863-86da-15de24757c3c"],
Cell[919708, 26143, 584, 13, 49, "Output",ExpressionUUID->"bd02b6f6-13bd-489c-9575-9abed94f1617"]
}, Open  ]],
Cell[920307, 26159, 1040, 29, 52, "Input",ExpressionUUID->"ea3c9d2d-5666-41c4-b6c6-c733dd3133b2"],
Cell[921350, 26190, 952, 28, 50, "Input",ExpressionUUID->"d3770e3f-13cc-4f13-902e-393075244fca"],
Cell[922305, 26220, 529, 15, 43, "Input",ExpressionUUID->"e1ee3db9-77da-4607-a63a-48a101a5c784"],
Cell[922837, 26237, 5208, 129, 376, "Input",ExpressionUUID->"073a34a8-e42d-427c-ba11-1b88a8301558"],
Cell[928048, 26368, 1393, 40, 81, "Input",ExpressionUUID->"0e72f1c8-20c8-4f8e-b144-986d7f9f215b"],
Cell[929444, 26410, 999, 27, 43, "Input",ExpressionUUID->"74d82419-f40d-4cfd-aaeb-c3a2eed2089c"],
Cell[CellGroupData[{
Cell[930468, 26441, 495, 12, 43, "Input",ExpressionUUID->"a9197c37-ab5d-4daf-af6f-96e68a8ba51c"],
Cell[930966, 26455, 92514, 2283, 3749, "Output",ExpressionUUID->"1ea2b04e-88d6-47b9-b7c6-305e76511ccc"]
}, Closed]],
Cell[1023495, 28741, 118, 1, 35, "Input",ExpressionUUID->"ef08e1c4-b8ff-4b14-a7eb-7e4bb33ab854"]
}, Closed]],
Cell[CellGroupData[{
Cell[1023650, 28747, 407, 8, 35, "Input",ExpressionUUID->"15cc277a-efbf-4f60-85ba-0ef8110d09a2"],
Cell[1024060, 28757, 2444, 65, 102, "Input",ExpressionUUID->"55329c2f-7b42-4b33-ac32-7900ff4bbb11"],
Cell[CellGroupData[{
Cell[1026529, 28826, 747, 19, 50, "Input",ExpressionUUID->"1b9f10b8-9885-49ce-9ab1-c505241618b8"],
Cell[1027279, 28847, 1054, 24, 49, "Output",ExpressionUUID->"c6c3472b-bd7d-42d2-9449-e92ae7e952fa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1028370, 28876, 622, 17, 50, "Input",ExpressionUUID->"1cca30d6-4e8d-4738-944b-9f696fdd0ccc"],
Cell[1028995, 28895, 1757, 48, 49, "Output",ExpressionUUID->"41359f22-74e6-4814-9369-9754eaf3b9f2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1030789, 28948, 607, 16, 82, "Input",ExpressionUUID->"3d2deaae-f906-4528-a621-29bc11cd9d53"],
Cell[1031399, 28966, 497, 9, 49, "Output",ExpressionUUID->"2994dd15-8f95-47ff-9e0b-3af25b36b73d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1031933, 28980, 445, 11, 43, "Input",ExpressionUUID->"760f7fd0-03e7-4e11-bd78-415b21934b73"],
Cell[1032381, 28993, 2015, 56, 79, "Output",ExpressionUUID->"4a797dfa-9614-43f8-88fc-e7ec0491cae6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1034433, 29054, 487, 12, 43, "Input",ExpressionUUID->"5c4f6aba-8d9f-4338-b422-6e49dae7a9d4"],
Cell[1034923, 29068, 434, 7, 49, "Output",ExpressionUUID->"aad5f392-e3a0-48d7-974d-fd03488bf631"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1035394, 29080, 667, 18, 82, "Input",ExpressionUUID->"7b9a46ff-4cb4-4bff-8493-77f4715e7d86"],
Cell[1036064, 29100, 708, 16, 49, "Output",ExpressionUUID->"7eff09b8-084b-4198-9d28-b09291f00769"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1036809, 29121, 584, 17, 81, "Input",ExpressionUUID->"70b387e4-cd7f-4c18-9086-2682e337e401"],
Cell[1037396, 29140, 1439, 38, 80, "Output",ExpressionUUID->"ea3f4e29-bbb5-468c-be77-5b2369ae88c8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1038872, 29183, 872, 20, 50, "Input",ExpressionUUID->"6aea6d02-e845-474f-9d18-a9c6932fd0c8"],
Cell[1039747, 29205, 477, 9, 48, "Output",ExpressionUUID->"76ae1dd9-24c0-4488-986f-166c22c77ad3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1040261, 29219, 598, 17, 50, "Input",ExpressionUUID->"dcb43b3e-87bd-4c9b-bd88-9151f1176819"],
Cell[1040862, 29238, 642, 15, 50, "Output",ExpressionUUID->"d8cc0d5a-e2b9-4db6-9151-ffddd1e0ed3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1041541, 29258, 648, 18, 50, "Input",ExpressionUUID->"28434785-1467-435a-873d-e610f06411b2"],
Cell[1042192, 29278, 629, 15, 48, "Output",ExpressionUUID->"8ebd78cd-a797-4f24-8138-98eeb57f37aa"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1042858, 29298, 627, 18, 50, "Input",ExpressionUUID->"1afdfd24-caee-4bbf-a817-1177782c61ec"],
Cell[1043488, 29318, 1794, 48, 78, "Output",ExpressionUUID->"4e216d51-e8f8-48f7-8365-92c6e517ab04"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1045319, 29371, 626, 18, 50, "Input",ExpressionUUID->"9c9a2ca2-20f3-4f5a-aed6-e65a1f8c66a1"],
Cell[1045948, 29391, 845, 22, 50, "Output",ExpressionUUID->"e4031244-ed2c-4b2d-832b-8d8fd8aa308b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1046830, 29418, 741, 19, 81, "Input",ExpressionUUID->"da6e6033-8e99-45c5-9f90-12c8900f2d5c"],
Cell[1047574, 29439, 555, 10, 48, "Output",ExpressionUUID->"1b9c3ef5-da4e-486c-8058-8f748ab51b1e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1048166, 29454, 544, 16, 81, "Input",ExpressionUUID->"d335120d-9737-4358-896e-8d90ed06f79b"],
Cell[1048713, 29472, 306, 6, 48, "Output",ExpressionUUID->"8d223d20-cab0-4650-b6fd-f95d48c3afc3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1049056, 29483, 571, 17, 81, "Input",ExpressionUUID->"89f95e8f-44bd-4071-8a71-b2cf46da89ef"],
Cell[1049630, 29502, 300, 6, 48, "Output",ExpressionUUID->"6e681067-807d-4b84-9cd3-bc636ea1198c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1049967, 29513, 659, 19, 81, "Input",ExpressionUUID->"3374b9f5-331b-43c9-b8e7-7a18d40e7d30"],
Cell[1050629, 29534, 1715, 47, 80, "Output",ExpressionUUID->"1191b513-503c-4f83-b010-07826850f5cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1052381, 29586, 586, 17, 81, "Input",ExpressionUUID->"741d294f-6fd8-4b03-bfe8-ae2e7df862d9"],
Cell[1052970, 29605, 2463, 69, 80, "Output",ExpressionUUID->"9d6e8a7f-86ec-4cbc-bbf4-92e8cdd54766"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1055470, 29679, 2793, 69, 171, "Input",ExpressionUUID->"6da3c64f-01d0-4437-b828-d3136452c3c9"],
Cell[1058266, 29750, 1397, 39, 50, "Output",ExpressionUUID->"165a9f03-f547-49a5-8b3b-05c9a3da5b34"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1059700, 29794, 545, 16, 50, "Input",ExpressionUUID->"eea8011d-0aca-42ad-ab9e-735906e1e4fc"],
Cell[1060248, 29812, 334, 7, 48, "Output",ExpressionUUID->"21771676-57c7-49ca-b06a-c69ade2c6e3b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1060619, 29824, 546, 16, 50, "Input",ExpressionUUID->"71c8aa72-7181-4783-b78c-5a52f56ea50a"],
Cell[1061168, 29842, 513, 13, 50, "Output",ExpressionUUID->"216a70d0-eea4-4ff4-b651-47f088f4c26b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1061718, 29860, 372, 10, 43, "Input",ExpressionUUID->"2974ac11-dc3b-466b-b5c0-f6add7dd33b7"],
Cell[1062093, 29872, 771, 21, 50, "Output",ExpressionUUID->"d3f8d187-ad63-4b4d-ac26-829d7b499910"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1062901, 29898, 401, 11, 43, "Input",ExpressionUUID->"d84cdc90-6acb-4f57-b33a-9f8d57c34655"],
Cell[1063305, 29911, 1134, 31, 50, "Output",ExpressionUUID->"4615cb07-84b5-4620-bc74-3b11981bf6ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1064476, 29947, 528, 14, 50, "Input",ExpressionUUID->"f81dae17-a391-4602-b906-c520fa1da2fc"],
Cell[1065007, 29963, 668, 15, 50, "Output",ExpressionUUID->"e8631eb6-a22a-41fb-af48-90dc9061b284"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1065712, 29983, 555, 15, 50, "Input",ExpressionUUID->"7e899087-7108-4230-a9c8-feb7e8b40ff6"],
Cell[1066270, 30000, 1329, 36, 50, "Output",ExpressionUUID->"4f62bc22-e4d5-4bac-b105-89f7f96ebede"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1067636, 30041, 503, 14, 50, "Input",ExpressionUUID->"320f6fc2-0f6b-45cb-bd2f-11384d3ce693"],
Cell[1068142, 30057, 1806, 49, 80, "Output",ExpressionUUID->"9b7c7dfe-b1dc-48f7-a2a2-21e8a5adef5c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1069985, 30111, 503, 14, 50, "Input",ExpressionUUID->"6b6b76ae-8fcb-4c76-81f3-377907c85015"],
Cell[1070491, 30127, 5159, 147, 167, "Output",ExpressionUUID->"c0c8c9f7-86d9-4f3e-b068-eb5d9f1a0609"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1075687, 30279, 421, 12, 43, "Input",ExpressionUUID->"c3665dfe-9f0a-4bf3-8e18-f731c82f91be"],
Cell[1076111, 30293, 298, 5, 48, "Output",ExpressionUUID->"97954254-f2ba-40b3-9ed6-17fa4eb8bbc0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1076446, 30303, 505, 14, 50, "Input",ExpressionUUID->"96112f9f-9eed-4b06-87ef-0ba5a84d93d3"],
Cell[1076954, 30319, 1579, 45, 78, "Output",ExpressionUUID->"b82c45f2-dd07-4249-94e2-b0eea1457ddf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1078570, 30369, 465, 13, 81, "Input",ExpressionUUID->"19b5f357-0c85-4065-98d7-311499630e88"],
Cell[1079038, 30384, 361, 7, 48, "Output",ExpressionUUID->"2cdc0052-a31e-46e6-bcc3-fa7f583890eb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1079436, 30396, 510, 14, 81, "Input",ExpressionUUID->"f2cbbc22-cd73-4b77-81a8-ea6da620b9a0"],
Cell[1079949, 30412, 328, 6, 48, "Output",ExpressionUUID->"2a8dbcb9-bc86-40fc-9952-919cc6a754dd"]
}, Open  ]],
Cell[1080292, 30421, 5616, 162, 209, "Input",ExpressionUUID->"387d43d9-b88b-42f4-8ecc-7b3731209cda"],
Cell[CellGroupData[{
Cell[1085933, 30587, 682, 16, 73, "Input",ExpressionUUID->"d8935064-942a-46f9-8556-33eb0dade75d"],
Cell[1086618, 30605, 331, 5, 48, "Output",ExpressionUUID->"b6541701-4f30-43d9-b0a2-4ec8516b413c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1086986, 30615, 517, 14, 81, "Input",ExpressionUUID->"3fa6357c-6c77-4216-9d49-8a10b73a4534"],
Cell[1087506, 30631, 1356, 36, 50, "Output",ExpressionUUID->"92d4e16c-ea41-4fb2-ab63-392d229c8f88"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1088899, 30672, 539, 16, 81, "Input",ExpressionUUID->"c71d681d-c668-4f43-8191-5a7ec84336dd"],
Cell[1089441, 30690, 4066, 112, 138, "Output",ExpressionUUID->"e42518ea-2d3b-4f12-9e01-e4be41cbe556"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1093544, 30807, 515, 14, 81, "Input",ExpressionUUID->"8197f067-2ff6-4ca5-ad39-6774d8f329c3"],
Cell[1094062, 30823, 510, 13, 50, "Output",ExpressionUUID->"57394d1a-9d5d-4f5c-8ddc-8232e5822d1f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1094609, 30841, 657, 18, 81, "Input",ExpressionUUID->"0825f03e-39e2-41bc-8f94-3d14a0f8efb8"],
Cell[1095269, 30861, 6389, 182, 225, "Output",ExpressionUUID->"93885c06-e22e-443b-ae78-cd2f52055c5d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1101695, 31048, 916, 25, 131, "Input",ExpressionUUID->"8b127f08-fdb4-4301-b26b-df3ecb505110"],
Cell[1102614, 31075, 452, 13, 54, "Output",ExpressionUUID->"010d7257-42fe-4268-a0a6-c1cc5b4497ef"],
Cell[1103069, 31090, 710, 21, 54, "Output",ExpressionUUID->"ed07a79c-f4ef-4e51-8ee0-b2bc91b93571"],
Cell[1103782, 31113, 340, 9, 49, "Output",ExpressionUUID->"b269ac38-5aa7-4dfb-8bbd-fa898147c6eb"],
Cell[1104125, 31124, 341, 8, 49, "Output",ExpressionUUID->"febf88d8-dcfe-4cef-abe9-29c37bebf783"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1104503, 31137, 720, 18, 131, "Input",ExpressionUUID->"ba9cb4f8-cc7c-442a-8461-8893a592b3e6"],
Cell[1105226, 31157, 5346, 154, 206, "Output",ExpressionUUID->"5099c271-5079-400f-8d2b-9d6ae0b2ace0"],
Cell[1110575, 31313, 7046, 196, 263, "Output",ExpressionUUID->"d86e187c-8857-4894-b008-1706f0986ce1"],
Cell[1117624, 31511, 2038, 60, 89, "Output",ExpressionUUID->"8589602c-5856-4709-81c2-7fcb9b6e2ae7"],
Cell[1119665, 31573, 21533, 595, 699, "Output",ExpressionUUID->"6c366293-842e-4815-ad5a-a067c760b3f9"]
}, Closed]],
Cell[1141213, 32171, 389, 11, 35, "Input",ExpressionUUID->"7eec41ed-f8be-4781-ad81-aacf1e19c61e"],
Cell[1141605, 32184, 732, 20, 43, "Input",ExpressionUUID->"efcccf1d-eca2-43bc-917e-f94759390949"],
Cell[CellGroupData[{
Cell[1142362, 32208, 292, 7, 43, "Input",ExpressionUUID->"2f433b1a-1b17-4f0e-a3ce-29308bad9797"],
Cell[1142657, 32217, 436, 12, 49, "Output",ExpressionUUID->"d728c7c7-e96d-4588-ac51-d0be55527b6b"]
}, Open  ]],
Cell[1143108, 32232, 404, 10, 43, "Input",ExpressionUUID->"e214592c-7835-4dc6-be0c-bda174edfd7c"],
Cell[CellGroupData[{
Cell[1143537, 32246, 632, 18, 81, "Input",ExpressionUUID->"e4eeff02-fec4-45f8-ac01-95f203e763a0"],
Cell[1144172, 32266, 1113, 33, 73, "Output",ExpressionUUID->"485dd270-6775-45fc-9198-1f39ca71befe"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1145322, 32304, 925, 28, 83, "Input",ExpressionUUID->"9ba43a2c-c2b4-4984-8032-65c16a2e65c1"],
Cell[1146250, 32334, 1239, 37, 80, "Output",ExpressionUUID->"0259a1e3-44c9-4eff-8e1d-ee8dfae1088e"]
}, Open  ]],
Cell[1147504, 32374, 191, 4, 43, "Input",ExpressionUUID->"9fcb005e-19fa-4519-9ffd-a9e261ac04c9"]
}, Closed]],
Cell[CellGroupData[{
Cell[1147732, 32383, 1002, 21, 65, "Input",ExpressionUUID->"d321ee18-6627-4990-b2ed-415d58916bd6"],
Cell[1148737, 32406, 7216, 191, 537, "Input",ExpressionUUID->"0a8e8e8a-3609-45ee-8ce9-392e90706df9"],
Cell[CellGroupData[{
Cell[1155978, 32601, 1583, 48, 182, "Input",ExpressionUUID->"fb0665d5-e548-40a8-9f22-2224518e4482"],
Cell[1157564, 32651, 1410, 32, 77, "Output",ExpressionUUID->"1ff743d9-4ae5-4903-b0e3-206ac5047fff"]
}, Open  ]],
Cell[1158989, 32686, 3014, 85, 266, "Input",ExpressionUUID->"59a15c7c-b673-47f0-bca7-e20735f997f8"],
Cell[1162006, 32773, 8453, 249, 739, "Input",ExpressionUUID->"d8f5588e-79a6-4c4a-a671-a42b0f8dee32"],
Cell[CellGroupData[{
Cell[1170484, 33026, 929, 26, 131, "Input",ExpressionUUID->"cc577558-17fd-4425-b12e-fe4994fbac7e"],
Cell[1171416, 33054, 549, 8, 48, "Output",ExpressionUUID->"f9d54ede-0fa3-40e8-8368-1cf50a03e141"],
Cell[1171968, 33064, 549, 8, 48, "Output",ExpressionUUID->"eba28cc7-9f57-4526-91e1-f80febcd6bfd"],
Cell[1172520, 33074, 549, 8, 48, "Output",ExpressionUUID->"ca48ee8b-857c-4643-8865-68184e05449f"],
Cell[1173072, 33084, 551, 8, 48, "Output",ExpressionUUID->"21830853-86f9-4bc8-bd5d-f5f8016dddb7"]
}, Open  ]],
Cell[1173638, 33095, 1849, 46, 218, "Input",ExpressionUUID->"fa482608-ba27-4222-9667-1f980e0bad31"],
Cell[CellGroupData[{
Cell[1175512, 33145, 1929, 45, 218, "Input",ExpressionUUID->"9aba5923-e5a3-4039-aad5-ee88c3f83d89"],
Cell[1177444, 33192, 5200, 129, 185, "Output",ExpressionUUID->"d19ccb55-26d1-4bf3-9d73-f4b92184cbf1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1182681, 33326, 846, 22, 112, "Input",ExpressionUUID->"5adbfb43-e90c-4d79-953c-29dd788097d0"],
Cell[1183530, 33350, 778, 24, 89, "Output",ExpressionUUID->"fb97d20e-1ac2-4a10-a478-5e15bd29c87c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1184345, 33379, 749, 20, 112, "Input",ExpressionUUID->"1a4c5904-b40d-4212-b233-4c93fe6be1db"],
Cell[1185097, 33401, 773, 26, 79, "Output",ExpressionUUID->"63b1ceb5-b4a7-4dea-a96c-20de677b66ea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1185907, 33432, 957, 26, 149, "Input",ExpressionUUID->"bde86704-ed30-47cf-8215-4bf576204b8d"],
Cell[1186867, 33460, 1027, 31, 82, "Output",ExpressionUUID->"edb6f536-b16a-4f40-8d3c-ccc6a2aabfd9"]
}, Open  ]],
Cell[1187909, 33494, 402, 9, 102, "Input",ExpressionUUID->"4d31055b-78b4-4f4d-8f3d-cd7706b559f0"],
Cell[1188314, 33505, 1027, 34, 126, "Input",ExpressionUUID->"588d976a-f329-4051-89b1-8f0209893500"],
Cell[1189344, 33541, 3550, 97, 395, "Input",ExpressionUUID->"fecf1826-7bbb-4fde-a549-394f7f44670f"],
Cell[1192897, 33640, 1078, 29, 131, "Input",ExpressionUUID->"34a1aab4-4b10-4126-b9d3-d90ac3d19d04"],
Cell[1193978, 33671, 4089, 111, 456, "Input",ExpressionUUID->"ce31f429-87f9-4fde-be38-bf20a4f68602"],
Cell[CellGroupData[{
Cell[1198092, 33786, 231, 4, 102, "Input",ExpressionUUID->"b79edb46-4a2e-43d2-9974-3922c307faf3"],
Cell[1198326, 33792, 7691, 198, 423, "Output",ExpressionUUID->"f19f9b9f-512f-4870-82e6-30d99c218a3c"],
Cell[1206020, 33992, 5476, 142, 325, "Output",ExpressionUUID->"e09dbf10-dd85-40f3-806b-332bcde5a902"],
Cell[1211499, 34136, 3894, 106, 291, "Output",ExpressionUUID->"4a7c6962-8faf-494f-9aec-d54232a018a2"]
}, Open  ]],
Cell[1215408, 34245, 283, 6, 43, "Input",ExpressionUUID->"3597df15-eff2-4ed4-aa43-908191e11351"],
Cell[CellGroupData[{
Cell[1215716, 34255, 599, 16, 73, "Input",ExpressionUUID->"a52a72e8-2345-4318-a838-50c617e16530"],
Cell[1216318, 34273, 1115, 29, 84, "Output",ExpressionUUID->"65179dca-abf8-48dd-be85-b9482c89b4b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1217470, 34307, 811, 17, 43, "Input",ExpressionUUID->"71fa9df2-df24-457f-8f6e-efa40bc2756c"],
Cell[1218284, 34326, 912, 24, 79, "Output",ExpressionUUID->"1d1584d0-67c5-4999-a7b2-3a131219a69a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1219233, 34355, 603, 14, 43, "Input",ExpressionUUID->"824c1965-b819-4529-9e50-524bb6a2027b"],
Cell[1219839, 34371, 1042, 30, 84, "Output",ExpressionUUID->"ae9dbcc5-f203-4855-bd49-677cbe93a20b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1220918, 34406, 608, 14, 43, "Input",ExpressionUUID->"a8ed7200-ff66-4301-96fd-d1b5092e622d"],
Cell[1221529, 34422, 1379, 37, 87, "Output",ExpressionUUID->"68481cc0-1225-4ea2-8d43-28961e092bea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1222945, 34464, 817, 23, 73, "Input",ExpressionUUID->"fe77d9ab-e42a-4b0f-b8d3-8ad954a5c16d"],
Cell[1223765, 34489, 970, 25, 80, "Output",ExpressionUUID->"79783f72-2567-46ef-8373-e064c7df2fee"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1224772, 34519, 823, 22, 73, "Input",ExpressionUUID->"4ef50966-613d-48a2-ad6b-8f4576a33b8b"],
Cell[1225598, 34543, 1479, 42, 134, "Output",ExpressionUUID->"e50f0abb-8a75-49fb-a3ad-620f388ca136"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1227114, 34590, 1104, 29, 102, "Input",ExpressionUUID->"b2ce507d-0029-4272-9a49-abb7e7e3fa25"],
Cell[1228221, 34621, 1014, 24, 84, "Output",ExpressionUUID->"821de013-5677-457a-801c-590e2bd90a6f"],
Cell[1229238, 34647, 592, 12, 48, "Output",ExpressionUUID->"d9ed9a9c-b426-489d-a3f4-129c90f33cb8"]
}, Open  ]],
Cell[1229845, 34662, 571, 11, 73, "Input",ExpressionUUID->"1abd80d6-4bca-4d11-9aa3-6e8d8279b5d9"],
Cell[CellGroupData[{
Cell[1230441, 34677, 313, 7, 43, "Input",ExpressionUUID->"1c542e02-0b9d-4a4b-ae08-4aebc7493bc1"],
Cell[1230757, 34686, 38204, 1022, 1400, "Input",ExpressionUUID->"211ff481-f835-4412-a9a6-b517851c99d4"],
Cell[1268964, 35710, 191, 4, 43, "Input",ExpressionUUID->"97540c34-6949-46fb-bceb-6b18bbdcff20"]
}, Closed]],
Cell[CellGroupData[{
Cell[1269192, 35719, 419, 12, 69, "Input",ExpressionUUID->"63af097e-ac04-4c1e-a636-eb7446313c61"],
Cell[1269614, 35733, 574, 16, 95, "Output",ExpressionUUID->"7cc5ac73-c1b7-4351-9043-42eee343fb55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1270225, 35754, 643, 15, 77, "Input",ExpressionUUID->"8ca5a54a-9b0a-41c4-a0f0-9aa6160e1071"],
Cell[1270871, 35771, 955, 21, 95, "Output",ExpressionUUID->"9a5b63bd-069c-423a-9637-1c89f579482e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1271863, 35797, 2322, 61, 247, "Input",ExpressionUUID->"7cd30665-483b-4bc7-b055-f8f5cca0197f"],
Cell[1274188, 35860, 1677, 44, 181, "Output",ExpressionUUID->"223dc905-1cd6-465e-a7e5-989d6041c246"],
Cell[1275868, 35906, 1592, 43, 181, "Output",ExpressionUUID->"50f327d1-28c1-4c93-b8e3-f2a92afe7b0a"],
Cell[1277463, 35951, 1457, 38, 134, "Output",ExpressionUUID->"5f31641f-aea6-4876-a169-339e30a6162d"]
}, Open  ]],
Cell[1278935, 35992, 498, 8, 102, "Input",ExpressionUUID->"106c6e54-700b-46f4-9ccf-34e19dfcedce"],
Cell[1279436, 36002, 277, 6, 43, "Input",ExpressionUUID->"86776efa-5583-4171-8704-5d2568aa556f"],
Cell[CellGroupData[{
Cell[1279738, 36012, 1147, 33, 230, "Input",ExpressionUUID->"c8987e81-cb9d-4cf6-ba16-d1a3a75b72dd"],
Cell[1280888, 36047, 1118, 28, 121, "Output",ExpressionUUID->"30c79800-d9c9-4532-b6cf-e7bf6927ad2f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1282043, 36080, 1026, 26, 160, "Input",ExpressionUUID->"de8bcfc2-893c-45aa-a6d4-0d19c1f473d0"],
Cell[1283072, 36108, 747, 19, 70, "Output",ExpressionUUID->"eeaded28-97f6-494e-ab2c-96de1a8aa318"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1283856, 36132, 502, 14, 73, "Input",ExpressionUUID->"969f5107-0f82-47a2-b969-751c92a0c880"],
Cell[1284361, 36148, 969, 26, 118, "Output",ExpressionUUID->"99a7d096-d4ee-40c8-b9c9-464696ca9421"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1285367, 36179, 1354, 37, 133, "Input",ExpressionUUID->"f21192aa-20e3-47bd-961d-79b2bdc7ed52"],
Cell[1286724, 36218, 2303, 62, 190, "Output",ExpressionUUID->"e1ff2c4b-e32f-4844-8c2a-ae226b2e4110"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1289064, 36285, 1299, 36, 162, "Input",ExpressionUUID->"be8f026a-90ee-4c54-9f71-5000c1b45522"],
Cell[1290366, 36323, 2344, 62, 190, "Output",ExpressionUUID->"8f202013-99a6-4b50-bda8-fe7f00bf60d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1292747, 36390, 7469, 193, 530, "Input",ExpressionUUID->"dff278fa-d72c-4a00-af7f-63aa4a278cf4"],
Cell[1300219, 36585, 2005, 50, 123, "Output",ExpressionUUID->"41e5579d-7086-412a-84e8-04d5d0ea1d56"],
Cell[1302227, 36637, 829, 13, 48, "Output",ExpressionUUID->"bea580ef-42de-42dd-8b92-ee5735f843db"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1303093, 36655, 14022, 316, 754, "Input",ExpressionUUID->"32e7236f-1d94-4fce-98c8-44331bf2727e"],
Cell[1317118, 36973, 1027, 20, 75, "Output",ExpressionUUID->"a3aae09a-baa8-43b2-b8e2-5112b67f74b2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1318182, 36998, 1522, 43, 197, "Input",ExpressionUUID->"f1f9f936-62c1-4117-93ad-55903c7628de"],
Cell[1319707, 37043, 802, 18, 79, "Output",ExpressionUUID->"6838de36-edc8-4b29-b5cc-eee96c3ff9a6"],
Cell[1320512, 37063, 811, 18, 78, "Output",ExpressionUUID->"d4a62007-2393-4192-b5d2-ea734403d4a4"],
Cell[1321326, 37083, 808, 18, 78, "Output",ExpressionUUID->"d7029043-d9e9-4710-99b2-d10390a32905"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1322171, 37106, 1571, 45, 131, "Input",ExpressionUUID->"6be7b7a4-f9db-4297-980a-fe706a9170ca"],
Cell[1323745, 37153, 505, 14, 74, "Output",ExpressionUUID->"96cd8cee-b69e-4294-bde1-0461c3c1c7f2"],
Cell[1324253, 37169, 616, 18, 71, "Output",ExpressionUUID->"febf90a1-dd6f-4efd-99d7-541627d944ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1324906, 37192, 1393, 39, 160, "Input",ExpressionUUID->"2a50a35d-708a-4b8a-a51e-b0be5699a0d4"],
Cell[1326302, 37233, 601, 15, 48, "Output",ExpressionUUID->"315ecd1f-a1d9-474c-ab8b-487a481f6d34"],
Cell[1326906, 37250, 640, 16, 48, "Output",ExpressionUUID->"285ffa8a-59c9-4011-b413-0077d3ddc4dc"]
}, Open  ]],
Cell[1327561, 37269, 118, 1, 43, "Input",ExpressionUUID->"2985d3ab-6579-4fff-ade3-ece69136b7df"]
}, Closed]],
Cell[CellGroupData[{
Cell[1327716, 37275, 1062, 23, 94, "Input",ExpressionUUID->"a80d0dd5-6809-4a15-8fc3-6c079ce758c5"],
Cell[1328781, 37300, 7216, 191, 537, "Input",ExpressionUUID->"5fcf443e-f7ce-45e3-a92f-cd9248f3d26a"],
Cell[CellGroupData[{
Cell[1336022, 37495, 1583, 48, 182, "Input",ExpressionUUID->"35370ff0-d491-4e66-9ff0-b5d683522163"],
Cell[1337608, 37545, 1460, 33, 77, "Output",ExpressionUUID->"c009682f-3a7d-4b31-b007-baadc8501f8b"]
}, Open  ]],
Cell[1339083, 37581, 3014, 85, 266, "Input",ExpressionUUID->"cd36303b-9ab1-404a-9517-0d5792a72f92"],
Cell[1342100, 37668, 8453, 249, 739, "Input",ExpressionUUID->"6dcc9c25-12a2-4a34-b868-8f83db149292"],
Cell[CellGroupData[{
Cell[1350578, 37921, 929, 26, 131, "Input",ExpressionUUID->"ff499ebf-ed9c-47ec-b502-8254558e7e04"],
Cell[1351510, 37949, 623, 9, 48, "Output",ExpressionUUID->"48a0fcc7-e168-4573-a51f-bc9e60dcb928"],
Cell[1352136, 37960, 623, 9, 48, "Output",ExpressionUUID->"e97f18c2-6950-423f-8c23-cdfb029ac3ce"],
Cell[1352762, 37971, 623, 9, 48, "Output",ExpressionUUID->"d12166ca-248e-4288-9e8a-4ed2496bb5cb"],
Cell[1353388, 37982, 623, 9, 48, "Output",ExpressionUUID->"75415a6e-d0fa-41ec-b2e0-0d6eab722562"]
}, Open  ]],
Cell[1354026, 37994, 1849, 46, 218, "Input",ExpressionUUID->"7c24fb2b-3f5e-4355-8afe-5af0fa6b4619"],
Cell[CellGroupData[{
Cell[1355900, 38044, 1929, 45, 218, "Input",ExpressionUUID->"ce3d0924-4d1f-483f-b5a1-182dae9bac25"],
Cell[1357832, 38091, 5227, 129, 185, "Output",ExpressionUUID->"f6d66079-01ba-43a2-86dc-1e5c426a0a34"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1363096, 38225, 846, 22, 112, "Input",ExpressionUUID->"87255e27-8585-46ec-96ea-0ccdaf7f196e"],
Cell[1363945, 38249, 852, 25, 89, "Output",ExpressionUUID->"5d7d2498-079d-4f75-9e46-31175a9a9875"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1364834, 38279, 749, 20, 112, "Input",ExpressionUUID->"c7057730-a00f-4768-9d5c-9f798a2f05ee"],
Cell[1365586, 38301, 848, 27, 79, "Output",ExpressionUUID->"d986218f-2a85-4942-b8fd-fe470b29e9fc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1366471, 38333, 957, 26, 149, "Input",ExpressionUUID->"ff353a56-bea6-4cac-98d5-a7d36795375c"],
Cell[1367431, 38361, 1096, 32, 82, "Output",ExpressionUUID->"fade02e1-e32f-449c-b9ab-28080a207e13"]
}, Open  ]],
Cell[1368542, 38396, 402, 9, 102, "Input",ExpressionUUID->"4192a6d8-dc89-40e1-be86-dfeb80aff403"],
Cell[1368947, 38407, 1027, 34, 126, "Input",ExpressionUUID->"a1054115-ee2c-4602-9853-dd74e324feff"],
Cell[1369977, 38443, 3550, 97, 395, "Input",ExpressionUUID->"54c1e476-552c-4b0d-b32b-40923fe9f84e"],
Cell[1373530, 38542, 1175, 31, 131, "Input",ExpressionUUID->"adade131-4d7f-4f79-8b47-caaa70441fcb"],
Cell[1374708, 38575, 4014, 109, 454, "Input",ExpressionUUID->"17fee81d-5e7f-4f6e-8a68-7f36950253bb"],
Cell[CellGroupData[{
Cell[1378747, 38688, 231, 4, 102, "Input",ExpressionUUID->"527da952-e60c-4e5d-a639-e33488d102e3"],
Cell[1378981, 38694, 3044, 81, 223, "Output",ExpressionUUID->"0b7c3677-9f53-49a1-8a93-87b5cbbf0532"],
Cell[1382028, 38777, 3001, 81, 223, "Output",ExpressionUUID->"d0aba220-ba73-4afb-8dfa-6b674a6b131c"],
Cell[1385032, 38860, 1997, 54, 188, "Output",ExpressionUUID->"48446737-cbb0-481d-98eb-ec1dbf679f42"]
}, Open  ]],
Cell[1387044, 38917, 283, 6, 43, "Input",ExpressionUUID->"0d2a6eac-64ff-4648-a2b8-4f2e1cd723aa"],
Cell[CellGroupData[{
Cell[1387352, 38927, 599, 16, 73, "Input",ExpressionUUID->"e6fc97c9-ddb4-448a-b0a2-ee7bb1047adb"],
Cell[1387954, 38945, 1213, 30, 84, "Output",ExpressionUUID->"122429d9-a8c3-4131-86ed-fac46c51d4cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1389204, 38980, 811, 17, 43, "Input",ExpressionUUID->"8b75dc96-fdd3-44cb-9210-3086c53536a3"],
Cell[1390018, 38999, 984, 25, 79, "Output",ExpressionUUID->"3aef0aa5-79a7-4e83-845d-91ce196f702e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1391039, 39029, 603, 14, 43, "Input",ExpressionUUID->"47a87269-0f17-49d5-8d4e-e6b54ff9319f"],
Cell[1391645, 39045, 1118, 31, 84, "Output",ExpressionUUID->"24408644-450b-46a5-be52-cdf48aec7b95"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1392800, 39081, 608, 14, 43, "Input",ExpressionUUID->"3e73b880-2ad7-48ce-ae18-5aad5861c78e"],
Cell[1393411, 39097, 1451, 38, 87, "Output",ExpressionUUID->"d5294322-f32a-4d16-ae66-ad18f617b88e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1394899, 39140, 817, 23, 73, "Input",ExpressionUUID->"7562f6d4-9b2e-44de-9254-c1983aae02c0"],
Cell[1395719, 39165, 1055, 27, 80, "Output",ExpressionUUID->"ea088ca4-2447-45e1-a7f9-c15a1bb97547"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1396811, 39197, 823, 22, 73, "Input",ExpressionUUID->"9caa4441-a8e5-4b82-bcd6-2ccefa5da8e0"],
Cell[1397637, 39221, 1728, 47, 121, "Output",ExpressionUUID->"b781742b-f1b7-4b39-b03e-8bd9189c9c5b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1399402, 39273, 1104, 29, 102, "Input",ExpressionUUID->"62402534-2d06-42b7-a65e-42bae8dffed0"],
Cell[1400509, 39304, 1368, 34, 87, "Output",ExpressionUUID->"b423ca47-9345-42a7-b879-83a700490080"],
Cell[1401880, 39340, 1355, 34, 87, "Output",ExpressionUUID->"9512d4ba-fd71-4beb-a1a9-b1107d2c0cbf"]
}, Open  ]],
Cell[1403250, 39377, 571, 11, 102, "Input",ExpressionUUID->"03d98672-c666-4425-bbe8-5b394771c571"],
Cell[CellGroupData[{
Cell[1403846, 39392, 313, 7, 43, "Input",ExpressionUUID->"2bba5c1e-59aa-4369-b837-f7e46132ee60"],
Cell[1404162, 39401, 38204, 1022, 1400, "Input",ExpressionUUID->"4d89da9a-2461-4599-9089-da5c95279364"],
Cell[1442369, 40425, 191, 4, 43, "Input",ExpressionUUID->"0d3935a7-4c95-46c7-b7e2-938e774517ca"]
}, Closed]],
Cell[CellGroupData[{
Cell[1442597, 40434, 419, 12, 69, "Input",ExpressionUUID->"1881ee72-8fca-44f9-9ba4-876119725e6c"],
Cell[1443019, 40448, 643, 17, 95, "Output",ExpressionUUID->"0f6c8c7a-a913-4b99-846b-4c274ba18256"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1443699, 40470, 643, 15, 77, "Input",ExpressionUUID->"836e41ea-29df-417f-83ed-1ea9a3b1a86c"],
Cell[1444345, 40487, 1027, 22, 95, "Output",ExpressionUUID->"0974b278-7904-4b27-95e2-df20b1eb9333"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1445409, 40514, 2370, 61, 247, "Input",ExpressionUUID->"fdfb3727-1f9e-42ff-943c-010b6fa8a38c"],
Cell[1447782, 40577, 1797, 45, 134, "Output",ExpressionUUID->"a7a11fed-c81e-430e-a24c-9f0354b2c3a0"],
Cell[1449582, 40624, 1712, 44, 134, "Output",ExpressionUUID->"43c4348c-15d0-4766-a496-7b93398f16bd"],
Cell[1451297, 40670, 1575, 39, 87, "Output",ExpressionUUID->"236b97ae-f1b2-42e7-a12a-0ad487df8600"]
}, Open  ]],
Cell[1452887, 40712, 496, 8, 450, "Input",ExpressionUUID->"4f997098-7bc8-4e81-ab10-f4d92a63c515"],
Cell[1453386, 40722, 498, 8, 102, "Input",ExpressionUUID->"8aa1c025-d825-450e-9e33-6e94e03866d6"],
Cell[1453887, 40732, 277, 6, 43, "Input",ExpressionUUID->"715a5fe4-ca63-4f1c-9b76-5826a1c7cbb4"],
Cell[CellGroupData[{
Cell[1454189, 40742, 1147, 33, 127, "Input",ExpressionUUID->"d3cf2da3-38f9-460b-8400-c2a2e9ecac19"],
Cell[1455339, 40777, 1142, 28, 123, "Output",ExpressionUUID->"07512fde-7457-40d7-9d62-dd30fc0fbc79"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1456518, 40810, 1026, 26, 102, "Input",ExpressionUUID->"1940d0ac-c3b3-43e2-afcf-3f618302d17b"],
Cell[1457547, 40838, 775, 20, 70, "Output",ExpressionUUID->"ed2e452b-e4cc-4575-940b-297609c26770"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1458359, 40863, 502, 14, 73, "Input",ExpressionUUID->"ad893a2e-dade-44d8-ab38-1e3d19913e34"],
Cell[1458864, 40879, 991, 26, 74, "Output",ExpressionUUID->"4f775161-aa2e-46d3-80cc-9da373498870"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1459892, 40910, 1354, 37, 133, "Input",ExpressionUUID->"f9407807-2ed4-4ad6-93b3-ec6f36d44e66"],
Cell[1461249, 40949, 2325, 62, 201, "Output",ExpressionUUID->"565a4f37-26ec-4014-a70b-bda52b0222e9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1463611, 41016, 1299, 36, 104, "Input",ExpressionUUID->"34dfd719-f8d5-4c88-a77b-a0d5a8463686"],
Cell[1464913, 41054, 2368, 62, 156, "Output",ExpressionUUID->"dbd528bf-f22a-4de9-a42e-e5e064fbb5e3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1467318, 41121, 7469, 193, 326, "Input",ExpressionUUID->"5a869a4c-5acb-4efa-b2ba-e4fd22e1e7ee"],
Cell[1474790, 41316, 2029, 50, 79, "Output",ExpressionUUID->"7e956214-ba78-404a-b061-789caeb4ec4d"],
Cell[1476822, 41368, 855, 13, 48, "Output",ExpressionUUID->"aaf0ccf5-1c4a-41e1-8f25-0b874c5e77a9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1477714, 41386, 14022, 316, 845, "Input",ExpressionUUID->"b6e20ce3-1167-4442-8d91-fa94be544aac"],
Cell[1491739, 41704, 827, 12, 48, "Output",ExpressionUUID->"9787ef98-1322-4ace-b5bd-224d3e1f6065"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1492603, 41721, 1522, 43, 197, "Input",ExpressionUUID->"18fe73ec-25e7-4bf6-b45a-c4f76186742d"],
Cell[1494128, 41766, 549, 8, 48, "Output",ExpressionUUID->"5d5bdf1f-c1fd-4dc0-a30b-060fe50ef7e6"],
Cell[1494680, 41776, 551, 8, 48, "Output",ExpressionUUID->"d68711c6-2582-406e-aedb-460ad219b164"],
Cell[1495234, 41786, 551, 8, 48, "Output",ExpressionUUID->"2f973cae-367f-42e2-9680-c464ff2bc2bb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1495822, 41799, 1571, 45, 131, "Input",ExpressionUUID->"d3fe69ce-3028-49b4-b32a-1a62ff0a5f62"],
Cell[1497396, 41846, 527, 14, 74, "Output",ExpressionUUID->"4674c9a1-40c4-4df4-8dc0-953a006d54f0"],
Cell[1497926, 41862, 640, 18, 71, "Output",ExpressionUUID->"c30d2568-693d-4b3a-bdc9-b13ef6cf8125"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1498603, 41885, 1393, 39, 160, "Input",ExpressionUUID->"462fa6b9-2ccc-4fd6-ba43-2a6e4c61cb29"],
Cell[1499999, 41926, 627, 16, 48, "Output",ExpressionUUID->"64abe947-bdad-48a3-a839-11aa197a48d7"],
Cell[1500629, 41944, 666, 17, 48, "Output",ExpressionUUID->"78727c3f-1a19-4d46-82d5-b16349f257d4"]
}, Open  ]],
Cell[1501310, 41964, 118, 1, 43, "Input",ExpressionUUID->"2eddc90d-027e-428e-9eec-74b8d1204f8f"]
}, Closed]],
Cell[CellGroupData[{
Cell[1501465, 41970, 966, 21, 65, "Input",ExpressionUUID->"3b6742c7-8ed0-4b2f-85aa-abda3c8e9eb6"],
Cell[1502434, 41993, 7216, 191, 450, "Input",ExpressionUUID->"1df053ca-ef77-4cd1-9561-72b021abb044"],
Cell[CellGroupData[{
Cell[1509675, 42188, 1583, 48, 151, "Input",ExpressionUUID->"13c1978d-4cf4-41d6-b29c-e2d00e33748b"],
Cell[1511261, 42238, 1436, 32, 77, "Output",ExpressionUUID->"de66c80d-85a9-4c29-b0f4-1febec68ec64"]
}, Open  ]],
Cell[1512712, 42273, 3014, 85, 233, "Input",ExpressionUUID->"68f6549f-4509-4e36-b900-4f0cc0e98df4"],
Cell[1515729, 42360, 8453, 249, 666, "Input",ExpressionUUID->"4535e837-f4cc-48e6-81a8-a8fd75041a50"],
Cell[CellGroupData[{
Cell[1524207, 42613, 929, 26, 131, "Input",ExpressionUUID->"ba98ff57-4ec1-4074-9f55-e6753b0a2f49"],
Cell[1525139, 42641, 599, 9, 48, "Output",ExpressionUUID->"b7e4db5c-ec2e-4807-8a8d-ac0be6f8f4f9"],
Cell[1525741, 42652, 599, 9, 48, "Output",ExpressionUUID->"0ad7521c-454c-4e17-87cd-f0a26c296d74"],
Cell[1526343, 42663, 599, 9, 48, "Output",ExpressionUUID->"3e5fe15c-c963-432f-b76a-c589297743dd"],
Cell[1526945, 42674, 601, 9, 48, "Output",ExpressionUUID->"a7c86fa4-97a6-4e3a-97cb-d44e070f2ef1"]
}, Open  ]],
Cell[1527561, 42686, 1921, 47, 189, "Input",ExpressionUUID->"1ea54654-f6a8-4934-8f2c-61508972cf82"],
Cell[CellGroupData[{
Cell[1529507, 42737, 1957, 45, 218, "Input",ExpressionUUID->"ea9f8a0b-6818-49df-98a8-4bba87022ebd"],
Cell[1531467, 42784, 13116, 325, 182, "Output",ExpressionUUID->"8cc8bab0-80cf-4b2e-a689-f9e545969e68"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1544620, 43114, 846, 22, 145, "Input",ExpressionUUID->"f965612a-ab56-4346-96f7-d245e4474a4b"],
Cell[1545469, 43138, 2163, 70, 157, "Output",ExpressionUUID->"3b83d721-2a7f-4552-8210-2cbda89cefae"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1547669, 43213, 749, 20, 112, "Input",ExpressionUUID->"e70b37e6-820b-4271-8de0-95a67cfccc89"],
Cell[1548421, 43235, 1597, 51, 123, "Output",ExpressionUUID->"5203fe39-8170-4220-96e3-4cab9d842998"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1550055, 43291, 957, 26, 178, "Input",ExpressionUUID->"953e392b-8e8a-405f-b4b3-54b77372172c"],
Cell[1551015, 43319, 3312, 93, 259, "Output",ExpressionUUID->"1f1d7751-0cfe-4a55-900e-3ca471bbb00c"]
}, Open  ]],
Cell[1554342, 43415, 385, 8, 73, "Input",ExpressionUUID->"2527de26-1d6f-426f-bc22-ab5f543ee511"],
Cell[1554730, 43425, 1027, 34, 126, "Input",ExpressionUUID->"2514a609-4573-45c2-9147-a12fe146bf3f"],
Cell[1555760, 43461, 3550, 97, 462, "Input",ExpressionUUID->"1be3489b-5bf0-4792-bf07-94cc7980c5db"],
Cell[1559313, 43560, 1078, 29, 160, "Input",ExpressionUUID->"452f122d-fbfe-4943-8919-17744873e469"],
Cell[1560394, 43591, 4187, 112, 554, "Input",ExpressionUUID->"99e3b531-add1-437d-a90a-4555f7aafd49"],
Cell[1564584, 43705, 283, 6, 43, "Input",ExpressionUUID->"14ad0a32-e8bd-49da-82b5-28e85c643575"],
Cell[CellGroupData[{
Cell[1564892, 43715, 599, 16, 73, "Input",ExpressionUUID->"cf61a379-2655-4ec4-905b-caa8f910b475"],
Cell[1565494, 43733, 3990, 106, 253, "Output",ExpressionUUID->"61e3ee29-59e2-453f-8e15-a130d951082c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1569521, 43844, 811, 17, 43, "Input",ExpressionUUID->"5844e075-faf3-4a25-a278-e9812e5d9829"],
Cell[1570335, 43863, 2163, 64, 123, "Output",ExpressionUUID->"27413244-3642-44c5-a91a-449396d799c9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1572535, 43932, 603, 14, 43, "Input",ExpressionUUID->"ed6e86d5-3825-48c1-9a1b-875673faa803"],
Cell[1573141, 43948, 1903, 56, 123, "Output",ExpressionUUID->"e068f215-9fc2-440b-937b-02e33cc6d0fd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1575081, 44009, 608, 14, 43, "Input",ExpressionUUID->"0392ce72-2094-4459-9d69-0c9f1fc09ebd"],
Cell[1575692, 44025, 3696, 104, 225, "Output",ExpressionUUID->"3bfb029c-4bed-4d3a-87f4-2624349aad4c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1579425, 44134, 865, 23, 73, "Input",ExpressionUUID->"6d240573-f5a0-4cc3-864e-9d13fd12482c"],
Cell[1580293, 44159, 2789, 76, 189, "Output",ExpressionUUID->"6cd3c66b-04de-4f2e-ad9b-4e4161a6a8a6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1583119, 44240, 823, 22, 73, "Input",ExpressionUUID->"e11a459b-8e3d-4372-9bd4-82262c230d03"],
Cell[1583945, 44264, 3364, 92, 191, "Output",ExpressionUUID->"df2436ec-a885-4af6-90e5-a20c5707d776"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1587346, 44361, 1104, 29, 102, "Input",ExpressionUUID->"3715e23a-59c1-41d5-a4d4-af81ea9d1269"],
Cell[1588453, 44392, 3892, 102, 214, "Output",ExpressionUUID->"9ac215c1-7af3-40ca-969d-7220aca83078"],
Cell[1592348, 44496, 1462, 39, 84, "Output",ExpressionUUID->"2cc1097d-0c60-479a-9f35-acfdd0367f20"]
}, Open  ]],
Cell[1593825, 44538, 571, 11, 73, "Input",ExpressionUUID->"90aa5eee-1d8a-4f2a-9686-346e3ee97194"],
Cell[CellGroupData[{
Cell[1594421, 44553, 313, 7, 43, "Input",ExpressionUUID->"cd2f591a-edd4-4804-9396-80b9f5279a22"],
Cell[1594737, 44562, 38204, 1022, 986, "Input",ExpressionUUID->"9d09c3e2-5112-4b17-822c-e591f7727538"],
Cell[1632944, 45586, 191, 4, 43, "Input",ExpressionUUID->"9c30b70a-1285-4bbf-9ab8-1fa799e0413e"]
}, Closed]],
Cell[CellGroupData[{
Cell[1633172, 45595, 915, 26, 70, "Input",ExpressionUUID->"ff728b24-3b00-42cf-8761-655108d67a34"],
Cell[1634090, 45623, 1076, 29, 95, "Output",ExpressionUUID->"360cb171-2571-4f90-8b6f-0c83c348ab40"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1635203, 45657, 643, 15, 78, "Input",ExpressionUUID->"1ad193fd-bc60-4d5e-88f8-a97591b879d0"],
Cell[1635849, 45674, 1001, 21, 95, "Output",ExpressionUUID->"e1679e84-64db-478b-9c93-b2e0b6c12f2c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1636887, 45700, 2402, 63, 160, "Input",ExpressionUUID->"e27303e9-3738-4176-acc6-36f39bbe1544"],
Cell[1639292, 45765, 2641, 70, 87, "Output",ExpressionUUID->"859d81ee-903c-4cf7-a095-7950fe754a1f"],
Cell[1641936, 45837, 2528, 67, 87, "Output",ExpressionUUID->"bfa62020-a1d6-464f-9bec-89979d887823"],
Cell[1644467, 45906, 2411, 64, 87, "Output",ExpressionUUID->"6df6433a-f1ca-4408-9db7-7456bd58b002"]
}, Open  ]],
Cell[1646893, 45973, 498, 8, 73, "Input",ExpressionUUID->"5d4fe59d-d493-4ab1-99d1-a809c4c7f4dc"],
Cell[1647394, 45983, 277, 6, 43, "Input",ExpressionUUID->"3a354455-7ae9-4a27-b55c-9b5094582f95"],
Cell[CellGroupData[{
Cell[1647696, 45993, 1147, 33, 80, "Input",ExpressionUUID->"a1042f49-5b6c-45c8-9d2e-d96c39ac1206"],
Cell[1648846, 46028, 1166, 28, 77, "Output",ExpressionUUID->"efe709e2-c9f3-4106-876c-6e6b43db37ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1650049, 46061, 1026, 26, 43, "Input",ExpressionUUID->"30435000-20eb-4d18-b23c-6176a42a8153"],
Cell[1651078, 46089, 821, 20, 69, "Output",ExpressionUUID->"ce342065-001f-4877-83db-ed947c121ce5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1651936, 46114, 502, 14, 43, "Input",ExpressionUUID->"f7ac7a96-7196-4312-9578-ddbd1fd1966b"],
Cell[1652441, 46130, 1039, 27, 73, "Output",ExpressionUUID->"11380286-d8df-4ded-85f9-9d9e83ac7283"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1653517, 46162, 1354, 37, 103, "Input",ExpressionUUID->"53bca740-71c2-4b6a-9bed-ad9f4f012176"],
Cell[1654874, 46201, 2376, 63, 155, "Output",ExpressionUUID->"77ef84f7-89f7-414e-8a68-a0d3cf358f48"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1657287, 46269, 1299, 36, 103, "Input",ExpressionUUID->"afa19171-1b49-4051-9ac1-0cd7294bb20a"],
Cell[1658589, 46307, 2416, 63, 121, "Output",ExpressionUUID->"b0cb9dab-9738-4d1d-8b88-8ceedf8be126"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1661042, 46375, 7207, 184, 263, "Input",ExpressionUUID->"634ae0ca-89c3-43db-8f1e-a68085a8e624"],
Cell[1668252, 46561, 2098, 51, 79, "Output",ExpressionUUID->"2f41bbe1-1f3d-4ab7-aa09-6d99eeaaf9b5"],
Cell[1670353, 46614, 924, 14, 48, "Output",ExpressionUUID->"550bf943-78a6-4e73-b139-ce38dde5d6ba"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1671314, 46633, 18793, 411, 959, "Input",ExpressionUUID->"a64dedc4-b2f7-411e-908d-5f360f297845"],
Cell[1690110, 47046, 318, 8, 62, "Message",ExpressionUUID->"c77c6190-3112-4bb3-9e4e-5cafed64374e"],
Cell[1690431, 47056, 318, 8, 62, "Message",ExpressionUUID->"f2b45787-9f89-48fc-aa5d-501d5943ab69"],
Cell[1690752, 47066, 387, 9, 35, "Message",ExpressionUUID->"1f36eccd-c677-41ef-962d-d48b38249cb4"],
Cell[1691142, 47077, 1065, 15, 48, "Output",ExpressionUUID->"15cfd52f-8cb9-4b99-9b30-5ecd185920dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1692244, 47097, 1622, 44, 197, "Input",ExpressionUUID->"d03c6bb7-e7b1-4698-ac34-113a56710d4b"],
Cell[1693869, 47143, 637, 9, 48, "Output",ExpressionUUID->"ebc269c0-dc9c-47d2-8e05-0a34a6d79c14"],
Cell[1694509, 47154, 637, 9, 48, "Output",ExpressionUUID->"0eb6d65b-418a-44a4-884a-74bbf2e31961"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1695183, 47168, 1571, 45, 131, "Input",ExpressionUUID->"bc95e162-0905-41fe-80b9-53954fd19a0f"],
Cell[1696757, 47215, 529, 14, 74, "Output",ExpressionUUID->"48548839-d421-4818-a504-34ac87e3d723"],
Cell[1697289, 47231, 642, 18, 71, "Output",ExpressionUUID->"62686fc1-19a6-486c-ae48-eb48820622e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1697968, 47254, 1393, 39, 131, "Input",ExpressionUUID->"b1980540-806e-40ed-951e-9368fcf9f44e"],
Cell[1699364, 47295, 629, 16, 48, "Output",ExpressionUUID->"2796a41d-da21-429b-ab2a-9f650a98ccb0"],
Cell[1699996, 47313, 668, 17, 48, "Output",ExpressionUUID->"da2efa14-d1b2-4fb4-b44f-663bd7643f3e"]
}, Open  ]],
Cell[1700679, 47333, 118, 1, 43, "Input",ExpressionUUID->"025ae85d-1f78-449e-843b-bb713f05e0a1"]
}, Closed]],
Cell[CellGroupData[{
Cell[1700834, 47339, 1156, 24, 94, "Input",ExpressionUUID->"a3544c8f-5d05-4199-a2b2-2f64468af5f5"],
Cell[1701993, 47365, 7216, 191, 537, "Input",ExpressionUUID->"9c195fc2-879d-41b1-8142-fec56106d04f"],
Cell[CellGroupData[{
Cell[1709234, 47560, 1583, 48, 182, "Input",ExpressionUUID->"796863b7-8173-4ed7-9819-19d6b9c7a40a"],
Cell[1710820, 47610, 1462, 33, 77, "Output",ExpressionUUID->"2b9ebad2-9744-4e08-a97f-babfa29b0a1a"]
}, Open  ]],
Cell[1712297, 47646, 3014, 85, 266, "Input",ExpressionUUID->"7156a42e-736b-44f9-8551-16f61393e602"],
Cell[1715314, 47733, 8453, 249, 739, "Input",ExpressionUUID->"9b0136ab-e18e-4024-a18c-8fb57d69da62"],
Cell[CellGroupData[{
Cell[1723792, 47986, 929, 26, 131, "Input",ExpressionUUID->"e8183c40-4844-41fa-be4e-dd2b289c2390"],
Cell[1724724, 48014, 621, 9, 48, "Output",ExpressionUUID->"121e73dc-33ad-474c-9a62-a68ef110339a"],
Cell[1725348, 48025, 621, 9, 48, "Output",ExpressionUUID->"72e8d2be-805d-4506-a1ae-c60fd51c5be6"],
Cell[1725972, 48036, 620, 9, 48, "Output",ExpressionUUID->"9850fba4-3ace-4840-b418-8db554206d4d"],
Cell[1726595, 48047, 620, 9, 48, "Output",ExpressionUUID->"b881f904-6c68-47b7-874e-9dc4daf7121e"]
}, Open  ]],
Cell[1727230, 48059, 1921, 47, 189, "Input",ExpressionUUID->"66c93d6d-b5f1-4eb9-b1b0-1330f0b6f36b"],
Cell[CellGroupData[{
Cell[1729176, 48110, 1957, 45, 218, "Input",ExpressionUUID->"c55e8c8d-6f09-40b6-a46e-dc517bcfe094"],
Cell[1731136, 48157, 13142, 325, 201, "Output",ExpressionUUID->"9f60be9d-8d27-4b04-9c1b-cefdd4eeec96"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1744315, 48487, 846, 22, 112, "Input",ExpressionUUID->"f0bfdaa2-75f5-43ce-85b8-f605725949ca"],
Cell[1745164, 48511, 2279, 72, 157, "Output",ExpressionUUID->"86b2e462-861a-4c91-9720-8dfc34061c86"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1747480, 48588, 749, 20, 112, "Input",ExpressionUUID->"fb817054-3698-4086-8843-6661905e0465"],
Cell[1748232, 48610, 1691, 53, 123, "Output",ExpressionUUID->"c1a36df4-726c-446e-9ffe-eb55bba934e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1749960, 48668, 957, 26, 149, "Input",ExpressionUUID->"7561a743-0cf6-479a-8eeb-536010748098"],
Cell[1750920, 48696, 3334, 93, 225, "Output",ExpressionUUID->"2fc7b7a1-a104-477f-ae5a-c2dcca6a370f"]
}, Open  ]],
Cell[1754269, 48792, 385, 8, 73, "Input",ExpressionUUID->"f08af11e-0e4d-482d-8865-45a5731d5ba9"],
Cell[1754657, 48802, 1027, 34, 126, "Input",ExpressionUUID->"38a602f5-7ce5-4099-ac1e-21cb99e1c27c"],
Cell[1755687, 48838, 3550, 97, 395, "Input",ExpressionUUID->"e6950db8-d6b4-45c8-bc4f-b142907a2ea6"],
Cell[1759240, 48937, 3975, 109, 454, "Input",ExpressionUUID->"7c789d8a-f7d1-4ddb-9af0-125d5f4d938e"],
Cell[CellGroupData[{
Cell[1763240, 49050, 231, 4, 102, "Input",ExpressionUUID->"c8e2da02-dec7-4746-b2e4-9dc0b1ce6335"],
Cell[1763474, 49056, 4483, 123, 293, "Output",ExpressionUUID->"ced5e4c0-8502-4b64-856d-c8832f918f45"],
Cell[1767960, 49181, 6737, 175, 491, "Output",ExpressionUUID->"c76efe31-1fed-4df9-bf5e-5e171f8bc140"],
Cell[1774700, 49358, 5025, 129, 389, "Output",ExpressionUUID->"44c71284-0c3e-473c-aaf3-603719f9c178"]
}, Open  ]],
Cell[1779740, 49490, 283, 6, 43, "Input",ExpressionUUID->"78644633-6d5f-4c37-ad69-07d97b537043"],
Cell[CellGroupData[{
Cell[1780048, 49500, 599, 16, 73, "Input",ExpressionUUID->"bdbf1f23-c3f6-4b43-8dec-8d9a9ecd1857"],
Cell[1780650, 49518, 3990, 106, 253, "Output",ExpressionUUID->"352142e8-44f6-4335-aaa9-2ca174bc18ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1784677, 49629, 811, 17, 43, "Input",ExpressionUUID->"0de46f77-83b4-416e-bc02-c0f9b4a9ea82"],
Cell[1785491, 49648, 2137, 63, 123, "Output",ExpressionUUID->"2eb27883-4cdd-4926-8c39-fcbeae8c5390"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1787665, 49716, 603, 14, 43, "Input",ExpressionUUID->"d00f3770-1860-4f01-a04f-060487e11c19"],
Cell[1788271, 49732, 1879, 56, 123, "Output",ExpressionUUID->"ac0263b1-17e6-4d14-b785-52be25a1800d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1790187, 49793, 608, 14, 43, "Input",ExpressionUUID->"49825ab2-abd6-43c1-8ed9-257cc3b9c3b6"],
Cell[1790798, 49809, 3670, 103, 225, "Output",ExpressionUUID->"efecb2bb-75ff-4b23-8a1a-8314cfc79ce1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1794505, 49917, 865, 23, 73, "Input",ExpressionUUID->"a442f620-3ed4-4591-b0c1-d46f98e9e261"],
Cell[1795373, 49942, 2595, 69, 189, "Output",ExpressionUUID->"f293b16d-4f66-4ec1-9075-ac418e33ea55"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1798005, 50016, 823, 22, 73, "Input",ExpressionUUID->"f3e4d95c-6ca8-4ec5-b707-6551b4a26c0c"],
Cell[1798831, 50040, 2892, 78, 189, "Output",ExpressionUUID->"d7d0cddf-06c9-446d-a18d-6086e0b82353"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1801760, 50123, 1104, 29, 102, "Input",ExpressionUUID->"e4419570-41ae-41d2-9750-4b86389e1720"],
Cell[1802867, 50154, 1462, 39, 84, "Output",ExpressionUUID->"05bb5126-daf1-4932-bac9-9cfc36e6ff45"],
Cell[1804332, 50195, 1462, 39, 84, "Output",ExpressionUUID->"078d642c-08cb-48ea-92a9-0aa728b66c72"]
}, Open  ]],
Cell[1805809, 50237, 571, 11, 102, "Input",ExpressionUUID->"4febc991-b712-4a8e-aecb-b2ba9decba2c"],
Cell[CellGroupData[{
Cell[1806405, 50252, 313, 7, 43, "Input",ExpressionUUID->"3eac66de-3e2b-4b56-b1d4-9cdc134ae85a"],
Cell[1806721, 50261, 38204, 1022, 986, "Input",ExpressionUUID->"db44289d-58b6-4268-897e-586611d1ef40"],
Cell[1844928, 51285, 191, 4, 43, "Input",ExpressionUUID->"65ac2757-4f75-4fd8-a7eb-68abaab30723"]
}, Closed]],
Cell[CellGroupData[{
Cell[1845156, 51294, 915, 26, 133, "Input",ExpressionUUID->"b85cd775-229a-47f4-9940-4fa4e37d66fe"],
Cell[1846074, 51322, 1052, 29, 95, "Output",ExpressionUUID->"0c81dc14-84ef-467c-812a-51c4c0103725"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1847163, 51356, 643, 15, 77, "Input",ExpressionUUID->"c0920caf-7e81-484c-b3ad-f8642aaf0353"],
Cell[1847809, 51373, 979, 21, 95, "Output",ExpressionUUID->"d1cf4057-07fe-4159-856d-edda23065321"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1848825, 51399, 2322, 61, 247, "Input",ExpressionUUID->"dcc95999-6a7b-4dab-b7dd-da0a882dbec2"],
Cell[1851150, 51462, 2617, 70, 155, "Output",ExpressionUUID->"f64760d0-1b23-4059-bf91-4d5e70fc807d"],
Cell[1853770, 51534, 2504, 67, 155, "Output",ExpressionUUID->"2b12c7be-9568-4162-8437-b7ec122b2cd3"],
Cell[1856277, 51603, 2389, 64, 155, "Output",ExpressionUUID->"b70f87a6-7bce-456a-8a9b-7a7ee9f923fb"]
}, Open  ]],
Cell[1858681, 51670, 498, 8, 102, "Input",ExpressionUUID->"8943e741-a5fb-4da1-843f-8f7098d06821"],
Cell[1859182, 51680, 329, 6, 247, "Input",ExpressionUUID->"64138038-4292-4ace-ac0f-7da333db98e8"],
Cell[1859514, 51688, 277, 6, 43, "Input",ExpressionUUID->"3985db62-482e-4a0f-8190-f7001f690e05"],
Cell[CellGroupData[{
Cell[1859816, 51698, 1147, 33, 127, "Input",ExpressionUUID->"0ae3a27c-369d-4620-9612-2408ce7e10b5"],
Cell[1860966, 51733, 1166, 28, 123, "Output",ExpressionUUID->"bd5247f0-0a38-42b7-b5f4-83429bf81af7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1862169, 51766, 1026, 26, 102, "Input",ExpressionUUID->"9a3eb415-6af4-4643-ad63-6bf2a24ba95c"],
Cell[1863198, 51794, 821, 20, 70, "Output",ExpressionUUID->"09f35c96-dc47-47b0-8daa-a9ceea6b43c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1864056, 51819, 502, 14, 73, "Input",ExpressionUUID->"444f6932-c49c-437f-ada8-916ce9ffcb91"],
Cell[1864561, 51835, 1039, 27, 74, "Output",ExpressionUUID->"71272e49-92e4-47fd-9a21-cef3621a9c0e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1865637, 51867, 1354, 37, 133, "Input",ExpressionUUID->"a2b7782e-cdc8-45f0-a470-3b9845e04312"],
Cell[1866994, 51906, 2532, 65, 157, "Output",ExpressionUUID->"8ed259f7-9e52-401c-907e-c2609bedf5e6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1869563, 51976, 1299, 36, 133, "Input",ExpressionUUID->"4eade83d-d23e-433e-bfb9-325ca2283ead"],
Cell[1870865, 52014, 2519, 64, 189, "Output",ExpressionUUID->"d7273d6e-2ca8-4121-bb41-49abcf876b7a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1873421, 52083, 7207, 184, 470, "Input",ExpressionUUID->"529f2bcd-8a78-4692-bc18-0f509a7a0aac"],
Cell[1880631, 52269, 2098, 51, 79, "Output",ExpressionUUID->"07a551da-3099-4d94-aad2-6140a4ec824f"],
Cell[1882732, 52322, 924, 14, 48, "Output",ExpressionUUID->"5e945b86-3c5a-4719-860e-4054174a95d0"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1883693, 52341, 18793, 411, 1106, "Input",ExpressionUUID->"0a051423-f6ce-49ed-bd33-c926035fbf1b"],
Cell[1902489, 52754, 2147, 51, 87, "Output",ExpressionUUID->"288200c8-4441-4895-984d-f0d7a16784c1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1904673, 52810, 1622, 44, 197, "Input",ExpressionUUID->"8f29872c-b1af-4225-90dd-4a0a71d87241"],
Cell[1906298, 52856, 1563, 41, 87, "Output",ExpressionUUID->"8f1e7d5c-17bd-4ad4-9697-57308b520436"],
Cell[1907864, 52899, 1708, 44, 89, "Output",ExpressionUUID->"d8bd3d55-1f01-49bb-8e53-9d2cd3fc5bcf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1909609, 52948, 1571, 45, 131, "Input",ExpressionUUID->"213e5907-07f5-4ea6-ae27-8422cf5eaa89"],
Cell[1911183, 52995, 505, 14, 74, "Output",ExpressionUUID->"90b68619-1a03-4cfe-9769-efeeae29b183"],
Cell[1911691, 53011, 616, 18, 71, "Output",ExpressionUUID->"5e4412a8-6d5b-4579-a227-b30b96b8f722"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1912344, 53034, 1393, 39, 160, "Input",ExpressionUUID->"b00a40b4-57e8-437a-95bc-e89c3632e7a7"],
Cell[1913740, 53075, 601, 15, 48, "Output",ExpressionUUID->"379e1483-5fa1-4eb6-ad85-5a15ae1ce263"],
Cell[1914344, 53092, 640, 16, 48, "Output",ExpressionUUID->"92dd6490-afa3-4797-ba3c-d53c904ada38"]
}, Open  ]],
Cell[1914999, 53111, 118, 1, 43, "Input",ExpressionUUID->"b7e0a758-bffe-4ff5-837e-f8bd504a4f22"]
}, Closed]],
Cell[1915132, 53115, 738, 24, 35, "Input",ExpressionUUID->"9292f020-ab30-408a-b3bb-090259ef4e11"]
}, Open  ]],
Cell[1915885, 53142, 193, 4, 43, "Input",ExpressionUUID->"64af0b94-a472-445b-8855-c20200ec1c45"]
}, Open  ]],
Cell[1916093, 53149, 120, 3, 42, "Text",ExpressionUUID->"7930e970-38f8-4ecb-ae4d-5a27665d1aaa"]
}
]
*)

